<div class="row">
    <div class="col-12">
        <h1 class="mb-3">{{ __('Cadastro de Pacientes com Fibromialgia') }}</h1>

        <p class="mb-3">{{ __("A Prefeitura de Angra dos Reis, por meio da Secretaria de Saúde, está realizando o Cadastro de Pacientes com Fibromialgia. A iniciativa tem como objetivo identificar, registrar e acompanhar de forma contínua os pacientes diagnosticados com essa condição no município.") }}</p>
        <p class="mb-3">{{ __("Para solicitar o cartão, acesse o link disponível e preencha o formulário, anexando digitalmente os seguintes documentos:  laudo médico com a descrição da condição de fibromialgia (CID 10 M79.7); foto 3x4; comprovante de residência; documento de identidade (RG); CPF; Cartão SUS.") }}</p>
        <p class="mb-3">{{ __("O acompanhamento do processo é de responsabilidade do paciente, e a retirada do cartão deverá ser feita presencialmente na sede da Secretaria de Saúde.") }}</p>
        <p class="mb-3">{{ __("De acordo com a ") }}<strong>{{ __("Lei Municipal nº 3.909, de 29 de novembro de 2019") }}</strong>{{ __(", o cartão garante atendimento preferencial nas mesmas filas destinadas a idosos, gestantes e pessoas com deficiência, assegurando mais dignidade e respeito no acesso aos serviços de saúde.") }}</p>

        <p class="mb-3">{{ __("Antes de iniciar o preenchimento, certifique-se de ter em mãos toda a documentação digitalizada necessária para emissão do cartão de identificação.") }}</p>

        <ol class="list-group list-group-numbered mb-3">
            <li class="list-group-item">{{ __("Laudo Médico com a descrição da condição de fibromialgia (CID10 M79.7);") }}</li>
            <li class="list-group-item">{{ __("01 foto tamanho 3x4;") }}</li>
            <li class="list-group-item">{{ __("Comprovante de residência;") }}</li>
            <li class="list-group-item">{{ __("RG;") }}</li>
            <li class="list-group-item">{{ __("CPF e;") }}</li>
            <li class="list-group-item">{{ __("Cartão SUS.") }}</li>
        </ol>

        <p class="alert alert-info mb-3">{{ __("Lembramos que é de responsabilidade do usuário acompanhar pelo sistema o andamento
        do processo e a retirada do cartão deverá ser feita na Secretaria de Saúde.") }}</p>

        <hr>

    </div>
</div>