<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.landing_pages.boletim-meteorologico.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body class="fade-in">
    <header>
        <?php echo $__env->make('layouts.landing_pages.boletim-meteorologico.elements.defaultBar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </header>
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>
    <footer class="footer-spdc">
        <?php echo $__env->make('layouts.landing_pages.boletim-meteorologico.elements.defaultFooter', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </footer>
</body>

</html><?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/boletim-meteorologico/theme.blade.php ENDPATH**/ ?>