<?php $__env->startSection('title', env('APP_NAME').' :: '.__('Nova Conta')); ?>
<?php $__env->startSection('content'); ?>
    <section class="d-flex align-items-center min-vh-100">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-12">
                    <div class="card-admin-login p-5">
                        <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        <div class="text-center">
                            <img src="<?php echo e(asset("pmar/assets/img/logo-angra-branco.svg")); ?>" class="card-img-top" title="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" alt="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                        </div>
                        <style>
                            .form-label{ color: #FFF !important}
                        </style>
                        <div class="card-body">
                            <h5 class="text-white card-title text-center"><?php echo e(__('Dados adicionais e nova senha')); ?></h5>
                            <br>
                            <?php if (isset($component)) { $__componentOriginalc0b0983469c2e101f870c247180c1ffb = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalc0b0983469c2e101f870c247180c1ffb = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.auth.new-account','data' => ['token' => $token]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('auth.new-account'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['token' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($token)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalc0b0983469c2e101f870c247180c1ffb)): ?>
<?php $attributes = $__attributesOriginalc0b0983469c2e101f870c247180c1ffb; ?>
<?php unset($__attributesOriginalc0b0983469c2e101f870c247180c1ffb); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalc0b0983469c2e101f870c247180c1ffb)): ?>
<?php $component = $__componentOriginalc0b0983469c2e101f870c247180c1ffb; ?>
<?php unset($__componentOriginalc0b0983469c2e101f870c247180c1ffb); ?>
<?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div id="recaptchaNovaConta" data-size="invisible"></div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.login.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/novaConta.blade.php ENDPATH**/ ?>