@php
    $registro = $registro ?? null;
    $val = static fn ($field, $default = '') => old($field, $registro->{$field} ?? $default);
    $checked = static fn ($field) => (int) old($field, $registro->{$field} ?? 0) === 1;
@endphp

<div class="row g-3">
    <div class="col-md-12">
        <label class="form-label">{{ __('Nome do Indicador') }} <span class="text-danger">*</span></label>
        <input type="text" name="nome" class="form-control @error('nome') is-invalid @enderror"
               value="{{ $val('nome') }}" maxlength="500" required>
        @error('nome')<div class="invalid-feedback">{{ $message }}</div>@enderror
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Tema') }}</label>
        <select name="tema_id" class="form-select @error('tema_id') is-invalid @enderror">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($temas as $tema)
                <option value="{{ $tema->id }}" @selected((string) $val('tema_id') === (string) $tema->id)>{{ $tema->nome }}</option>
            @endforeach
        </select>
        @error('tema_id')<div class="invalid-feedback">{{ $message }}</div>@enderror
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Diretriz') }}</label>
        <select name="diretriz_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($diretrizes as $item)
                <option value="{{ $item->id }}" @selected((string) $val('diretriz_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Eixo') }}</label>
        <select name="eixo_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($eixos as $item)
                <option value="{{ $item->id }}" @selected((string) $val('eixo_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Órgão') }}</label>
        <select name="orgao_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($orgaos as $item)
                <option value="{{ $item->id }}" @selected((string) $val('orgao_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Programa') }}</label>
        <select name="programa_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($programas as $item)
                <option value="{{ $item->id }}" @selected((string) $val('programa_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Fonte') }}</label>
        <select name="fonte_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($fontes as $item)
                <option value="{{ $item->id }}" @selected((string) $val('fonte_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Base') }}</label>
        <select name="base_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($bases as $item)
                <option value="{{ $item->id }}" @selected((string) $val('base_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-6">
        <label class="form-label">{{ __('Periodicidade') }}</label>
        <select name="periodicidade_id" class="form-select">
            <option value="">{{ __('Selecione...') }}</option>
            @foreach($periodicidades as $item)
                <option value="{{ $item->id }}" @selected((string) $val('periodicidade_id') === (string) $item->id)>{{ $item->descricao }}</option>
            @endforeach
        </select>
    </div>

    <div class="col-md-4">
        <label class="form-label">{{ __('Próxima Apuração') }}</label>
        <input type="text" name="proxima_apuracao" class="form-control" value="{{ $val('proxima_apuracao') }}" maxlength="50">
    </div>

    <div class="col-md-4">
        <label class="form-label">{{ __('Status') }}</label>
        <select name="status" class="form-select">
            <option value="ATIVADO" @selected($val('status', 'ATIVADO') === 'ATIVADO')>{{ __('Ativado') }}</option>
            <option value="DESATIVADO" @selected($val('status') === 'DESATIVADO')>{{ __('Desativado') }}</option>
        </select>
    </div>

    <div class="col-md-12">
        <label class="form-label">{{ __('Memória de Cálculo') }}</label>
        <textarea name="memoria_calculo" class="form-control" rows="2">{{ $val('memoria_calculo') }}</textarea>
    </div>

    <div class="col-md-12">
        <label class="form-label">{{ __('Link da Planilha') }}</label>
        <input type="url" name="planilha_link" class="form-control @error('planilha_link') is-invalid @enderror"
               value="{{ $val('planilha_link') }}" maxlength="1000" placeholder="{{ __('https://docs.google.com/spreadsheets/d/...') }}">
        @error('planilha_link')<div class="invalid-feedback">{{ $message }}</div>@enderror
        <small class="text-muted">{{ __('Link público da planilha com os dados do indicador.') }}</small>
    </div>

    <div class="col-md-12">
        <label class="form-label">{{ __('Gráficos (código embed / iframe)') }}</label>
        <small class="d-block text-muted">{{ __('Cole o código embed completo de cada gráfico que será exibido na página do indicador.') }}</small>
    </div>

    @for ($numero = 1; $numero <= 5; $numero++)
        @php $campoGrafico = "grafico_link_{$numero}"; @endphp
        <div class="col-md-12">
            <label class="form-label">
                {{ __('Gráfico (código embed / iframe)') }} {{ $numero }}
                <i class="fa-solid fa-circle-info text-muted" title="{{ __('Cole aqui o código do gráfico (ex.: <iframe ...></iframe>). Será exibido na página do indicador.') }}"></i>
            </label>
            <textarea name="{{ $campoGrafico }}" class="form-control @error($campoGrafico) is-invalid @enderror" rows="4" placeholder="{{ __('Cole aqui o código embed / iframe do gráfico') }}">{{ $val($campoGrafico) }}</textarea>
            @error($campoGrafico)<div class="invalid-feedback">{{ $message }}</div>@enderror
        </div>
    @endfor

    <div class="col-md-12">
        <div class="d-flex flex-wrap gap-4 mt-2">
            <div class="form-check form-switch">
                <input type="hidden" name="observatorio" value="0">
                <input class="form-check-input" type="checkbox" name="observatorio" value="1" id="obs" @checked($checked('observatorio'))>
                <label class="form-check-label" for="obs">{{ __('Exibir no Observatório') }}</label>
            </div>
            <div class="form-check form-switch">
                <input type="hidden" name="ppa" value="0">
                <input class="form-check-input" type="checkbox" name="ppa" value="1" id="ppa" @checked($checked('ppa'))>
                <label class="form-check-label" for="ppa">{{ __('PPA') }}</label>
            </div>
            <div class="form-check form-switch">
                <input type="hidden" name="destaque" value="0">
                <input class="form-check-input" type="checkbox" name="destaque" value="1" id="destaque" @checked($checked('destaque'))>
                <label class="form-check-label" for="destaque">{{ __('Destaque na Home') }}</label>
            </div>
        </div>
    </div>
</div>

<div class="mt-4">
    <button type="submit" class="btn btn-success">
        <i class="fa-solid fa-floppy-disk"></i> {{ __('Salvar') }}
    </button>
</div>
