@foreach($array_tabs as $tab)
<button class="btn btn-outline-secondary" onclick="anteriorAba('cadastro')"
    type="button">
    <i class="fa-solid fa-arrow-left-long"></i> Anterior
</button>
<button class="btn btn-primary" onclick="proximaAba('email')" type="button">
    Próximo <i class="fa-solid fa-arrow-right-long"></i>
</button>
@endforeach

{{-- Ainda não está em uso --}}