<!DOCTYPE html>
<html lang="pt-BR">

<head>
    <meta charset="UTF-8">
    <title>Planilha de Acompanhamento dos Projetos</title>
    <style>
        @page {
            margin: 20px;
        }

        body {
            font-family: 'Helvetica', 'Arial', sans-serif;
            font-size: 7.5pt;
            color: #000;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            text-align: center;
        }

        th,
        td {
            border: 1px solid #000;
            padding: 4px;
            vertical-align: middle;
        }

        th {
            background-color: #f2f2f2;
            font-weight: bold;
            text-transform: uppercase;
            font-size: 6.5pt;
        }

        .td-projeto {
            font-weight: bold;
            text-align: center;
        }

        .bg-cgp {
            background-color: #ff4d00;
        }

        .bg-estudo {
            background-color: #ff9900;
        }

        .bg-consulta {
            background-color: #ffe600;
        }

        .bg-edital {
            background-color: #ccff00;
        }

        .bg-tce {
            background-color: #80ff00;
        }

        .bg-sessao {
            background-color: #33ff00;
        }

        .bg-contrato {
            background-color: #00ff00;
        }

        .bg-default {
            background-color: #ffffff;
        }

        .legend-table {
            width: auto;
            border-collapse: collapse;
            margin-top: 20px;
            font-size: 7pt;
        }

        .legend-table th,
        .legend-table td {
            border: 1px solid #000;
            padding: 3px 6px;
        }

        .legend-title {
            background-color: #f2f2f2;
            font-weight: bold;
            text-align: center;
        }

        .header {
            border-bottom: 2px solid #003366;
            padding-bottom: 10px;
            margin-bottom: 20px;
            text-align: center;
        }

        .header img {
            max-height: 60px;
            margin-bottom: 5px;
        }

        .header h1 {
            font-size: 14pt;
            margin: 0;
            color: #003366;
            text-transform: uppercase;
        }

        .header h2 {
            font-size: 10pt;
            margin: 3px 0 0;
            color: #666;
            font-weight: normal;
        }
    </style>
</head>

<body>

    <div class="header">
        <img src="{{ public_path('pmar/assets/fiveicon/brasao-angra-dos-reis.png') }}" alt="Brasão de Angra">
        <h1>Secretaria de Planejamento e Gestão</h1>
        <h2>Prefeitura Municipal de Angra dos Reis</h2>
    </div>

    <table>
        <thead>
            <tr>
                <th style="width: 8%;">PROJETO</th>
                <th style="width: 6%;">CRITÉRIO DE JULGAMENTO</th>
                <th style="width: 6%;">EMPRESA</th>
                <th style="width: 5%;">DATA DE ASSINATURA DE CONTRATO / PRAZO DE CONCESSÃO</th>
                <th style="width: 6%;">SECRETARIA RESPONSÁVEL</th>
                <th style="width: 6%;">ANDAMENTO</th>
                <th style="width: 8%;">PRÓXIMA ETAPA</th>
                <th style="width: 4%;">PRAZO DE IMPLANTAÇÃO</th>
                <th style="width: 4%;">OUTORGA FIXA</th>
                <th style="width: 4%;">OUTORGA VARIÁVEL</th>
                <th style="width: 5%;">INVESTIMENTO TOTAL</th>
                <th style="width: 5%;">APORTE MUNICÍPIO</th>
                <th style="width: 5%;">CONTRAPRESTAÇÃO MENSAL</th>
                <th style="width: 4%;">OBRIGAÇÃO</th>
                <th style="width: 4%;">PAYBACK</th>
                <th style="width: 4%;">OPEX</th>
                <th style="width: 4%;">CAPEX</th>
                <th style="width: 3%;">TIR</th>
                <th style="width: 5%;">VALOR ESTIMADO DO CONTRATO</th>
                <th style="width: 8%;">OBSERVAÇÕES</th>
            </tr>
        </thead>
        <tbody>
            @foreach($ppps as $ppp)
                @php
                    $andamentoRaw = strtolower($ppp->andamento ?? '');
                    $bgColor = 'bg-default';

                    if (str_contains($andamentoRaw, 'contrato')) {
                        $bgColor = 'bg-contrato';
                    } elseif (str_contains($andamentoRaw, 'sessão pública') || str_contains($andamentoRaw, 'sessao publica')) {
                        $bgColor = 'bg-sessao';
                    } elseif (str_contains($andamentoRaw, 'tce')) {
                        $bgColor = 'bg-tce';
                    } elseif (str_contains($andamentoRaw, 'edital')) {
                        $bgColor = 'bg-edital';
                    } elseif (str_contains($andamentoRaw, 'consulta pública') || str_contains($andamentoRaw, 'consulta publica')) {
                        $bgColor = 'bg-consulta';
                    } elseif (str_contains($andamentoRaw, 'estud')) {
                        $bgColor = 'bg-estudo';
                    } elseif (str_contains($andamentoRaw, 'cgp') || str_contains($andamentoRaw, 'autorização') || str_contains($andamentoRaw, 'autorizacao')) {
                        $bgColor = 'bg-cgp';
                    }
                @endphp
                <tr>
                    <td class="td-projeto">{{ $ppp->projeto ?? '-' }}</td>
                    <td>{{ $ppp->criterio_julgamento ?? '-' }}</td>
                    <td>{{ $ppp->empresa ?? '-' }}</td>
                    <td>{{ $ppp->prazo_concessao ?? '-' }}</td>
                    <td>{{ $ppp->secretaria_responsavel ?? '-' }}</td>
                    <td class="{{ $bgColor }}" style="font-weight: bold;">{{ $ppp->andamento ?? '-' }}</td>
                    <td>{{ $ppp->proxima_etapa ?? '-' }}</td>
                    <td>{{ $ppp->prazo_implantacao ?? '-' }}</td>
                    <td>{{ $ppp->outorga_fixa ?? '-' }}</td>
                    <td>{{ $ppp->outorga_variavel ?? '-' }}</td>
                    <td>{{ $ppp->investimento_total ?? '-' }}</td>
                    <td>{{ $ppp->aporte_municipio ?? '-' }}</td>
                    <td>{{ $ppp->contraprestacao_mensal ?? '-' }}</td>
                    <td>{{ $ppp->obrigacao ?? '-' }}</td>
                    <td>{{ $ppp->payback ?? '-' }}</td>
                    <td>{{ $ppp->opex ?? '-' }}</td>
                    <td>{{ $ppp->capex ?? '-' }}</td>
                    <td>{{ $ppp->tir ?? '-' }}</td>
                    <td>{{ $ppp->valor_estimado_contrato ?? '-' }}</td>
                    <td>{{ $ppp->observacoes ?? '-' }}</td>
                </tr>
            @endforeach
        </tbody>
    </table>

    <table class="legend-table" style="width: 350px;">
        <tr>
            <th colspan="2" class="legend-title">LEGENDA DO ANDAMENTO</th>
        </tr>
        <tr>
            <td class="bg-cgp" style="width: 30px;"></td>
            <td style="text-align: left;">AUTORIZAÇÃO DO CGP (15%)</td>
        </tr>
        <tr>
            <td class="bg-estudo"></td>
            <td style="text-align: left;">ESTUDO (30%)</td>
        </tr>
        <tr>
            <td class="bg-consulta"></td>
            <td style="text-align: left;">CONSULTA PÚBLICA (45%)</td>
        </tr>
        <tr>
            <td class="bg-edital"></td>
            <td style="text-align: left;">EDITAL (60%)</td>
        </tr>
        <tr>
            <td class="bg-tce"></td>
            <td style="text-align: left;">ENVIO AO TCE (75%)</td>
        </tr>
        <tr>
            <td class="bg-sessao"></td>
            <td style="text-align: left;">SESSÃO PÚBLICA (90%)</td>
        </tr>
        <tr>
            <td class="bg-contrato"></td>
            <td style="text-align: left;">CONTRATO (100%)</td>
        </tr>
    </table>

</body>

</html>