<?php if($permission == null): ?>
    <li <?php if(Route::currentRouteName() == $route): ?> class="active" <?php endif; ?>>
        <a href="<?php echo e(route($route)); ?>">
            <?php echo $fontawesome; ?>

            <span class="links_name"><?php echo e($nameButton); ?></span>
        </a>
        <span class="tooltip"><?php echo e($nameButton); ?></span>
    </li>
    <?php if($divider != null): ?>
        <hr>
    <?php endif; ?>
<?php else: ?>
    <?php if(in_array($permission, auth()->user()->listaPermissoes())): ?>
        <li <?php if(Route::currentRouteName() == $route): ?> class="active" <?php endif; ?>>
            <a href="<?php echo e(route($route)); ?>">
                <?php echo $fontawesome; ?>

                <span class="links_name"><?php echo e($nameButton); ?></span>
            </a>
            <span class="tooltip"><?php echo e($nameButton); ?></span>
        </li>
    <?php endif; ?>
    <?php if($divider != null): ?>
        <hr>
    <?php endif; ?>
<?php endif; ?><?php /**PATH /var/www/html/portal/resources/views/components/lists/_liLinkMenu.blade.php ENDPATH**/ ?>