<div class="defaultBar">
    <div class="container">
        <div class="defaultBar-row">
            <div class="defaultBar-icons">
                <a class="px-2" href="https://portal.angra.rj.gov.br/transparencia.asp?indexsigla=transp" style="font-weight: 600">{{ __("Portal da Transparência") }}</a>
                <a class="zoom" title="Aumentar fonte" href="#" data-value="0.25">
                    <i class="fa-solid fa-magnifying-glass-plus"></i>
                </a>
                <a class="zoom" title="Reduzir fonte" href="#" data-value="-0.25">
                    <i class="fa-solid fa-magnifying-glass-minus"></i>
                </a>
                <a class="zoom" title="Fonte em tamanho padrão" href="#" data-value="1">
                    <i class="fa-solid fa-font"></i>
                </a>
            </div>
        </div>
    </div>
</div>

