<section class="secretario-footer bg-waves">
    <div class="container">
        <div class="row secretario-footer-row">
            <!-- Foto e nome do Secretário -->
            <div class="secretario-footer-foto col-sm-12 col-md-12 col-lg-12 col-xl-3 col-xxl-3">
                <img src="{{ asset($secretaria->managerPhoto) }}" alt="{{ $secretaria->manager }}" title="{{ $secretaria->manager }}"                    >
                <p>
                    @if ($secretaria->type == 'SECRETARIA')
                        @if ($secretaria->pronunciation == 'SECRETARIO')
                            {{ __('Secretário') }}
                        @elseif($secretaria->pronunciation == 'PROCURADO_GERAL_DO_MUNICIPIO')
                            {{ __('Procurador-Geral') }}
                        @elseif($secretaria->pronunciation == 'CONTROLADOR_GERAL_DO_MUNICIPIO')
                            {{ __('Controlador-Geral') }}
                        @elseif($secretaria->pronunciation == 'DIRETOR')
                            {{ __('Diretor') }}
                        @elseif($secretaria->pronunciation == 'DIRETORA')
                            {{ __('Diretora') }}
                        @elseif($secretaria->pronunciation == 'SUPERINTENDENTE')
                            {{ __('Superintendente') }}
                        @else
                            {{ __('Secretária') }}
                        @endif
                    @elseif($secretaria->type == 'FUNDACAO' || $secretaria->type == 'AUTARQUIA')
                        {{ __('Presidente') }}
                    @elseif($secretaria->type == 'SECRETARIA_EXECUTIVA')
                        @if ($secretaria->pronunciation == 'SECRETARIO_EXECUTIVO')
                            {{ __('Secretário Executivo') }}
                        @else
                            {{ __('Secretária Executiva') }}
                        @endif
                    @endif
                </p>
                <a href="{{ route("paginas.formacao-academica", $secretaria->slug) }}">
                    <h5>{{ $secretaria->manager }}</h5>
                </a>
            </div>

            <!-- Localização -->
            @include('paginas.parts.google-maps')
        </div>
    </div>
</section>