@php
    $shortcuts = $shortcuts ?? [];
@endphp

<div class="dashboard-card">
    <div class="dashboard-card-header">
        <h3 class="dashboard-card-title">
            <i class="fa-solid fa-external-link-alt me-2"></i>
            {{ __("Atalhos para o Portal") }}
        </h3>
    </div>
    <div class="dashboard-card-body">
        <div class="shortcuts-grid">
            @foreach($shortcuts as $shortcut)
                @include('components.dashboard._shortcutItem', $shortcut)
            @endforeach
        </div>
    </div>
</div>