<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.cmgd.elements.head')

<body id="page-top">
    <header >
        @include('layouts.cmgd.elements.defaultBar')
        @include('layouts.cmgd.elements.nav')
    </header>
    <section class= "p-0 m-0">
        @include('layouts.cmgd.elements.modal')
    </section>
    <main>
        @yield('content')
    </main>
    <section class="py-0">
        @include('layouts.cmgd.elements.footer')
    </section>
</body>

</html>