@php($dados = $dados ?? [])

<h1>{{ __('CADASTRO REALIZADO') }}</h1>
<p>{{ __('Seu cadastro está em fase de análise pela equipe da Secretaria de Desenvolvimento Social e Promoção da Cidadania.') }}</p>
<p>{{ __('Em caso de dúvidas, envie e-mail para seas.familiaacolhedora@angra.rj.gov.br .') }}</p>

<h3>{{ __('DADOS DO CANDIDATO') }}</h3>
<p><strong>{{ __('Nome do candidato') }}:</strong> {{ $dados['nome'] ?? '' }}</p>
<p><strong>{{ __('Data de Nascimento') }}:</strong> {{ isset($dados['data_nascimento']) ? \Carbon\Carbon::parse($dados['data_nascimento'])->format('d/m/Y') : '' }}</p>
<p><strong>{{ __('Endereço') }}:</strong> {{ $dados['endereco'] ?? '' }}</p>
<p><strong>{{ __('Referência') }}:</strong> {{ $dados['referencia'] ?? '' }}</p>
<p><strong>{{ __('Bairro') }}:</strong> {{ $dados['bairro'] ?? '' }}</p>
<p><strong>{{ __('Cidade') }}:</strong> {{ $dados['municipio'] ?? '' }}</p>
<p><strong>{{ __('Telefone 1') }}:</strong> {{ $dados['telefone_1'] ?? '' }}</p>
<p><strong>{{ __('Telefone 2') }}:</strong> {{ $dados['telefone_2'] ?? '' }}</p>
<p><strong>{{ __('E-mail') }}:</strong> {{ $dados['email'] ?? '' }}</p>
<p><strong>{{ __('Disponibilidade de horário') }}:</strong> {{ $dados['disponibilidade'] ?? '' }}</p>
<p><strong>{{ __('Como soube do serviço') }}:</strong> 
    {{ $dados['como_soube'] ?? '' }}
    @if(!empty($dados['indicacao']))
        : {{ $dados['indicacao'] }}
    @endif
    @if(!empty($dados['outros']))
        : {{ $dados['outros'] }}
    @endif
</p>
<p><strong>{{ __('Motivação') }}:</strong> {{ $dados['motivo'] ?? '' }}</p>
