
<h4><?php echo e($estrategia ['titulo']); ?></h4>
<p><?php echo e($estrategia ['conteudo']); ?></p>
<hr>
<?php /**PATH /var/www/html/portal/resources/views/components/lists/_divEstrategiaCmgd.blade.php ENDPATH**/ ?>