<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.login.elements.head')
<body class="login-body d-flex align-items-center justify-content-center">
    <video autoplay loop playsinline id="video-background" poster="{{ asset('pmar/assets/img/ilhacombarco.jpg') }}" muted>
        <source src="https://visite.angra.rj.gov.br/assets/imgs/angra_linda.mp4" type="video/mp4">
    </video>
    <main>
        @yield('content')
    </main>
    @include('layouts.login.elements.footer')
</body>
</html>
