@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Novas imagens para: " . $ponto->ponto)
@section('content')

    <div class="container mt-4">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                    @php $headLine = "<i class='fa-solid fa-map-location-dot fa-2x'></i> Visite Angra - Pontos Turísticos - Novas imagens para {$ponto->ponto}"; @endphp

                    @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        'routeBack' => 'admin.visiteAngra.pontos.arquivos.index',
                        'routeBackParams' => [$ponto->id], 
                        'nameBack' => __("Voltar"),
                    ])

                    <div class="card-body">

                        <form action="{{ route('admin.visiteAngra.pontos.arquivos.store', $ponto->id) }}" method="post" enctype="multipart/form-data">

                            @csrf
                            @include("errors.messageFlash")

                            <div class="mb-3">
                            <!-- Campo Foto -->
                                @include('components.inputs._inputType',[
                                            "for" => "link",
                                            "label" => "Escolhas as imagens",
                                            "name" => "link[]",
                                            "id" => 'link',
                                            "required" => true,
                                            "type" => 'file',
                                            "old" => null,
                                            "oninput" => null,
                                            "readonly" => true,
                                            "multiple" => true,
                                            "small" => "* Apenas documentos de imagem: JPG, JPEG, PNG, GIF, BMP, WEBP.",
                                            "accept" => 'image/*',
                                        ])
                            </div>
                            <div class="mb-3">

                                @include('components.buttons._backAndSend',[
                                    'routeBack' => 'admin.visiteAngra.pontos.arquivos.index',
                                    'backId' => $ponto->id,
                                    'textBack' => "Voltar",
                                    'textSend' => "Cadastrar",
                                ])

                            </div>

                        </form>

                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection