<!DOCTYPE html>
<html lang="pt-BR">
<head>
<meta charset="UTF-8">
<title>Senha Temporária - Conta Angra</title>
</head>
<body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">

<table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
    <tr>
        <td align="center">

            <!-- Container -->
            <table width="600" cellpadding="0" cellspacing="0" style="background:#ffffff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">

                <!-- Header com logo -->
                <tr>
                    <td align="center" style="background-color:#007bc3; padding:30px;">
                        <img src="https://angra.rj.gov.br/pmar/assets/img/logo-angra-tematico-white.png"
                             alt="Logo Prefeitura de Angra dos Reis"
                             width="260"
                             style="max-width:260px; height:auto; display:block;">
                    </td>
                </tr>

                <!-- Corpo -->
                <tr>
                    <td style="padding:30px; color:#333333; font-size:15px; line-height:1.6;">

                        <p style="margin:0 0 15px;">
                            Olá, <strong>{{ $user->name ?? $user->email }}</strong>.
                        </p>

                        <p style="margin:0 0 15px;">
                            Geramos uma <strong>senha temporária</strong> para sua Conta Angra.
                        </p>

                        <p style="margin:0 0 25px;">
                            Utilize esta senha para acessar sua conta:
                        </p>

                        <!-- Senha temporária -->
                        <p style="
                            background:#f7f7f7;
                            border:1px solid #dddddd;
                            padding:12px 18px;
                            font-size:16px;
                            text-align:center;
                            font-weight:bold;
                            border-radius:6px;
                            letter-spacing:1px;
                            margin:0 0 25px;
                        ">
                            {{ $senha }}
                        </p>

                        <p style="margin:0 0 25px;">
                            Ao entrar, o sistema solicitará que você crie uma nova senha imediatamente.
                        </p>

                        <!-- Botão CTA -->
                        <p style="text-align:center; margin:30px 0;">
                            <a href="{{ route('admin.login') }}"
                               style="
                                    background-color:#007bff;
                                    color:#ffffff;
                                    padding:14px 28px;
                                    text-decoration:none;
                                    font-weight:bold;
                                    border-radius:6px;
                                    display:inline-block;
                               ">
                                Fazer login agora
                            </a>
                        </p>

                        <p style="margin:30px 0 0; color:#666666; font-size:13px;">
                            Se você não solicitou esta senha, recomendamos alterar sua senha assim que possível.
                        </p>

                    </td>
                </tr>

                <!-- Rodapé -->
                <tr>
                    <td style="background:#f7f7f7; text-align:center; padding:18px; font-size:12px; color:#aaaaaa;">
                        Prefeitura Municipal de Angra dos Reis<br>
                        Este é um e-mail automático, por favor não responda.
                    </td>
                </tr>

            </table>
            <!-- Fim Container -->

        </td>
    </tr>
</table>

</body>
</html>
