<section>
    <div class="container-full shadow-sm">
        <div class="d-flex justify-content-center p-1 border-gray border-bottom border-3">
            <a href="https://angra.rj.gov.br" target="_blank">
                <img src="<?php echo e(asset('pmar/assets/img/logo-pmar.png')); ?>" alt="Prefeitura de Angra dos Reis - Site Oficial" style="width: 4.5rem;">
            </a>
            <!-- <a class="px-2" href="<?php echo e(route('transparencia.index')); ?>" style="font-weight: 600"><?php echo e(__("Portal da Transparência ")); ?></a>
                <a class="zoom" title="Aumentar fonte" href="#" data-value="0.25">
                    <i class="fa-solid fa-magnifying-glass-plus"></i>
                </a>
                <a class="zoom" title="Reduzir fonte" href="#" data-value="-0.25">
                    <i class="fa-solid fa-magnifying-glass-minus"></i>
                </a>
                <a class="zoom" title="Fonte em tamanho padrão" href="#" data-value="1">
                    <i class="fa-solid fa-font"></i>
                </a> -->
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/boletim-meteorologico/elements/defaultBar.blade.php ENDPATH**/ ?>