<!DOCTYPE html>
<html>

<head>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
        }

        h1 {
            text-align: center;
            background-color: #d3d3d3;
            font-size: 2em;
            color: #333;
            width: 100%;
        }

        .section {
            margin: 20px auto;
            padding-left: 10px;
            padding-right: 10px;
            border-radius: 8px;
            width: 100%;
        }

        .label {
            font-weight: bold;
            color: #333;
        }

        .info-container {
            float: left;
            width: 50%;
            padding-right: 20px;
        }

        .photo-container {
            float: left;
            width: 45%;
            text-align: center;
        }

        .photo-container img {
            max-width: 100%;
            max-height: 250px;
            border-radius: 8px;
            box-shadow: 0 0 8px rgba(0, 0, 0, 0.2);
        }

        .descricao-container {
            width: 100%;
            clear: both;
        }

        .descricao-fake-textarea {
            width: 95%;
            min-height: 150px;
            max-height: 210px;
            margin-top: 10px;
            padding: 10px 12px;
            border-radius: 6px;
            border: 1px solid #ccc;
            background-color: #f8f9fa;
            overflow-y: auto;
            white-space: pre-wrap;
            word-wrap: break-word;
            overflow-wrap: break-word;
            font-size: 0.9rem;
        }

        .descricao-fake-textarea * {
            margin: 0 !important;
            padding: 0;
            line-height: 1.25;
        }

        .row {
            width: 100%;
            margin-bottom: 10px;
            font-size: 14px;
            white-space: nowrap;
        }

        .pair {
            display: inline-block;
            width: 32%;
            vertical-align: top;
            text-align: left;
        }

        .row .pair:nth-child(2) {
            text-align: center;
        }

        .row .pair:nth-child(3) {
            text-align: right;
        }

        .info-table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 15px;
            margin-left: 45px;
        }

        .info-table td {
            vertical-align: top;
            width: 20%;
        }

        .bordered-group {
            width: 95%;
            border: 1px solid #999;
            border-radius: 8px;
            margin-top: 20px;
            background-color: #f9f9f9;
        }

        .group-title {
            margin-top: 0;
            margin-bottom: 15px;
            font-size: 18px;
            color: #444;
            text-align: center;
        }

        .historico-container {
            border: 1px solid #bbb;
            border-radius: 10px;
            padding: 18px;
            margin-bottom: 30px;
            page-break-inside: avoid;
            background-color: #fefefe;
        }

        .historico-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 15px;
            color: #333;
        }

        .bloco-info {
            margin-bottom: 10px;
            font-size: 14px;
            color: #333;
        }

        .bloco-info p {
            margin: 3px 0;
        }

        .bloco-conteudo {
            border: 1px solid #ccc;
            border-radius: 8px;
            padding: 10px;
            background-color: #f9f9f9;
            font-size: 14px;
            color: #333;
        }

        .linha-dupla {
            display: flex;
            justify-content: space-between;
            font-size: 14px;
            margin-top: 8px;
            margin-bottom: 5px;
        }
    </style>
</head>

<body>
    <h1>Inventário do Museu Arte Sacra</h1>

    <div class="section">
        <div class="info-container">
            <span class="label">Código Acervo:</span> {{ $arte->codigo_acervo }}<br>
            <span class="label">Atualização:</span>
            {{ $arte->historicos->sortByDesc('created_at')->pluck('novo_acervo')->filter()->implode(', ') }}<br>
            <span class="label">Tipo:</span> {{ optional($arte->tipo)->tipo ?? 'Não informado' }}<br>
            <span class="label">Nome da Peça:</span> {{ $arte->nome_peca }}<br>
            <span class="label">Proprietário:</span>
            {{ optional($arte->proprietario)->proprietario ?? 'Não informado' }}<br>
            <span class="label">Localização:</span>
            {{ optional($arte->localizacao)->proprietario ?? 'Não informado' }}<br>
            <span class="label">Ano:</span> {{ $arte->ano_arte ?? 'Não informado' }}<br>
            <span class="label">Período:</span> {{ $arte->periodo_peca ?? 'Não informado' }}<br>
            <span class="label">Roca:</span> {{ $arte->roca ? 'Sim' : 'Não' }}<br>
            <span class="label">Modo de Aquisição:</span>
            {{ optional($arte->modoAquisicao)->modo_aquisicao ?? 'Não informado' }}<br>
        </div>

        <div class="photo-container">
            @if ($arte->imagem && $arte->imagem !== 'default.jpg')
                <img src="{{ public_path('pmar/assets/img/arte_sacra/' . $arte->imagem) }}" class="img-fluid"
                    alt="{{ $arte->nome_peca }}">
            @else
                <img src="{{ public_path('pmar/assets/img/arte_sacra/default.jpg') }}" class="img-fluid"
                    alt="Sem imagem">
            @endif
        </div>
        <div class="clearfix"></div>
    </div>

    <div class="section descricao-container">
        <span class="label">Descrição:</span>
        <div class="descricao-fake-textarea">
            {!! $arte->descricao ?? 'Não informado' !!}
        </div>
    </div>

    <h2 class="group-title">Informações Detalhadas</h2>
    <div class="section bordered-group">
        <div class="row">
            <div class="pair">
                <div class="label">Autoria:</div>
                <div class="value">{{ $arte->autoria ?? 'Não informado' }}</div>
            </div>
            <div class="pair">
                <div class="label">Material:</div>
                <div class="value">{{ optional($arte->material)->material ?? 'Não informado' }}</div>
            </div>
            <div class="pair">
                <div class="label">Técnica:</div>
                <div class="value">{{ optional($arte->tecnica)->tecnica ?? 'Não informado' }}</div>
            </div>
        </div>

        <div class="row">
            <div class="pair">
                <div class="label">Uso:</div>
                <div class="value">{{ optional($arte->designacao)->designacao ?? 'Não informado' }}</div>
            </div>
            <div class="pair">
                <div class="label">Classe:</div>
                <div class="value">{{ optional($arte->classe)->classe ?? 'Não informado' }}</div>
            </div>
            <div class="pair">
                <div class="label">Tombamento:</div>
                <div class="value">{{ optional($arte->tombamento)->tombamento ?? 'Não informado' }}</div>
            </div>
        </div>
    </div>

    <h2 class="group-title">Dimensões e Características</h2>
    <div class="section bordered-group">
        <table class="info-table">
            <tr>
                <td>
                    <div class="label">Altura:</div>
                    <div class="value">{{ $arte->altura ?? '0' }} Ø</div>
                </td>
                <td>
                    <div class="label">Largura:</div>
                    <div class="value">{{ $arte->largura ?? '0' }} Ø</div>
                </td>
                <td>
                    <div class="label">Profundidade:</div>
                    <div class="value">{{ $arte->profundidade ?? '0' }} Ø</div>
                </td>
                <td>
                    <div class="label">Diâmetro:</div>
                    <div class="value">{{ $arte->diametro ?? '0' }} Ø</div>
                </td>
                <td>
                    <div class="label">Peso:</div>
                    <div class="value">{{ $arte->peso ?? '0' }}</div>
                </td>
            </tr>
        </table>
    </div>

    @if ($arte->permitir_exibicao === 'Permitida')
        <div style="text-align: right; margin-top: 50px;">
            <div style="display: inline-block; text-align: center; padding: 10px;">
                <table style="border-collapse: collapse;">
                    <tr>
                        <td style="padding-right: 10px; vertical-align: middle;">
                            <span style="font-size: 12px; font-weight: bold;">Visualizar Imagem na Area Publica:</span>
                        </td>
                        <td>
                            <img src="{{ public_path('pmar/assets/img/arte_sacra/qrcodes/' . $arte->codigo_acervo . '.png') }}"
                                alt="QR Code do Acervo" style="display: block; max-width: 100px;">
                        </td>
                    </tr>
                </table>
            </div>
        </div>
    @endif

    <div style="page-break-before: always;"></div>

    <h2 class="group-title">Levantamento de Intervenção</h2>
    @if ($arte->historicos->count())
        <div class="section">
            @foreach ($arte->historicos as $index => $historico)
                <div class="historico-container">
                    <table
                        style="width: 100%; margin-bottom: 10px; border-bottom: 1px solid #eee; padding-bottom: 8px;">
                        <tr>
                            <td style="width: 50%;">
                                <span style="font-weight: bold;">Data do levantamento:</span>
                                {{ $arte->created_at->format('d/m/Y') }}
                            </td>
                            @if ($historico->novo_acervo)
                                <td style="width: 50%; text-align: right;">
                                    <span style="font-weight: bold;">Atualização de Acervo:</span>
                                    <span>{{ $historico->novo_acervo }}</span>
                                </td>
                            @endif
                        </tr>
                    </table>

                    @if ($historico->restauracoes)
                        <div style="margin-bottom: 10px;">
                            <span class="label">Restaurações:</span><br>
                            <div class="bloco-conteudo">
                                {{ $historico->restauracoes }}
                            </div>
                        </div>
                    @endif

                    @if ($historico->dados_historicos)
                        <div style="margin-bottom: 10px;">
                            <span class="label">Históricos de Exposições:</span><br>
                            <div class="bloco-conteudo">
                                {{ $historico->dados_historicos }}
                            </div>
                        </div>

                        <div style="margin-bottom: 10px;">
                            <span class="label">Históricos de Movimentações:</span><br>
                            <div class="bloco-conteudo">
                                {{ $historico->dados_historicos }}
                            </div>
                        </div>
                    @endif

                    @if ($historico->referencias_bibliograficas)
                        <div style="margin-bottom: 10px;">
                            <span class="label">Referências Bibliográficas / Arquivísticas:</span><br>
                            <div class="bloco-conteudo">
                                {{ $historico->referencias_bibliograficas }}
                            </div>
                        </div>
                    @endif

                    @if ($historico->observacoes)
                        <div style="margin-bottom: 10px;">
                            <span class="label">Observações:</span><br>
                            <div class="bloco-conteudo">
                                {{ $historico->observacoes }}
                            </div>
                        </div>
                    @endif

                    @if ($historico->data_realizacao || $historico->data_revisao || $historico->responsavel || $historico->revisor)
                        <table style="width: 100%; margin-top: 20px; margin-bottom: 10px; font-size: 14px;">
                            <tr>
                                @if ($historico->data_realizacao)
                                    <td style="text-align: center; width: 50%;">
                                        <strong>Data da Realização:</strong>
                                        {{ $historico->data_realizacao }}
                                    </td>
                                @endif
                                @if ($historico->data_revisao)
                                    <td style="text-align: center;">
                                        <strong>Data da Revisão:</strong>
                                        {{ $historico->data_revisao }}
                                    </td>
                                @endif
                            </tr>
                            <tr>
                                @if ($historico->responsavel)
                                    <td style="text-align: center; width: 50%;">
                                        <strong>Responsável:</strong>
                                        {{ $historico->responsavel }}
                                    </td>
                                @endif
                                @if ($historico->revisor)
                                    <td style="text-align: center;">
                                        <strong>Revisor:</strong>
                                        {{ $historico->revisor }}
                                    </td>
                                @endif
                            </tr>
                        </table>
                    @endif

                </div>
            @endforeach
        </div>
    @else
        <p style="text-align: center; font-size: 12px; margin-top: 20px; color: #424242c4;">
            * Nenhum histórico encontrado *
        </p>
    @endif

    <div style="page-break-before: always;"></div>

    <h2 class="group-title">Avaliações Técnicas</h2>

    @if ($arte->avaliacoesTecnicas->count())
        <div class="section">
            @foreach ($arte->avaliacoesTecnicas as $avaliacao)
                <div class="avaliacao-container"
                    style="margin-bottom: 30px; padding: 15px; border: 1px solid #ccc; border-radius: 8px;">

                    <h4 class="avaliacao-title" style="margin-bottom: 15px;">
                        Avaliação Técnica -
                        {{ $avaliacao->data_avaliacao ? \Carbon\Carbon::parse($avaliacao->data_avaliacao)->format('d/m/Y') : 'Data não informada' }}
                    </h4>

                    <table style="width: 100%; margin-bottom: 15px; border-spacing: 10px;">
                        <tr>
                            @if ($avaliacao->imagem_antes_frente)
                                <td style="width: 25%; text-align: center;">
                                    <span class="label">Antes Frente:</span><br>
                                    <img src="{{ public_path('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_antes_frente) }}"
                                        alt="Imagem Antes Frente"
                                        style="width: 150px; height: 180px; object-fit: cover; border: 1px solid #999; border-radius: 6px;">
                                </td>
                            @endif

                            @if ($avaliacao->imagem_antes_verso)
                                <td style="width: 25%; text-align: center;">
                                    <span class="label">Antes Verso:</span><br>
                                    <img src="{{ public_path('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_antes_verso) }}"
                                        alt="Imagem Antes Verso"
                                        style="width: 150px; height: 180px; object-fit: cover; border: 1px solid #999; border-radius: 6px;">
                                </td>
                            @endif

                            @if ($avaliacao->imagem_depois_frente)
                                <td style="width: 25%; text-align: center;">
                                    <span class="label">Depois Frente:</span><br>
                                    <img src="{{ public_path('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_depois_frente) }}"
                                        alt="Imagem Depois Frente"
                                        style="width: 150px; height: 180px; object-fit: cover; border: 1px solid #999; border-radius: 6px;">
                                </td>
                            @endif

                            @if ($avaliacao->imagem_depois_verso)
                                <td style="width: 25%; text-align: center;">
                                    <span class="label">Depois Verso:</span><br>
                                    <img src="{{ public_path('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_depois_verso) }}"
                                        alt="Imagem Depois Verso"
                                        style="width: 150px; height: 180px; object-fit: cover; border: 1px solid #999; border-radius: 6px;">
                                </td>
                            @endif
                        </tr>
                    </table>

                    <div style="margin-bottom: 10px;">
                        <strong>Suporte:</strong>
                        <div class="bloco-conteudo">{{ $avaliacao->suporte ?? 'Não informado' }}</div>
                    </div>

                    <div style="margin-bottom: 10px;">
                        <strong>Policromia:</strong>
                        <div class="bloco-conteudo">{{ $avaliacao->policromia ?? 'Não informado' }}</div>
                    </div>

                    <div style="margin-bottom: 10px;">
                        <strong>Diagnóstico:</strong>
                        <div class="bloco-conteudo" style="white-space: pre-wrap;">
                            {{ $avaliacao->diagnostico ? strip_tags($avaliacao->diagnostico) : 'Não informado' }}
                        </div>
                    </div>

                    <div style="margin-bottom: 10px;">
                        <strong>Procedimentos:</strong>
                        <div class="bloco-conteudo" style="white-space: pre-wrap;">
                            {{ $avaliacao->procedimentos ? strip_tags($avaliacao->procedimentos) : 'Não informado' }}
                        </div>
                    </div>

                    <div style="margin-top: 20px; font-size: 14px;">
                        <table style="width: 100%; font-size: 14px;">
                            <tr>
                                <td style="text-align: center; width: 50%;">
                                    <strong>Data da Avaliação:</strong><br>
                                    {{ $avaliacao->data_avaliacao ? \Carbon\Carbon::parse($avaliacao->data_avaliacao)->format('d/m/Y') : 'Não informada' }}
                                </td>
                                <td style="text-align: center;">
                                    <strong>Responsável:</strong><br>
                                    {{ $avaliacao->responsavel ?? 'Não informado' }}
                                </td>
                            </tr>
                        </table>
                    </div>

                </div>
            @endforeach
        </div>
    @else
        <p style="text-align: center; font-size: 12px; margin-top: 20px; color: #424242c4;">
            * Nenhuma avaliação técnica encontrada *
        </p>
    @endif

</body>

</html>
