@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Página inicial')
@section('content')
<section class="home-noticias bg-waves">
    <div class="container">
        @include('paginas.partsHome.headlineNoticias')
    </div>
</section>

<section class="home-banners-1">
    <div class="container">
        @include('paginas.partsHome.homebanners1')
    </div>
</section>

<section class="home-links-institucionais">
    <div class="container mx-auto px-4 ">
        @include('paginas.partsHome.linksInstitucionais')
    </div>
</section>

    <section class="home-banners-2">
        <div class="container">
            @include('paginas.partsHome.homebanners2')
        </div>
    </section>

    <section class="home-guia-rapido">
        <div class="container">
            @include('paginas.partsHome.comoPodemosAjudar')
        </div>
    </section>

    <section class="home-banners-3">
        <div class="container">
            @include('paginas.partsHome.homebanners3')
        </div>
    </section>

<!-- Seção: Destaques de Redes Sociais -->
<section class="home-redes-sociais bg-waves-blue">
    <div class="container">
        @include('paginas.partsHome.redesSociais')
    </div>
</section>

<!-- Seção: Tópicos mais Buscados -->
<section class="home-mais-buscados">
    <div class="container">
        @include('paginas.partsHome.topicoMaisBuscados')
    </div>
</section>

<!-- Seção: Tópicos mais Buscados 
<section class="home-VideoInstitucional">
    <div class="container">
        @include('paginas.partsHome.home-VideoInstitucional')
    </div>
</section>
-->

<!-- Seção: Galeria de Fotos -->
<section class="home-galeria-fotos bg-waves">
    <div class="container-full">
        @include('paginas.partsHome.galeriaDeFotos')
    </div>
</section>

<!-- Seção: Pontos Turísticos -->
<section class="home-pontos-turisticos">
    <div class="container">
        @include('paginas.partsHome.pontosTuristicos')
    </div>
</section>
@endsection