@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Editar evento'))
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-calendar'></i> " . __('Editar evento'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.cultura.credenciamentoMusicos.eventos.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            <form action="{{ route('admin.cultura.credenciamentoMusicos.eventos.update', $evento) }}" method="post">
                @csrf
                @method('put')
                @include('admin.cultura.credenciamentoMusicos.eventos._form', ['evento' => $evento])
                <button type="submit" class="btn btn-success">{{ __('Atualizar') }}</button>
            </form>
        </div>
    </div>
@endsection
