<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover">
    <meta name="robots" content="noindex, nofollow">
    <title><?php echo e(__('Mapa MobiAngra')); ?></title>
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css"
        integrity="sha256-p4NxAoJBhIIN+hmNHrzRCf9tD/miZyoHS5obTRR9BMY=" crossorigin="">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/maplibre-gl/4.7.1/maplibre-gl.min.css"
        integrity="sha512-qN/uDg9bS3IAldWq4lswyC+9ZSoShtfyNDp+FaJhdtXJqdgubHA+s4nB8BajW0m90Y0+RBGbqu2anzbxiQYdHA="
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css"
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="<?php echo e(asset('mobiangra-assets/css/mapa-embed.css')); ?>?v=<?php echo e(@filemtime(public_path('mobiangra-assets/css/mapa-embed.css')) ?: time()); ?>">
</head>
<body class="ma-embed-body">
    <div id="ma-embed-map" role="application" aria-label="<?php echo e(__('Mapa resumido do transporte coletivo')); ?>"></div>

    <script>
        window.MOBIANGRA_EMBED = {
            liveDataUrl: <?php echo json_encode(route('mobiangra.live_data'), 15, 512) ?>,
            shapesUrl: <?php echo json_encode(route('mobiangra.shapes'), 15, 512) ?>,
            tripsUrl: <?php echo json_encode(route('mobiangra.trips'), 15, 512) ?>,
            routeNames: <?php echo json_encode($routeNames, 15, 512) ?>,
            lineColors: <?php echo json_encode($lineColors, 15, 512) ?>,
            vehicleColors: <?php echo json_encode($vehicleColors, 15, 512) ?>,
            microVehicles: <?php echo json_encode($microVehicles, 15, 512) ?>,
            defaults: <?php echo json_encode($mapDefaults, 15, 512) ?>,
            refreshInterval: <?php echo e((int) $previewRefreshMs); ?>,
            mapUrl: <?php echo json_encode(route('mobiangra.mapa'), 15, 512) ?>,
            i18n: {
                ida: <?php echo json_encode(__('Ida'), 15, 512) ?>,
                volta: <?php echo json_encode(__('Volta'), 15, 512) ?>,
                linha: <?php echo json_encode(__('Linha'), 15, 512) ?>,
                veiculo: <?php echo json_encode(__('Veículo'), 15, 512) ?>,
            },
        };
    </script>
    <script src="https://unpkg.com/leaflet@1.9.4/dist/leaflet.js"
        integrity="sha256-20nQCchB9co0qIjJZRGuk2/Z9VM+kNiyxNV1lvTlZBo=" crossorigin=""></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/maplibre-gl/4.7.1/maplibre-gl.min.js"
        integrity="sha512-dXgoFR02YHJ9Fa29P3D/1umNaZ0EXS2N0w29Lm3b/1BK8UDLMdLWDFwuujIyJJdU27/PLuk3dmS1V9NO8ABX1A=="
        crossorigin="anonymous" referrerpolicy="no-referrer"></script>
    <script src="https://unpkg.com/@maplibre/maplibre-gl-leaflet@0.1.3/leaflet-maplibre-gl.js" crossorigin="anonymous"
        referrerpolicy="no-referrer"></script>
    <script src="<?php echo e(asset('mobiangra-assets/js/mapa-embed.js')); ?>?v=<?php echo e(@filemtime(public_path('mobiangra-assets/js/mapa-embed.js')) ?: time()); ?>"></script>
</body>
</html>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/mapa_embed.blade.php ENDPATH**/ ?>