@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Histórico de convocações'))
@section('content')

    <div class="card shadow-sm">
        @php
            $headLine = "<i class='fa-solid fa-list'></i> " . __('Histórico de convocações');
            if (isset($musico)) {
                $headLine .= ' – ' . ($musico->grupo_nome ?: optional($user)->name);
            }
        @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => $perfil ? 'admin.cultura.credenciamentoMusicos.perfil.index' : 'admin.cultura.credenciamentoMusicos.edit',
            'routeBackParams' => $perfil ? [] : [$musico->id],
            'nameBack' => __('Voltar'),
            'permission' => $perfil ? 'GERENCIADOR_DE_CONTA_ANGRA' : 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            @if($convocacoes->isEmpty())
                <p class="text-muted mb-0">{{ __('Nenhuma convocação registrada para este credenciamento.') }}</p>
            @else
                <div class="table-responsive">
                    <table class="table table-sm">
                        <thead>
                            <tr>
                                <th>{{ __('Evento') }}</th>
                                <th>{{ __('Data da convocação') }}</th>
                                <th>{{ __('Status') }}</th>
                                <th>{{ __('Ordem') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($convocacoes as $c)
                                <tr>
                                    <td>{{ $c->evento->nome ?? '–' }} @if($c->evento->data)<small class="text-muted">({{ $c->evento->data->format('d/m/Y') }})</small>@endif</td>
                                    <td>{{ $c->data_convocacao ? $c->data_convocacao->format('d/m/Y') : '–' }}</td>
                                    <td>
                                        @if($c->status === 'CONFIRMADA')
                                            <span class="badge bg-success">{{ __('Confirmada') }}</span>
                                        @elseif($c->status === 'CANCELADA')
                                            <span class="badge bg-danger">{{ __('Cancelada') }}</span>
                                        @else
                                            <span class="badge bg-warning text-dark">{{ __('Pendente') }}</span>
                                        @endif
                                    </td>
                                    <td>{{ $c->ordem }}</td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            @endif
        </div>
    </div>
@endsection
