<head>
    <!-- Mobile Specific Meta -->
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <!-- Favicon-->
    <link rel="shortcut icon" href="img/fav.png">
    <!-- Author Meta -->
    <meta name="author" content="codepixer">
    <!-- Meta Description -->
    <meta name="description" content="">
    <!-- Meta Keyword -->
    <meta name="keywords" content="">
    <!-- meta character set -->
    <meta charset="UTF-8">
    <!-- Site Title -->

    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>Museu de Arte Sacra</title>

    <link href="https://fonts.googleapis.com/css?family=Poppins:100,200,400,300,500,600,700" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.linearicons.com/free/1.0.0/icon-font.min.css">

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Cinzel+Decorative:wght@400;700;900&family=Montserrat:ital,wght@0,100..900;1,100..900&display=swap"
        rel="stylesheet">

    <!-- FIVEICON -->
    <link rel="apple-touch-icon" sizes="57x57" href="{{ asset('pmar/assets/fav/apple-icon-57x57-2026.png') }}">
    <link rel="apple-touch-icon" sizes="60x60" href="{{ asset('pmar/assets/fav/apple-icon-60x60-2026.png') }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ asset('pmar/assets/fav/apple-icon-72x72-2026.png') }}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{ asset('pmar/assets/fav/apple-icon-76x76-2026.png') }}">
    <link rel="apple-touch-icon" sizes="114x114" href="{{ asset('pmar/assets/fav/apple-icon-114x114-2026.png') }}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{ asset('pmar/assets/fav/apple-icon-120x120-2026.png') }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ asset('pmar/assets/fav/apple-icon-144x144-2026.png') }}">
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset('pmar/assets/fav/apple-icon-180x180-2026.png') }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset('pmar/assets/fav/favicon-32x32-2026.png') }}">
    <link rel="icon" type="image/png" sizes="96x96" href="{{ asset('pmar/assets/fav/favicon-96x96-2026.png') }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset('pmar/assets/fav/favicon-16x16-2026.png') }}">

    <!-- Swiper CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@9/swiper-bundle.min.css" />

    <link rel="stylesheet" href="{{ asset('arte-sacra/css/linearicons.css') }}">
    <link rel="stylesheet" href="{{ asset('arte-sacra/css/font-awesome.min.css') }}">
    <link rel="stylesheet" href="{{ asset('arte-sacra/css/bootstrap.css') }}">
    <link rel="stylesheet" href="{{ asset('arte-sacra/css/main.css') }}">
</head>
