<section class="bg-light animate__animated animate__backInUp" id="perguntas">
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 p-3 text-center">
                <h1>Perguntas Frequentes</h1>
            </div>
        </div>
    </div>

    <div class="container px-5">
        <div class="row gx-5">
            <div class="col-12">
                <div class="accordion accordion-flush" id="accordionFlushExample">
                    <h3 class="lead">Sobre o SEI!</h3>
                    <div id="primeirasPerguntas">
                        <div class="accordion-item">
                            <h2 class="accordion-header" id="flush-heading00"> <button
                                    class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                    data-bs-target="#flush-collapse00" aria-expanded="false"
                                    aria-controls="flush-collapse00"> O que é o SEI? </button>
                            </h2>
                            <div id="flush-collapse00" class="accordion-collapse collapse"
                                aria-labelledby="flush-heading00" data-bs-parent="#accordionFlushExample">
                                <div class="accordion-body">
                                    <p>O Sistema Eletrônico de Informações (SEI) é um sistema de produção e gestão de
                                        documentos e processos eletrônicos desenvolvido pelo Tribunal Regional Federal
                                        da 4ª Região (TRF4) e cedido gratuitamente à administração pública. </p>
                                    <p> O SEI foi escolhido como a solução de processo eletrônico no âmbito do projeto
                                        Processo Eletrônico Nacional (PEN) - iniciativa conjunta de órgãos e entidades
                                        de diversas esferas da administração pública, com o intuito de construir uma
                                        infraestrutura pública de processos e documentos administrativos eletrônicos, e
                                        têm sido implementados em vários órgãos e entidades das mais variadas esferas
                                        administrativas. </p>
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header" id="flush-heading01"> <button
                                    class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                    data-bs-target="#flush-collapse01" aria-expanded="false"
                                    aria-controls="flush-collapse01"> Para que serve? </button>
                            </h2>
                            <div id="flush-collapse01" class="accordion-collapse collapse"
                                aria-labelledby="flush-heading01" data-bs-parent="#accordionFlushExample">
                                <div class="accordion-body">
                                    <p> O SEI possui diversas funcionalidades e permitem estabelecer a gestão de
                                        documentos de forma sistematizada por meio de:
                                    <ul>
                                        <li>Produção de documentos dentro do ambiente do próprio sistema e assinatura
                                            eletrônica;</li>
                                        <li>Controle do nível de acesso, gerenciamento e o trâmite de processos e
                                            documentos restritos e sigilosos, conferindo o acesso somente às unidades
                                            envolvidas ou a usuários específicos;</li>
                                        <li>Criação de modelos de documentos;</li>
                                        <li>Criação de textos padrão;</li>
                                        <li>Criação de Base de Conhecimento dos processos (fluxo de trâmite do
                                            processo);</li>
                                        <li>Autuação do documento em qualquer unidade administrativa e tramitação em
                                            múltiplas unidades, que podem ser demandadas simultaneamente e manifestar-se
                                            no mesmo expediente administrativo;</li>
                                        <li>Acompanhamento especial do andamento dos processos de interesse da unidade;
                                        </li>
                                        <li>Controle de prazos; estatísticas da unidade e tempo do trâmite do processo;
                                        </li>
                                        <li>Assinatura de documentos por meio de blocos de assinatura;</li>
                                        <li>Organização interna de processos em bloco;</li>
                                        <li>Sobrestamento de processos;</li>
                                        <li>Pesquisa em todo teor, nos casos de processos públicos;</li>
                                        <li>Inspeção administrativa, com fornecimento de estatísticas da unidade (tais
                                            como: tempo de trâmite do processo, quantidade e tipos de documentos
                                            gerados); </li>
                                        <li>Acesso externo ao processo (gerencia o acesso de usuários externos aos
                                            expedientes administrativos que lhes digam respeito, permitindo que tomem
                                            conhecimento do teor do processo e, por exemplo, assinem remotamente
                                            contratos e outros tipos de documentos);</li>
                                        </li> Dentre outras funcionalidades. </li>
                                    </ul>
                                    <p>O SEI tem ainda vantagens tecnológicas e econômicas importantes para as
                                        organizações públicas:</p>
                                    <ul>
                                        <li>Portabilidade: 100% Web e acessado por meio dos principais navegadores do
                                            mercado: Internet Explorer, Firefox e Google Chrome;</li>
                                        <li>Acesso Remoto: pode ser acessado remotamente por diversos tipos de
                                            equipamentos, como microcomputadores, notebooks, tablets e smartphones de
                                            vários sistemas operacionais (Windows, Linux, IOS e Android). Isto
                                            possibilita que os usuários trabalhem a distância;</li>
                                        <li>Sistema intuitivo: estruturado com boa navegabilidade e usabilidade; </li>
                                        <li>Economia nos contratos de compra de papel; em outsourcing, material de
                                            escritório e serviço de postagem, redução de custos em logística e
                                            transporte de documentos, e permite maior produtividade, rapidez,
                                            transparência e segurança aos trâmites administrativos.</li>
                                    </ul>
                                    </p>
                                </div>
                            </div>
                        </div>
                        <!-- <div class="accordion-item">
                            <h2 class="accordion-header" id="flush-heading02"> <button
                                    class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                    data-bs-target="#flush-collapse02" aria-expanded="false"
                                    aria-controls="flush-collapse02"> Como será realizada a implantação do SEI em Angra
                                    dos Reis? </button>
                            </h2>
                            <div id="flush-collapse02" class="accordion-collapse collapse"
                                aria-labelledby="flush-heading02" data-bs-parent="#accordionFlushExample">
                                <div class="accordion-body">
                                    <p>A implantação do SEI nos órgãos e entidades da PMAR tem sido realizada, gradativamente, de maneira escalonada.</p>
                                </div>
                            </div> -->


                    </div>
                </div>
                <br>
                <div class="accordion" id="restantePerguntas" style="display: none;">
                    <h3 class="lead">Usuários</h3>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading04"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse04" aria-expanded="false"
                                aria-controls="flush-collapse04"> Quem são os usuários do
                                SEI? </button>
                        </h2>
                        <div id="flush-collapse04" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading04" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Poderão utilizar o sistema, desde que autorizados pelas chefias da unidades, os
                                    servidores, funcionários contratados, estagiários e futuramente usuário
                                    externos. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading05"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse05" aria-expanded="false"
                                aria-controls="flush-collapse04"> Como solicitar meu
                                Cadastro no SEI? </button>
                        </h2>
                        <div id="flush-collapse05" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading05" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Para obter sua conta no SEI, você deve dirigir-se a um <strong>Ponto Focal
                                        SEI</strong> do seu departamento e solicitar a ele a criação de seu usuário.
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading06"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse06" aria-expanded="false"
                                aria-controls="flush-collapse06"> Qual será o meu login e a
                                minha senha no SEI (Treinamento e Produção)? </button>
                        </h2>
                        <div id="flush-collapse06" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading06" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Para acessar o SEI da PMAR basta acessar o endereço eletrônico (<a
                                        href="https://angra.sei.rj.gov.br" class="link-sei"
                                        target="_blank">https://angra.sei.rj.gov.br</a>) utilizando a matrícula de
                                    servidor como login e senha da rede interna da Prefeitura (usada para ligar seu
                                    Computador), logo após, selecione o órgão/secretaria. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading07"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse07" aria-expanded="false"
                                aria-controls="flush-collapse07"> Como é o acesso ao SEI?
                            </button>
                        </h2>
                        <div id="flush-collapse07" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading07" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> O usuário interno deve entrar na página inicial do SEI (<a
                                        href="https://angra.sei.rj.gov.br" class="link-sei"
                                        target="_blank">https://angra.sei.rj.gov.br</a>), inserir seu login, senha
                                    e orgão. O ícone para acesso ao sistema também está disponível no sítio da PMAR
                                    através do endereço eletrônico (<a href="https://portal.angra.rj.gov.br/sei"
                                        class="link-sei" target="_blank">https://portal.angra.rj.gov.br/sei</a>).
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading08"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse08" aria-expanded="false"
                                aria-controls="flush-collapse08"> Todos os usuários têm
                                assinatura eletrônica? Como funciona? </button>
                        </h2>
                        <div id="flush-collapse08" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading08" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Todos os servidores da Prefeitura têm assinatura eletrônica. Basta informar a
                                    senha de login da rede, escolhendo o cargo adequado. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading09"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse09" aria-expanded="false"
                                aria-controls="flush-collapse09"> É possível uma pessoa
                                redigir um documento e outra assinar? </button>
                        </h2>
                        <div id="flush-collapse09" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading09" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Sim. Os usuários podem assinar documentos de processos que estiverem tramitando
                                    em sua unidade, mesmo que redigidos por outro servidor. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading10"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse10" aria-expanded="false"
                                aria-controls="flush-collapse10"> Há modelos padronizados de
                                documentos? </button>
                        </h2>
                        <div id="flush-collapse10" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading10" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Sim. Caso queira acrescentar mais algum modelo favor entrar em contato com seu
                                    Ponto Focal. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading11"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse11" aria-expanded="false"
                                aria-controls="flush-collapse11"> Como iniciar/criar um
                                processo no SEI? </button>
                        </h2>
                        <div id="flush-collapse11" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading11" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Na tela principal do SEI, no menu lateral à esquerda, clique em “Iniciar
                                    Processo”. Em seguida, selecione o tipo de processo e preencha os campos da tela
                                    de “Iniciar processo”. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading12"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse12" aria-expanded="false"
                                aria-controls="flush-collapse12"> Como cadastrar um
                                documento? </button>
                        </h2>
                        <div id="flush-collapse12" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading12" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Clique sobre o número do processo desejado. Clique no ícone "Incluir Documento".
                                    Escolha na lista o tipo de documento desejado. Digite as informações de
                                    identificação do documento.
                                <ul>
                                    <li> <strong>Texto inicial:</strong> Para um documento em branco, selecione a
                                        opção "Nenhum". (Para mais informações sobre como usar documentos e textos
                                        cadastrados acesse: "Criar texto padrão" e "Criar documento modelo" ). </li>
                                    <li> <strong>Descrição ( opcional ):</strong> Digite o assunto do documento.
                                    </li>
                                    <li> <strong>Nome na árvore:</strong> Complementação do nome do documento. </li>
                                    <li> <strong>Interessados:</strong> Por padrão, o sistema preencherá
                                        automaticamente com os interessados cadastrados no processo. Caso queira
                                        adicionar interessados, digite parte do nome do interessado, e: </li>
                                    <ul>
                                        <li>Se o interessado for exibido: clique sobre o nome do interessado. </li>
                                        <li>Se o interessado não for exibido: Digite o nome completo, tecle "enter"
                                            e clique em "Ok".</li>
                                    </ul>
                                    <li><strong>Destinatários ( opcional ):</strong> Digite o destinatário do
                                        documento.</li>
                                    <li><strong>Classificação por assuntos:</strong> É automaticamente preenchido, e
                                        <span class="text-decoration-underline">não deve ser alterado</span>.
                                    </li>
                                    <li><strong>Observação desta Unidade ( opcional )</strong>: É um campo de livre
                                        preenchimento, onde devem ser inseridas informações que facilitem a
                                        identificação do processo. Essas informações podem ser recuperadas na
                                        pesquisa exclusivamente pela unidade que as inseriu.</li>
                                    <li><strong>Nível de acesso:</strong> Permite definir o nível de acesso global
                                        do processo, se "sigiloso", se "restrito" ou se "público".</li>
                                </ul>
                                <p>Clique em "Salvar". O documento aparecerá na árvore do processo.</p>
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading13"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse13" aria-expanded="false"
                                aria-controls="flush-collapse13"> Como os processos
                                tramintam no SEI? </button>
                        </h2>
                        <div id="flush-collapse13" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading13" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Depois de iniciar um processo e incluir todos os documentos necessários, basta
                                    enviá-lo à unidade respectiva. A tramitação é eletrônica, por isso o processo é
                                    instantaneamente recebido pela outra unidade, para que ela faça a análise e os
                                    despachos necessários por meio do SEI. </p>
                                <p> É possível enviar um processo a mais de uma unidade ao mesmo tempo, caso elas
                                    não dependam umas das outras para dar os devidos despachos a esse processo e
                                    ainda manter o processo aberto na unidade de origem. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading14"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse14" aria-expanded="false"
                                aria-controls="flush-collapse14"> Como um documento
                                eletrônico é assinado? Os documentos podem ficar sem assinatura? </button>
                        </h2>
                        <div id="flush-collapse14" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading14" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> No SEI, qualquer servidor cadastrado no sistema pode assinar um documento
                                    eletronicamente. Isso é feito por meio de uso de senha ou de certificação
                                    digital. A senha é de uso pessoal e intransferível, e deve ser mantida em sigilo
                                    por cada servidor nenhum servidor pode utilizar a senha de outro. Por isso,
                                    guarde bem sua senha! Os documentos de um processo podem ser assinados por mais
                                    de um servidor, sem que necessariamente haja uma hierarquia de assinaturas. Para
                                    que um documento seja assinado por várias pessoas, ele deve ser ncluído num
                                    Bloco de Assinaturas no SEI. </p>
                                <p> O bloco deve ser disponibilizado às unidades que devem assinar o documento. Ele
                                    funciona como uma “pasta” que reúne e organiza despachos e permite que a chefia
                                    de sua unidade ou de outras unidades assinem qualquer documento que tenha sido
                                    criado por sua unidade. </p>
                                <p> Se um processo enviado a outra unidade contiver um documento sem assinatura, o
                                    conteúdo desse documento não poderá ser visualizado pela unidade que o recebeu.
                                    Trata-se de uma minuta. Por isso, é necessário assinar os documentos no SEI
                                    antes de enviar o processo a outra unidade. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading15"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse15" aria-expanded="false"
                                aria-controls="flush-collapse15"> Quem pode autuar processos
                                eletrônicos? </button>
                        </h2>
                        <div id="flush-collapse15" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading15" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Todos os usuários podem autuar processos eletrônicos em suas unidades. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading16"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse16" aria-expanded="false"
                                aria-controls="flush-collapse16"> O SEI possui
                                acessibilidade? </button>
                        </h2>
                        <div id="flush-collapse16" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading16" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> A disponibilização de mecanismos de acessibilidade no SEI pode ser realizada
                                    ativando a opção "Ativar recursos de acessibilidade" no cadastro do usuário.
                                    Para realizar essa ativação, a Unidade Setorial deverá acessar o menu
                                    "Administração > Usuários > Listar" do SEI, consultar o usuário para alteração,
                                    selecionar a opção "Alterar Usuário" e marcar a opção "Ativar recursos de
                                    acessibilidade". </p>
                                <p> Importante frisar que, para o pleno funcionamento e ativação dos recursos de
                                    acessibilidade, é necessária também a configuração das opções de "Facilidade de
                                    Acesso" no computador do usuário. No sistema operacional Windows essas opções
                                    estão disponíveis no "Painel de Controle", opção "Facilidade de Acesso ->
                                    Central de Facilidade de Acesso". Ao acessar essa Central, deverão ser
                                    selecionadas as opções pertinentes às necessidades especiais do usuário. </p>
                            </div>
                        </div>
                    </div>
                    <br>
                    <h3 class="lead">Transição</h3>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading17"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse17" aria-expanded="false"
                                aria-controls="flush-collapse17"> Os processos antigos serão
                                digitalizados? </button>
                        </h2>
                        <div id="flush-collapse17" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading17" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Inicialmente os processos antigos não serão incluídos no SEI. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading18"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse18" aria-expanded="false"
                                aria-controls="flush-collapse18"> Vai ser necessária a
                                digitalização de algum documento? </button>
                        </h2>
                        <div id="flush-collapse18" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading18" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Sim, em duas as situações:
                                <ol>
                                    <li>O documento que chegar ao protocolo será digitalizado e inserido no SEI até
                                        o dia 08/02/2024 conforme o artigo primeiro, parágrafo único e inciso III do
                                        Decreto Municipal Nº 13.367, de 03 de janeiro de 2024 criando-se um processo
                                        ou inserindo-o em um processo SEI já existente. Tanto o processo eletrônico
                                        gerado quanto o documento físico (que foi digitalizado) serão encaminhados à
                                        área competente; </li>
                                    <li>Quando um processo físico já arquivado for receber novo impulso (documentos
                                        novos para análise), deverá ser digitalizado e inserido no SEI como processo
                                        eletrônico.
                                </ol>
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading19"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse19" aria-expanded="false"
                                aria-controls="flush-collapse19"> O que ocorrerá com o
                                sistema anterior/legado (PRODATA)? </button>
                        </h2>
                        <div id="flush-collapse19" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading19" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Será utilizado apenas para consulta ou trâmite dos processos físicos arquivados
                                    encaminhados meramente para consulta. </p>
                            </div>
                        </div>
                    </div>
                    <br>
                    <h3 class="lead">Dúvidas</h3>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading20"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse20" aria-expanded="false"
                                aria-controls="flush-collapse20"> Em caso de dúvidas quanto
                                ao uso do SEI, a quem devo recorrer? </button>
                        </h2>
                        <div id="flush-collapse20" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading20" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Devem ser procurados os Pontos Focais de cada Secretaria, que são os servidores
                                    já designados para auxiliar os colaboradores quanto ao uso da ferramenta, para
                                    sanar as dúvidas. </p>
                            </div>
                        </div>
                    </div>
                    <br>
                    <h3 class="lead">Perguntas Gerais</h3>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading21"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse21" aria-expanded="false"
                                aria-controls="flush-collapse21"> Qual navegador devo
                                utilizar para acessar o SEI? </button>
                        </h2>
                        <div id="flush-collapse21" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading21" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> O sistema tem função multibrowser, entretanto, fica a sugestão pelos navegadores
                                    Chrome e Firefox, que apresentam melhor rendimento. O Internet Explorer tem
                                    apresentado inconsistências, portanto, evite o seu uso. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading22"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse22" aria-expanded="false"
                                aria-controls="flush-collapse22"> Existe algum custo pela
                                utilização? O programa é cedido gratuitamente? </button>
                        </h2>
                        <div id="flush-collapse22" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading22" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> O programa é cedido gratuitamente, sem custos, através da celebração do Acordo
                                    de Cooperação Técnica nº 2/2023. entre o Estado do Rio de Janeiro por meio da
                                    Secretaria de transformação Digital e a PMAR. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading23"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse23" aria-expanded="false"
                                aria-controls="flush-collapse23"> Como os processos
                                tramintam no SEI? </button>
                        </h2>
                        <div id="flush-collapse23" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading23" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Depois de iniciar um processo e incluir todos os documentos necessários, basta
                                    enviá-lo à unidade respectiva através do botão de “Enviar Processo”. A
                                    tramitação é eletrônica, por isso o processo é instantaneamente recebido pela
                                    outra unidade, para que ela faça a análise e os despachos necessários por meio
                                    do SEI. </p>
                                <p> É possível enviar um processo a mais de uma unidade ao mesmo tempo, caso elas
                                    não dependam umas das outras para dar os devidos despachos a esse processo.
                                    Também é possível encaminhar mais de um processo ao mesmo tempo, desde que, os
                                    processos sejam encaminhados para a mesma unidade. </p>
                            </div>
                        </div>
                    </div>
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading24"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse24" aria-expanded="false"
                                aria-controls="flush-collapse24"> Como um documento
                                eletrônico é assinado? Os documentos podem ficar sem assinatura? </button>
                        </h2>
                        <div id="flush-collapse24" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading24" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> No SEI, qualquer servidor cadastrado no sistema pode assinar um documento
                                    eletronicamente. Isso é feito por meio de uso de senha. A senha é de uso pessoal
                                    e intransferível, e deve ser mantida em sigilo por cada servidor – nenhum
                                    servidor pode utilizar a senha de outro. Por isso, guarde bem sua senha! </p>
                                <p> Os documentos de um processo podem ser assinados por mais de um servidor, sem
                                    que necessariamente haja uma hierarquia de assinaturas. Para que um documento
                                    seja assinado por várias pessoas, ele deve ser incluído num Bloco de Assinaturas
                                    no SEI. O bloco deve ser disponibilizado às unidades que devem assinar o
                                    documento. </p>
                                <p> Ele funciona como uma “pasta” que reúne e organiza despachos, e permite a
                                    assinatura de qualquer documento que tenha sido criado por sua unidade. e
                                    permite que a chefia de sua unidade ou de outras unidades assinem qualquer
                                    documento que tenha sido criado por sua unidade. </p>
                                <p> Se um processo enviado à outra unidade contiver um documento sem assinatura, o
                                    conteúdo desse documento não poderá ser visualizado pela unidade que o recebeu.
                                    Trata-se de uma minuta. Por isso, é necessário assinar os documentos no SEI
                                    antes de enviar o processo à outra unidade. Para mais informações, consulte o
                                    manual do usuário. </p>
                            </div>
                        </div>
                    </div>
                    <!-- <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading25"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse25" aria-expanded="false"
                                aria-controls="flush-collapse25"> Caso a sua questão
                                esteja contemplada neste FAQ: </button>
                        </h2>
                        <div id="flush-collapse25" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading25" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Envie sua pergunta para nosso canal de atendimento ao usuário externo: <span
                                        class="text-primary">sei@angra.rj.gov.br</span>. </p>
                            </div>
                        </div>
                    </div> -->
                    <!-- <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading26"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse26" aria-expanded="false"
                                aria-controls="flush-collapse26"> A minha unidade poderá
                                ter um usuário e senha? </button>
                        </h2>
                        <div id="flush-collapse26" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading26" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Não. Os acessos ao SEI são pessoais e intransferíveis, não sendo possível
                                    acessar o sistema através do e-mail da unidade. </p>
                            </div>
                        </div>
                    </div> -->
                    <!-- <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading27"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse27" aria-expanded="false"
                                aria-controls="flush-collapse27"> Quais são as formas de
                                assinar documentos no SEI? </button>
                        </h2>
                        <div id="flush-collapse27" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading27" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Há 3 (três) formas de assinar documentos no SEI:
                                <ul>
                                    <li>Por usuários da própria unidade;</li>
                                    <li>Por usuários de outras unidades através de bloco de assinaturas; e/ou </li>
                                    <li>Por usuários externos.</li>
                                </ul>
                                </p>
                            </div>
                        </div>
                    </div> -->
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading28"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse28" aria-expanded="false"
                                aria-controls="flush-collapse28"> Como editar um documento
                                produzido no SEI? </button>
                        </h2>
                        <div id="flush-collapse28" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading28" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> É possível editar apenas documentos que foram produzidos pela sua unidade e que
                                    ainda não foram assinados e não foram acessados por terceiros (usuários de
                                    outras unidades ou através da Pesquisa Pública). Para editar um documento, o
                                    usuário deve:
                                <ul>
                                    <li> Entrar no processo desejado (clicar sobre o NUP do processo);</li>
                                    <li> Clicar sobre o documento desejado na árvore do processo (lateral esquerda
                                        da tela);</li>
                                    <li> Clicar no ícone “Editar Conteúdo”;</li>
                                    <li> Realizar as alterações desejadas;</li>
                                    <li> Clicar no botão “Salvar” (canto superior esquerdo da tela).</li>
                                </ul>
                                </p>
                            </div>
                        </div>
                    </div>
                    <!-- <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading29"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse29" aria-expanded="false"
                                aria-controls="flush-collapse29"> Não possuo login/senha
                                do SEI-Angra dos Reis. Como solicitar? </button>
                        </h2>
                        <div id="flush-collapse29" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading29" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> No caso de um usuário interno o acesso poderá ser solicitado para o Ponto Focal
                                    da unidade / secretaria ou através do e-mail: <span
                                        class="text-primary">sei@angra.rj.gov.br</span>. </p>
                            </div>
                        </div>
                    </div> -->
                    <div class="accordion-item">
                        <h2 class="accordion-header" id="flush-heading30"> <button
                                class="accordion-button collapsed text-dark" type="button" data-bs-toggle="collapse"
                                data-bs-target="#flush-collapse30" aria-expanded="false"
                                aria-controls="flush-collapse30"> Como saber se um
                                processo foi recebido na minha unidade? </button>
                        </h2>
                        <div id="flush-collapse30" class="accordion-collapse collapse"
                            aria-labelledby="flush-heading30" data-bs-parent="#accordionFlushExample">
                            <div class="accordion-body">
                                <p> Para identificar se um processo foi ou não recebido em sua unidade, basta
                                    verificar a cor em que se encontra seu número na tela de controle de processos:
                                </p>
                                <p>
                                <ul>
                                    <li><span class="text-danger">Cor vermelha</span> significa que o processo
                                        ainda não foi recebido na Unidade, ou seja, nenhum usuário da Unidade
                                        acessou o processo. </li>
                                    <li><span class="text-dark">Cor preta</span> significa que o processo já foi
                                        acessado por algum usuário da unidade. Para identificar o recebedor,
                                        consulte o andamento do processo.</li>
                                    <li><span class="text-primary">Cor azul</span> significa que o processo foi
                                        acessado pelo usuário logado que visualiza a cor azul.</li>
                                </ul>
                                <p>Para acusar o recebimento de um processo, basta clicar no número do processo que
                                    estiver na cor vermelha e seu registro automaticamente aparecerá no andamento do
                                    processo. Para visualizar, clique em “Consultar Andamento”.</p>
                                </p>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-12 text-center">
                    <button id="buttonFAQ" onclick="mostrarRestante()" class="btn btn-primary mt-3 mb-5">
                        <i class="fa-solid fa-plus"></i> &nbsp;
                        Mostrar Mais Perguntas
                    </button>
                </div>
            </div>
        </div>
    </div>
    </div>
</section>
