<p>{{ __('Uma nova manifestação foi registrada no formulário Fale Conosco do MobiAngra.') }}</p>

@if ($manifestacao->chamado)
    <p><strong>{{ __('Número de registro') }}:</strong> {{ $manifestacao->chamado->numeroChamado }}</p>
@endif

<p><strong>{{ __('Data') }}:</strong> {{ $manifestacao->created_at?->format('d/m/Y H:i') }}</p>
<p><strong>{{ __('Identificação') }}:</strong> {{ $manifestacao->identificacao }}</p>
<p><strong>{{ __('E-mail para retorno') }}:</strong> {{ $manifestacao->email }}</p>
<p><strong>{{ __('Linha') }}:</strong> {{ $manifestacao->linha ?: '-' }}</p>
<p><strong>{{ __('Sentido') }}:</strong> {{ $sentidoLabel }}</p>
<p><strong>{{ __('Horário') }}:</strong> {{ $manifestacao->horario ?: '-' }}</p>
<p><strong>{{ __('Local') }}:</strong> {{ $manifestacao->local ?: '-' }}</p>
<p><strong>{{ __('Número do veículo') }}:</strong> {{ $manifestacao->numero_veiculo ?: '-' }}</p>

<p><strong>{{ __('Relato') }}:</strong></p>
<p>{{ $manifestacao->relato }}</p>

@if ($manifestacao->imagem_path)
    <p><strong>{{ __('Imagem anexada') }}:</strong> {{ __('Disponível no painel administrativo do MobiAngra.') }}</p>
@endif
