@php
    $stats = $stats ?? [];
@endphp

<div class="dashboard-card">
    <div class="dashboard-card-header">
        <h3 class="dashboard-card-title">
            <i class="fa-solid fa-chart-bar me-2"></i>
            {{ __("Informações sobre o Site de Angra") }}
        </h3>
    </div>
    <div class="dashboard-card-body">
        <div class="stats-grid">
            @foreach($stats as $stat)
                @include('components.dashboard._statItem', $stat)
            @endforeach
        </div>
    </div>
</div>