<section class="bg-white" style="padding-top: 0 !important; padding-bottom: 0 !important;" id="cmgd">
    <div class="container">
        <div class="row">
            <div class="col-10 offset-1 text-center my-5">
                <h2><?php echo e(__("Representantes do CMGD")); ?></h2>
                <div>
                    <?php $nomedasuavariavelgustavo = "O <strong>Comitê de Governança Digital de Angra dos Reis</strong> é um órgão de caráter consultivo e deliberativo, responsável por planejar, coordenar e acompanhar as ações de transformação digital no município. Seu objetivo é promover a modernização dos serviços públicos, garantindo mais eficiência, transparência, inovação e facilidade no acesso dos cidadãos aos serviços digitais. O comitê também atua na definição de estratégias, normas e diretrizes que fortalecem a gestão pública e impulsionam o desenvolvimento tecnológico da cidade." ?>
                    <p><?php echo __($nomedasuavariavelgustavo); ?></p>
                    <h3><?php echo e(__("Membros do Comitê")); ?></h3>
                    <p><?php echo e(__("Confira a composição do Comitê Municipal de Governança Digital da Prefeitura de Angra dos Reis, com os representantes distribuídos por secretaria.")); ?></p>
                </div>
            </div>
            <div class="col-10 offset-1 mb-5">
                <div class="accordion" id="accordionCMGD">
                    <?php
                    $array_accordion = [
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Econômico (SDE)'),
                            'itens' => [
                                [
                                    "nome" => 'Yasmin Muniz Suisso Santos',
                                    "matricula" => '30272',
                                    "cargo" => 'Coordenação Técnica de Empregabilidade',
                                ],
                                [
                                    "nome" => 'Giuliane Sousa de Meira',
                                    "matricula" => '28072',
                                    "cargo" => 'Coordenação Técnica e Dados e Pesquisas',
                                ],
                            ],
                            'collapse' => __('collapse1'),
                            'TF' => __('true'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Regional (SDR) <br> Secretaria Executiva de Serviços Públicos (SESEP)'),
                            'itens' => [
                                [
                                    "nome" => 'Pryscila de Jesus de Sousa Tamburini',
                                    "matricula" => '18218',
                                    "cargo" => 'Técnica de Edificações',
                                ],
                                [
                                    "nome" => 'Dulcinéia Gil da Silva',
                                    "matricula" => '21819',
                                    "cargo" => 'Diretora de Apoio a Departamento Administrativo',
                                ],
                            ],
                            'collapse' => __('collapse2'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Saúde (SSA)'),
                            'itens' => [
                                [
                                    "nome" => 'Luciano Chaves Ferreira',
                                    "matricula" => '32653',
                                    "cargo" => 'Auxiliar Técnico da Atenção Primária',
                                ],
                                [
                                    "nome" => 'Leandro Medeiros Silva',
                                    "matricula" => '32747',
                                    "cargo" => 'Coordenador Técnico de TI',
                                ],
                            ],
                            'collapse' => __('collapse3'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Articulação Governamental (SAG) <br> Secretaria Executiva de Comunicação (SECO)'),
                            'itens' => [
                                [
                                    "nome" => 'Ludmila da Silva Pereira',
                                    "matricula" => '32361',
                                    "cargo" => 'Superintendente de Comunicação',
                                ],
                                [
                                    "nome" => 'Luis Gustavo Campos muniz da Silva',
                                    "matricula" => '33123',
                                    "cargo" => 'Superintendente de Estratégia e Gestão da Comunicação',
                                ],
                            ],
                            'collapse' => __('collapse4'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Regional (SDR) <br> Secretario Executvo de Ilha Grande (SEIG)'),
                            'itens' => [
                                [
                                    "nome" => 'Esabellen Barros',
                                    "matricula" => '32761',
                                    "cargo" => 'Coordenadora Técnica de Logistica',
                                ],
                                [
                                    "nome" => 'Luana Cantanhede Serra Ventura',
                                    "matricula" => '27900',
                                    "cargo" => 'Coordenadora Técnica da Ilha Grande',
                                ],
                            ],
                            'collapse' => __('collapse5'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Esporte e Lazer (SEL)'),
                            'itens' => [
                                [
                                    "nome" => 'Evelyn Conceição Botelho',
                                    "matricula" => '32645',
                                    "cargo" => 'Coordenador Técnica de Administração, Operacional e Planejamento',
                                ],
                                [
                                    "nome" => 'Iderlan Cadilha Cunha',
                                    "matricula" => '32634',
                                    "cargo" => 'Coordenador Técnica de Administração Esportiva',
                                ],
                            ],
                            'collapse' => __('collapse6'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Urbanização, Parques e Jardins (SUPJ)'),
                            'itens' => [
                                [
                                    "nome" => 'Adriana da Costa Rodrigues',
                                    "matricula" => '21529',
                                    "cargo" => 'Assessora de Contratos',
                                ],
                                [
                                    "nome" => 'Leandro Corrêa da Silva',
                                    "matricula" => '32578',
                                    "cargo" => 'Acessor Administrativo',
                                ],
                            ],
                            'collapse' => __('collapse7'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Regional (SDR)'),
                            'itens' => [
                                [
                                    "nome" => 'Hugo Marques Machado Ferreira',
                                    "matricula" => '3095',
                                    "cargo" => 'Coordenador Técnico Gestão de Contrato',
                                ],
                                [
                                    "nome" => 'Tiziana Rodrigues',
                                    "matricula" => '31641',
                                    "cargo" => 'Diretora de Departamento Administrativo',
                                ],
                            ],
                            'collapse' => __('collapse8'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Finanças (SFI)'),
                            'itens' => [
                                [
                                    "nome" => 'Mariana de Abreu Ferreira',
                                    "matricula" => '13774',
                                    "cargo" => 'Diretora Departamento de Liquidação',
                                ],
                                [
                                    "nome" => 'Claúdia Porto de Arroxellas Bragança',
                                    "matricula" => '22299',
                                    "cargo" => 'Diretora do Departamento de Tesouraria',
                                ],
                            ],
                            'collapse' => __('collapse9'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Modernização e Gestão de Pessoal (SMGP) <br> Assessoria Técna de Operação em TI (ATOP)'),
                            'itens' => [
                                [
                                    "nome" => 'Tiago Soares da Rosa',
                                    "matricula" => '19823',
                                    "cargo" => 'Diretor do Departamento de Sistemas',
                                ],
                                [
                                    "nome" => 'Isaque Soares do Brasil Luiz',
                                    "matricula" => '32766',
                                    "cargo" => 'Coordenador Técnico de Sistemas',
                                ],
                            ],
                            'collapse' => __('collapse10'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Modernização e Gestão de Pessoal (DMAP)'),
                            'itens' => [
                                [
                                    "nome" => 'Gilberto Bicalho Cardoso',
                                    "matricula" => '26292',
                                    "cargo" => 'Diretor do Departamento de Modernização da Administração Pública',
                                ],
                                [
                                    "nome" => 'Leidiane Anacleto Pinheiro Soares',
                                    "matricula" => '32564',
                                    "cargo" => 'Coordenadora-Técnica de Apoio Administrativo',
                                ],
                            ],
                            'collapse' => __('collapse11'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Agricultura, Aquicultura e Pesca (SAAP)'),
                            'itens' => [
                                [
                                    "nome" => 'Jordan Cidral Maia',
                                    "matricula" => '32588',
                                    "cargo" => 'Coordenador Técnico de Monitoramento Pesqueiro',
                                ],
                                [
                                    "nome" => 'Willys Ferreira de Araújo Júnior',
                                    "matricula" => '30153',
                                    "cargo" => 'Coordenador Técnico de Operações Agrícolas',
                                ],
                            ],
                            'collapse' => __('collapse12'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Procuradoria Geral do Município (PGM) <br> Chefe de Gabinete - Rafaela Pimenta Serrão (CHGAB)'),
                            'itens' => [
                                [
                                    "nome" => 'Brunna Correa Pinheiro da SIlva',
                                    "matricula" => '31587',
                                    "cargo" => 'Diretora do Departamento de Normas e Procedimentos',
                                ],
                                [
                                    "nome" => 'Eduarda Arruda',
                                    "matricula" => '29509',
                                    "cargo" => 'Assessora de Cooperação Institucional',
                                ],
                            ],
                            'collapse' => __('collapse13'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Educação, Juventude e Inovação (SEJIN)'),
                            'itens' => [
                                [
                                    "nome" => 'Danielle Noronha de Melo',
                                    "matricula" => '22449',
                                    "cargo" => 'Diretora Departamento de Sistemas e Políticas de Tecnologia Educacional',
                                ],
                                [
                                    "nome" => 'Ethel Dora do Amaral Duveen',
                                    "matricula" => '31787',
                                    "cargo" => 'Diretora do Departamento de Protocolo, Atendimento e Ouvidoria',
                                ],
                            ],
                            'collapse' => __('collapse14'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Serviço Autônomo de Água e Esgoto (SAAE)'),
                            'itens' => [
                                [
                                    "nome" => 'Leonardo Lopes Barbosa',
                                    "matricula" => '190379',
                                    "cargo" => 'Diretor do Departamento de Informática',
                                ],
                                [
                                    "nome" => 'Ethel Dora do Amaral Duveen',
                                    "matricula" => '31787',
                                    "cargo" => 'Diretora do Departamento de Protocolo, Atendimento e Ouvidoria',
                                ],
                            ],
                            'collapse' => __('collapse15'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Cultura e Patrimônio (SCP)'),
                            'itens' => [
                                [
                                    "nome" => 'Jefferson Affonso Soares',
                                    "matricula" => '17802',
                                    "cargo" => 'Superintendente de Gestão',
                                ],
                                [
                                    "nome" => 'Diana Soares dos Santos',
                                    "matricula" => '17023',
                                    "cargo" => 'Administrativo',
                                ],
                            ],
                            'collapse' => __('collapse16'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Regional (SDR) <BR> Secretaria Executiva do Parque Manbucaba (SEPM)'),
                            'itens' => [
                                [
                                    "nome" => 'Helena Amaral de Souza',
                                    "matricula" => '22215',
                                    "cargo" => 'Agente de Ouvidoria',
                                ],
                                [
                                    "nome" => 'Fernanda Mendes Dutra',
                                    "matricula" => '29403',
                                    "cargo" => 'Coordenador Técnico de Gestão',
                                ],
                            ],
                            'collapse' => __('collapse17'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Desenvolvimento Social e Promoção da Cidadania (SDSP.SE)'),
                            'itens' => [
                                [
                                    "nome" => 'Marcelle Jordão Fonseca Ramos',
                                    "matricula" => '29604',
                                    "cargo" => 'Coordenadora Técnica de Planejamento',
                                ],
                                [
                                    "nome" => 'Arão de assis Carrilho',
                                    "matricula" => '29548',
                                    "cargo" => 'Coordenador Técnico de Vigilância Socioassistencial',
                                ],
                            ],
                            'collapse' => __('collapse18'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Articulação Governamental (SAG)'),
                            'itens' => [
                                [
                                    "nome" => 'Taisa Monteiro',
                                    "matricula" => '',
                                    "cargo" => 'Superontendente de Articulação',
                                ],
                                [
                                    "nome" => 'João Gabriel dos Santos Xavier',
                                    "matricula" => '32635',
                                    "cargo" => 'Coordenadora Técnico de Apoio Institucional',
                                ],
                            ],
                            'collapse' => __('collapse19'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Controladoria Geral <br> Controladoria Geral do Município (CGM)'),
                            'itens' => [
                                [
                                    "nome" => 'Rodrigo Fonseca de Castro',
                                    "matricula" => '12569',
                                    "cargo" => 'Assessor Técnico de Normas e Controles',
                                ],
                                [
                                    "nome" => 'Jobson Rodrigues da Silva',
                                    "matricula" => '19706',
                                    "cargo" => 'Ramal: 1174',
                                ],
                            ],
                            'collapse' => __('collapse20'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Parcerias e Inovação Tecnológica (SPIT)'),
                            'itens' => [
                                [
                                    "nome" => 'Lorival Curtrim Gomes Neto',
                                    "matricula" => '327939',
                                    "cargo" => 'Assessor Administrativo',
                                ],
                                [
                                    "nome" => 'Odilane Rodrigues Viveiros Gonçalves',
                                    "matricula" => '32671',
                                    "cargo" => 'Coordenação Técnica de Parceirias',
                                ],
                            ],
                            'collapse' => __('collapse21'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Proteção e Defesa Civil <br> Coordenação técnico de Tecnolia da Informação (SPDC)'),
                            'itens' => [
                                [
                                    "nome" => 'Adriano Camargo de Oliveira',
                                    "matricula" => '19125',
                                    "cargo" => 'Coordenador de Depuração e Análise',
                                ],
                                [
                                    "nome" => 'Gilsilane de Oliveira Freita da Silva',
                                    "matricula" => '17946',
                                    "cargo" => 'Controle Interno',
                                ],
                            ],
                            'collapse' => __('collapse22'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Fundação de Turismo de Angra dos Reis <br> Presidência de Turismo Angra dos Reis (FTAR)'),
                            'itens' => [
                                [
                                    "nome" => 'Nilton Júdice Portugal',
                                    "matricula" => '3500288',
                                    "cargo" => 'Assessor de Marketing Turístico Administrativo',
                                ],
                                [
                                    "nome" => 'Odilane Rodrigues Viveiros Gonçalves',
                                    "matricula" => '3500290',
                                    "cargo" => 'Coordenação Técnica de Atividades Administrarivas Financeiras',
                                ],
                            ],
                            'collapse' => __('collapse23'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Instituto municipal do ambiente de Angra dos Reis (IMAAR)'),
                            'itens' => [
                                [
                                    "nome" => 'Rômulo Marques Carvalho',
                                    "matricula" => '32238',
                                    "cargo" => 'Arquiteto',
                                ],
                                [
                                    "nome" => 'Andresa Maria Azevedo da Silva',
                                    "matricula" => '3400033',
                                    "cargo" => 'Coordenadora Técnica de licenciamento Urbanísmo',
                                ],
                            ],
                            'collapse' => __('collapse24'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Cultura e Patrimônio <br> Secretário Executivo de Gestão Cultural (SCP.SEGC)'),
                            'itens' => [
                                [
                                    "nome" => 'Samuel Teodoro Ferreira',
                                    "matricula" => '22161',
                                    "cargo" => 'Coordenador de Gestão de Eventos',
                                ],
                                [
                                    "nome" => 'Cristina Aparecida dos Santos Martins',
                                    "matricula" => '17669',
                                    "cargo" => 'Coordenadora de Gestão de Pessoal',
                                ],
                            ],
                            'collapse' => __('collapse25'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria Extraordinária de Infraestrutura (SEINF)'),
                            'itens' => [
                                [
                                    "nome" => 'Carlos José Maia da Rocha',
                                    "matricula" => '33141',
                                    "cargo" => 'Assessor de Controle Interno',
                                ],
                                [
                                    "nome" => 'Danilo Nunes Ferreira de Alencar',
                                    "matricula" => '32716',
                                    "cargo" => 'Coordenador Técnico de Controle',
                                ],
                            ],
                            'collapse' => __('collapse26'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Educação, Juventude e Inovação (SEJIN) <br> Secretaria Executivo da Juventude (SEJUV)'),
                            'itens' => [
                                [
                                    "nome" => 'Jackson Barbosa Leal',
                                    "matricula" => '33130',
                                    "cargo" => 'Acessor Técnico de Novas Oportunidades',
                                ],
                                [
                                    "nome" => 'André Alexandre Santos',
                                    "matricula" => '33127',
                                    "cargo" => 'Coordenador Técnico de programas continuados',
                                ],
                            ],
                            'collapse' => __('collapse27'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Instituto de Previdência Social de Angra dos Reis (ANGRAPREV)'),
                            'itens' => [
                                [
                                    "nome" => 'Paulo Henrique da Silva Bulé',
                                    "matricula" => '17345',
                                    "cargo" => 'Chefe de Gabinete',
                                ],
                                [
                                    "nome" => 'Camile Gomes Dourado',
                                    "matricula" => '2500275',
                                    "cargo" => 'Coordenação de TI',
                                ],
                            ],
                            'collapse' => __('collapse28'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Segurança Pública (SSP) <br> Secretaria Executiva de Ordem Publica e mobilidade de Urbana (SEOPM)'),
                            'itens' => [
                                [
                                    "nome" => 'Marcel Araújo Carneiro',
                                    "matricula" => '20399',
                                    "cargo" => 'Superintendente de Mobilidade Urbana e TRansportes Concedidos',
                                ],
                                [
                                    "nome" => 'Igor ods Santos Talyuli Vieira',
                                    "matricula" => '11762',
                                    "cargo" => 'Virgilante Patrimonial',
                                ],
                            ],
                            'collapse' => __('collapse29'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Obras e Habitção (SOH)'),
                            'itens' => [
                                [
                                    "nome" => 'Gustavo da Silva Marinho',
                                    "matricula" => '32752',
                                    "cargo" => 'Coordenador Técnico de Obras',
                                ],
                                [
                                    "nome" => 'Gilson César Alves de Oliveira',
                                    "matricula" => '10375',
                                    "cargo" => 'Assessoria Técnica de Manutenção de Patrimônio Histórico',
                                ],
                            ],
                            'collapse' => __('collapse30'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Planejamento e Gestão (SPG)'),
                            'itens' => [
                                [
                                    "nome" => 'Rodolfo Bontempo',
                                    "matricula" => '33110',
                                    "cargo" => 'Super entendente de Transformação Digital',
                                ],
                                [
                                    "nome" => 'Rogério Pontes',
                                    "matricula" => '28934',
                                    "cargo" => 'Acessor Técnico de Inovação Tecnológica',
                                ],
                            ],
                            'collapse' => __('collapse31'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Saúde (SSA) <BR> Secretaria Executiva de Atenção Primária (SEAPR)'),
                            'itens' => [
                                [
                                    "nome" => 'Janser Leandro Cardoso de Bulhões Correa',
                                    "matricula" => '32695',
                                    "cargo" => '',
                                ],
                                [
                                    "nome" => 'Livia Rodrigues Pereira',
                                    "matricula" => '4502944',
                                    "cargo" => '',
                                ],
                            ],
                            'collapse' => __('collapse32'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Saúde <br> Secretario-Executivo Hospitalar (SSA.SEHMJ)'),
                            'itens' => [
                                [
                                    "nome" => 'Rodrigo de Campos Camões',
                                    "matricula" => '3320',
                                    "cargo" => 'Coordenador de TI',
                                ],
                                [
                                    "nome" => 'Leandro Oliveira Campos',
                                    "matricula" => '32750',
                                    "cargo" => 'Superintendente Geral Hospitalar',
                                ],
                            ],
                            'collapse' => __('collapse33'),
                            'TF' => __('false'),
                        ],
                        [
                            'Titulo' => __('Secretaria de Planejamento e Gestão (SPG)'),
                            'itens' => [
                                [
                                    "nome" => 'Maria da Fonseca Ornelas de Azevedo',
                                    "matricula" => '32557',
                                    "cargo" => '',
                                ],
                                [
                                    "nome" => 'Raissa do Naiscimento Silvestre',
                                    "matricula" => '30043',
                                    "cargo" => '',
                                ],
                            ],
                            'collapse' => __('collapse34'),
                            'TF' => __('false'),
                        ],
                    ];

                    ?>
                    
                    <?php $__empty_1 = true; $__currentLoopData = $array_accordion; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $accordion): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                        <?php echo $__env->make('components/lists/_divAccordionCmgd', $accordion, array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
                        <p>Nenhum item encontrado.</p>
                    <?php endif; ?>
                        
                </div>
            </div>
        </div>
    </div>
</section><?php /**PATH /var/www/html/portal/resources/views/cmgd/accordion.blade.php ENDPATH**/ ?>