@once
    @push('scripts')
        <link rel="stylesheet" href="{{ asset('pmar/css/observatorio-admin.css') }}">
        <script src="{{ asset('pmar/js/observatorio-admin.js') }}"></script>
    @endpush
@endonce
