@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Castração Animal - Lista de Raças')

@section('content')


    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-paw'></i> Castração Animal <i class='fa-solid fa-dog'></i> Lista de Raças"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
            'routeBackParams' => [],
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.meioAmbiente.castracaoAnimal.racas.create',
            'routeAddParams' => [],
            'nameAdd' => __('Nova raça'),
            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
        ])


        <div class="card-body">

           @include("errors.messageFlash")
            
            <div class="mb-3">
                <span class="badge bg-primary fs-6"> {!! $totalRaca !!} </span>
            </div>

            @include('components/forms/_filtroPesquisaDefault', [
                "id" => "cadastroDeRaca",
                "placeholder" => "Pesquisar por raça..."
            ])
            
            <strong>Braquicefálicos</strong> <small>são animais (cães, gatos, etc.) com crânios curtos e largos, resultando em focinhos achatados</small>

            <x-tables._table :thead="['Criado em','Nome', 'Espécie', 'Tipo', 'Status', 'Ações']" :pagination="$racas->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                            @foreach($racas as $raca)
                        <tr>
                            <td>{{ date("d/m/Y H:i", strtotime($raca->created_at)) }}</td>
                            <td>
                                {{ $raca->nome }}
                            </td>
                            <td>
                                {{ $raca->especie }}
                            </td>
                            <td>
                                @if($raca->is_braquicefalico)
                                    <strong>Braquicefálicos</strong>
                                @else 
                                    ---
                                @endif
                            </td>
                            <td class="text-center align-middle">
                                @include('components.buttons._status', [
                                    "index" => $index,
                                    "route" => "admin.meioAmbiente.castracaoAnimal.racas.status",
                                    "id" => $raca->id,
                                    "status" => $raca->status,
                                    "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                ])
                            </td>
                            <td>
                                <div class="d-flex gap-2 justify-content-center">

                                    @include('components.buttons._editButton', [
                                            "route" => "admin.meioAmbiente.castracaoAnimal.racas.edit",
                                            "id" => $raca->id,
                                            "title" => "Editar",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                    @include('components.buttons._deleteButton', [
                                            "message" => __("* Esta raça será excluída e esta ação não poderá ser desfeita, deseja continuar?"),
                                            "route" => "admin.meioAmbiente.castracaoAnimal.racas.destroy",
                                            "id" => $raca->id,
                                            "title" => "Excluir",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                </div>

                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>  

        </div>
    </div>
@endsection