@if(isset($htmls) && $htmls->count() > 0)
    <div class="col-12 mb-3">
        <div class="row d-flex flex-column align-items-center">
            <div class="col">
                <div class="card-slug">
                    <h2 class="slug-telefone">{{ __("Serviços") }}</h2>

                    <ul id="telefones-container" class="list-unstyled">

                        @foreach($htmls as $html)

                            <h5 class="slug-summary mt-3">
                                <i class="fa-solid fa-screwdriver-wrench" style="color: #94ff28;"></i>
                                <a class="text-dark text-decoration-none tel-number" href="{{ url("servicos/".$html->slug) }}" alt="{{ $html->title }}" title="{{ $html->title }}">
                                    {{ $html->title }}
                                </a>
                            </h5>
                            <ul class="list-unstyled">
                                <li>
                                    <small>{!! $html->summary !!}</small>
                                </li>
                            </ul>
                        @endforeach
                    </ul>

                </div>
            </div>
        </div>
    </div>
@endif
