@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Sobre a Cidade de Angra dos Reis")
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <div class="col-sm-12 col-md-8">
                    <hr/>
                    <div class="col-12">
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route("paginas.home") }}">Portal</a>
                                </li>
                                <li class="breadcrumb-item active" aria-current="page">Sobre a Cidade de Angra dos Reis</li>
                            </ol>
                        </nav>
                    </div>
                    <h1>Sobre a Cidade de Angra dos Reis</h1>
                    <hr/>
                    <article>
                        <h3>História</h3>
                        <p>Angra dos Reis foi descoberta pelo navegador Gonçalo Coelho no dia 6 de janeiro de 1502. Como era dia dos Reis Magos, recebeu este nome devido a enorme angra pontilhada de ilhas paradisíacas, montanhas, rios e florestas, além de um mar profundamente azul.</p>
                        <p>Bem antes, os índios tamoios já desfrutavam de toda a beleza do lugar. A abundância de recursos naturais e sua exuberante paisagem certamente atraíram os primeiros colonizadores.</p>
                        <p>Sua localização geográfica, propícia ao corso, atraiu piratas de várias nacionalidades, algum tempo depois. A primeira colonização foi feita no continente, em 1530, por uma expedição a mando da Coroa de Portugal. Somente em 1556 chegaram os colonizadores, vindos dos Açores, que criaram um povoado ao se fixarem na enseada.</p>
                        <p>Em 1608, tornou-se Vila dos Reis Magos da Ilha Grande.</p>
                        <p>A primeira atividade econômica de Angra foi a cultura da cana-de-açúcar, além de servir de parada no trajeto entre Santos e Rio de Janeiro. Depois, exportando e importando os produtos de Minas Gerais e São Paulo, chegou a ser um dos maiores portos do Brasil. Na época do império, Angra conheceu um grande apogeu, durante o ciclo do café.</p>
                        <p>Nos fins do século, porém, abriu-se à estrada de ferro São Paulo-Rio, terminando com as vantagens que Angra oferecia às comunicações entre as duas cidades. Logo depois, em 1888, a abolição da escravatura acabou com a mão-de-obra essencial para a agricultura: o município parou. Só meio século depois, com o estabelecimento de uma estrada de ferro para Minas Gerais e a reativação do porto, Angra voltou a crescer.</p>
                        <p>Mas somente na década de 60, com a instalação do Estaleiro da Verolme, a cidade volta a ter uma economia mais expressiva. Logo depois, foram instalados no município a Usina Nuclear de Furnas e o Terminal da Petrobrás.</p>
                        <h3>Formação Administrativa</h3>
                        <p>Freguesia criada com a denominação de Ilha Grande, em 1593.</p>
                        <p>Elevado à categoria de vila com a denominaçào de Ilha Grande, em 1608. Instalado em 02-10-1624.</p>
                        <p>Elevado à condição de cidade e sede do município com a denominação de Angra dos Reis, pela Lei Provincial n.° 6, de 28-03-1835.</p>
                        <p>O distrito do mesmo nome teve confirmada sua criação, pelos Decretos Estaduais n.ºs 1 e 1-A, de 09-05-1892 e 03-06-1892, respectivamente.</p>
                        <p>Em divisão administrativa referente ao ano de 1911, o município aparece com 6 distritos: Angra dos Reis, Ilha Grande, Jacuecanga, Mambucaba, Ribeira e Matariz.</p>
                        <p>Assim permanecendo em divisão administrativa de 1933.</p>
                        <p>Assim permanecendo em divisões territoriais datadas de 31-XII-1936 e 31-XII-1937.</p>
                        <p>Pelo Decreto-lei n.º 392-A, de 31-03-1938, distrito de Ilha Grande passou a denominar-se Abraão.</p>
                        <p>No quadro fixado para vigorar no período de 1939-1943, o município é constituído de 6 distritos: Angra dos Reis, Abraão, Jacuecanga, Mambucaba, Ribeira e Matriz.</p>
                        <p>Pelo Decreto-lei Estadual n.° 1.056, de 31-12-1943, o distrito de Ribeira passou a denominar-se Frade que passou a denominar-se Cunhambebe. Sob a mesma lei acima citada, o distrito de Mataraiz passoua denominar-se Praia de Araçatiba.</p>
                        <p>Em divisão territorial datada de I-VII-1950, o município é constituído de 6 distritos: Angra dos Reis, Abraão, Cunhambebe, Jacuecanga, Mambucaba e Praia de Araçatiba (ex-Mataraiz).</p>
                        <p>Assim permanecendo em divisão territorial datada de 1-VII-1960.</p>
                        <p>Em divisão territorial datada de I-I-1979, teve as áreas urbanas dos distritos: Angra dos Reis, Abraão, Jacuecanga, Mambucaba, Cunhambebe e Praia de Araçatiba, delimitadas pela Lei Municipal n.º 144, de 30-12- 1981.</p>
                        <p>Em divisão territorial datada de 18-XIII-1988, é constituído de 6 distritos: Angra dos Reis, Abraão, Cunhambebe, Jacuecanga, Mambucaba, e Praia de Araçatiba.</p>
                        <p>Assim permanecendo em divisão territorial datada de 2007.</p>
                        <h3>Fonte</h3>
                        <p><small><a href="https://cidades.ibge.gov.br/brasil/rj/angra-dos-reis/historico" target="_blank">Cidades IBGE</a></small></p>
                    </article>
                </div>
            </div>
        </div>
    </section>
@endsection
