@if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar'])
    <a href="{{ route($route, $id) }}" class="btn btn-sm btn-warning">
        @if(isset($fontawesome))
            {!! $fontawesome !!}
        @else
            <i class="fa-solid fa-cloud-arrow-up"></i>
        @endif
    </a>
@endif