@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Editar conselho'))
@section('content')
<div class="card shadow-sm">
@php $headLine = "<i class='fa-solid fa-people-group'></i> " . __('Editar conselho'); @endphp
@include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.conselhosMunicipais.conselhos.index', 'nameBack' => __('Voltar'), 'permission' => 'GERENCIADOR_DE_CONSELHOS'])
<div class="card-body">
@include('errors.messageFlash')
<form action="{{ route('admin.conselhosMunicipais.conselhos.update', $conselho->id) }}" method="POST" enctype="multipart/form-data">@csrf @method('PUT')
@include('admin.conselhosMunicipais.conselhos._form')

@include('components.buttons._backAndSend', [
        'textBack' => __('Voltar'),
        'textSend' => __('Salvar'),
        'routeBack' => 'admin.conselhosMunicipais.conselhos.index'
    ])
</form>
</div>
</div>
@endsection
