<?php
    $end = $secretaria->endereco;
?>

<article class="org-fale-conosco-miolo">
    <section class="org-fale-conosco-section" aria-labelledby="org-fale-conosco-endereco">
        <h2 id="org-fale-conosco-endereco" class="org-fale-conosco-section__title"><?php echo e(__('Endereço físico')); ?></h2>
        <div class="org-fale-conosco-section__body">
            <?php if(filled($secretaria->address)): ?>
                <p><strong><?php echo e(__('Endereço:')); ?></strong> <?php echo e(e($secretaria->address)); ?></p>
            <?php endif; ?>
            <?php if($end): ?>
                <p><strong><?php echo e(__('Logradouro:')); ?></strong> <?php echo e(e($end->logradouro)); ?><?php echo e(filled($end->numero) ? ', '.e($end->numero) : ''); ?></p>
                <?php if(filled($end->complemento)): ?>
                    <p><strong><?php echo e(__('Complemento:')); ?></strong> <?php echo e(e($end->complemento)); ?></p>
                <?php endif; ?>
                <?php if(filled($end->bairro)): ?>
                    <p><strong><?php echo e(__('Bairro:')); ?></strong> <?php echo e(e($end->bairro)); ?></p>
                <?php endif; ?>
                <?php if(filled($end->cep)): ?>
                    <p><strong><?php echo e(__('CEP:')); ?></strong> <?php echo e(e($end->cep)); ?></p>
                <?php endif; ?>
                <?php if(filled($end->cidade) || filled($end->uf)): ?>
                    <p>
                        <strong><?php echo e(__('Cidade/UF:')); ?></strong>
                        <?php
                            $cidadeUf = trim(($end->cidade ?? '').((filled($end->cidade) && filled($end->uf)) ? ' / ' : '').($end->uf ?? ''));
                        ?>
                        <?php echo e(e($cidadeUf)); ?>

                    </p>
                <?php endif; ?>
            <?php endif; ?>
            <?php if(!empty($mapEmbedSrc)): ?>
                <p>
                    <strong><?php echo e(__('Local:')); ?></strong>
                    <a href="<?php echo e($mapEmbedSrc); ?>" target="_blank" rel="noopener noreferrer"><?php echo e(__('Mapa')); ?></a>
                </p>
            <?php endif; ?>
            <?php if(filled($secretaria->phoneNumber)): ?>
                <p><strong><?php echo e(__('Telefones:')); ?></strong> <?php echo e(e($secretaria->phoneNumber)); ?></p>
            <?php endif; ?>
            <?php if(filled($secretaria->email1)): ?>
                <p><strong><?php echo e(__('E-mail:')); ?></strong> <a href="mailto:<?php echo e(e($secretaria->email1)); ?>"><?php echo e(e($secretaria->email1)); ?></a></p>
            <?php endif; ?>
            <?php if(filled($secretaria->email2)): ?>
                <p><strong><?php echo e(__('E-mail (2):')); ?></strong> <a href="mailto:<?php echo e(e($secretaria->email2)); ?>"><?php echo e(e($secretaria->email2)); ?></a></p>
            <?php endif; ?>
            <?php if(filled($secretaria->email3)): ?>
                <p><strong><?php echo e(__('E-mail (3):')); ?></strong> <a href="mailto:<?php echo e(e($secretaria->email3)); ?>"><?php echo e(e($secretaria->email3)); ?></a></p>
            <?php endif; ?>
            <?php if(filled($secretaria->openingHours)): ?>
                <p><strong><?php echo e(__('Horário de Funcionamento:')); ?></strong> <?php echo e(e($secretaria->openingHours)); ?></p>
            <?php endif; ?>
            <?php if(filled($secretaria->serviceHours)): ?>
                <p><strong><?php echo e(__('Horário de Atendimento:')); ?></strong> <?php echo e(e($secretaria->serviceHours)); ?></p>
            <?php endif; ?>
        </div>
    </section>

    <?php if(filled($secretaria->faleConoscoExtraInfo)): ?>
        <div
            class="org-fale-conosco-extra-info org-fale-conosco-section__body"
            role="complementary"
            aria-label="<?php echo e(__('Informações adicionais')); ?>">
            <?php echo \App\Helpers\HtmlSanitizer::sanitize($secretaria->faleConoscoExtraInfo); ?>

        </div>
    <?php endif; ?>

    <?php if(!empty($mapEmbedSrc)): ?>
        <section class="org-fale-conosco-section" aria-labelledby="org-fale-conosco-localizacao">
            <h2 id="org-fale-conosco-localizacao" class="org-fale-conosco-section__title"><?php echo e(__('Localização')); ?></h2>
            <div class="org-fale-conosco-mapa ratio ratio-21x9">
                <iframe
                    title="<?php echo e(__('Mapa de localização de :org', ['org' => $secretaria->name])); ?>"
                    src="<?php echo e($mapEmbedSrc); ?>"
                    class="border-0"
                    loading="lazy"
                    referrerpolicy="no-referrer-when-downgrade"
                    allowfullscreen></iframe>
            </div>
        </section>
    <?php endif; ?>

    <section class="org-fale-conosco-section org-fale-conosco-section--ouvidoria" aria-labelledby="org-fale-conosco-ouvidoria">
        <h2 id="org-fale-conosco-ouvidoria" class="org-fale-conosco-section__title"><?php echo e(__('Ouvidoria - Fala.BR')); ?></h2>
        <div class="org-fale-conosco-section__intro">
            <p><?php echo e(__('A Ouvidoria é um canal para você apresentar sugestões, elogios, solicitações, reclamações, denúncias e outros tipos de manifestações. No serviço público, a Ouvidoria é uma espécie de "ponte" entre você e a Administração, neste caso, a Prefeitura de Angra dos Reis.')); ?></p>
            <p><?php echo e(__('A Ouvidoria recebe as manifestações dos cidadãos, de empresas e de entidades não-governamentais, analisa, orienta, encaminha às áreas responsáveis pelo tratamento ou apuração, responde ao manifestante e conclui a manifestação.')); ?></p>
        </div>

        <?php if (isset($component)) { $__componentOriginal09a349c188792093a22331c65e555f5c = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal09a349c188792093a22331c65e555f5c = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.org.falabr-manifestacao-grid','data' => ['items' => $falabrManifestacaoTypes]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('org.falabr-manifestacao-grid'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($falabrManifestacaoTypes)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal09a349c188792093a22331c65e555f5c)): ?>
<?php $attributes = $__attributesOriginal09a349c188792093a22331c65e555f5c; ?>
<?php unset($__attributesOriginal09a349c188792093a22331c65e555f5c); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal09a349c188792093a22331c65e555f5c)): ?>
<?php $component = $__componentOriginal09a349c188792093a22331c65e555f5c; ?>
<?php unset($__componentOriginal09a349c188792093a22331c65e555f5c); ?>
<?php endif; ?>

        <p class="org-falabr-footer-link">
            <strong><?php echo e(__('Ainda está com dúvidas?')); ?></strong>
            <?php echo e(__('Saiba mais sobre a')); ?>

            <a href="<?php echo e($ouvidoriaInfoUrl); ?>" target="_blank" rel="noopener noreferrer" class="fw-semibold text-decoration-none">
                <?php echo e(__('Ouvidoria Externa - Fala.BR')); ?>

                <img src="<?php echo e(asset('pmar/assets/img/icons/falabr/falabr.png')); ?>" alt="">
            </a>
            <?php echo e(__('da Prefeitura de Angra dos Reis.')); ?>

        </p>
    </section>
</article>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/org-fale-conosco-miolo.blade.php ENDPATH**/ ?>