@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Procissão Marítima')
@section('content')
    <section class="">
        <div class="container-full">
            <div class="row-12 d-flex justify-content-center">
                <div class="col-12">
                    <img class="w-100 img-fluid" src="{{ asset('pmar/assets/img/procissao2025.png') }}">
                </div>
            </div>
        </div>
    </section>

    <section class="my-5">
        <div class="container">
            <div class="row">
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Secretaria de Eventos</li>
                        </ol>
                    </nav>
                </div>
            </div>
            <div class="row">
                <div class="col-12">
                    <p>
                        As inscrições para a <strong>46ª Procissão Marítima de Angra dos Reis</strong> foram abertas hoje
                        (10) e vão até às 12h do dia 23 de dezembro. A tradicional festa no mar acontece sempre em 1º de
                        janeiro e reúne dezenas de embarcações para dar as boas-vindas ao novo ano.
                        <br><br>
                        A premiação desta edição vai ultrapassar R$ 80 mil e será dividida entre quatro categorias, com
                        destaque para o prêmio destinado às embarcações de menor porte.
                    </p>
                </div>

                <div class="col-12">
                    <ul>
                        <li>
                            <a class="fs-5" target="_blank"
                                href="https://angra.rj.gov.br/downloads/SEV/Procissao2025/Regulamento-46-Procissao-Maritima.pdf"><i
                                    class="fa-solid fa-download"></i> Regulamento - Procissão Marítima 2025</a>
                        </li>
                        <li>
                            <a class="fs-5" target="_blank"
                                href="https://angra.rj.gov.br/downloads/SEV/Procissao2025/Anexo-I_Ficha-de-Inscricao.pdf"><i
                                    class="fa-solid fa-download"></i> Anexo I - Ficha de Inscrição</a>
                        </li>
                    </ul>
                </div>

                <div class="col-12 mt-4">
                    <h2 class="text-primary">Premiações</h2>
                    <p>
                        Para a categoria Alegoria, a Procissão Marítima 2025 oferecerá as seguintes premiações: 1º lugar: R$
                        12.000,00 e troféu, 2º lugar: R$ 10.000,00 e troféu e 3º lugar: R$ 8.000,00 e troféu.

                        <br><br>

                        Na categoria Animação, conhecida como Prêmio Márcio da Fla Angra, os prêmios serão distribuídos da
                        seguinte forma: 1º lugar: R$ 10.000,00 e troféu, 2º lugar: R$ 8.000,00 e troféu e 3º lugar: R$
                        6.000,00 e troféu.

                        <br><br>

                        A categoria Originalidade apresenta as seguintes premiações: 1º lugar: R$ 8.000,00 e troféu, 2º
                        lugar: R$ 6.000,00 e troféu e 3º lugar: R$ 4.000,00 e troféu.

                        <br><br>

                        Já na categoria Lancha, as premiações serão distribuídas da seguinte maneira: 1º lugar: R$ 6.000,00
                        e troféu e 2º lugar: R$ 4.000,00 e troféu.
                    </p>
                </div>
            </div>
        </div>
    </section>
@endsection
