@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Novo Credenciamento'))
@section('content')

    <div class="card shadow">
        @php $headLine = "<i class='fa-solid fa-guitar'></i> " . __('Novo Credenciamento'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.cultura.credenciamentoMusicos.perfil.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_CONTA_ANGRA',
        ])

        <div class="card-body">
            @include('errors.messageFlash')

            <p class="mb-4">{{ __('Selecione o tipo de pessoa para este credenciamento:') }}</p>

            <form action="{{ route('admin.cultura.credenciamentoMusicos.perfil.storeNovo') }}" method="post" class="row g-3">
                @csrf
                <div class="col-12">
                    <div class="form-check">
                        <input class="form-check-input" type="radio" name="tipo_pessoa" id="tipo_pf" value="PF" checked>
                        <label class="form-check-label" for="tipo_pf">{{ __('Pessoa Física (CPF)') }}</label>
                    </div>
                    <div class="form-check">
                        <input class="form-check-input" type="radio" name="tipo_pessoa" id="tipo_pj" value="PJ">
                        <label class="form-check-label" for="tipo_pj">{{ __('Pessoa Jurídica (CNPJ) – banda, grupo ou produtora') }}</label>
                    </div>
                </div>
                <div class="col-12">
                    <button type="submit" class="btn btn-primary">{{ __('Criar Credenciamento') }}</button>
                </div>
            </form>
        </div>
    </div>

@endsection
