<div class="container">
    <div class="row gx-4 gx-lg-5 gy-4">
        <section class="internas-secretarias-home-news org-secretarias-news col-12 col-lg-9 col-md-9 order-1">
            @include('paginas.parts.org-news-grid')
        </section>

        <section class="internas-secretarias-home-aside col-12 col-lg-3 col-md-3 mt-4 mt-lg-0 order-2">
            @include('paginas.parts.links')
            @include('paginas.parts.servicos')
            @include('paginas.parts.telefones')
        </section>
    </div>
</div>
@include('paginas.parts.secretario')
