@props([
    'boletim' => null,
    'class' => 'small link-primary',
])

@if ($boletim && $boletim->nr_bo !== '-')
    @if ($boletim->public_bo_pdf_url)
        <a href="{{ $boletim->public_bo_pdf_url }}"
            target="_blank"
            rel="noopener noreferrer"
            @class([$class])
            title="{{ __('Abrir Boletim Oficial nº :numero', ['numero' => $boletim->nr_bo]) }}">
            {{ $boletim->nr_bo }}
        </a>
    @else
        <span @class([$class, 'text-muted'])>{{ $boletim->nr_bo }}</span>
    @endif
@else
    <span class="text-muted">—</span>
@endif
