@extends('layouts.landing_pages.carnaval2025.theme')
@section("title", "Carnaval 2025 em Angra dos Reis")
@section('content')
    <!-- Container para os confetes -->
    <canvas id="confettiCanvas"></canvas>


    <section class="container text-center my-5">
        <div class="row d-flex flex-column flex-md-row align-items-center">
            <div class="col-lg-4 col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-start">
                    <div class="date-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 300 100" preserveAspectRatio="xMidYMid slice"
                            xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="Camada_x0020_1">
                                <path class="fill-amarela"
                                    d="M7.22 34.5l167.77 -15.47c0.66,-0.06 1.22,-0.02 1.87,0.14l75.21 18.57c0.87,0.21 1.64,0.23 2.51,0.04l31.79 -6.66c1.83,-0.38 3.52,0.07 5.03,1.37 1.52,1.29 2.44,3.05 2.76,5.26l4.74 33.53c0.63,4.4 -1.83,8.6 -5.48,9.36l-39.26 8.23c-0.87,0.18 -1.64,0.17 -2.5,-0.04l-77.11 -19.04c-0.65,-0.16 -1.21,-0.21 -1.87,-0.15l-162.34 14.98c-1.85,0.17 -3.49,-0.48 -4.9,-1.94 -1.41,-1.46 -2.19,-3.32 -2.33,-5.55l-2.09 -33.93c-0.28,-4.46 2.51,-8.36 6.2,-8.7z" />
                            </g>
                        </svg>
                        <div class="date-title-top">
                            26 FEV <span>QUARTA-FEIRA</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-amarela">16H30</span>
                            <strong>BLOCO DO SOCIAL</strong><br>
                            <span>"É DIREITO VIVER SEM PRECONCEITO"</span>
                            <span class="concentracao">Concentração: Praça Guarda Marinha Greenhalgh – </span>
                            <strong class="bairro">São Bento</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-amarela">19H</span>
                            <strong>BLOCO DA FELIZ IDADE</strong><br>
                            <span class="concentracao">Concentração: Cruzeiro (rua do Convento São Bernardino de
                                Sena) –
                          </span>
                            <strong class="bairro">Centro</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-amarela">20H</span>
                            <strong>BLOCO DOS ARTISTAS</strong><br>
                            <span class="concentracao">Concentração: Praça Guarda-marinha Greenhalgh – </span>
                            <strong class="bairro">São Bento</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-amarela">21H</span>
                            <strong>BLOCO FLA-VILLAGE</strong><br>
                            <span class="concentracao">Concentração: Rua Pereira D'eça (em frente ao Centro
                                Comercial) –
                          </span>
                            <strong class="bairro">Jacuecanga</strong>
                        </li>
                    </ul>
                </div>
            </div>

            <!-- Imagem central -->
            <div class="col-lg-4 col-md-12 d-flex justify-content-center order-0 order-lg-1 text-hover">
                <img src="{{ asset("carnaval-2025-angra/assets/img/logo.svg") }}" alt="Carnaval 2025" class="img-fluid central-image">
            </div>

            <div class="col-lg-4 col-md-6 order-1 order-lg-2">
                <div class="schedule-card text-start">
                    <div class="date-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 300 100" preserveAspectRatio="xMidYMid slice"
                            xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="Camada_x0020_1">
                                <path class="fill-laranja"
                                    d="M291.78 72.5l-167.77 15.47c-0.66,0.06 -1.22,0.02 -1.87,-0.14l-75.21 -18.57c-0.87,-0.22 -1.64,-0.23 -2.51,-0.05l-31.79 6.67c-1.83,0.38 -3.52,-0.08 -5.03,-1.37 -1.52,-1.29 -2.44,-3.05 -2.76,-5.26l-4.74 -33.53c-0.62,-4.4 1.83,-8.6 5.48,-9.36l39.26 -8.23c0.87,-0.19 1.64,-0.17 2.5,0.04l77.12 19.04c0.64,0.16 1.2,0.2 1.86,0.14l162.34 -14.97c1.85,-0.17 3.49,0.48 4.9,1.94 1.41,1.46 2.19,3.32 2.33,5.55l2.09 33.93c0.28,4.45 -2.5,8.36 -6.2,8.7z" />
                            </g>
                        </svg>
                        <div class="mt-2 date-title-top">
                            27 FEV <span>QUINTA-FEIRA</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-laranja">17H</span>
                            <strong>BLOCO DOS FAZEDORES DE CULTURA DO ABRAÃO</strong><br>
                            <span class="concentracao">Concentração: Em frente à Casa de Cultura Constantino Cokotós
                                –
                          </span>
                            <strong class="bairro">Ilha Grande</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">18H30</span>
                            <strong>BLOCO ESQUENTA DO RITMO QUENTE</strong><br>
                            <span class="concentracao">Concentração: Praça do bairro – </span>
                            <strong class="bairro">Nova Angra</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">20H</span>
                            <strong>BLOCO DO GODOFREDO</strong><br>
                            <span class="concentracao">Concentração: Rua das Flores – </span>
                            <strong class="bairro">Vila Histórica de Mambucaba</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">20H</span>
                            <strong>BLOCO REVOADA</strong><br>
                            <span class="concentracao">Concentração: Praça General Osório – </span>
                            <strong class="bairro">Centro</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">21H</span>
                            <strong>BLOCO DA NEGA</strong><br>
                            <span class="concentracao">Concentração: Praça Chefe Cotta – </span>
                            <strong class="bairro">São Bento</strong>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">23H</span>
                            <strong>BLOCO ELETRO FOLIA</strong><br>
                            <span class="concentracao">Concentração: Praça General Osório – </span>
                            <strong class="bairro">Centro</strong>
                        </li>
                    </ul>

                    <ul>
                    </ul>
                </div>
            </div>
    </section>

    <section class="container text-center mb-5">
        <div class="row d-flex flex-column flex-md-row align-items-center">
            <div class="col-12">
                <div class="schedule-card p-4 text-start">
                    <div class="banner-padrao title-hover  banner-28">
                        <div class="date-title date-title-alto">
                            28 FEV <span>SEXTA-FEIRA</span>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-rosa">17H</span>
                                    <strong>BLOCO LGBTQIA+</strong><br>
                                    <span class="concentracao">Concentração: Praça José Pimenta – </span>
                                    <strong class="bairro">Japuíba</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">18H</span>
                                    <strong>BLOCO CALMA CALMA SUA PIRANHA</strong><br>
                                    <span class="concentracao">Concentração: Avenida Beira-Mar (em frente à academia
                                        do
                                        Zé Capoeira) – </span>
                                    <strong class="bairro">Bracuí</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">19H</span>
                                    <strong>BLOCO CARNAVALESCO COMUNIDADE DA CAVA</strong><br>
                                    <span class="concentracao">Concentração: Rua Moacyr de Paula Lobo (Rua da
                                        Palmeiras)
                                        – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">19H</span>
                                    <strong>BLOCO SUJOS DE LAMA</strong><br>
                                    <span class="concentracao">Concentração: Rua Barra Mansa (em frente à empresa
                                        Senhor
                                        Bonfim) – </span>
                                    <strong class="bairro">Japuíba</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-rosa">20H</span>
                                    <strong>BLOCO PEZINHO INCHADO</strong><br>
                                    <span class="concentracao">Concentração: Rua dos Suspiros (em frente à pizzaria
                                        Bhering) – </span>
                                    <strong class="bairro">Campo Belo</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">20H</span>
                                    <strong>BLOCO DA IMPRENSA</strong><br>
                                    <span class="concentracao">Concentração: Praça Zumbi dos Palmares – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">20H</span>
                                    <strong>BLOCO 6 DE JANEIRO</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">22H</span>
                                    <strong>BLOCO CAPRICHOSOS DA VILA</strong><br>
                                    <span class="concentracao">Concentração: Praça da Francisco Magalhães de Castro,
                                        ao
                                        lado da creche municipal – </span>
                                    <strong class="bairro">Parque Mambucaba</strong>
                                </li>
                            </ul>

                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-rosa">22H</span>
                                    <strong>BLOCO FURIOSA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-rosa">22H30</span>
                                    <strong>BLOCO DA NAÇÃO URUBUZADA</strong><br>
                                    <span class="concentracao">Concentração: Monumento dos Três Reis Magos – </span>
                                    <strong class="bairro">Praia do Anil</strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-12">
                <div class="schedule-card p-4 text-start">
                    <div class="banner-padrao title-hover  banner-01">
                        <div class="date-title date-title-baixo">
                            1 MAR <span>SABADO</span>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">14H</span>
                                    <strong>BLOCO UNIÃO UNIVERSITÁRIA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">14H</span>
                                    <strong>BLOCO UNIDOS DO CAMORIM</strong><br>
                                    <span class="concentracao">Concentração: Rua da Pedreira – </span>
                                    <strong class="bairro">Camorim</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">17H</span>
                                    <strong>ACADÊMICOS DAS ROLAS E DAS PIRIQUITAS CANSADAS DO BONFIM</strong><br>
                                    <span class="concentracao">Concentração: Portaria do Condomínio Refúgio do
                                        Corsário
                                        – </span>
                                    <strong class="bairro">Bonfim</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">18H</span>
                                    <strong>BLOCO DO REIZINHO MIRIM</strong><br>
                                    <span class="concentracao">Concentração: Rua Moacyr de Paula Lobo (Rua da
                                        Palmeiras)
                                        – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">18H30</span>
                                    <strong>BLOCO DAS PIRANHAS LOUCAS DO CARMO</strong><br>
                                    <span class="concentracao">Concentração: Praça 6 de Janeiro – </span>
                                    <strong class="bairro">Morro do Carmo</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">19H</span>
                                    <strong>BLOCO UNIDOS DA PORTELINHA</strong><br>
                                    <span class="concentracao">Concentração: Praça 6 de Janeiro – </span>
                                    <strong class="bairro">Morro do Carmo</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">19H</span>
                                    <strong>BLOCO ME CONECTA QUE EU VOU</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">20H</span>
                                    <strong>BLOCO ACADÊMICOS DO CARAVELAS</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">20H</span>
                                    <strong>BLOCO DA VÓ NINA</strong><br>
                                    <span class="concentracao">Concentração: Rua do Maneco – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">21H</span>
                                    <strong>BLOCO PAREI DE BEBER E NÃO DE MENTIR</strong><br>
                                    <span class="concentracao">Concentração: Ao lado do Campo de Futebol – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">21H30</span>
                                    <strong>BLOCO UNIDOS DA PAZ</strong><br>
                                    <span class="concentracao">Concentração: Avenida Bom Jesus (em frente à padaria
                                        do
                                        Jorge) – </span>
                                    <strong class="bairro">Belém</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">21H30</span>
                                    <strong>BLOCO DA MALHAÇÃO DA FORTALEZA</strong><br>
                                    <span class="concentracao">Concentração: Rua Prefeito João Gregório Galindo, em
                                        frente à Uniscap – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">22H</span>
                                    <strong>BLOCO DO ENCRUZO</strong><br>
                                    <span class="concentracao">Concentração: Bica D' Água, na Estrada Vereador
                                        Benedito
                                        Adelino – </span>
                                    <strong class="bairro">Encruzo da Enseada</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">22H</span>
                                    <strong>BLOCO KI MERDA É ESSA?</strong><br>
                                    <span class="concentracao">Concentração: Rua Moacyr de Paula Lobo (Rua da
                                        Palmeiras)
                                        – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">23H</span>
                                    <strong>BLOCO TÔA TÔA</strong><br>
                                    <span class="concentracao">Concentração: Monumento dos Três Reis Magos – </span>
                                    <strong class="bairro">Praia do Anil</strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-12">
                <div class="schedule-card p-4 text-start">
                    <div class="banner-padrao title-hover  banner-02">
                        <div class="date-title date-title-alto">
                            2 MAR <span>DOMINGO</span>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-laranja">13H</span>
                                    <strong>BLOCO DAS PIRANHAS DO FRADE</strong><br>
                                    <span class="concentracao">Concentração: Calçadão da praia – </span>
                                    <strong class="bairro">Frade</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">14H</span>
                                    <strong>BLOCO DA PAZ</strong><br>
                                    <span class="concentracao">Concentração: Início da rua Francisco Jerônimo –
                                  </span>
                                    <strong class="bairro">Ariró</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">14H</span>
                                    <strong>PIRANHAS DO CENTRO</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">15H</span>
                                    <strong>BLOCO DA FOFOCA</strong><br>
                                    <span class="concentracao">Concentração: Pousada Gabriel Praia de Araçatiba –
                                  </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">15H30</span>
                                    <strong>BLOCO ENCONTRO DAS ANTIGAS</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">15H30</span>
                                    <strong>BLOCO GORÓ BELEZA</strong><br>
                                    <span class="concentracao">Concentração: Praça Chefe Cotta – </span>
                                    <strong class="bairro">São Bento</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">16H</span>
                                    <strong>BLOCO FURDUNÇO DA MADRASTA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">16H</span>
                                    <strong>BLOCO UNIDOS DO BONFIM</strong><br>
                                    <span class="concentracao">Concentração: Praia do Bonfim – </span>
                                    <strong class="bairro">Bonfim</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-laranja">16H</span>
                                    <strong>BLOCO DO PERNETA</strong><br>
                                    <span class="concentracao">Concentração: Rua Paraíba (antes da esquina com a rua
                                        Goiás) – </span>
                                    <strong class="bairro">Bracuí</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">17H</span>
                                    <strong>BLOCO DA LUA</strong><br>
                                    <span class="concentracao">Concentração: Praça Zumbi dos Palmares – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">18H30</span>
                                    <strong>BLOCO UNIDOS DA PORTEIRA</strong><br>
                                    <span class="concentracao">Concentração: Praça José Pimenta – </span>
                                    <strong class="bairro">Japuíba</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">19H</span>
                                    <strong>BLOCO INÚTEIS DE GARATUCAIA</strong><br>
                                    <span class="concentracao">Concentração: Rua D, Condomínio de Garatucaia –
                                  </span>
                                    <strong class="bairro">Garatucaia</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">19H</span>
                                    <strong>BLOCO DOS MENDIGOS</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">19H</span>
                                    <strong>BLOCO DO REIZINHO</strong><br>
                                    <span class="concentracao">Concentração: Rua Moacyr de Paula Lobo (Rua da
                                        Palmeiras)
                                        – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">20H</span>
                                    <strong>BLOCO JACU ELÉTRICO</strong><br>
                                    <span class="concentracao">Concentração: Praça Gelsom de Souza – </span>
                                    <strong class="bairro">Jacuecanga</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-laranja">20H</span>
                                    <strong>BLOCO VEM COM TUDO</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">21H30</span>
                                    <strong>ESCORREGA SHOW</strong><br>
                                    <span class="concentracao">Concentração: Condomínio Vale da Banqueta – </span>
                                    <strong class="bairro">Banqueta</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">22H</span>
                                    <strong>BLOCO NIGHT BOYS FOLIA</strong><br>
                                    <span class="concentracao">Concentração: Monumento dos Três Reis Magos – </span>
                                    <strong class="bairro">Praia do Anil</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">22H</span>
                                    <strong>BLOCO ROSINHAS DA ILHA</strong><br>
                                    <span class="concentracao">Concentração: Rua Nagib Monteiro de Queiroz – Vila do
                                        Abraão – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-laranja">22H</span>
                                    <strong>BLOCO DO FUTEBOL DAS PIRANHAS DA MONSUABA</strong><br>
                                    <span class="concentracao">Concentração: Rua Antônio Bertholdo da Silva Jordão
                                        (Campo dos Bandeirantes) – </span>
                                    <strong class="bairro">Monsuaba</strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-12">
                <div class="schedule-card p-4 text-start">
                    <div class="banner-padrao title-hover  banner-03">
                        <div class="date-title date-title-baixo">
                            3 MAR <span>SEGUNDA-FEIRA</span>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-amarela">15H</span>
                                    <strong>BLOCO TIPO COLÔMBIA</strong><br>
                                    <span class="concentracao">Concentração: Rua João Pedro I (Rua da Pedreira) –
                                  </span>
                                    <strong class="bairro">Camorim</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">16H</span>
                                    <strong>BLOCO MUSTACHE FOLIA</strong><br>
                                    <span class="concentracao">Concentração: Praça do Rotary (Costeirinha) – </span>
                                    <strong class="bairro">São Bento</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">16H</span>
                                    <strong>BLOCO PIRANHAS DO BONFIM</strong><br>
                                    <span class="concentracao">Concentração: Praia do Bonfim – </span>
                                    <strong class="bairro">Bonfim</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">16H</span>
                                    <strong>BLOCO PEIXINHOS DO ABRAÃO</strong><br>
                                    <span class="concentracao">Concentração: Cais da Barca, Vila do Abraão – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">17H</span>
                                    <strong>BLOCO DAS PIRANHAS DO PERES</strong><br>
                                    <span class="concentracao">Concentração: Rua do Cajueiro (em frente à quadra) –
                                  </span>
                                    <strong class="bairro">Morro do Peres</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-amarela">18H</span>
                                    <strong>BLOCO DO BALNEÁRIO</strong><br>
                                    <span class="concentracao">Concentração: Praça Juiz Saragoça (quadra de
                                        esportes) –
                                  </span>
                                    <strong class="bairro">Balneário</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">18H</span>
                                    <strong>BLOCO UNIDOS DE JACUECANGA</strong><br>
                                    <span class="concentracao">Concentração: Rua Conde Maurício de Nassau (em frente
                                        ao
                                        Bar do Genecy) – </span>
                                    <strong class="bairro">Jacuecanga</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">19H</span>
                                    <strong>BLOCO CHAMEGO UNIDO BOLA DE NEVE</strong><br>
                                    <span class="concentracao">Concentração: Praça Zumbia dos Palmares – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">19H30</span>
                                    <strong>BLOCO UNS E OUTROS DE LADEIRA ABAIXO</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-amarela">20H</span>
                                    <strong>BLOCO BATUKE NUCLEAR</strong><br>
                                    <span class="concentracao">Concentração: Praça da Avenida Francisco Magalhães de
                                        Castro – </span>
                                    <strong class="bairro">Parque Mambucaba</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">20H</span>
                                    <strong>BLOCO DA CARIOCA</strong><br>
                                    <span class="concentracao">Concentração: Bica da Carioca – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">20H</span>
                                    <strong>BLOCO FLA ILHA GRANDE</strong><br>
                                    <span class="concentracao">Concentração: Campo de futebol, Vila do Abraão –
                                  </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-amarela">23H</span>
                                    <strong>BLOCO CONEXÃO BAHIA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-12">
                <div class="schedule-card p-4 text-start">
                    <div class="banner-padrao title-hover  banner-04">
                        <div class="date-title date-title-alto">
                            04 MAR <span>TERÇA-FEIRA</span>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">15H</span>
                                    <strong>BLOCO DO MARINAS</strong><br>
                                    <span class="concentracao">Concentração: Estrada do Marinas – </span>
                                    <strong class="bairro">Marinas</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">16H</span>
                                    <strong>BLOCO PIRANHAS CAMORIM</strong><br>
                                    <span class="concentracao">Concentração: Rua João Pedro I (em frente ao bar do
                                        Zé
                                        Quintino) – </span>
                                    <strong class="bairro">Camorim</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">16H</span>
                                    <strong>BLOCO SIRI GOSTOSO</strong><br>
                                    <span class="concentracao">Concentração: Praça da Itinga – </span>
                                    <strong class="bairro">Itinga</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">17H</span>
                                    <strong>BLOCO TUDO PELA DINHA</strong><br>
                                    <span class="concentracao">Concentração: Vila do Abraão – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">17H</span>
                                    <strong>BLOCO REBOBINA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">18H</span>
                                    <strong>BLOCO CONEXÃO REQUEBRA</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">19H</span>
                                    <strong>BLOCO DO CHE</strong><br>
                                    <span class="concentracao">Concentração: Bar do Che Vila do Abraão – </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">19H30</span>
                                    <strong>MOCIDADE UNIDA DO TATU</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">20H</span>
                                    <strong>BLOCO DA JAQUEIRA</strong><br>
                                    <span class="concentracao">Concentração: Praça 6 de Janeiro – </span>
                                    <strong class="bairro">Morro do Carmo</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">21H</span>
                                    <strong>BLOCO AFRO REGGAE HOMOHEYN</strong><br>
                                    <span class="concentracao">Concentração: Showpana dos Músicos Vila do Abraão –
                                  </span>
                                    <strong class="bairro">Ilha Grande</strong>
                                </li>
                            </ul>
                        </div>

                        <div class="col-md-4">
                            <ul class="blocos-lista">
                                <li class="text-hover">
                                    <span class="hora bg-roxa">21H30</span>
                                    <strong>BLOCO QUARTA SEM LEI</strong><br>
                                    <span class="concentracao">Concentração: Praça General Osório – </span>
                                    <strong class="bairro">Centro</strong>
                                </li>
                                <li class="text-hover">
                                    <span class="hora bg-roxa">22H30</span>
                                    <strong>BLOCO GALERA DO ROCK</strong><br>
                                    <span class="concentracao">Concentração: Em frente ao Quiosque do Baiano –
                                  </span>
                                    <strong class="bairro">Praia do Anil</strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </section>

    <section class="container text-center my-5">
        <h2 class="display-6 fw-normal text-white text-hover my-5 fw-bold">
            PROGRAMAÇÃO FOLIA NOS BAIRROS
        </h2>

        <div class="row d-flex flex-column flex-md-row align-items-center">
            <div class="col-lg-4 col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-amarela"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>PARQUE</span>
                            <span class="small">MAMBUCABA</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Rua do Areal – Frente ao Marconi)</p>

                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>Wellington DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Grupo Nossa Raiz</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>Wellington DJ</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>Wellington DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Siricandeia</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>Wellington DJ</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ Pedro Henryk</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Banda Sereno</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Pedro Henryk</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">4 MAR</span> <span class="dia">TERÇA</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ Pedro Henryk</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Bryan Cantor</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Pedro Henryk</strong></div>
                        </li>
                    </ul>
                </div>
            </div>

            <!-- Imagem central -->
            <div class="col-lg-4 col-md-12 d-flex justify-content-center order-0 order-lg-1 text-hover">
                <img src="{{ asset("carnaval-2025-angra/assets/img/logo.svg") }}" alt="Carnaval 2025" class="img-fluid central-image">
            </div>

            <div class="col-lg-4 col-md-6 order-1 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-laranja"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>VILA HISTÓRICA</span>
                            <span class="small">DE MAMBUCABA</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Praia)</p>

                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-laranja"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span>
                            </div>
                            <div class="horario"><span>16h às 18h -</span> <strong>Pagode do Pablito</strong></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Jacaré</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Dyego Rezende</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Jacaré</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-laranja"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span>
                            </div>
                            <div class="horario"><span>16h às 18h -</span> <strong>Siricandeia</strong></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Timão</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Banda Sereno</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Timão</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-laranja"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span>
                            </div>
                            <div class="horario"><span>16h às 18h -</span> <strong>Dyego Rezende</strong></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Timão</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Bryan Cantor</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Timão</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-laranja"><span class="data">4 MAR</span> <span class="dia">TERÇA</span>
                            </div>
                            <div class="horario"><span>16h às 18h -</span> <strong>Banda Sol</strong></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Timão</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Grupo Nossa Raiz</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Timão</strong></div>
                        </li>
                    </ul>

                </div>
            </div>
        </div>

        <div class="row d-flex flex-column flex-md-row align-items-center">
            <div class="col-lg-4 col-md-6 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-rosa"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>FRADE</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Praça Juca Mariano)</p>
                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-rosa"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Pedro Henryk</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Pagode do Pablito</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Pedro Henryk</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-rosa"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Pedro Henryk</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Bryan Cantor</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Pedro Henryk</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-rosa"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Renathynho</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Siricandeia</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Renathynho</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-rosa"><span class="data">4 MAR</span> <span class="dia">TERÇA</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Renathynho</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Higor</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Renathynho</strong></div>
                        </li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-4 col-md-6 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-azul"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>JACUECANGA</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Praça Gelsom de Souza)</p>
                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-azul"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Spencio</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Nosso Som</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Spencio</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-azul"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Tom</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Inspirasamba</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Tom</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-azul"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ Toninho Lopes</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Agytae</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Toninho Lopes</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-azul"><span class="data">4 MAR</span> <span class="dia">TERÇA</span></div>
                            <div class="horario"><span>21h -</span> <strong>Fábio DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Pagode do Pablito</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>Fábio DJ</strong></div>
                        </li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-4 col-md-6 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-amarela"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>MONSUABA</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Praça Vereador Carlos Alberto Tavares Carneiro)</p>
                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ Juninho Magnata</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Siricandeia</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Juninho Magnata</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ Spencio</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Pagode do Pablito</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Spencio</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ André Costa</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Inspirasamba</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ André Costa</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-amarela"><span class="data">4 MAR</span> <span class="dia">TERÇA</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ Spencio</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Nosso Som</strong></div>
                            <div class="horario"><span>0h30 -</span> <strong>DJ Spencio</strong></div>
                        </li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-6 col-md-6 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-verde"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>ILHA GRANDE</span>
                            <span class="small">VILA DO ABRAÃO</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Rua da Praia)</p>
                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-verde"><span class="data">1º MAR</span> <span class="dia">SÁBADO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Raylane Mendes</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-verde"><span class="data">2 MAR</span> <span class="dia">DOMINGO</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Pakere</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-verde"><span class="data">3 MAR</span> <span class="dia">SEGUNDA</span>
                            </div>
                            <div class="horario"><span>21h -</span> <strong>DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Aglomerou</strong></div>
                        </li>

                        <li class="text-hover">
                            <div class="cor-verde"><span class="data">4 MAR</span> <span class="dia">TERÇA</span></div>
                            <div class="horario"><span>21h -</span> <strong>DJ</strong></div>
                            <div class="horario"><span>23h -</span> <strong>Marah</strong></div>
                        </li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-6 col-md-6 order-lg-2">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-verdeAgua"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span>ILHA GRANDE</span>
                            <span class="small">PRAIA DO PROVETÁ</span>
                        </div>
                    </div>
                    <p class="localizacao text-hover">(Praça Wilton Santos)</p>
                    <ul class="evento-lista">
                        <li class="text-hover">
                            <div class="cor-verdeAgua">
                                <span class="data">1º MAR</span> <span class="dia">SÁBADO</span> <br>
                                <span class="data">a</span> <br>
                                <span class="data">4 MAR</span> <span class="dia">TERÇA</span>
                            </div>
                            <div class="horario"><span>A partir das 19H -</span> <strong>Apresentação musicais com a
                                    participação da juventude do Provetá e convidados.</strong></div>
                        </li>
                    </ul>
                </div>
            </div>
    </section>

    <section class="container text-center my-5 pb-5">
        <h2 class="display-6 text-white text-hover my-5">
            <span class="fw-bold"> PROGRAMAÇÃO DE SHOWS PRAIA DO ANIL </span>
        </h2>
        <div class="row d-flex flex-column flex-md-row align-items-center">
            <div class="col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-amarela"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span class="data">1º MAR</span> <span class="dia">SÁBADO</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-amarela">23h</span>
                            <strong>Soweto</strong><br>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-amarela">0h30</span>
                            <strong>Vitinho</strong><br>
                        </li>
                    </ul>
                </div>
            </div>
            <div class="col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-laranja"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span class="data">2º MAR</span> <span class="dia">DOMINGO</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-laranja">23h</span>
                            <strong>Bateria da Império Serrano</strong><br>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-laranja">0h30</span>
                            <strong>Bokaloka</strong><br>
                        </li>
                    </ul>
                </div>
            </div>
            <div class="col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-azul"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span class="data">3º MAR</span> <span class="dia">SEGUNDA-FEIRA</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-azul">23h</span>
                            <strong>Bateria da Estação Primeira de Mangueira</strong><br>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-azul">0h30</span>
                            <strong>Naldo Benny</strong><br>
                        </li>
                    </ul>
                </div>
            </div>
            <div class="col-md-6 order-1 order-lg-0">
                <div class="schedule-card text-center">
                    <div class="bairro-banner title-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            xmlns:xodm="http://www.corel.com/coreldraw/odm/2003" xml:space="preserve" width="600px"
                            height="200px" version="1.1"
                            style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd"
                            viewBox="0 0 600 200" preserveAspectRatio="xMidYMid slice">
                            <g id="Camada_x0020_1">
                                <path class="fill-verde"
                                    d="M15.29 74.84l332.25 -24.8c1.3,-0.09 2.42,-0.03 3.7,0.23l148.94 29.76c1.72,0.34 3.24,0.36 4.96,0.07l62.96 -10.68c3.62,-0.61 6.97,0.12 9.97,2.19 3.01,2.07 5.09,4.87 5.45,8.43l9.4 91.56c0.73,7.11 -3.64,13.78 -10.86,15l-77.74 13.2c-1.73,0.29 -3.25,0.27 -4.96,-0.08l-152.71 -30.51c-1.27,-0.25 -2.39,-0.32 -3.69,-0.23l-321.48 24c-3.67,0.27 -6.92,-0.77 -9.71,-3.11 -2.78,-2.33 -4.44,-5.31 -4.6,-8.89l-4.15 -92.21c-0.32,-7.15 4.96,-13.39 12.27,-13.93z" />
                            </g>
                        </svg>
                        <div class="date-title-bairro pt-3">
                            <span class="data">4º MAR</span> <span class="dia">TERÇA-FEIRA</span>
                        </div>
                    </div>
                    <ul class="blocos-lista">
                        <li class="text-hover">
                            <span class="hora bg-verde">23h</span>
                            <strong>Intimistas</strong><br>
                        </li>
                        <li class="text-hover">
                            <span class="hora bg-verde">0h30</span>
                            <strong>Matheusinho</strong><br>
                        </li>
                    </ul>
                </div>
            </div>


        </div>
    </section>

    <footer class="container-fluid mt-5 pt-5">
        <div class="container">
            <div class="row align-items-center text-center text-md-start justify-content-between">
                <!-- Se Beber, Não Dirija -->
                <div class="col-12 col-md-3 d-flex justify-content-center justify-content-md-start mb-md-0">
                    <img src="{{ asset("carnaval-2025-angra/assets/img/nao-beba.png") }}" class="img-fluid" alt="Se beber não dirija"
                        style="max-width: 150px;">
                </div>

                <!-- Logos Centrais -->
                <div class="col-12 col-md-5 d-flex flex-wrap justify-content-center align-items-center gap-3 me-5">
                    <a href="https://angra.rj.gov.br/" target="_blank">
                        <img class="img-fluid" src="{{ asset("carnaval-2025-angra/assets/img/logo-angra-branco.png") }}" alt="Prefeitura de Angra dos Reis"
                            style="max-width: 130px; padding-top: 12px;">
                    </a>
                    <span class="text-white d-none d-lg-inline">|</span>
                    <a href="https://angra.rj.gov.br/secretarias/fundacao-de-turismo-de-angra-dos-reis" target="_blank">
                        <img class="img-fluid" src="{{ asset("carnaval-2025-angra/assets/img/logo-turisangra.png") }}"
                            alt="Fundação de Turismo de Angra dos Reis" style="max-width: 200px;">
                    </a>
                </div>

                <!-- Logo Funarj -->
                <div class="col-12 col-md-3 d-flex justify-content-center justify-content-md-end ms-2 mb-md-0">
                    <img src="{{ asset("carnaval-2025-angra/assets/img/logo-funarj.png") }}" class="img-fluid" alt="Logo Funarj" style="max-width: 290px;">
                </div>
            </div>
        </div>
    </footer>
@endsection