<?php $__env->startSection('title', 'SEI - Lives Angra dos Reis'); ?>
<?php $__env->startSection('content'); ?>
    <section class="mt-5" id="treinamento">
        <div class="container px-5">
            <div class="row mb-5 gx-5 align-items-center justify-content-center justify-content-lg-between">
                <div class="col-12">
                    <h2 class="display-4 lh-1 mb-4 text-center">Lives de Treinamento do SEI Angra dos Reis</h2>
                </div>
            </div>

            <div class="row mb-5 gx-5 align-items-center justify-content-center justify-content-lg-between">
                <div class="col-12">
                    <h3 class="display-4 lh-1">Aula 1</h3>
                    <div class=" ratio ratio-16x9">
                        <video title="Treinamento Sei - Aula 01" poster="<?php echo e(asset("sei-angra/assets/thumb.jpg")); ?>" controls="controls">
                            <source src="<?php echo e(asset("sei-angra/assets/live-sei/live-sei-1.mp4")); ?>" type="video/mp4">
                            Seu navegador não tem suporte à vídeos.
                        </video>
                    </div>
                </div>
            </div>

            <div class="row gx-5 align-items-center justify-content-center justify-content-lg-between">
                <div class="col-12">
                    <h3 class="display-4 lh-1 mb-4">Aula 2</h3>
                    <div class=" ratio ratio-16x9">
                        <video title="Treinamento Sei - Aula 02" poster="<?php echo e(asset("sei-angra/assets/thumb.jpg")); ?>" controls="controls">
                            <source src="<?php echo e(asset("sei-angra/assets/live-sei/live-sei-2.mp4")); ?>" type="video/mp4">
                            Seu navegador não tem suporte à vídeos.
                        </video>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.sei.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/sei/lives.blade.php ENDPATH**/ ?>