@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar Arquivos do Músico - Credenciamento")
@section('content')

    <div class="card shadow">

        @php $headLine = "<i class='fa-solid fa-guitar'></i> Editar Arquivos do Músico - Credenciamento"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                    ])

        <div class="card-body">

            @include('components.modal._modelProfile')

            <hr>

            <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">

                @include('components.lists._liLinkBtnNavInterna', [
                    'items' => [
                        ['class' => 'active bg-success disabled', 'hash' => 'primeiraSection', 'label' => 'Dados de Usuário'],
                        ['class' => 'active bg-success disabled', 'hash' => 'segundaSection', 'label' => 'Dados Pessoais'],
                        ['class' => 'active bg-success disabled', 'hash' => 'terceiraSection', 'label' => 'Documentos'],
                        ['class' => 'active bg-success disabled', 'hash' => 'quartaSection', 'label' => 'Endereço'],
                        ['class' => 'active bg-success disabled', 'hash' => 'quintaSection', 'label' => 'Credenciamento'],
                        ['class' => 'active bg-success disabled', 'hash' => 'sextaSection', 'label' => 'Integrantes'],
                        ['class' => 'active bg-success disabled', 'hash' => 'setimaSection', 'label' => 'Arquivos'],
                    ]
                ])

            </ul>

            <div class="tab-content">
                <div class="mb-3">
                    @if(!empty($musico->filePortfolio))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileFoto">
                            <div>
                                <a href="{{ url($musico->filePortfolio) }}" class="text-primary" download>
                                    Portfólio Artístico - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [$musico->id, "filePortfolio"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif

                    @if(!empty($musico->fileRepertorio))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileLaudo">
                            <div>
                                <a href="{{ url($musico->fileRepertorio) }}" class="text-primary" download>
                                    Repertório - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [ $musico->id, "fileRepertorio"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif

                    @if(!empty($musico->fileIntegrantes))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileRG">
                            <div>
                                <a href="{{ url($musico->fileIntegrantes) }}" class="text-primary" download>
                                    Relação de Integrantes - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [ $musico->id, "fileIntegrantes"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif

                    @if(!empty($musico->fileAnexoIV))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileCPF">
                            <div>
                                <a href="{{ url($musico->fileAnexoIV) }}" class="text-primary" download>
                                    Anexo IV - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [ $musico->id, "fileAnexoIV"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif

                    @if(!empty($musico->fileAnexoV))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileCartaoSUS">
                            <div>
                                    <a href="{{ url($musico->fileAnexoV) }}" class="text-primary" download>
                                    Anexo V - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [ $musico->id, "fileAnexoV"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif

                    @if(!empty($musico->fileAnexoVI))
                        <div class="d-flex justify-content-between align-items-center mb-2 laudo-wrapper" id="laudo-fileAnexoVI">
                            <div>
                                <a href="{{ url($musico->fileAnexoVI) }}" class="text-primary" download>
                                    Anexo VI - <small>baixar arquivo</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                            <div>
                                @include('components.buttons._deleteButton', [
                                        "message" => __("* Este arquivo será excluído do cadastro e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroyArquivo",
                                        "id" => [ $musico->id, "fileAnexoVI"],
                                        "title" => "Excluir",
                                        "fontawesome" => "<i class='fa-solid fa-trash'></i> Excluir",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                            </div>
                        </div>
                    @endif


                </div>
                <div class="mb-3">
                    <form action="{{ route('admin.cultura.credenciamentoMusicos.arquivos.update', $musico->id) }}" method="post" enctype="multipart/form-data">
                        <div class="mb-3">

                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                        <!-- Portfólio Artístico -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Portfólio Artístico",
                            "name" => "filePortfolio",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .jpg, .jpeg, .png)",
                            "accept" => 'application/pdf,image/*',
                        ])

                        </div>
                        <div class="mb-3">

                        <!-- Repertório -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Repertório",
                            "name" => "fileRepertorio",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .jpg, .jpeg, .png)",
                            "accept" => 'application/pdf,image/*',
                        ])

                        </div>
                        <div class="mb-3">

                        <!-- Relação de Integrantes (PDF/CSV/TXT) -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Relação de Integrantes",
                            "name" => "fileIntegrantes",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .csv, .txt)",
                            "accept" => 'application/pdf,text/plain,.csv',
                        ])

                        </div>
                        <div class="mb-3">

                        <!-- Anexo IV -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Anexo IV",
                            "name" => "fileAnexoIV",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .jpg, .jpeg, .png)",
                            "accept" => 'application/pdf,image/*',
                        ])

                        </div>
                        <div class="mb-3">

                        <!-- Anexo V -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Anexo V",
                            "name" => "fileAnexoV",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .jpg, .jpeg, .png)",
                            "accept" => 'application/pdf,image/*',
                        ])
                                    <i class="fa-solid fa-arrow-left-long"></i> {{ __("Anterior") }}
                                </a>
                                <button class="btn btn-primary d-inline" type="submit">
                                    <i class="fa-solid fa-user-plus"></i> {{ __("Salvar e Prosseguir") }}
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

                        <div class="mb-3">
                        <!-- Anexo VI -->
                            @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Anexo VI",
                            "name" => "fileAnexoVI",
                            "id" => null,
                            "required" => false,
                            "type" => 'file',
                            "old" => null,
                            "oninput" => null,
                            "readonly" => true,
                            "small" => "(.pdf, .jpg, .jpeg, .png)",
                            "accept" => 'application/pdf,image/*',
                        ])
                        </div>
                        </div>
                        <div class="row">
                            <div class="d-flex justify-content-between mt-4">
                                <a class="btn btn-outline-secondary" href="{{ route('admin.cultura.credenciamentoMusicos.integrantes', $musico->id) }}">
