<?php if(config('recaptcha.enabled') && in_array(Route::currentRouteName(), ['roadshow-virtual', 'index'])): ?> <script src="https://www.google.com/recaptcha/api.js?onload=onloadCallback&render=explicit" async defer type="text/x-javascript"></script> <?php endif; ?>
<script src="https://plugin.handtalk.me/web/latest/handtalk.min.js"></script>
<script>
    var ht = new HT({
            token: "7a92081e27daf17bd3b2efe277d0648c",
            avatar: "MAYA",
            pageSpeech: true,
            maxTextSize: 1000
     });
</script>

<!-- Google Map -->
<script src="https://maps.googleapis.com/maps/api/js?key=AIzaSyAkeLMlsiwzp6b3Gnaxd86lvakimwGA6UA&callback=initMap"></script>    

<script src="<?php echo e(asset('rderiscos/assets/js/script.js')); ?>"></script>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.7/dist/js/bootstrap.bundle.min.js" integrity="sha384-ndDqU0Gzau9qJ1lfW4pNLlhNTkCfHzAVBReH9diLvGRem5+R9g2FzA8ZGN954O5Q" crossorigin="anonymous"></script>
<script src="https://unpkg.com/jquery@3.7.1/dist/jquery.min.js"></script>

<?php if(Route::currentRouteName() == 'roadshow-virtual'): ?> <script src="<?php echo e(asset('assets/js/roadshowRecaptcha.js')); ?>"></script> <?php endif; ?>
<?php if(Route::currentRouteName() == 'index'): ?> <script src="<?php echo e(asset('assets/js/contatoRecaptcha.js')); ?>"></script> <?php endif; ?><?php /**PATH /var/www/html/portal/resources/views/layouts/reducaoderiscos/elements/scripts.blade.php ENDPATH**/ ?>