<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'items' => [],
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'items' => [],
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<div class="org-falabr-grid row g-3 mb-4" role="list">
    <?php $__currentLoopData = $items; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
        <div class="col-12 col-sm-6 col-lg-4 d-flex" role="listitem">
            <a href="<?php echo e($item['url']); ?>"
               target="_blank"
               rel="noopener noreferrer"
               class="org-falabr-card flex-fill"
               style="--org-falabr-bg: <?php echo e($item['bg_color']); ?>;"
               title="<?php echo e(__($item['tooltip'])); ?>"
               aria-label="<?php echo e(__($item['title'])); ?> — <?php echo e(__($item['description'])); ?>">
                <span class="org-falabr-card__icon" aria-hidden="true">
                    <img src="<?php echo e(asset($item['icon_image'])); ?>" alt="">
                </span>
                <span class="org-falabr-card__text">
                    <span class="org-falabr-card__title"><?php echo e(__($item['title'])); ?></span>
                    <span class="org-falabr-card__desc"><?php echo e(__($item['description'])); ?></span>
                </span>
            </a>
        </div>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/org/falabr-manifestacao-grid.blade.php ENDPATH**/ ?>