<?php $__env->startSection("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção"); ?>
<?php $__env->startSection('content'); ?>

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>"><?php echo e(__("Portal")); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page"><?php echo e(__("Concursos Públicos e Processos de Seleção")); ?></li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <h1><?php echo e(__("Concursos Públicos e Processos de Seleção")); ?></h1>


                    <hr>
                    <h1 class="top30">PMAR</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        <?php $__currentLoopData = $concursos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $concurso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if($concurso->id_instituicao == 1 && $concurso->cd_status == 1): ?>
                                <li>
                                    <strong><?php echo e($concurso->ds_ano); ?></strong><br>
                                    <?php echo $concurso->ds_observacao; ?>

                                    <br>
                                    <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |
				
                                    <a href="<?php echo e(route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 
                                    
                                    <a href="<?php echo e(route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Publicação</strong>
                                    </a>	
                                </li>
                            <?php endif; ?>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                    <h3>Realizados</h3>
                    <ul class="olist_normal">
                        <?php $__currentLoopData = $concursos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $concurso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if($concurso->id_instituicao == 1 && $concurso->cd_status == 2): ?>
                                <li>
                                    <strong><?php echo e($concurso->ds_ano); ?></strong><br>
                                    <?php echo $concurso->ds_observacao; ?>

                                    <br>
                                    <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |
				
                                    <a href="<?php echo e(route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 
                                    
                                    <a href="<?php echo e(route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            <?php endif; ?>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                    <h1 class="top30">ANGRAPREV</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        <?php $__currentLoopData = $concursos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $concurso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if($concurso->id_instituicao == 3 && $concurso->cd_status == 1): ?>
                                <li>
                                    <strong><?php echo e($concurso->ds_ano); ?></strong><br>
                                    <?php echo $concurso->ds_observacao; ?>

                                    <br>
                                    <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="<?php echo e(route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="<?php echo e(route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            <?php endif; ?>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                    <h1 class="top30">FUSAR</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        <?php $__currentLoopData = $concursos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $concurso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if($concurso->id_instituicao == 2 && $concurso->cd_status == 1): ?>
                                <li>
                                    <strong><?php echo e($concurso->ds_ano); ?></strong><br>
                                    <?php echo $concurso->ds_observacao; ?>

                                    <br>
                                    <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="<?php echo e(route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="<?php echo e(route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            <?php endif; ?>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                    <h3>Realizados</h3>
                    <ul class="olist_normal">
                        <?php $__currentLoopData = $concursos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $concurso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if($concurso->id_instituicao == 2 && $concurso->cd_status == 2): ?>
                                <li>
                                    <strong><?php echo e($concurso->ds_ano); ?></strong><br>
                                    <?php echo $concurso->ds_observacao; ?>

                                    <br>
                                    <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="<?php echo e(route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="<?php echo e(route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso)); ?>">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            <?php endif; ?>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                </div>
            </div>
        </div>
    </section>


<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/concursos/index.blade.php ENDPATH**/ ?>