<tr>
    <td style="background:#f7f7f7; text-align:center; padding:18px; font-size:12px; color:#aaaaaa;">
        {{ __('Prefeitura Municipal de Angra dos Reis') }}<br>
        {{ __('Este é um e-mail automático, por favor não responda.') }}
    </td>
</tr>
