<div class="col-sm-6 col-md-4 col-lg-3 mb-3">
    <div class="card my-3">
        <div class="card-body">
            <p class="card-text">
                <span class="d-inline-block w-100"><i class="fa-regular fa-user"></i> {{ $cargo }}</span>
            </p>
            <h5 class="card-title" style="font-size: 15px; height: 40px">{{ $nome }}</h5>
            <p class="card-text">
                <span class="badge badge-info fs-6 d-inline-block w-100" style="background-color: #007cbf !important"><strong>{{ __("Órgão") }}</strong>: {{ $sigla }}</span>
            </p>
            <hr>
            <p class="card-text">
                <strong>{{ __("Matrícula") }}</strong>: {{ $matricula }} <br>
            </p>
        </div>
    </div>
</div>