<?php $__env->startSection("title", env("APP_NAME") . " - Portal de Dados Abertos (API)"); ?>
<?php $__env->startSection('content'); ?>


    <div class="container mb-5">
        <div class="row">
            <div class="col-12 my-3">
                <?php echo $__env->make('servicos.parts.breadcrumb-dados-abertos', ['current' => __('Estrutura Organizacional (API)')], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </div>

            <div class="col-12 mb-1">
                <div class="col-12 mb-3">
                    <h1 class="title">Estrutura Organizacional (API)</h1>
                </div>
            </div>
        </div>
    </div>

<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/servicos/api/estruturaOrganizacional.blade.php ENDPATH**/ ?>