<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.landing_pages.boletim-meteorologico.elements.head')

<body class="fade-in">
    <header>
        @include('layouts.landing_pages.boletim-meteorologico.elements.defaultBar')
    </header>
    <main>
        @yield('content')
    </main>
    <footer class="footer-spdc">
        @include('layouts.landing_pages.boletim-meteorologico.elements.defaultFooter')
    </footer>
</body>

</html>