{{-- <footer id="footer" class="footer-pmar">
    <div class="container">
        <div class="row">
            <div
                class="col-12 col-sm-12 col-md-12 col-lg-12 col-xl-4 col-xxl-4 mb-5 d-flex justify-content-center align-items-start">
                <div class="d-flex justify-content-center align-items-start" style="cursor:pointer;"
                    onclick="window.location='https://angra.rj.gov.br/'">
                    <img src="{{ asset('assets/img/logo-angra-branco.svg') }}" alt="Prefeitura de Angra dos Reis"
                        class="footer-pmar-logo m-auto">
                </div>
            </div>
            <div class="footer-pmar-colunas col-12 col-sm-12 col-md-12 col-lg-6 col-xl-4 col-xxl-4 mb-5">
                <h5>Concessões, PPPs e Investimentos</h5>
                <ul>
                    <li>
                        <a href="https://maps.app.goo.gl/14ovbkFQAySAGb1L8" target="_blank">
                            <i class="footer-pmar-icons fa-solid fa-location-dot"></i>
                            <span>Praça Nilo Peçanha, nº 186 - Centro<br>
                                Angra dos Reis, RJ - CEP: 23900-901</span>
                        </a>
                    </li>
                    <li>
                        <a href="tel:+552433651108">
                            <i class="footer-pmar-icons fa-solid fa-phone"></i>
                            <span>Tel: +55 (24) 3365-1108</span>
                        </a>
                    </li>
                    <li>
                        <a href="tel:+552433651212">
                            <i class="footer-pmar-icons fa-solid fa-phone"></i>
                            <span>Tel: +55 (24) 3365-1212</span>
                        </a>
                    </li>
                    <li>
                        <a href="mailto:angrappp@angra.rj.gov.br" target="_blank">
                            <i class="footer-pmar-icons fa-solid fa-envelope"></i>
                            <span>angrappp@angra.rj.gov.br</span>
                        </a>
                    </li>
                </ul>
            </div>
            <div class="footer-pmar-colunas col-12 col-sm-12 col-md-12 col-lg-6 col-xl-4 col-xxl-4">
                <h5>Acompanhe, comente e compartilhe:</h5>
                <ul>
                    <li>
                        <a href="http://facebook.com/PrefeituradeAngra" target="_blank">
                            <i class="footer-pmar-icons fa-brands fa-facebook"></i>
                            <span>Curta nossa página no Facebook</span>
                        </a>
                    </li>
                    <li>
                        <a href="https://www.instagram.com/prefeituraangra" target="_blank">
                            <i class="footer-pmar-icons fa-brands fa-instagram"></i>
                            <span>Siga nosso perfil no Instagram</span>
                        </a>
                    </li>
                </ul>
                <h5 class="mt-5">Outros sites relevantes:</h5>
                <ul>
                    <li>
                        <a href="https://visite.angra.rj.gov.br/" target="_blank">
                            <i class="footer-pmar-icons fa-solid fa-sun"></i>
                            <span>Portal Visite Angra</span>
                        </a>
                    </li>
                    <li>
                        <a href="https://saaeangra.com.br/" target="_blank">
                            <i class="footer-pmar-icons fa-solid fa-droplet"></i>
                            <span>SAAE - Água e esgoto</span>
                        </a>
                    </li>
                    <li>
                        <a href="https://www.angraprev.rj.gov.br/" target="_blank">
                            <i class="footer-pmar-icons fa-solid fa-person"></i>
                            <span>Angraprev - Previdência Social</span>
                        </a>
                    </li>
                </ul>
            </div>
        </div>
    </div>
</footer>
 --}}
<a href="#" id="scroll-top" class="scroll-top d-flex align-items-center justify-content-center"><i
        class="bi bi-arrow-up-short"></i></a>

<script>
document.addEventListener("DOMContentLoaded", function () {
  const scrollTopBtn = document.getElementById("scroll-top");

  // Mostrar/esconder botão ao rolar
  window.addEventListener("scroll", function () {
    if (window.scrollY > 200) { // aparece após 200px rolados
      scrollTopBtn.classList.add("active");
    } else {
      scrollTopBtn.classList.remove("active");
    }
  });

  // Rolar para o topo ao clicar
  scrollTopBtn.addEventListener("click", function (e) {
    e.preventDefault();
    window.scrollTo({
      top: 0,
      behavior: "smooth"
    });
  });
});
</script>