@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Cadastros da legislação'))

@php
    $legislacaoIndexParams = request()->only(\App\Http\Resources\LegislacaoResource::ADMIN_FILTER_KEYS);
@endphp

@section('content')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-gears'></i> " . __('Cadastros da legislação'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.legislacao.index',
            'routeBackParams' => $legislacaoIndexParams,
            'nameBack' => __('Legislações'),
            'permission' => 'GERENCIADOR_DE_LEGISLACAO',
        ])

        <div class="card-body">
            <ul class="nav nav-tabs nav-fill mb-4 flex-column flex-sm-row" role="tablist">
                <li class="nav-item" role="presentation">
                    <a class="text-dark nav-link @if ($aba === 'tipos') active @endif"
                        href="{{ route('admin.legislacao.cadastros.index', ['aba' => 'tipos'] + $legislacaoIndexParams) }}"
                        @if ($aba === 'tipos') aria-current="page" @endif>{{ __('Tipos') }}</a>
                </li>
                <li class="nav-item" role="presentation">
                    <a class="text-dark nav-link @if ($aba === 'categorias') active @endif"
                        href="{{ route('admin.legislacao.cadastros.index', ['aba' => 'categorias'] + $legislacaoIndexParams) }}"
                        @if ($aba === 'categorias') aria-current="page" @endif>{{ __('Categorias') }}</a>
                </li>
                <li class="nav-item" role="presentation">
                    <a class="text-dark nav-link @if ($aba === 'cargos') active @endif"
                        href="{{ route('admin.legislacao.cadastros.index', ['aba' => 'cargos'] + $legislacaoIndexParams) }}"
                        @if ($aba === 'cargos') aria-current="page" @endif>{{ __('Cargos') }}</a>
                </li>
                <li class="nav-item" role="presentation">
                    <a class="text-dark nav-link @if ($aba === 'autores') active @endif"
                        href="{{ route('admin.legislacao.cadastros.index', ['aba' => 'autores'] + $legislacaoIndexParams) }}"
                        @if ($aba === 'autores') aria-current="page" @endif>{{ __('Autores') }}</a>
                </li>
            </ul>

            @if ($aba === 'tipos')
                <div class="card border mb-4">
                    <div class="card-header bg-light">
                        <span class="fw-semibold">{{ __('Novo tipo') }}</span>
                    </div>
                    <div class="card-body">
                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['adicionar'])
                            <form method="post" action="{{ route('admin.legislacao.tipos.store') }}" class="row g-3 align-items-end">
                                @csrf
                                <div class="col-12 col-md-8 col-lg-9">
                                    <label class="form-label" for="cadastro_tipo_desc">{{ __('Descrição') }}</label>
                                    <input id="cadastro_tipo_desc" type="text" name="ds_tipo_legislacao" class="form-control" required
                                        maxlength="120" value="{{ old('ds_tipo_legislacao') }}">
                                </div>
                                <div class="col-12 col-md-4 col-lg-3">
                                    <button type="submit" class="btn btn-success w-100">
                                        <i class="fa-solid fa-plus me-1" aria-hidden="true"></i>{{ __('Incluir') }}
                                    </button>
                                </div>
                            </form>
                        @else
                            <p class="text-muted mb-0">{{ __('Sem permissão para incluir.') }}</p>
                        @endif
                    </div>
                </div>

                <x-tables._table :thead="['#', __('Descrição'), __('Ações')]" :pagination="$tipos->links()">
                    <x-slot name="body">
                        @php $i = $tipos->firstItem(); @endphp
                        @forelse ($tipos as $tipo)
                            <tr>
                                <td>{{ $i }}</td>
                                <td>{{ $tipo->ds_tipo_legislacao }}</td>
                                <td>
                                    <div class="d-flex justify-content-center gap-2">
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                            <a class="btn btn-sm btn-warning" href="{{ route('admin.legislacao.tipos.edit', array_merge(['tipo' => $tipo], $legislacaoIndexParams)) }}"
                                                title="{{ __('Editar') }}">
                                                <i class="fa-solid fa-pen-to-square" aria-hidden="true"></i>
                                            </a>
                                        @endif
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                            <form class="d-inline" method="post" action="{{ route('admin.legislacao.tipos.destroy', $tipo) }}"
                                                onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                @foreach($legislacaoIndexParams as $key => $value)
                                                    @if($value !== null && $value !== '')
                                                        <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                    @endif
                                                @endforeach
                                                <input type="hidden" name="confirm"
                                                    value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                    <i class="fa-solid fa-trash" aria-hidden="true"></i>
                                                </button>
                                            </form>
                                        @endif
                                    </div>
                                </td>
                            </tr>
                            @php $i++; @endphp
                        @empty
                            <tr>
                                <td colspan="3" class="text-center">{{ __('Nenhum registro encontrado.') }}</td>
                            </tr>
                        @endforelse
                    </x-slot>
                </x-tables._table>
            @endif

            @if ($aba === 'categorias')
                <div class="card border mb-4">
                    <div class="card-header bg-light">
                        <span class="fw-semibold">{{ __('Nova categoria') }}</span>
                    </div>
                    <div class="card-body">
                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['adicionar'])
                            <form method="post" action="{{ route('admin.legislacao.categorias.store') }}" class="row g-3 align-items-end">
                                @csrf
                                <div class="col-12 col-md-8 col-lg-9">
                                    <label class="form-label" for="cadastro_cat_nome">{{ __('Nome') }}</label>
                                    <input id="cadastro_cat_nome" type="text" name="nm_categoria" class="form-control" required maxlength="255"
                                        value="{{ old('nm_categoria') }}">
                                </div>
                                <div class="col-12 col-md-4 col-lg-3">
                                    <button type="submit" class="btn btn-success w-100">
                                        <i class="fa-solid fa-plus me-1" aria-hidden="true"></i>{{ __('Incluir') }}
                                    </button>
                                </div>
                            </form>
                        @else
                            <p class="text-muted mb-0">{{ __('Sem permissão para incluir.') }}</p>
                        @endif
                    </div>
                </div>

                <x-tables._table :thead="['#', __('Nome'), __('Ações')]" :pagination="$categorias->links()">
                    <x-slot name="body">
                        @php $i = $categorias->firstItem(); @endphp
                        @forelse ($categorias as $categoria)
                            <tr>
                                <td>{{ $i }}</td>
                                <td>{{ $categoria->nm_categoria }}</td>
                                <td>
                                    <div class="d-flex justify-content-center gap-2">
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                            <a class="btn btn-sm btn-warning" href="{{ route('admin.legislacao.categorias.edit', array_merge(['categoria' => $categoria], $legislacaoIndexParams)) }}"
                                                title="{{ __('Editar') }}">
                                                <i class="fa-solid fa-pen-to-square" aria-hidden="true"></i>
                                            </a>
                                        @endif
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                            <form class="d-inline" method="post" action="{{ route('admin.legislacao.categorias.destroy', $categoria) }}"
                                                onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                @foreach($legislacaoIndexParams as $key => $value)
                                                    @if($value !== null && $value !== '')
                                                        <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                    @endif
                                                @endforeach
                                                <input type="hidden" name="confirm"
                                                    value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                    <i class="fa-solid fa-trash" aria-hidden="true"></i>
                                                </button>
                                            </form>
                                        @endif
                                    </div>
                                </td>
                            </tr>
                            @php $i++; @endphp
                        @empty
                            <tr>
                                <td colspan="3" class="text-center">{{ __('Nenhum registro encontrado.') }}</td>
                            </tr>
                        @endforelse
                    </x-slot>
                </x-tables._table>
            @endif

            @if ($aba === 'cargos')
                <div class="card border mb-4">
                    <div class="card-header bg-light">
                        <span class="fw-semibold">{{ __('Novo cargo') }}</span>
                    </div>
                    <div class="card-body">
                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['adicionar'])
                            <form method="post" action="{{ route('admin.legislacao.cargos.store') }}" class="row g-3 align-items-end">
                                @csrf
                                <div class="col-12 col-md-8 col-lg-9">
                                    <label class="form-label" for="cadastro_cargo_nome">{{ __('Nome do cargo') }}</label>
                                    <input id="cadastro_cargo_nome" type="text" name="nm_cargo" class="form-control" required maxlength="120"
                                        value="{{ old('nm_cargo') }}">
                                </div>
                                <div class="col-12 col-md-4 col-lg-3">
                                    <button type="submit" class="btn btn-success w-100">
                                        <i class="fa-solid fa-plus me-1" aria-hidden="true"></i>{{ __('Incluir') }}
                                    </button>
                                </div>
                            </form>
                        @else
                            <p class="text-muted mb-0">{{ __('Sem permissão para incluir.') }}</p>
                        @endif
                    </div>
                </div>

                <x-tables._table :thead="['#', __('Nome do cargo'), __('Ações')]" :pagination="$cargos->links()">
                    <x-slot name="body">
                        @php $i = $cargos->firstItem(); @endphp
                        @forelse ($cargos as $cargo)
                            <tr>
                                <td>{{ $i }}</td>
                                <td>{{ $cargo->nm_cargo }}</td>
                                <td>
                                    <div class="d-flex justify-content-center gap-2">
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                            <a class="btn btn-sm btn-warning" href="{{ route('admin.legislacao.cargos.edit', array_merge(['cargo' => $cargo], $legislacaoIndexParams)) }}"
                                                title="{{ __('Editar') }}">
                                                <i class="fa-solid fa-pen-to-square" aria-hidden="true"></i>
                                            </a>
                                        @endif
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                            <form class="d-inline" method="post" action="{{ route('admin.legislacao.cargos.destroy', $cargo) }}"
                                                onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                @foreach($legislacaoIndexParams as $key => $value)
                                                    @if($value !== null && $value !== '')
                                                        <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                    @endif
                                                @endforeach
                                                <input type="hidden" name="confirm"
                                                    value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                    <i class="fa-solid fa-trash" aria-hidden="true"></i>
                                                </button>
                                            </form>
                                        @endif
                                    </div>
                                </td>
                            </tr>
                            @php $i++; @endphp
                        @empty
                            <tr>
                                <td colspan="3" class="text-center">{{ __('Nenhum registro encontrado.') }}</td>
                            </tr>
                        @endforelse
                    </x-slot>
                </x-tables._table>
            @endif

            @if ($aba === 'autores')
                <div class="card border mb-4">
                    <div class="card-header bg-light">
                        <span class="fw-semibold">{{ __('Novo autor') }}</span>
                    </div>
                    <div class="card-body">
                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['adicionar'])
                            <form method="post" action="{{ route('admin.legislacao.autores.store') }}" class="row g-3 align-items-end">
                                @csrf
                                <div class="col-12 col-md-5">
                                    <label class="form-label" for="cadastro_autor_nome">{{ __('Nome') }}</label>
                                    <input id="cadastro_autor_nome" type="text" name="nm_autor" class="form-control" required maxlength="255"
                                        value="{{ old('nm_autor') }}">
                                </div>
                                <div class="col-12 col-md-4">
                                    <label class="form-label" for="cadastro_autor_cargo">{{ __('Cargo') }}</label>
                                    <select id="cadastro_autor_cargo" name="id_cargo" class="form-select">
                                        <option value="">{{ __('Selecione') }}</option>
                                        @foreach ($cargosLista as $cargo)
                                            <option value="{{ $cargo->id_cargo }}" @selected((int) old('id_cargo') === (int) $cargo->id_cargo)>
                                                {{ $cargo->nm_cargo }}
                                            </option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="col-12 col-md-3">
                                    <button type="submit" class="btn btn-success w-100">
                                        <i class="fa-solid fa-plus me-1" aria-hidden="true"></i>{{ __('Incluir') }}
                                    </button>
                                </div>
                            </form>
                        @else
                            <p class="text-muted mb-0">{{ __('Sem permissão para incluir.') }}</p>
                        @endif
                    </div>
                </div>

                <x-tables._table :thead="['#', __('Nome'), __('Cargo'), __('Ações')]" :pagination="$autores->links()">
                    <x-slot name="body">
                        @php $i = $autores->firstItem(); @endphp
                        @forelse ($autores as $autor)
                            <tr>
                                <td>{{ $i }}</td>
                                <td>{{ $autor->nm_autor }}</td>
                                <td>{{ $autor->cargo->nm_cargo ?? '-' }}</td>
                                <td>
                                    <div class="d-flex justify-content-center gap-2">
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                            <a class="btn btn-sm btn-warning" href="{{ route('admin.legislacao.autores.edit', array_merge(['autor' => $autor], $legislacaoIndexParams)) }}"
                                                title="{{ __('Editar') }}">
                                                <i class="fa-solid fa-pen-to-square" aria-hidden="true"></i>
                                            </a>
                                        @endif
                                        @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                            <form class="d-inline" method="post" action="{{ route('admin.legislacao.autores.destroy', $autor) }}"
                                                onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                @foreach($legislacaoIndexParams as $key => $value)
                                                    @if($value !== null && $value !== '')
                                                        <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                    @endif
                                                @endforeach
                                                <input type="hidden" name="confirm"
                                                    value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                    <i class="fa-solid fa-trash" aria-hidden="true"></i>
                                                </button>
                                            </form>
                                        @endif
                                    </div>
                                </td>
                            </tr>
                            @php $i++; @endphp
                        @empty
                            <tr>
                                <td colspan="4" class="text-center">{{ __('Nenhum registro encontrado.') }}</td>
                            </tr>
                        @endforelse
                    </x-slot>
                </x-tables._table>
            @endif
        </div>
    </div>
@endsection
