<!-- Botão Fixo do WhatsApp com Bootstrap -->
<div class="position-fixed bottom-0 start-0 p-2 mb-2 me-3 z-3">
    <button data-bs-toggle="offcanvas" data-bs-target="#offcanvasScrolling"
            aria-controls="offcanvasScrolling"
            class="p-2 rounded-5 shadow border-0 bg-primary d-flex align-items-center text-decoration-none">
        <div class="d-flex align-items-center justify-content-center bg-primary text-white rounded-circle shadow p-2 me-2"
             style="width: 40px; height: 40px;">
            <i class="fa fa-book fs-4"></i>
        </div>
        <span class="text-white">SUMÁRIO</span>
    </button>
</div>
<?php /**PATH /var/www/html/portal/resources/views/sei/sectionsManual/botaoSumario.blade.php ENDPATH**/ ?>