@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Cadastro de Ambulantes - Editar Ajudante de " . $ambulante->proprietario->firstName . " " . $ambulante->proprietario->lastName)
@section('content')


    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
                        <h5 class="my-2">Cadastro de Ambulantes - Editar Ajudante de {{$ambulante->proprietario->firstName . " " . $ambulante->proprietario->lastName}}</h5>
                    </div>
                    <div class="card-body">

                        @include("errors.messageFlash")


                        <form action="{{ route('admin.cadastroDeAmbulantes.ajudantes.update', [$ambulante->id, $ajudante->id]) }}" method="post" enctype="multipart/form-data" autocomplete="off">
                            <div class="container">
                                <div class="row">
                                    <div class="col-12">
                                        <div class="card">
                                            <div class="card-body">
                                                <h5 class="card-title">Proprietário do comércio ambulante</h5>
                                                <div class="container">
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                @csrf
                                                                @method('PUT')
                                                                <input type="hidden" name="userId" id="userId" value="{{ old('userId', $ajudante?->user?->id ?? NULL) }}"/>
                                                                <input type="hidden" name="domicilioAjudante" id="domicilioAjudante" value="{{ old('domicilioAjudante', $endereco?->domicilio ?? "OUTROS") }}"/>
                                                                <input type="hidden" name="papersAjudante" id="papersAjudante" value="{{ old('papersAjudante', $ajudante->user?->papers ?? "EDIT") }}"/>
                                                                <input type="hidden" name="permissionAjudante" id="permissionAjudante" value="{{ old('permissionAjudante', $ajudante->user?->permission ?? "GUEST") }}"/>
                                                                <input type="hidden" name="passwordAjudante" id="passwordAjudante" value="{{ old('passwordAjudante', $ajudante->user?->password ?? "mudar123") }}"/>
                                                                <label for="fullNameAjudante" class="form-label text-bold">Nome completo: <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control @error('fullNameAjudante') is-invalid @enderror" name="fullNameAjudante" id="fullNameAjudante" value="{{ old('fullNameAjudante', $ajudante->user?->id ? $ajudante->user->firstName . " " . $ajudante->user->lastName : NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('fullNameAjudante')
                                                                    <small class="text-danger text-bold">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            <div class="mb-3">
                                                                <label for="cpfAjudante" class="form-label text-bold">CPF: <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control @error('cpfAjudante') is-invalid @enderror" name="cpfAjudante" id="cpfAjudante" value="{{ formatCnpjCpf(old('cpfAjudante', $ajudante->user?->cpf ) ) }}" oninput="javascript:aplicarMascaraCPF(this)" autocomplete="off">
                                    @error('cpfAjudante')
                                                                    <small class="text-danger text-bold">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="phoneNumberAjudante" class="form-label text-bold">Telefone: <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control @error('phoneNumberAjudante') is-invalid @enderror" name="phoneNumberAjudante" id="phoneNumberAjudante" value="{{ old('phoneNumberAjudante', $ajudante->user?->phoneNumber ?? NULL) }}" oninput="aplicarMascaraTelefone(this)" autocomplete="off">
                                    @error('phoneNumberAjudante')
                                                                    <small class="text-danger text-bold">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            <div class="mb-3">
                                                                <label for="emailAjudante" class="form-label text-bold">Email: <span class="span-admin-create">*</span></label>
                                                                <input type="emailAjudante" class="form-control @error('emailAjudante') is-invalid @enderror" name="emailAjudante" id="emailAjudante" value="{{ old('emailAjudante', $ajudante->user?->email ?? NULL) }}" oninput="this.value = this.value.toLowerCase()" autocomplete="off">
                                    @error('emailAjudante')
                                                                    <small class="text-danger text-bold">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="photoAjudante" class="form-label text-bold">Foto:</label>
                                                                <input type="file" class="form-control @error('photoAjudante') is-invalid @enderror" name="photoAjudante" id="photoAjudante" accept="image/jpeg,image/jpg,image/png,image/gif" />
                                    @error('photoAjudante')
                                                                    <small class="text-danger text-bold">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            @if(isset($ajudante->user?->id))
                                                                <div style="width: 90px;">
                                                                    @include('components.tables._openPhoto',[
                                            'asset' => $ajudante->user?->photo,
                                            'alt' => $ajudante->user?->firstName . " " . $ajudante->user?->lastName,
                                            'title' => $ajudante->user?->firstName . " " . $ajudante->user?->lastName,
                                            'text' => 'Visualizar foto',
                                            'index' => 1,
                                        ])
                                                                </div>
                                                            @endif
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="container my-3">
                                <div class="row">
                                    <div class="col-12">
                                        <div class="card">
                                            <div class="card-body">
                                                <h5 class="card-title">Endereço do responsável</h5>
                                                <div class="container address">
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="cepAjudante" class="form-label">CEP <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control cep @error('cepAjudante') is-invalid @enderror" name="cepAjudante" id="cepAjudante" oninput="aplicarMascaraCEP(this)" autocomplete="off" value="{{ old('cepAjudante', $endereco?->cep ?? NULL) }}" autocomplete="off">
                                        @error('cepAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            <div class="mb-3">
                                                                <label for="logradouroAjudante" class="form-label">Logradouro <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control logradouro @error('logradouroAjudante') is-invalid @enderror" name="logradouroAjudante" id="logradouroAjudante" value="{{ old('logradouroAjudante', $endereco?->logradouro ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('logradouroAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="numeroAjudante" class="form-label">Número</label>
                                                                <input type="text" class="form-control numero @error('numeroAjudante') is-invalid @enderror" name="numeroAjudante" id="numeroAjudante" value="{{ old('numeroAjudante', $endereco?->numero ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('numeroAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            <div class="mb-3">
                                                                <label for="complementoAjudante" class="form-label">Complemento</label>
                                                                <input type="text" class="form-control complemento @error('complementoAjudante') is-invalid @enderror" name="complementoAjudante" id="complementoAjudante" value="{{ old('numeroAjudante', $endereco?->complemento ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('complementoAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="cidadeAjudante" class="form-label">Cidade <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control cidade @error('cidadeAjudante') is-invalid @enderror" name="cidadeAjudante" id="cidadeAjudante" value="{{ old('cidadeAjudante', $endereco?->cidade ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('cidadeAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                        <div class="col-sm-12 col-md-5">
                                                            <div class="mb-3">
                                                                <label for="bairroAjudante" class="form-label">Bairro <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control bairro @error('bairroAjudante') is-invalid @enderror" name="bairroAjudante" id="bairroAjudante" value="{{ old('bairroAjudante', $endereco?->bairro ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('bairroAjudante')
                                                                    <small class="text-danger">{{ $message }}</small>
                                                                @enderror
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-12 col-md-7">
                                                            <div class="mb-3">
                                                                <label for="ufAjudante" class="form-label">UF <span class="span-admin-create">*</span></label>
                                                                <input type="text" class="form-control uf @error('ufAjudante') is-invalid @enderror" list="optionsSiglasAjudante" name="ufAjudante" id="ufAjudante" maxlength="2" value="{{ old('ufAjudante', $endereco?->uf ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                                            <datalist id="optionsSiglasAjudante">
                                                                <option value="AC"></option>
                                                                <option value="AL"></option>
                                                                <option value="AP"></option>
                                                                <option value="AM"></option>
                                                                <option value="BA"></option>
                                                                <option value="CE"></option>
                                                                <option value="DF"></option>
                                                                <option value="ES"></option>
                                                                <option value="GO"></option>
                                                                <option value="MA"></option>
                                                                <option value="MT"></option>
                                                                <option value="MS"></option>
                                                                <option value="MG"></option>
                                                                <option value="PA"></option>
                                                                <option value="PB"></option>
                                                                <option value="PR"></option>
                                                                <option value="PE"></option>
                                                                <option value="PI"></option>
                                                                <option value="RJ"></option>
                                                                <option value="RN"></option>
                                                                <option value="RS"></option>
                                                                <option value="RO"></option>
                                                                <option value="RR"></option>
                                                                <option value="SC"></option>
                                                                <option value="SP"></option>
                                                                <option value="SE"></option>
                                                                <option value="TO"></option>
                                                            </datalist>
                                        @error('ufAjudante')
                                                                <small class="text-danger">{{ $message }}</small>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                    <div class="col-sm-12 col-md-5">

                                                    </div>
                                                </div>
                                                <div class="row">
                                                    <div class="col-sm-12 col-md-7">
                                                        <div class="mb-3">
                                                            <label for="latitudeAjudante" class="form-label">Latitude <span class="span-admin-create">*</span></label>
                                                            <input type="text" class="form-control latitude @error('latitudeAjudante') is-invalid @enderror bg-light" name="latitudeAjudante" id="latitudeAjudante" value="{{ old('latitudeAjudante', $endereco?->latitude ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('latitudeAjudante')
                                                                <small class="text-danger">{{ $message }}</small>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                    <div class="col-sm-12 col-md-5">
                                                        <div class="mb-3">
                                                            <label for="longitudeAjudante" class="form-label">Longitude <span class="span-admin-create">*</span></label>
                                                            <input type="text" class="form-control longitude @error('longitudeAjudante') is-invalid @enderror bg-light" name="longitudeAjudante" id="longitudeAjudante" value="{{ old('longitudeAjudante', $endereco?->longitude ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('longitudeAjudante')
                                                                <small class="text-danger">{{ $message }}</small>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="row">
                                                    <div class="col-sm-12 col-md-7">
                                                        <div class="mb-3">
                                                            <label for="comprovanteAjudante" class="form-label text-bold">Comprovante de endereço:</label>
                                                            <input type="file" class="form-control comprovante @error('comprovanteAjudante') is-invalid @enderror" name="comprovanteAjudante" id="comprovanteAjudante" accept="image/jpeg,image/jpg,image/png,image/gif,.pdf" />
                                        @error('comprovanteAjudante')
                                                                <small class="text-danger">{{ $message }}</small>
                                                            @enderror
                                                        </div>
                                                    </div>
                                                    <div class="col-sm-12 col-md-5">
                                                        @if(isset($endereco->id))
                                                            <div style="width: 90px;">
                                                                @include('components.tables._openPhotoAndPdf',[
                                                'asset' => $endereco->comprovante,
                                                'alt' => "Comprovante de " . $ajudante->user?->firstName . " " . $ajudante->user?->lastName,
                                                'title' => "Comprovante de " . $ajudante->user?->firstName . " " . $ajudante->user?->lastName,
                                                'text' => 'Visualizar foto',
                                                'index' => 2,
                                            ])
                                                            </div>
                                                        @endif
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="d-flex justify-content-end mt-4">
                            <div>
                                <button class="btn btn-danger me-2 d-inline" type="button"
                                        onclick="window.location.href='{{ route('admin.cadastroDeAmbulantes.ajudantes.index', $ambulante->id) }}'">
                                    <i class="fa-solid fa-xmark"></i> Cancelar
                                </button>
                                <button class="btn btn-primary d-inline" type="submit">
                                    <i class="fa-solid fa-user-plus"></i> Atualizar
                                </button>
                            </div>
                        </div>
                    </form>




                </div>
            </div>
        </div>
    </div>
    </div>

@endsection
