<head>
    <!-- Meta tags Obrigatórias -->
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">

    <title><?php echo $__env->yieldContent('title', __('Calendário de Eventos 2026 em Angra dos Reis')); ?></title>

    <meta name="description" content="<?php echo e(__('Calendário completo de eventos na cidade de Angra dos Reis')); ?>">
    <meta name="author" content="<?php echo e(__('Prefeitura de Angra dos Reis')); ?>">
    <meta name="keywords" content="<?php echo e(__('eventos, angra dos reis, praia, mar, costa verde, paraíso, verão, rio de janeiro, ilha grande, cultura, turismo, esporte')); ?>">
    <meta name="generator" content="<?php echo e(__('Prefeitura de Angra dos Reis')); ?>">
    <meta name="robots" content="index, follow">

    <!-- Open Graph / Facebook -->
    <meta property="og:title" content="<?php echo $__env->yieldContent('og_title', __('Calendário de Eventos 2026/2027')); ?>">
    <meta property="og:type" content="website">
    <meta property="og:url" content="<?php echo e(url()->current()); ?>">
    <meta property="og:image" content="<?php echo e(asset('calendario-de-eventos/assets/images/eventos2026.jpg')); ?>">
    <meta property="og:description" content="<?php echo e(__('Veja o calendário de eventos oficial da cidade de Angra dos Reis.')); ?>">
    <meta property="og:locale" content="pt_BR">

    <!-- Favicon -->
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('calendario-de-eventos/assets/icons/apple-touch-icon.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('calendario-de-eventos/assets/icons/favicon.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('calendario-de-eventos/assets/icons/favicon-16x16.png')); ?>">
    <link rel="manifest" href="<?php echo e(asset('calendario-de-eventos/assets/icons/site.webmanifest')); ?>">
    <link rel="mask-icon" href="<?php echo e(asset('calendario-de-eventos/assets/icons/safari-pinned-tab.svg')); ?>" color="#5bbad5">
    <meta name="msapplication-TileColor" content="#da532c">
    <meta name="theme-color" content="#ffffff">

    <!-- Bootstrap CSS (CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">

    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer">

    <!-- Estilos customizados -->
    <link rel="stylesheet" href="<?php echo e(asset('calendario-de-eventos/assets/css/style.css')); ?>">

    <?php echo $__env->yieldContent('styles'); ?>
</head>
<?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/calendariodeeventos/elements/head.blade.php ENDPATH**/ ?>