@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Convocações'))
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-list-check'></i> " . __('Convocações'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.cultura.credenciamentoMusicos.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            <p class="text-muted">{{ __('Selecione um evento para gerenciar convocações de artistas credenciados.') }}</p>
            <div class="list-group">
                @forelse($eventos as $evento)
                    <a href="{{ route('admin.cultura.credenciamentoMusicos.convocacoes.show', $evento) }}" class="list-group-item list-group-item-action d-flex justify-content-between align-items-center">
                        <span>{{ $evento->nome }} @if($evento->categoria)<small class="text-muted">({{ $evento->categoria }})</small>@endif @if($evento->data) – {{ $evento->data->format('d/m/Y') }}@endif</span>
                        <span class="badge bg-primary rounded-pill">{{ $evento->convocacoes()->count() }} {{ __('convocações') }}</span>
                    </a>
                @empty
                    <p class="mb-0">{{ __('Nenhum evento ativo.') }} <a href="{{ route('admin.cultura.credenciamentoMusicos.eventos.create') }}">{{ __('Criar evento') }}</a></p>
                @endforelse
            </div>
            <div class="mt-3">
                <a href="{{ route('admin.cultura.credenciamentoMusicos.eventos.index') }}" class="btn btn-outline-secondary">{{ __('Gerenciar eventos') }}</a>
            </div>
        </div>
    </div>
@endsection
