@extends('layouts.mobiangra.theme')

@section('title', __('Fale Conosco - MobiAngra') . ' - ' . config('app.name'))

@section('content')
    <section class="mobiangra-subpage">
        <div class="container">
            <x-mobiangra.breadcrumb :items="[
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Fale Conosco')],
            ]" />

            <div class="mobiangra-subpage-card">
                <x-mobiangra.subpage-header :title="__('Fale Conosco')" />

                <div class="p-4 mobiangra-subpage-body">
                    <p class="mb-4">
                        {{ __('Registre reclamações, sugestões ou elogios sobre o transporte coletivo. É necessário estar logado na Conta Angra para enviar uma manifestação.') }}
                    </p>

                    @php
                        $protocoloManifestacao = session('mobiangra_manifestacao_protocolo');
                    @endphp

                    @if (is_array($protocoloManifestacao) && ! empty($protocoloManifestacao['numero']))
                        <x-mobiangra.manifestacao-sucesso
                            :numero="$protocoloManifestacao['numero']"
                            :chamado-url="! empty($protocoloManifestacao['chamado_id'])
                                ? route('admin.contaAngra.chamados.show', $protocoloManifestacao['chamado_id'])
                                : route('admin.contaAngra.chamados.index')" />
                    @endif

                    @include('errors.messageFlash')

                    <x-mobiangra.fale-conosco-form
                        :linhas="$linhas"
                        :relato-max="$relatoMax"
                        :usuario-logado="$usuarioLogado ?? auth()->user()" />

                    <x-mobiangra.lgpd-aviso />
                </div>
            </div>
        </div>
    </section>
@endsection

@push('scripts')
    @if (config('recaptcha.enabled'))
        <script src="https://www.google.com/recaptcha/api.js?hl={{ str_replace('_', '-', app()->getLocale()) }}" async defer></script>
    @endif
    <script src="{{ asset('mobiangra-assets/js/fale_conosco.js') }}?v={{ time() }}"></script>
@endpush
