<form id="formCriarConta" name="formCriarConta" autocomplete="off" method="post" action="{{ route('admin.contas.publicas.store') }}">
    @csrf
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('CPF'),
        'name'=>'cpf',
        'id'=>null,
        'required'=>true,
        'type'=>null,
        'old'=>old('cpf'),
        'oninput'=>'aplicarMascaraCPF(this)',
        'readonly'=>false,
        'small'=>null,
        ])
        <small class="small-cpf"></small>
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('E‑mail'),
        'name'=>'email',
        'id'=>null,
        'required'=>true,
        'type'=>null,
        'old'=>old('email'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
        <small class="small-email"></small>
    </div>
    <input type="hidden" name="recaptcha" id="recaptcha">
    <button class="btn btn-primary" type="submit" id="submitCriarConta">{{ __('Solicitar') }}</button>
    <div class="my-3">
        <a href="{{ route("admin.login") }}" class="text-white">Login</a> | <a href="{{ route("admin.esqueceuSenha") }}" class="text-white">Esqueceu senha?</a>
    </div>
    <div id='recaptchaCriarConta' data-size="invisible"></div>
</form>
