{{-- 
    @include("admin.components.btnStatus", [
        'route' => "id do serviço",
        'id' => "id do serviço",
    ])
--}}

<form id="{{ "checkStatus_" . $id }}" class="fix" action="{{ route($route, $id)}}" method="post">
    @csrf
    @if($secretaria->status == "ATIVADO")
        <div class="form-check form-switch">
            <input type="hidden" name="checkStatus" value="DESATIVADO">
            <input class="form-check-input" type="checkbox" checked onclick="javascript:$('#{{ "checkStatus_" . $id }}').submit()">
        </div>
    @else
        <div class="form-check form-switch">
            <input type="hidden" name="checkStatus" value="ATIVADO">
            <input class="form-check-input" type="checkbox" onclick="javascript:$('#{{ "checkStatus_" . $id }}').submit()">
        </div>
    @endif
</form>