@props([
    'numero',
    'naoLidas' => 0,
    'monospace' => true,
])

@php
    $totalNaoLidas = max(0, (int) $naoLidas);
    $rotuloNaoLidas = $totalNaoLidas > 99 ? '99+' : (string) $totalNaoLidas;
@endphp

<div class="chamado-registro-numero">
    <span @class([
        'chamado-registro-numero__pill',
        'badge bg-light text-dark border',
        'font-monospace' => $monospace,
    ])>{{ $numero }}</span>

    @if ($totalNaoLidas > 0)
        <span class="chamado-registro-numero__novas"
              title="{{ __(':count nova(s) mensagem(ns)', ['count' => $totalNaoLidas]) }}"
              aria-label="{{ __(':count nova(s) mensagem(ns)', ['count' => $totalNaoLidas]) }}">
            {{ $rotuloNaoLidas }}
        </span>
    @endif
</div>
