<header id="header" class="header d-flex align-items-center fixed-top">
    <div class="container-fluid container-xl position-relative d-flex align-items-center">
        <a href="" class="logo d-flex align-items-center me-auto">
            <img src="rderiscos/assets/images/logo-reducao-de-riscos.svg" height="100" alt="Plano Municipal de Redução de Riscos">
        </a>

        <nav id="navmenu" class="navmenu">
            <ul>
                <li><a href="#sobre">O Plano</a></li>
                <li><a href="#realizacao">Realização</a></li>
                
                <li><a href="#audiencia">Audiência Pública</a></li>
                <li><a href="#noticias">Notícias</a></li>
                <li><a href="#tecnica">Ficha Técnica</a></li>
                <li><a href="#contato">Contato</a></li>
            </ul>
            <i class="mobile-nav-toggle d-xl-none bi bi-list"></i>
        </nav>
    </div>
</header><?php /**PATH /var/www/html/portal/resources/views/layouts/reducaoderiscos/elements/nav.blade.php ENDPATH**/ ?>