@extends('layouts.admin.theme')

@section('title', 'Lista - Situações')

@section('content')
@include('errors.messageFlash')

<div class="card shadow-lg">
    <div class="card-header bg-primary text-white py-3">
        <div class="d-flex justify-content-between align-items-center">
            <h5 class="mb-0">
                <i class="fas fa-cloud-sun me-2"></i>Situações Meteorológicas
            </h5>
            <div class="ms-auto me-2">
                @include('components.buttons._backButton', ['url' => 'admin.boletim.meteorologico.index', 'label' => 'Voltar'])
            </div>
            <a href="{{ route('admin.situacoes.create') }}" class="btn btn-light ">
                <i class="fas fa-plus me-1"></i>Nova Situação
            </a>
        </div>
    </div>

    <div class="card-body p-4">
        @if($situacoes->count() > 0)
        <div class="table-responsive">
            <table class="table table-hover table-bordered align-middle">
                <thead class="table-light">
                    <tr>
                        <th width="80" class="text-center">ID</th>
                        <th>Descrição da Situação</th>
                        <th width="120" class="text-center">Ações</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($situacoes as $situacao)
                    <tr>
                        <td class="text-center fw-bold text-primary">{{ $situacao->id }}</td>
                        <td class="text-start">{{ $situacao->descricao }}</td>
                        <td class="text-center">
                            <div class="btn-group btn-group-sm" role="group">
                                <a href="{{ route('admin.situacoes.edit', $situacao->id) }}"
                                    class="btn btn-warning"
                                    title="Editar situação">
                                    <i class="fas fa-edit"></i>
                                </a>
                                <form action="{{ route('admin.situacoes.destroy', $situacao->id) }}"
                                    method="POST"
                                    class="d-inline"
                                    onsubmit="return confirm('Tem certeza que deseja excluir esta situação?')">
                                    @csrf
                                    @method('DELETE')
                                    <button type="submit" class="btn btn-danger" title="Excluir situação">
                                        <i class="fas fa-trash"></i>
                                    </button>
                                </form>
                            </div>
                        </td>
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
        @else
        <div class="text-center py-5">
            <i class="fas fa-inbox fa-3x text-muted mb-3"></i>
            <h5 class="text-muted">Nenhuma situação cadastrada</h5>
            <p class="text-muted">Clique no botão "Nova Situação" para adicionar a primeira.</p>
            <a href="{{ route('admin.situacoes.create') }}" class="btn btn-primary mt-3">
                <i class="fas fa-plus me-2"></i>Criar Primeira Situação
            </a>
        </div>
        @endif
    </div>
</div>
@endsection