@extends('layouts.admin.theme')

@section('title', 'Visualizar - Fluxo de Ônibus')

@section('content')
<div class="card shadow-sm border-0">
    <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
        <h3 class="my-2 fw-bolder">
            <i class="fa fa-bus me-2"></i> Visualizar Fluxo de Ônibus
        </h3>

        <div class="d-flex gap-2">
            <a href="{{ route('admin.fluxoOnibus.index') }}" class="btn btn-light btn">
                <i class="fa fa-arrow-left me-2"></i> Voltar
            </a>
        </div>
    </div>

    <div class="card-body">
        <div class="row">
            <!-- Datas e Horários -->
            <div class="col-md-6 mb-4">
                <h5 class="text-primary mb-3">
                    <i class="fa fa-calendar me-2"></i> Datas e Horários
                </h5>
                <div class="info-group">
                    <label class="fw-bold">Data de Chegada:</label>
                    <p>{{ \Carbon\Carbon::parse($fluxoOnibus->data_chegada)->format('d/m/Y') }}</p>
                </div>
                <div class="info-group">
                    <label class="fw-bold">Horário de Chegada:</label>
                    <p>{{ $fluxoOnibus->horario_chegada }}</p>
                </div>
                <div class="info-group">
                    <label class="fw-bold">Data de Retorno:</label>
                    <p>{{ \Carbon\Carbon::parse($fluxoOnibus->data_retorno)->format('d/m/Y') }}</p>
                </div>
                <div class="info-group">
                    <label class="fw-bold">Horário de Retorno:</label>
                    <p>{{ $fluxoOnibus->horario_retorno }}</p>
                </div>
            </div>
            <div class="row">
                <div class="col-12 mb-4">
                    <h5 class="text-primary mb-3">
                        <i class="fa fa-paperclip me-2"></i> Arquivo Anexado
                    </h5>
                    @if($fluxoOnibus->upload)
                    <div class="d-flex align-items-center gap-3 p-3 border rounded">
                        <i class="fa fa-file-pdf fa-2x text-danger"></i>
                        <div class="flex-grow-1">
                            <strong>Arquivo:</strong>
                            {{ basename($fluxoOnibus->upload) }}
                        </div>
                        <div class="d-flex gap-2">
                            <a href="{{ Storage::disk('public')->url($fluxoOnibus->upload) }}"
                                target="_blank" class="btn btn-primary btn-sm">
                                <i class="fa fa-eye me-1"></i> Visualizar
                            </a>
                            <a href="{{ route('admin.fluxoOnibus.download', $fluxoOnibus->id) }}"
                                class="btn btn-success btn-sm">
                                <i class="fa fa-download me-1"></i> Download
                            </a>
                        </div>
                    </div>
                    @else
                    <div class="text-muted p-3 border rounded">
                        <i class="fa fa-times-circle me-2"></i> Nenhum arquivo anexado
                    </div>
                    @endif
                </div>
            </div>

            <!-- Informações da Viagem -->
            <div class="col-md-6 mb-4">
                <h5 class="text-primary mb-3">
                    <i class="fa fa-route me-2"></i> Informações da Viagem
                </h5>
                <div class="info-group">
                    <label class="fw-bold">Origem:</label>
                    <p>{{ $fluxoOnibus->origem }}</p>
                </div>
                <div class="info-group">
                    <label class="fw-bold">Número de Passageiros:</label>
                    <p>{{ $fluxoOnibus->nr_passageiros }}</p>
                </div>
            </div>
        </div>

        <!-- Continue com as outras seções seguindo o mesmo padrão -->
        <!-- Empresa, Guia, Receptivo, etc. -->

        <div class="row mt-4">
            <div class="col-12">
                <div class="d-flex justify-content-end gap-2">
                    <a href="{{ route('admin.fluxoOnibus.edit', $fluxoOnibus->id) }}" class="btn btn-warning">
                        <i class="fa fa-edit me-2"></i> Editar
                    </a>
                    <a href="{{ route('admin.fluxoOnibus.index') }}" class="btn btn-secondary">
                        <i class="fa fa-arrow-left me-2"></i> Voltar
                    </a>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .info-group {
        margin-bottom: 1rem;
        padding: 0.5rem;
        border-bottom: 1px solid #eee;
    }

    .info-group label {
        color: #666;
        margin-bottom: 0.25rem;
    }

    .info-group p {
        margin: 0;
        font-size: 1.1em;
    }
</style>
@endsection