<!DOCTYPE html>
<html lang="pt-BR">
    <head>
        <meta charset="UTF-8">
        <title>Validação de E-mail - Conta Angra</title>
    </head>
    <body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">

        <table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
            <tr>
                <td align="center">

                    <!-- Container -->
                    <table width="600" cellpadding="0" cellspacing="0" style="background:#ffffff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">

                        <!-- Header com a logo -->
                        <tr>
                            <td align="center" style="background-color:#007bc3; padding:30px;">
                                <img src="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png"
                                     alt="Logo Prefeitura de Angra dos Reis"
                                     width="260"
                                     style="max-width:80px; height:auto; display:block;">
                            </td>
                        </tr>

                        <!-- Corpo do e-mail -->
                        <tr>
                            <td style="padding:30px; color:#333333; font-size:15px; line-height:1.6;">

                                <p style="margin:0 0 15px;">Olá, <strong><?php echo e($email); ?></strong></p>

                                <p style="margin:0 0 15px;">
                                    Recebemos sua solicitação para criar sua <strong>Conta Angra</strong>.
                                </p>

                                <p style="margin:0 0 25px;">
                                    Use o botão abaixo para validar seu e-mail e definir sua senha.
                                    <br>
                                    <strong>O link é válido por até 60 minutos.</strong>
                                </p>

                                <!-- Botão CTA -->
                                <p style="text-align:center; margin:30px 0;">
                                    <a href="<?php echo e(route('admin.novaConta', $token)); ?>"
                                       style="
                                       background-color:#007bff;
                                       color:#ffffff;
                                       padding:14px 28px;
                                       text-decoration:none;
                                       font-weight:bold;
                                       border-radius:6px;
                                       display:inline-block;
                                       ">
                                        Criar minha conta
                                    </a>
                                </p>

                                <p style="margin:30px 0 0; color:#666666; font-size:13px;">
                                    Se você não fez esta solicitação, apenas ignore este e-mail.
                                </p>

                            </td>
                        </tr>

                        <!-- Rodapé -->
                        <tr>
                            <td style="background:#f7f7f7; text-align:center; padding:18px; font-size:12px; color:#aaaaaa;">
                                Prefeitura Municipal de Angra dos Reis<br>
                                Este é um e-mail automático, por favor não responda.
                            </td>
                        </tr>

                    </table>
                    <!-- Fim container -->

                </td>
            </tr>
        </table>

    </body>
</html>
<?php /**PATH /var/www/html/portal/resources/views/emails/novaConta.blade.php ENDPATH**/ ?>