<a href="{{ asset($url) }}" class="text-primary" target="_blank" download>
    @if($fontawesome == null)
        <i class="fa-solid fa-download"></i> {{ $text }}
    @else
        {!! $fontawesome !!} {{ $text }}
    @endif
</a>
