@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Nova Startup'))

@section('content')
<div class="card shadow-sm border-0">
    @php $headLine = "<i class='fa-solid fa-lightbulb'></i> " . __('Nova Startup'); @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
        'headLine' => $headLine,
        'routeBack' => 'admin.parqueTecnologico.index',
        'routeBackParams' => ['tab' => 'startups'],
        'nameBack' => __('Voltar'),
        'permission' => 'GERENCIADOR_DE_PARQUE_TECNOLOGICO',
    ])

    <div class="card-body p-4">
        @include('errors.messageFlash')

        <form action="{{ route('admin.parqueTecnologico.startups.store') }}" method="POST" enctype="multipart/form-data">
            @csrf

            @include('admin.parqueTecnologico.startups._form')

            <div class="d-flex justify-content-between mt-4">
                <a href="{{ route('admin.parqueTecnologico.index', ['tab' => 'startups']) }}" class="btn btn-light">
                    <i class="fa-solid fa-arrow-left me-1"></i> {{ __('Voltar') }}
                </a>

                <button class="btn btn-success px-4">
                    <i class="fa-solid fa-check me-1"></i> {{ __('Cadastrar Startup') }}
                </button>
            </div>
        </form>
    </div>
</div>
@endsection