@foreach($items as $item)
    <li class="nav-item-fibromialgia me-2" role="presentation">
        @if(isset($item['route']) && isset($item['routeParams']))
            <a class="nav-link fw-bold {{ $item['class'] ?? '' }}"
               href="{{ route($item['route'], $item['routeParams']) }}"
               role="tab">
                {!! $item['label'] !!}
            </a>
        @else
            <a class="nav-link fw-bold {{ $item['class'] ?? '' }}"
               data-bs-toggle="tab"
               href="#{{ $item['hash'] }}"
               role="tab">
                {!! $item['label'] !!}
            </a>
        @endif
    </li>
@endforeach
