<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.cmgd.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body id="page-top">
    <header >
        <?php echo $__env->make('layouts.cmgd.elements.defaultBar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <?php echo $__env->make('layouts.cmgd.elements.nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </header>
    <section class= "p-0 m-0">
        <?php echo $__env->make('layouts.cmgd.elements.modal', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </section>
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>
    <section class="py-0">
        <?php echo $__env->make('layouts.cmgd.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </section>
</body>

</html><?php /**PATH /var/www/html/portal/resources/views/layouts/cmgd/theme.blade.php ENDPATH**/ ?>