<section>
    <div class="container">
        <div class="row">
            <div
                class="col-12 col-sm-12 col-md-12 col-lg-12 col-xl-4 col-xxl-4 mb-5 d-flex justify-content-center align-items-start">
                <div class="d-flex justify-content-center align-items-start px-2" style="cursor:pointer;"
                    onclick="window.location='https://angra.rj.gov.br/secretarias/secretaria-de-protecao-e-defesa-civil';">
                    <img style="height: 10rem;" src="{{ asset('pmar/assets/img/logo-pmar-transp.png') }}"
                        class="footer-pmar-logo m-auto">

                </div>
                <div class="d-flex justify-content-center align-items-start px-2">
                    <img style="height: 10rem;" src="{{ asset('pmar/assets/img/spdc-logo-transp.png') }}"
                        class="footer-pmar-logo m-auto">
                </div>
            </div>
            <div class="footer-pmar-colunas col-12 col-sm-12 col-md-12 col-lg-6 col-xl-4 col-xxl-4 mb-5">
                <h5 class="text-white">Entre em contato:</h5>
                <ul>
                    <li>
                        <span class="text-white">Telefones:</span>

                    </li>
                    <li>
                        <a href="tel:+552433777991">
                            <i class="me-2 footer-pmar-icons fa-solid fa-phone"></i>
                            <span>(24) 3377-7991</span>
                        </a>
                    </li>
                    <li>
                        <a href="tel:+552433654588">
                            <i class="me-2 footer-pmar-icons fa-solid fa-phone"></i>
                            <span>(24) 3365-4588</span>
                        </a>
                    </li>
                    <li>
                        <a href="mailto:defesacivil@angra.rj.gov.br" target="_blank">
                            <i class="me-2 footer-pmar-icons fa-solid fa-book"></i>
                            <span>E-mail: defesacivil@angra.rj.gov.br</span>
                        </a>
                    </li>
                    <li>
                        <a href="https://maps.app.goo.gl/PStfdiVrGEjopj7L8" target="_blank">
                            <i class="me-2 footer-pmar-icons fa-solid fa-location-dot"></i>
                            <span>Av. Almirante Júlio César de Noronha, 271, São Bento<br>
                                Angra dos Reis – RJ – CEP 23.900-010</span>
                        </a>
                    </li>
                </ul>
            </div>
            <div class="footer-pmar-colunas col-12 col-sm-12 col-md-12 col-lg-6 col-xl-4 col-xxl-4">
                <h5 class="text-white">Siga a Defesa Civil em nossas redes sociais:</h5>
                <ul>
                    <li>
                        <a href="https://www.facebook.com/defesacivilangra" target="_blank">
                            <i class="me-2 footer-pmar-icons fa-brands fa-facebook"></i>
                            <span>
                                Defesa Civil Municipal - Angra dos Reis - RJ
                            </span>
                        </a>
                    </li>
                    <li>
                        <a href="https://www.instagram.com/defesacivilangra/" target="_blank">
                            <i class="me-2 footer-pmar-icons fa-brands fa-instagram"></i>
                            <span>@defesacivilangra</span>
                        </a>
                    </li>
                </ul>
            </div>
            <button id="backToTop" aria-label="Voltar ao Topo">
                <i class="text-white fa-solid fa-chevron-up fw-bold fs-4"></i>
            </button>


        </div>
    </div>
</section>

<script src="https://plugin.handtalk.me/web/latest/handtalk.min.js"></script>
<script>
    var ht = new HT({
        token: "7a92081e27daf17bd3b2efe277d0648c",
        avatar: "MAYA",
        pageSpeech: true,
        maxTextSize: 1000
    });
</script>

@if(Route::currentRouteName() == "saude.fibromialgia" && config('recaptcha.enabled'))
    <script src="https://www.google.com/recaptcha/api.js?onload=onloadCallback&render=explicit" async defer
        type="text/x-javascript"></script>
@endif

<!-- angra.rj.gov.br -->
<script defer src="https://wdg.plugfield.com.br/device/plugfield-widget-v1-sd-x.js"></script>

<script src="{{ asset('pmar/js/jquery-3.7.1.min.js') }}"></script>
{{-- Bootstrap JS (via npm - copiado pelo Vite durante o build) --}}
<script src="{{ asset('pmar/build/bootstrap/js/bootstrap.bundle.min.js') }}"></script>
{{-- TinyMCE (via npm - copiado pelo Vite durante o build) --}}
<script src="{{ asset('pmar/build/tinymce/tinymce.min.js') }}"></script>
<script src="{{ asset('pmar/js/preparaMenu.js') }}"></script>
<script src="{{ asset('pmar/js/mascaras.js') }}"></script>
<script src="{{ asset('pmar/js/validacoes.js') }}"></script>
<script src="{{ asset('pmar/js/utilitarios.js') }}"></script>
<script src="{{ asset('pmar/js/janelas.js') }}"></script>
<script src="{{ asset('pmar/js/toggle.js') }}"></script>
<script src="{{ asset('pmar/js/shareBoletimMeteorologico.js') }}?v={{ time() }}"></script>
<script src="{{ asset('pmar/js/functions.js') }}"></script>
@if(Route::currentRouteName() == "paginas.slug")
<script src="{{ asset('pmar/js/socialNoticias.js') }}"></script> @endif
<script src="{{ asset('pmar/js/app.js') }}"></script>
<script src="{{ asset('pmar/js/galeria.js') }}"></script>
@if(Route::currentRouteName() == "paginas.home")
<script src="{{ asset('pmar/js/pontos-turisticos.js') }}"></script> @endif
<script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>

<script async src="https://cse.google.com/cse.js?cx=b5b7c1de20bbd48fb"></script>

@if(Route::currentRouteName() == "saude.fibromialgia")
<script src="{{ asset('pmar/js/fibromialgia/login.js') }}"></script> @endif
@if (Route::currentRouteName() == 'saude.fibromialgia')
<script src="{{ asset('pmar/js/FormCadastroPaciente.js') }}"></script> @endif
@if (Route::currentRouteName() == 'paginas.html')
    <script>
        {
            !!$html - > js!!
        }
</script> @endif
@if (Route::currentRouteName() == 'servicos.index')
<script src="{{ asset('pmar/js/servicos/index.js') }}"></script> @endif
@if (Route::currentRouteName() == 'servicos.escolasMunicipais' || Route::currentRouteName() == 'servicos.crechesMunicipais')
<script src="{{ asset('pmar/js/servicos/escolasCrechesMunicipais.js') }}"></script> @endif
@if (Route::currentRouteName() == 'servicos.unidadesSaude')
<script src="{{ asset('pmar/js/servicos/unidadesSaude.js') }}"></script> @endif