<!-- Turismo -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-purple">
        <div class="card-header text-white bg-purple" >
            <div class="d-flex align-items-center">
                <i class="fas fa-umbrella-beach fa-2x me-3"></i>
                <h5 class="card-title mb-0">Turismo</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-ship me-2 text-muted"></i> Passeios de barco e escunas <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-map-marked-alt me-2 text-muted"></i> Roteiros turísticos <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-calendar-alt me-2 text-muted"></i> Eventos e festivais <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-bed me-2 text-muted"></i> Cadastro de meios de hospedagem <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-utensils me-2 text-muted"></i> Guia gastronômico <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-life-ring me-2 text-muted"></i> Segurança nas praias <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-info-circle me-2 text-muted"></i> Postos de informação turística <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-umbrella-beach me-2 text-muted"></i> Turismo <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-door-open me-2 text-muted"></i> 
                    <a href="https://desembarque.angra.rj.gov.br" target="_blank" class="text-dark">Taxa de Desembarque</a>
                </li>
            </ul>
        </div>
        <div class="card-footer bg-transparent">
            <small class="text-muted">Angra dos Reis - Capital do Litoral Verde</small>
        </div>
    </div>
</div>