@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Conselhos Municipais")
@section('content')
<div class="container my-4">
    <div class="row mb-4">
        <div class="col-12 my-3">
            <nav aria-label="breadcrumb">
                <ol class="breadcrumb">
                    <li class="breadcrumb-item">
                        <a href="{{ route('paginas.home') }}">{{ __("Portal") }}</a>
                    </li>
                    <li class="breadcrumb-item">
                        <span class="text-primary">Conselhos Municipais</span>
                    </li>
                </ol>
            </nav>
        </div>
    </div>

    <div class="container">
        <div class="row">
            <div class="col-12">
                <h1 class="fw-bold text-center">Conselhos Municipais</h1>
            </div>
        </div>
    </div>

    <div class="container py-4">
        <div class="alert alert-info mt-4">
            <div class="d-flex align-items-center">
                <i class="fas fa-map-marker-alt fa-2x me-3"></i>
                <div>
                    <h3 class="h5 mb-1">Onde ser atendido</h3>
                    <p class="mb-0">Veja abaixo todos os conselhos municipais de Angra dos Reis.</p>
                </div>
            </div>
        </div>
    </div>

    <div class="row" id="escolasContainer">
        @foreach($conselhos as $conselho)
            <div class="col-md-6 col-lg-4 mb-4 escola-card" 
                data-nome="{{ strtolower($conselho->nome) }}" 
                data-bairro="{{ strtolower($conselho->endereco->bairro) }}">
                <div class="card h-100 shadow-sm">
                    <img src="{{ asset($conselho->foto) }}" class="card-img-top" alt="{{ $conselho->nome }}" style="height: 180px; object-fit: cover;">
                    <div class="card-body">
                        <h5 class="card-title">{{ $conselho->nome }}</h5>
                        <p class="card-text mb-1">
                            <i class="fas fa-map-marker-alt text-muted me-1 text-danger"></i>
                            {{ $conselho->endereco->bairro }}
                        </p>
                        <p class="card-text">
                            <i class="fas fa-building text-primary me-1"></i>
                            {{ $conselho->pertence->name ?? 'Secretaria não informada' }}
                        </p>
                    </div>
                    <div class="card-footer bg-white">
                        <a class="btn btn-sm btn-primary w-100" href="{{ route("paginas.conselho-detalhes", $conselho->slug) }}">
                            <i class="fas fa-info-circle me-1"></i> Detalhes
                        </a>
                    </div>
                </div>
            </div>
        @endforeach
    </div>

    <div id="noResults" class="row d-none">
        <div class="col-12">
            <div class="alert alert-warning text-center py-4">
                <i class="fas fa-school fa-3x mb-3"></i>
                <h4>Nenhum conselho encontrado</h4>
                <p class="mb-0">Tente ajustar os filtros de pesquisa</p>
            </div>
        </div>
    </div>
</div>
@endsection
