<?php $__env->startSection('title', __('MobiAngra - Transporte Coletivo') . ' - ' . config('app.name')); ?>

<?php $__env->startSection('content'); ?>
    <?php echo $__env->make('mobiangra.sections.hero', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('mobiangra.sections.feature-grid', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('mobiangra.sections.map-preview', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('mobiangra.sections.alerts-promo', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('mobiangra.sections.news', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('mobiangra.sections.org-info', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<?php $__env->stopSection(); ?>

<?php $__env->startPush('scripts'); ?>
    <?php if(($linhas ?? collect())->isNotEmpty()): ?>
        <script>
            window.mobiangraHorariosConfig = {
                navigateUrl: <?php echo json_encode(route('mobiangra.horarios'), 15, 512) ?>,
            };
        </script>
        <script src="<?php echo e(asset('mobiangra-assets/js/mobiangra_busca_linhas.js')); ?>?v=<?php echo e(time()); ?>"></script>
        <script src="<?php echo e(asset('mobiangra-assets/js/horarios.js')); ?>?v=<?php echo e(time()); ?>"></script>
    <?php endif; ?>
    <?php if(($alertasDestaque ?? collect())->count() > 1): ?>
        <script src="<?php echo e(asset('mobiangra-assets/js/feature-alertas-rotator.js')); ?>?v=<?php echo e(time()); ?>"></script>
    <?php endif; ?>
    <script src="<?php echo e(asset('mobiangra-assets/js/nearby-lines.js')); ?>?v=<?php echo e(time()); ?>"></script>
<?php $__env->stopPush(); ?>

<?php echo $__env->make('layouts.mobiangra.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/mobiangra/index.blade.php ENDPATH**/ ?>