<!-- Cultura -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-secondary">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-theater-masks fa-2x me-3"></i>
                <h5 class="card-title mb-0">Cultura</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-book me-2 text-muted"></i> Bibliotecas <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-calendar-alt me-2 text-muted"></i> Eventos culturais <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-umbrella-beach me-2 text-muted"></i> Turismo Cultural <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-landmark me-2 text-muted"></i>
                    <a href="{{ route("paginas.cultura.arteSacra.index") }}" class="text-dark">Museu de Arte Sacra <small class="text-secondary">(Digital)</small></a>
                </li>
                <li class="list-group-item"><i class="fas fa-user-edit me-2 text-muted"></i> Cadastro de Fazedor de Cultura <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
    </div>
</div>