@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Nova Ata'))

@section('content')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-file-signature'></i> " . __('Nova Ata'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.atas.index',
            'routeBackParams' => request()->only(\App\Http\Resources\AtaResource::ADMIN_FILTER_KEYS),
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_ATAS',
        ])

        <div class="card-body">
            <form method="post" action="{{ route('admin.atas.store') }}" enctype="multipart/form-data">
                @csrf
                @include('admin.atas._filterHidden')
                @include('admin.atas._form')
            </form>
        </div>
    </div>
@endsection

