
<?php
    $mensagensNaoLidasPorChamado = $mensagensNaoLidasPorChamado ?? [];
?>
<div class="tab-pane fade <?php echo e($tabAtual === 'manifestacoes' ? 'show active' : ''); ?>"
     id="tab-manifestacoes" role="tabpanel" aria-labelledby="tab-manifestacoes-btn">

    <div class="d-flex flex-wrap align-items-center justify-content-between gap-2 mb-3">
        <h5 class="mb-0">
            <i class="fa-solid fa-comments me-1"></i><?php echo e(__('Manifestações')); ?>

            <?php if($manifestacoes): ?>
                <span class="badge bg-secondary ms-1"><?php echo e($manifestacoes->total()); ?></span>
            <?php endif; ?>
        </h5>
        <a href="<?php echo e(route('mobiangra.fale_conosco')); ?>" target="_blank" class="btn btn-sm btn-outline-primary">
            <i class="fa-solid fa-eye me-1"></i><?php echo e(__('Ver formulário no site')); ?>

        </a>
    </div>

    <?php if($manifestacoes && $manifestacoes->isNotEmpty()): ?>
        <div class="table-responsive">
            <table class="table table-hover align-middle mb-0">
                <thead class="table-light">
                    <tr>
                        <th scope="col" style="width:150px"><?php echo e(__('Nº registro')); ?></th>
                        <th scope="col"><?php echo e(__('Data')); ?></th>
                        <th scope="col"><?php echo e(__('Solicitante')); ?></th>
                        <th scope="col"><?php echo e(__('Linha')); ?></th>
                        <th scope="col" style="width:150px"><?php echo e(__('Status')); ?></th>
                        <th scope="col" class="text-end"><?php echo e(__('Ações')); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?php $__currentLoopData = $manifestacoes; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <tr>
                            <td class="text-nowrap chamado-registro-numero-cell">
                                <?php if($item->chamado): ?>
                                    <?php if (isset($component)) { $__componentOriginal018c289c834ca61b8c2b8ef0361ed1dd = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal018c289c834ca61b8c2b8ef0361ed1dd = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.chamados.registro-numero-badge','data' => ['numero' => $item->chamado->numeroChamado,'naoLidas' => $mensagensNaoLidasPorChamado[(string) $item->chamado->id] ?? 0]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('chamados.registro-numero-badge'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['numero' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($item->chamado->numeroChamado),'nao-lidas' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($mensagensNaoLidasPorChamado[(string) $item->chamado->id] ?? 0)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal018c289c834ca61b8c2b8ef0361ed1dd)): ?>
<?php $attributes = $__attributesOriginal018c289c834ca61b8c2b8ef0361ed1dd; ?>
<?php unset($__attributesOriginal018c289c834ca61b8c2b8ef0361ed1dd); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal018c289c834ca61b8c2b8ef0361ed1dd)): ?>
<?php $component = $__componentOriginal018c289c834ca61b8c2b8ef0361ed1dd; ?>
<?php unset($__componentOriginal018c289c834ca61b8c2b8ef0361ed1dd); ?>
<?php endif; ?>
                                <?php else: ?>
                                    <span class="text-muted">-</span>
                                <?php endif; ?>
                            </td>
                            <td class="text-nowrap"><?php echo e($item->created_at?->format('d/m/Y H:i')); ?></td>
                            <td><?php echo e($item->identificacao); ?></td>
                            <td><?php echo e($item->linha ?: '-'); ?></td>
                            <td>
                                <?php if($item->chamado): ?>
                                    <span class="badge <?php echo e($item->chamado->statusChamado === 'Finalizado' ? 'bg-secondary' : 'bg-primary'); ?>">
                                        <?php echo e($item->chamado->statusChamado); ?>

                                    </span>
                                <?php else: ?>
                                    <span class="badge bg-warning text-dark"><?php echo e(__('Legado')); ?></span>
                                <?php endif; ?>
                            </td>
                            <td class="text-end">
                                <?php if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_MOBIANGRA')['visualizar'] ?? false): ?>
                                    <a href="<?php echo e(route('admin.mobiangra.manifestacoes.show', $item)); ?>"
                                       class="btn btn-sm btn-outline-primary"
                                       title="<?php echo e(__('Visualizar')); ?>">
                                        <i class="fa-solid fa-eye"></i>
                                    </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </tbody>
            </table>
        </div>

        <div class="mt-3">
            <?php echo e($manifestacoes->withQueryString()->links()); ?>

        </div>
    <?php else: ?>
        <div class="alert alert-info mb-0">
            <i class="fa-solid fa-circle-info me-1"></i>
            <?php echo e(__('Nenhuma manifestação registrada até o momento.')); ?>

        </div>
    <?php endif; ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/admin/mobiangra/manifestacoes/_tab.blade.php ENDPATH**/ ?>