<div class="home-mais-buscados-col col-12 col-sm-12 col-md-6 col-lg-4 col-xl-3 col-xxl-3">
    <div onclick="javascript:window.open('{{ $url }}', '_blank')" class="card">
        <div class="imgTopicos" style="background-color: {{ $color }}">
            <h4>{!! __($header) !!}</h4>
            <img src="{{ asset($image) }}" class="card-img-top img-fluid">
        </div>
        <div class="card-body">
            <h5 class="card-title">{{ __($title) }}</h5>
            <p class="card-text">{{ __($subtitle) }}</p>
        </div>
    </div>
</div>