<p>{{ __('Olá, :nome.', ['nome' => $chamado->user?->name ?? __('cidadão')]) }}</p>

<p>{{ __('Há uma nova resposta referente à sua manifestação no MobiAngra.') }}</p>

<p><strong>{{ __('Número de registro') }}:</strong> {{ $chamado->numeroChamado }}</p>
<p><strong>{{ __('Status') }}:</strong> {{ $chamado->statusChamado }}</p>

<p><strong>{{ __('Mensagem') }}:</strong></p>
<p>{!! nl2br(e(strip_tags($mensagem->mensagem))) !!}</p>

<p>{{ __('Acesse sua Conta Angra para visualizar o histórico completo e responder, se necessário.') }}</p>
