@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Lista de Unidades de Saúde')
@section('content')

    @include("errors.messageFlash")


    <div class="card shadow-sm">
        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center mb-3 tittle-sup">
            <h5 class="mb-0"> Lista de Unidades de Saúde</h5>
            
        </div>
        
        <div class="card-body">
            <div class="d-flex">
                @include('components.buttons._newButton', ['url' => 'admin.unidadesSaude.create', 'text' => 'Nova unidade'])
            </div>
            <form id="searchAccounts" class="d-flex mb-4 pt-3" method="get">
                <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
                <input type="text" class="form-control me-2" name="q" placeholder="Pesquisar unidade de saúde..."
                    value="{{ request()->input('q') }}">
                <button class="btn btn-outline-success" type="submit"><i class="fa-solid fa-magnifying-glass"></i></button>
            </form>

            <div class="table-responsive">
                <table class="table table-bordered table-hover table-striped align-middle text-center">
                    @include('components.tables._thead', ['thead' => ['Foto', 'Nome', 'Pertence a', 'Bairro', 'Email', 'Telefone', 'Tipo', 'Status', 'Ações']])
                    <tbody>
                        @php $index = 0 @endphp
                        @forelse($unidadesSaude as $unidade)
                            <tr>
                                <td>
                                    <img src="{{ asset($unidade->foto) }}" alt="{{ $unidade->nome }}" class="rounded-circle"
                                        style="width: 90px; height: 90px; object-fit: cover; cursor: pointer;"
                                        data-bs-toggle="modal" data-bs-target="#modalUnidadeSaude{{ $unidade->id }}" />

                                    <!-- Modal exclusivo para esse paciente -->
                                    <div class="modal fade" id="modalUnidadeSaude{{ $unidade->id }}" tabindex="-1"
                                        aria-hidden="true">
                                        <div class="modal-dialog modal-fullscreen">
                                            <div class="modal-content bg-dark">
                                                <div class="modal-header border-0">
                                                    <button type="button" class="btn-close btn-close-white ms-auto"
                                                        data-bs-dismiss="modal" aria-label="Fechar"></button>
                                                </div>
                                                <div class="modal-body d-flex justify-content-center align-items-center">
                                                    <img src="{{ asset($unidade->foto) }}" alt="{{ $unidade->nome }}"
                                                        class="img-fluid rounded" style="max-height: 90vh;" />
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </td>
                                <td>{{ $unidade->nome }}</td>
                                <td>{{ $unidade->pertence->name }}</td>
                                <td>{{ $unidade->endereco->bairro }}</td>
                                <td>{{ $unidade->email }}</td>
                                <td>{{ $unidade->telefone }}</td>
                                <td>{{ $unidade->tipoUnidadeSaude }}</td>
                                <td>
                                    <form id="{{ "checkStatus_" . $index }}" class="fix"
                                        action="{{ route("admin.unidadesSaude.status", $unidade->id)}}" method="post">
                                        @csrf
                                        <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
                                        @if($unidade->status == "ATIVADO")
                                            <div class="form-check form-switch d-flex justify-content-center">
                                                <input type="hidden" name="checkStatus" value="DESATIVADO">
                                                <input class="form-check-input" type="checkbox" checked
                                                    onclick="javascript:$('#{{ "checkStatus_" . $index }}').submit()">
                                            </div>
                                        @else
                                            <div class="form-check form-switch d-flex justify-content-center">
                                                <input type="hidden" name="checkStatus" value="ATIVADO">
                                                <input class="form-check-input" type="checkbox"
                                                    onclick="javascript:$('#{{ "checkStatus_" . $index }}').submit()">
                                            </div>
                                        @endif
                                    </form>
                                </td>
                                <td>
                                    <div class="btn-group" role="group">
                                        <a href="{{ route('admin.unidadesSaude.edit', $unidade->id) }}"
                                            class="btn btn-sm btn-warning" title="Editar"><i
                                                class="fa-solid fa-pen-to-square"></i></a>

                                        @if (in_array('DELETE', explode(',', auth()->user()->papers)))
                                            <form class="d-inline" action="{{ route('admin.unidadesSaude.destroy', $unidade->id) }}"
                                                method="post" onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
                                                <input type="hidden" name="confirm"
                                                    value="{{ __('* Esta unidade de saúde será excluída e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger" title="Excluir">
                                                    <i class="fa-solid fa-trash"></i>
                                                </button>
                                            </form>
                                        @endif

                                    </div>
                                </td>
                            </tr>
                            @php $index++ @endphp
                        @empty
                            <tr>
                                <td colspan="9" class="text-muted fst-italic">* Nenhum registro encontrado!</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>

            <div class="d-flex justify-content-center mt-4">
                {!! $unidadesSaude->links() !!}
            </div>
        </div>
    </div>
@endsection