@props([
    'labels' => [],
    'empty' => '-',
])

@php
    $items = array_values(array_filter((array) $labels));
@endphp

@if($items === [])
    <span class="text-muted small">{{ $empty }}</span>
@else
    <div class="d-flex flex-column align-items-start gap-1 cr-responsible-badges">
        @foreach($items as $label)
            <span class="badge text-bg-light border fw-normal">{{ $label }}</span>
        @endforeach
    </div>
@endif
