<!-- Tecnologia e Inovação -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-danger">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-microchip fa-2x me-3"></i>
                <h5 class="card-title mb-0">Tecnologia e Inovação</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item">
                    <i class="fas fa-file-alt me-2 text-muted"></i> 
                    <a href="https://angra.sei.rj.gov.br/sei/controlador_externo.php?acao=usuario_externo_logar&id_orgao_acesso_externo=0" target="_blank" class="text-dark">Sistema eletrônico de informações (SEI)</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-network-wired me-2 text-muted"></i> 
                    <a href="https://parquetecmar.angra.rj.gov.br" target="_blank" class="text-dark">Parque tecnológico do mar</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-database me-2 text-muted"></i> 
                    <a href="{{ route("servicos.dadosAbertos.index") }}" class="text-dark">Portal de dados abertos</a> 
                </li>
                <li class="list-group-item">
                    <i class="fas fa-database me-2 text-muted"></i> 
                    <a href="{{ route("servicos.comiteGovernanca.index") }}" class="text-dark">Comitê Municipal de Governança Digital</a> 
                </li>
            </ul>
        </div>
    </div>
</div>