@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção")
@section('content')

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Concursos Públicos e Processos de Seleção") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <h1>{{ __("Concursos Públicos e Processos de Seleção") }}</h1>


                    <hr>
                    <h1 class="top30">PMAR</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        @foreach($concursos as $concurso)
                            @if($concurso->id_instituicao == 1 && $concurso->cd_status == 1)
                                <li>
                                    <strong>{{ $concurso->ds_ano}}</strong><br>
                                    {!! $concurso->ds_observacao !!}
                                    <br>
                                    <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |
				
                                    <a href="{{ route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 
                                    
                                    <a href="{{ route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Publicação</strong>
                                    </a>	
                                </li>
                            @endif
                        @endforeach
                    </ul>
                    <h3>Realizados</h3>
                    <ul class="olist_normal">
                        @foreach($concursos as $concurso)
                            @if($concurso->id_instituicao == 1 && $concurso->cd_status == 2)
                                <li>
                                    <strong>{{ $concurso->ds_ano}}</strong><br>
                                    {!! $concurso->ds_observacao !!}
                                    <br>
                                    <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |
				
                                    <a href="{{ route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 
                                    
                                    <a href="{{ route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            @endif
                        @endforeach
                    </ul>
                    <h1 class="top30">ANGRAPREV</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        @foreach($concursos as $concurso)
                            @if($concurso->id_instituicao == 3 && $concurso->cd_status == 1)
                                <li>
                                    <strong>{{ $concurso->ds_ano}}</strong><br>
                                    {!! $concurso->ds_observacao !!}
                                    <br>
                                    <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="{{ route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="{{ route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            @endif
                        @endforeach
                    </ul>
                    <h1 class="top30">FUSAR</h1>
                    <h3>Em andamento</h3>
                    <ul class="olist_normal">
                        @foreach($concursos as $concurso)
                            @if($concurso->id_instituicao == 2 && $concurso->cd_status == 1)
                                <li>
                                    <strong>{{ $concurso->ds_ano}}</strong><br>
                                    {!! $concurso->ds_observacao !!}
                                    <br>
                                    <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="{{ route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="{{ route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            @endif
                        @endforeach
                    </ul>
                    <h3>Realizados</h3>
                    <ul class="olist_normal">
                        @foreach($concursos as $concurso)
                            @if($concurso->id_instituicao == 2 && $concurso->cd_status == 2)
                                <li>
                                    <strong>{{ $concurso->ds_ano}}</strong><br>
                                    {!! $concurso->ds_observacao !!}
                                    <br>
                                    <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">
                                        <strong>Andamento do Concurso</strong> 
                                    </a>  |

                                    <a href="{{ route("paginas.concursos.editaisConvocacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Convocação</strong>
                                    </a> | 

                                    <a href="{{ route("paginas.concursos.editaisPublicacoes", $concurso->id_concurso) }}">
                                        <strong>Editais de Publicação</strong>
                                    </a>
                                </li>
                            @endif
                        @endforeach
                    </ul>
                </div>
            </div>
        </div>
    </section>


@endsection