@props([
    'structureId' => null,
    'ariaLabel' => null,
])

@php
    $ariaLabel = $ariaLabel ?? __('Informações laterais do órgão');
    $sidebar = \App\Support\StructureSidebar::forStructure($structureId);
@endphp

@if ($sidebar['secretaria'])
    <aside
        {{ $attributes->merge(['class' => 'internas-secretarias-home-aside col-lg-3 col-md-3 col-sm-12']) }}
        aria-label="{{ $ariaLabel }}"
    >
        @include('paginas.parts.links', [
            'secretaria' => $sidebar['secretaria'],
            'links' => $sidebar['links'],
        ])
        @include('paginas.parts.servicos', [
            'htmls' => $sidebar['htmls'],
        ])
        @include('paginas.parts.telefones', [
            'telefones' => $sidebar['telefones'],
        ])
    </aside>
@endif
