@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: História - História da Obra')

@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-church'></i> Arte Sacra - História da Obra"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            "headLine" => __($headLine),
            "routeBack" => "admin.cultura.arteSacra.index",
            "routeBackParams" => [],
            "fontawesomeBack" => '<i class="fa-solid fa-rectangle-list"></i>',
            "nameBack" => __("Lista de Peças"),
            "routeAdd" => "admin.cultura.arteSacra.create",
            "routeAddParams" => [],
            "nameAdd" => __("Nova peça"),
            "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
        ])

        <div class="alert alert-info rounded-0 mb-0">
            <small>
                <strong>Nome:</strong> {{ $acervo->nome_peca }} <br>
                <strong>Código:</strong> {{ $acervo->codigo_acervo }}
            </small>
        </div>
        <div class="alert alert-warning rounded-top-0">
            @if ($historiaAtual)
                <p>{!! $historiaAtual->historia_obra !!}</p>
            @else
                <p class="text-muted text-center">Ainda não há uma história cadastrada para esta obra.</p>
            @endif
        </div>

        <div class="card-body">

            @include('errors.messageFlash')

            

            <div class="col mb-5">
                <div class="card shadow-lg border-light">
                    <div class="card-header text-center bg-warning text-dark">
                        <h4 class="mb-0">Adicionar ou Editar História</h4>
                    </div>
                    <div class="card-body">
                        <form action="{{ route('admin.cultura.arteSacra.historiaArte.update', $acervo->id) }}" method="POST">
                            @csrf
                            @method('PUT')

                            @if (session('conteudoSolicitacao') && session('solicitacaoId'))
                                <input type="hidden" name="solicitacao_id" value="{{ session('solicitacaoId') }}">
                            @endif

                            <textarea class="form-control textarea-body @error('descricao') is-invalid @enderror" name="descricao" id="descricao"
                                rows="10">{{ old('descricao', session('conteudoSolicitacao') ?? ($historiaAtual->historia_obra ?? '')) }}</textarea>

                            <small class="text-muted mt-2 d-block text-center">Descreva a história ou o significado dessa obra de
                            arte.</small>

                            @error('descricao')
                                <small class="text-danger fw-bold">{{ $message }}</small>
                            @enderror

                            <div class="d-flex justify-content-end mt-3">
                                <button type="submit" class="btn btn-primary btn-lg ms-auto">Salvar História</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <div class="col">
                <h4 class="text-center mb-4">Solicitações de Comentários</h4>

                <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">
                    <li class="nav-item-fibromialgia me-2" role="presentation">
                        <button class="nav-link" id="aceitas-tab" data-bs-toggle="tab" data-bs-target="#aceitas" type="button"
                        role="tab">Aceitas</button>
                    </li>
                    <li class="nav-item-fibromialgia me-2" role="presentation">
                        <button class="nav-link active" id="pendentes-tab" data-bs-toggle="tab" data-bs-target="#pendentes"
                        type="button" role="tab">Pendentes</button>
                    </li>
                </ul>

                <div class="tab-content mt-3" id="solicitacoesTabsContent">
                    <div class="tab-pane fade show active" id="pendentes" role="tabpanel">
                        @if ($solicitacoesPendentes->isEmpty())
                            <p class="text-muted text-center">Nenhuma solicitação pendente.</p>
                        @else
                            <ul class="list-group">
                                @foreach ($solicitacoesPendentes as $solicitacao)
                                    <li class="list-group-item mb-3 shadow-sm rounded">
                                        <strong>{{ $solicitacao->nome_usuario ?? 'Usuário Anônimo' }}</strong>
                                        <p>{!! $solicitacao->historia_obra !!}</p>
                                        <div class="d-flex justify-content-end gap-3">
                                            <form action="{{ route('admin.cultura.arteSacra.historiaArte.aceitar', $solicitacao->id) }}"
                                      method="POST">
                                                @csrf
                                                <button type="submit" class="btn btn-success btn-sm">Aprovar</button>
                                            </form>

                                            <form action="{{ route('admin.cultura.arteSacra.historiaArte.destroy', $solicitacao->id) }}"
                                      method="POST">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-danger btn-sm"
                                            onclick="return confirm('Tem certeza que deseja excluir esta solicitação? Esta ação não pode ser desfeita.')">
                                        Rejeitar
                                                </button>
                                            </form>
                                        </div>
                                    </li>
                                @endforeach
                            </ul>
                        @endif
                    </div>

                    <div class="tab-pane fade" id="aceitas" role="tabpanel">
                        @if ($solicitacoesAceitas->isEmpty())
                            <p class="text-muted text-center">Nenhuma solicitação aceita.</p>
                        @else
                            <ul class="list-group">
                                @foreach ($solicitacoesAceitas as $solicitacao)
                                    <li class="list-group-item mb-3 shadow-sm rounded">
                                        <strong>{{ $solicitacao->nome_usuario ?? 'Usuário Anônimo' }}</strong>
                                        <p>{!! $solicitacao->historia_obra !!}</p>
                                        <div class="d-flex justify-content-end gap-3">
                                            <form action="{{ route('admin.cultura.arteSacra.historiaArte.destroy', $solicitacao->id) }}"
                                      method="POST">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-danger btn-sm"
                                            onclick="return confirm('Tem certeza que deseja excluir esta solicitação? Esta ação não pode ser desfeita.')">
                                        Remover
                                                </button>
                                            </form>
                                        </div>
                                    </li>
                                @endforeach
                            </ul>
                        @endif
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
