<?php $__env->startSection('title', env('APP_NAME') . ' :: Horários de Ônibus'); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route('paginas.home')); ?>">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(url('/secretarias/secretaria-executiva-de-ordem-publica-e-mobilidade-urbana')); ?>"><?php echo e(__('Secretaria Executiva de Ordem Pública e Mobilidade Urbana')); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Transporte e Trânsito</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-md-9 nopadding single-article espaco_conteudo">
                    <header class="article-header">
                        <h1 class="title">Transporte Coletivo</h1>
                    </header>
                    <article class="article-main">
                        <h3 class="top30">H&oacute;rarios e Itinerários do Município</h3>
                        <p><strong>Linhas</strong></p>
                        <ul class="olist_normal">
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/1">101 - Cantagalo <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/2">102 - Caputera <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/3">103 - Camorim <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/4">104 - Monsuaba <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/5">106 - Jacuecanga <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/6">202 - Frade - Via Beira Rio
                                    | Sertãozinho <i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/7">203 - Serra d'&aacute;gua <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/8">205 - Areal <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/36">206 - Banqueta <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/34">207 - Japu&iacute;ba <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/35">208 - Belém <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/13">220 - Japu&iacute;ba - Via
                                    Balneário <i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/14">221 - Nova Angra <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/15">224 - Vila Nova <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/16">225 - Campo Belo <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/31">227 - Expresso - Parque
                                    Mambucaba <i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/32">230 - Itinga <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/18">300 - Japu&iacute;ba X
                                    Ponta Leste<i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/19">306 - Bel&eacute;m X
                                    jacuecanga <i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/20">C01 - Circular <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/21">C03 - Marinas <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/22">C04 - Vila Velha <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/23">C05 - Retiro <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/38">C07 - Circular Parque
                                    Mambucaba <i class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/25">T10 - Div. Mangaratiba <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/26">T11 - Ponta Leste <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/27">T20 - Parque Mambucaba <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                            <li><a target="_blank" href="http://www.vsbonfim.com.br/horarios/37">T21 - Frade <i
                                        class="fa fa-external-link-square" aria-hidden="true"></i></a></li>
                        </ul>

                        <h3 class="top30">Integração</h3>
                        <p><strong>Linhas que efetuam integração / Tempo para integração</strong></p>
                        <ul class="olist_normal">
                            <li>(C01) Circular com (C04) Vila Velha / 60 minutos</li>

                            <li>(C05) Retiro com (207) Japuíba / 100 minutos</li>
                            <li>(C05) Retiro com (225) Japuíba Campo Belo / 100 minutos</li>
                            <li>(C05) Retiro com (220) Japuíba via Balneário / 100 minutos</li>

                            <li>(206) Banqueta com (300) Japuíba Ponta Leste / 120 minutos</li>
                            <li>(206) Banqueta com (306) Belém Jacuecanga / 120 minutos</li>

                            <li>(T10) Divisa Mangaratiba com (306) Belém Jacuecanga / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (300) Japuíba Ponta Leste / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (T11) Ponta Leste / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (104) Monsuaba / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (101) Cantagalo / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (102) Caputera / 120 minutos</li>
                            <li>(T10) Divisa Mangaratiba com (206) Banqueta / 120 minutos</li>
                            <li>(T11) Ponta Leste-volta com (208) Belém-ida / 120 minutos</li>

                            <li>(T20) Parque Mambucaba com (230) Itinga / 120 minutos</li>
                            <li>(230) Itinga com (T20) Parque Mambucaba / 120 minutos</li>

                            <li>(T21) Frade com (230) Itinga / 120 minutos</li>
                            <li>(202) Frade “micrinho” com (230) Itinga / 120 minutos</li>

                            <li>(206) Banqueta com (T11) Ponta Leste / 120 minutos</li>
                            <li>(206) Banqueta com (106) Jacuecanga / 120 minutos</li>

                            <li>(300) Japuíba Ponta Leste com (208) Belém / 120 minutos</li>
                            <li>(101) Cantagalo com (T10) Divisa Mangaratiba com (300) Japuíba Ponta Leste / 120 minutos
                            </li>
                            <li>(101) Cantagalo com (T10) Divisa Mangaratiba com (306) Belém Jacuecanga / 120 minutos</li>

                            <li>(103) Camorim com (300) Japuíba Ponta Leste / 120 minutos</li>
                            <li>(103) Camorim com (306) Belém Jacuecanga / 120 minutos</li>
                            <li>(104) Monsuaba com (300) Japuíba Ponta Leste / 120 minutos</li>

                        </ul>




                    </article>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/horarios-onibus.blade.php ENDPATH**/ ?>