@php
    use App\Models\PontoFocal;
    use App\Models\Structure;

    // Buscar todos os pontos focais com suas instituições
    $pontosFocais = PontoFocal::with('instituicao')
        ->whereHas('instituicao', function ($query) {
            $query->where('status', 'ATIVADO');
        })
        ->get()
        ->groupBy('structure_id');

    // Buscar as instituições que têm pontos focais
    $instituicoesIds = $pontosFocais->keys();
    $instituicoes = Structure::whereIn('id', $instituicoesIds)
        ->where('status', 'ATIVADO')
        ->orderBy('name', 'asc')
        ->get();
@endphp



<section id="pontosFocais">
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 p-3 text-center">
                <h1> <strong> PONTOS FOCAIS </strong></h1>
            </div>
            <div class="col-12 mb-5 pt-2">
                <div class="card border-0 shadow rounded-4 overflow-hidden">
                    <div class="card-body p-4 p-lg-5">
                        <div class="row g-4 align-items-center">
                            <div class="col-12 col-lg-8">
                                <div class="d-flex align-items-center gap-3 mb-3">
                                    <img src="{{ asset('sei-angra/assets/img/guia-ponto-focal-thumb.png') }}"
                                        alt="{{ __('Capa do Guia do Ponto Focal') }}"
                                        class="rounded-3 shadow-sm border"
                                        style="width: 84px; height: 120px; object-fit: cover;"
                                        loading="lazy">
                                    <div>
                                        <div class="d-flex align-items-center gap-2 flex-wrap">
                                            <h2 class="h4 mb-0 fw-bold">{{ __('Guia do Ponto Focal') }}</h2>
                                        </div>
                                        <div class="text-body-secondary mt-1">
                                            {{ __('Conheça suas responsabilidades, atribuições e recomendações para atuar como Ponto Focal.') }}
                                        </div>
                                    </div>
                                </div>

                                <div class="d-flex flex-wrap gap-2">
                                    <span class="badge rounded-pill text-bg-light border text-body">
                                        <i class="fa-solid fa-circle-check me-1 text-success" aria-hidden="true"></i>
                                        {{ __('Responsabilidades') }}
                                    </span>
                                    <span class="badge rounded-pill text-bg-light border text-body">
                                        <i class="fa-solid fa-circle-check me-1 text-success" aria-hidden="true"></i>
                                        {{ __('Atribuições') }}
                                    </span>
                                    <span class="badge rounded-pill text-bg-light border text-body">
                                        <i class="fa-solid fa-circle-check me-1 text-success" aria-hidden="true"></i>
                                        {{ __('Boas práticas') }}
                                    </span>
                                </div>
                            </div>

                            <div class="col-12 col-lg-4">
                                <div class="d-grid gap-2">
                                    <a href="{{ asset('sei-angra/assets/docs/guiadopontofocal.pdf') }}" target="_blank"
                                        rel="noopener noreferrer" class="btn btn-primary btn-lg">
                                        <span class="me-2">{{ __('Abrir guia em PDF') }}</span>
                                        <i class="fa-solid fa-arrow-up-right-from-square" aria-hidden="true"></i>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-12 p-3 text-center">
            <h3>Veja quem são os Ponto Focais da PMAR e CMAR</h3>
        </div>

        <div class="container mt-2">
            <div class="accordion border-0 shadow-sm rounded-5" id="instituicoesAccordion">
                <!-- SECRETARIA - PONTO FOCAL ACCORDION -->
                <div class="accordion-item border-0 shadow my-2 rounded-5">
                    <h2 class="accordion-header" id="camaraHeader"> <button class="accordion-button fw-bold collapsed"
                            type="button" data-bs-toggle="collapse" data-bs-target="#camaraCollapse"
                            aria-expanded="false" aria-controls="camaraCollapse"> Câmara
                            Municipal de Angra dos Reis (CMAR)</button> </h2>
                    <div id="camaraCollapse" class="accordion-collapse collapse" aria-labelledby="camaraHeader"
                        data-bs-parent="#instituicoesAccordion">
                        <div class="accordion-body">
                            <ul class="list-group mb-4">
                                <li class="list-group-item "> <strong>1- Bernard de
                                        Oliveira Maia</strong><br> Matrícula: 5272<br>
                                    Tel: (24) 2404-1713 <br> Email:
                                    sti@angradosreis.rj.leg.br </li>
                                <li class="list-group-item "> <strong>2- Carlos Frederico
                                        de Carvalho </strong><br> Matrícula: 4545<br>
                                    Tel: (24) 2404-1713 <br> Email:
                                    sti@angradosreis.rj.leg.br </li>
                                <li class="list-group-item "> <strong>3- Thiago da Silva
                                        Oliveira Souza </strong><br> Matrícula: 5270<br>
                                    Tel: (24) 2404-1713 <br> Email:
                                    sti@angradosreis.rj.leg.br </li>
                                <li class="list-group-item "> <strong>4- Maximiliano
                                        Moreira Rodrigues </strong><br> Matrícula:
                                    4616<br> Tel: (24) 2404-1713 <br> Email:
                                    sti@angradosreis.rj.leg.br </li>
                                <li class="list-group-item "> <strong>5- André da Glória
                                        Santos Ferreira </strong><br> Matrícula:
                                    8289<br> Tel: (24) 2404-1713 <br> Email:
                                    sti@angradosreis.rj.leg.br </li>
                            </ul>
                        </div>
                    </div>
                </div>
                @foreach($instituicoes as $instituicao)
                    @php
                        $pontos = $pontosFocais->get($instituicao->id, collect());
                        $headerId = 'header' . str_replace([' ', '(', ')', '-'], '', $instituicao->id);
                        $collapseId = 'collapse' . str_replace([' ', '(', ')', '-'], '', $instituicao->id);
                    @endphp
                    <div class="accordion-item border-0 shadow my-2 rounded-5">
                        <h2 class="accordion-header" id="{{ $headerId }}">
                            <button class="accordion-button fw-bold collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#{{ $collapseId }}" aria-expanded="false" aria-controls="{{ $collapseId }}">
                                {{ $instituicao->name }}@if($instituicao->abbreviation)
                                ({{ $instituicao->abbreviation }})@endif
                            </button>
                        </h2>
                        <div id="{{ $collapseId }}" class="accordion-collapse collapse" aria-labelledby="{{ $headerId }}"
                            data-bs-parent="#instituicoesAccordion">
                            <div class="accordion-body">
                                <ul class="list-group mb-4">
                                    @foreach($pontos as $index => $ponto)
                                        <li class="list-group-item">
                                            <strong>{{ $index + 1 }}- {{ $ponto->nome }}</strong><br>
                                            @if($ponto->matricula)
                                                Matrícula: {{ $ponto->matricula }}<br>
                                            @endif
                                            @if($ponto->telefone_ramal)
                                                @php
                                                    $telefoneRamal = $ponto->telefone_ramal;
                                                    if (str_contains($telefoneRamal, 'Ramal:')) {
                                                        $telefoneRamal = str_replace('Ramal:', '', $telefoneRamal);
                                                        echo 'Ramal: ' . trim($telefoneRamal) . '<br>';
                                                    } elseif (str_contains($telefoneRamal, '/')) {
                                                        $parts = explode('/', $telefoneRamal);
                                                        $tel = trim($parts[0]);
                                                        $ramal = isset($parts[1]) ? trim(str_replace('Ramal:', '', $parts[1])) : '';
                                                        if ($tel) {
                                                            echo 'Tel: ' . $tel . '<br>';
                                                        }
                                                        if ($ramal) {
                                                            echo 'Ramal: ' . $ramal . '<br>';
                                                        }
                                                    } else {
                                                        echo 'Tel: ' . $telefoneRamal . '<br>';
                                                    }
                                                @endphp
                                            @endif
                                            @if($ponto->email)
                                                Email: {{ $ponto->email }}
                                            @endif
                                        </li>
                                    @endforeach
                                </ul>
                            </div>
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
    </div>
</section>