<?php $__env->startSection("title", env("APP_NAME") . " :: " . __("Pesquisa de Satisfação")); ?>
<?php $__env->startPush('scripts'); ?>
<link rel="stylesheet" href="<?php echo e(asset('pmar/css/pesquisa-satisfacao.css')); ?>">
<script src="<?php echo e(asset('pmar/js/pesquisa-satisfacao.js')); ?>"></script>
<?php $__env->stopPush(); ?>
<?php $__env->startSection('content'); ?>

<div class="container">
    <div class="row pb-5mx-auto justify-content-center">
        <div class="col">
            <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <!-- Card de Informações do Chamado -->
            <div class="card border-0 shadow-sm mb-4">
                <div class="card-header bg-primary text-white py-3">
                    <h1 class="text-center text-white"><?php echo e(__("Pesquisa de Satisfação")); ?></h1>
                    <p class="text-center text-white">
                        <?php echo e(__("Sua opinião é muito importante para nós!")); ?>

                    </p>
                </div>

                <!-- Alerta Informativo -->
                <div class="alert alert-info border-0 shadow-sm mb-4" role="alert">
                    <div class="d-flex align-items-start">
                        <i class="fa-solid fa-info-circle me-3 mt-1 pesquisa-info-icon"></i>
                        <div>
                            <h5 class="alert-heading mb-2"><?php echo e(__("Por que responder?")); ?></h5>
                            <p class="mb-0"><?php echo e(__("Esta pesquisa nos ajuda a melhorar nossos serviços. Leva menos de 2 minutos e é totalmente anônima.")); ?></p>
                        </div>
                    </div>
                </div>
                <div class="card-body">
                    <div class="row g-2">
                        <div class="col-md-6">
                            <div class="info-item">
                                <i class="fa-solid fa-hashtag text-primary me-2 my-1"></i>
                                <strong><?php echo e(__("Número")); ?>:</strong>
                                <span class="ms-2"><?php echo e($chamado->numeroChamado); ?></span>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="info-item">
                                <i class="fa-solid fa-file-lines text-primary me-2 my-1"></i>
                                <strong><?php echo e(__("Assunto")); ?>:</strong>
                                <span class="ms-2"><?php echo e($chamado->assunto); ?></span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <form action="<?php echo e(route('admin.contaAngra.chamados.pesquisa-satisfacao.store', $chamado->id)); ?>" method="post" id="pesquisaForm">
                <?php echo csrf_field(); ?>
                <?php echo method_field('post'); ?>

                <!-- Pergunta 1: Chamado Resolvido -->
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-body p-4">
                        <h4 class="pergunta-titulo mb-4">
                            <i class="fa-solid fa-circle-check text-primary me-2"></i>
                            <?php echo e(__("O chamado foi resolvido?")); ?>

                            <span class="text-danger">*</span>
                        </h4>
                        <div class="row g-2">
                            <div class="col-6">
                                <label class="opcao-card opcao-sim" for="chamado_resolvido_sim">
                                    <input type="radio" name="chamado_resolvido" id="chamado_resolvido_sim" value="1" required class="d-none">
                                    <div class="opcao-content">
                                        <i class="fa-solid fa-check-circle"></i>
                                        <span><?php echo e(__("Sim")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6">
                                <label class="opcao-card opcao-nao" for="chamado_resolvido_nao">
                                    <input type="radio" name="chamado_resolvido" id="chamado_resolvido_nao" value="0" required class="d-none">
                                    <div class="opcao-content">
                                        <i class="fa-solid fa-times-circle"></i>
                                        <span><?php echo e(__("Não")); ?></span>
                                    </div>
                                </label>
                            </div>
                        </div>
                        <?php $__errorArgs = ['chamado_resolvido'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                        <small class="text-danger d-block mt-2"><?php echo e($message); ?></small>
                        <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                    </div>
                </div>

                <!-- Pergunta 2: Problema Resolvido -->
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-body p-4">
                        <h4 class="pergunta-titulo mb-4">
                            <i class="fa-solid fa-puzzle-piece text-primary me-2"></i>
                            <?php echo e(__("O problema foi resolvido?")); ?>

                            <span class="text-danger">*</span>
                        </h4>
                        <div class="row g-2">
                            <div class="col-6">
                                <label class="opcao-card opcao-sim" for="problema_resolvido_sim">
                                    <input type="radio" name="problema_resolvido" id="problema_resolvido_sim" value="1" required class="d-none">
                                    <div class="opcao-content">
                                        <i class="fa-solid fa-check-circle"></i>
                                        <span><?php echo e(__("Sim")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6">
                                <label class="opcao-card opcao-nao" for="problema_resolvido_nao">
                                    <input type="radio" name="problema_resolvido" id="problema_resolvido_nao" value="0" required class="d-none">
                                    <div class="opcao-content">
                                        <i class="fa-solid fa-times-circle"></i>
                                        <span><?php echo e(__("Não")); ?></span>
                                    </div>
                                </label>
                            </div>
                        </div>
                        <?php $__errorArgs = ['problema_resolvido'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                        <small class="text-danger d-block mt-2"><?php echo e($message); ?></small>
                        <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                    </div>
                </div>

                <!-- Pergunta 3: Satisfação -->
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-body p-4">
                        <h4 class="pergunta-titulo mb-4">
                            <i class="fa-solid fa-heart text-primary me-2"></i>
                            <?php echo e(__("Como você avalia nosso atendimento?")); ?>

                            <span class="text-danger">*</span>
                        </h4>
                        <p class="text-muted mb-4 text-center"><?php echo e(__("Clique na opção que melhor representa sua satisfação")); ?></p>
                        <div class="row g-2">
                            <div class="col-6 col-md-4 col-lg">
                                <label class="satisfacao-card satisfacao-muito-ruim" for="satisfacao_muito_ruim">
                                    <input type="radio" name="satisfacao" id="satisfacao_muito_ruim" value="Muito Ruim" required class="d-none">
                                    <div class="satisfacao-content">
                                        <i class="fa-solid fa-face-frown"></i>
                                        <span class="satisfacao-label"><?php echo e(__("Muito Ruim")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6 col-md-4 col-lg">
                                <label class="satisfacao-card satisfacao-ruim" for="satisfacao_ruim">
                                    <input type="radio" name="satisfacao" id="satisfacao_ruim" value="Ruim" required class="d-none">
                                    <div class="satisfacao-content">
                                        <i class="fa-solid fa-face-meh"></i>
                                        <span class="satisfacao-label"><?php echo e(__("Ruim")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6 col-md-4 col-lg">
                                <label class="satisfacao-card satisfacao-regular" for="satisfacao_regular">
                                    <input type="radio" name="satisfacao" id="satisfacao_regular" value="Regular" required class="d-none">
                                    <div class="satisfacao-content">
                                        <i class="fa-solid fa-face-meh-blank"></i>
                                        <span class="satisfacao-label"><?php echo e(__("Regular")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6 col-md-4 col-lg">
                                <label class="satisfacao-card satisfacao-bom" for="satisfacao_bom">
                                    <input type="radio" name="satisfacao" id="satisfacao_bom" value="Bom" required class="d-none">
                                    <div class="satisfacao-content">
                                        <i class="fa-solid fa-face-smile"></i>
                                        <span class="satisfacao-label"><?php echo e(__("Bom")); ?></span>
                                    </div>
                                </label>
                            </div>
                            <div class="col-6 col-md-4 col-lg">
                                <label class="satisfacao-card satisfacao-muito-bom" for="satisfacao_muito_bom">
                                    <input type="radio" name="satisfacao" id="satisfacao_muito_bom" value="Muito Bom" required class="d-none">
                                    <div class="satisfacao-content">
                                        <i class="fa-solid fa-face-smile-beam"></i>
                                        <span class="satisfacao-label"><?php echo e(__("Muito Bom")); ?></span>
                                    </div>
                                </label>
                            </div>
                        </div>
                        <?php $__errorArgs = ['satisfacao'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                        <small class="text-danger d-block mt-3 text-center"><?php echo e($message); ?></small>
                        <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                    </div>
                </div>

                <!-- Comentários Opcionais -->
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-body p-4">
                        <h4 class="pergunta-titulo mb-3">
                            <i class="fa-solid fa-comment-dots text-primary me-2"></i>
                            <?php echo e(__("Comentários (opcional)")); ?>

                        </h4>
                        <p class="text-muted small mb-3"><?php echo e(__("Tem alguma sugestão ou observação? Compartilhe conosco!")); ?></p>
                        <?php echo $__env->make('components.inputs._textarea', [
                        'label' => '',
                        'name' => 'comentario',
                        'id' => 'comentario',
                        'rows' => 5,
                        'required' => false,
                        'height' => '120px',
                        'class' => "form-control",
                        'style' => null,
                        "oninput" => null,
                        'value' => old('comentario'),
                        'small' => __('Máximo de 1000 caracteres'),
                        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    </div>
                </div>

                <!-- Botões de Ação -->
                <div class="d-grid gap-2 d-md-flex justify-content-center mb-4 text-center">
                    <button type="submit" class="btn btn-green btn-lg px-5">
                        <i class="fa-solid fa-paper-plane me-2"></i>
                        <?php echo e(__("Enviar Pesquisa")); ?>

                    </button>
                </div>

            </form>
        </div>
    </div>
</div>

<div data-message-incomplete="<?php echo e(__('Por favor, responda todas as questões obrigatórias antes de enviar.')); ?>" class="d-none"></div>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/contaAngra/chamados/pesquisa-satisfacao.blade.php ENDPATH**/ ?>