@extends('layouts.admin.theme')

@section('title', 'Editar Situação')

@section('content')
@include('errors.messageFlash')

<div class="card shadow-lg h-100">
    <div class="card-header bg-primary text-white fw-bolder py-3">
        <div class="d-flex justify-content-between align-items-center">
            <h5 class="mb-0">
                <i class="fas fa-edit me-2"></i>Editar Situação Meteorológica
            </h5>
            <a href="{{ route('admin.situacoes.index') }}" class="btn btn-light btn-sm">
                <i class="fas fa-arrow-left me-1"></i>Voltar
            </a>
        </div>
    </div>

    <div class="card-body p-4 mt-5 pt-5">
        <form action="{{ route('admin.situacoes.update', $situacao->id) }}" method="POST">
            @csrf
            @method('PUT')

            <div class="row justify-content-center">
                <div class="col-md-8">
                    <div class="card border-0 bg-light">
                        <div class="card-body p-4">
                            <div class="text-center mb-4">
                                <i class="fas fa-edit fa-2x text-soft mb-3"></i>
                                <h5 class="text-soft">Editar Informações da Situação</h5>
                                <p class="text-muted">Atualize os dados da situação meteorológica</p>
                            </div>

                            <div class="mb-4">
                                <label for="descricao" class="form-label fw-bold text-dark">
                                    Descrição da Situação *
                                </label>
                                <input type="text" 
                                       name="descricao" 
                                       id="descricao" 
                                       class="form-control form-control-lg @error('descricao') is-invalid @enderror" 
                                       value="{{ old('descricao', $situacao->descricao) }}" 
                                       placeholder="Ex: Tempo parcialmente nublado com possibilidade de chuvas isoladas"
                                       required
                                       autofocus>
                                @error('descricao')
                                    <div class="invalid-feedback">
                                        <i class="fas fa-exclamation-triangle me-1"></i>{{ $message }}
                                    </div>
                                @enderror
                                <div class="form-text">
                                    <i class="fas fa-lightbulb text-warning me-1"></i>
                                    Descreva detalhadamente as condições meteorológicas
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="d-flex justify-content-between align-items-center mt-4 pt-3 border-top">
                        <a href="{{ route('admin.situacoes.index') }}" class="btn btn-outline-secondary">
                            <i class="fas fa-times me-2"></i>Cancelar
                        </a>
                        <button type="submit" class="btn btn-success px-4">
                            <i class="fas fa-save me-2"></i>Atualizar Situação
                        </button>
                    </div>
                </div>
            </div>
        </form>
    </div>
</div>
@endsection