@if($permission == null)
    <li @if (Route::currentRouteName() == $route) class="active" @endif>
        <a href="{{ route($route) }}">
            {!! $fontawesome !!}
            <span class="links_name">{{ $nameButton }}</span>
        </a>
        <span class="tooltip">{{ $nameButton }}</span>
    </li>
    @if($divider != null)
        <hr>
    @endif
@else
    @if (in_array($permission, auth()->user()->listaPermissoes()))
        <li @if (Route::currentRouteName() == $route) class="active" @endif>
            <a href="{{ route($route) }}">
                {!! $fontawesome !!}
                <span class="links_name">{{ $nameButton }}</span>
            </a>
            <span class="tooltip">{{ $nameButton }}</span>
        </li>
    @endif
    @if($divider != null)
        <hr>
    @endif
@endif