<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <meta name="site" content="https://angra.rj.gov.br">

    <title><?php echo $__env->yieldContent('title'); ?></title>

    <meta name="description" content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade."/>
    <meta name="robots" content="noodp"/>

    <link rel="canonical" href="https://www.angra.rj.gov.br" />

    <meta property="og:locale" content="pt_BR" />
    <meta property="og:type" content="government" />
    <meta property="og:title" content="Prefeitura de Angra dos Reis" />
    <meta property="og:description" content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade." />
    <meta property="og:url" content="https://www.angra.rj.gov.br" />
    <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
    <meta property="og:image"content="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png"/>

    <meta http-equiv="cache-control" content="max-age=0" />
    <meta http-equiv="cache-control" content="no-cache" />
    <meta http-equiv="expires" content="0" />
    <meta http-equiv="expires" content="Tue, 01 Jan 2977 1:00:00 GMT" />
    <meta http-equiv="pragma" content="no-cache" />

    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-57x57-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-60x60-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-72x72-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-76x76-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-114x114-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-120x120-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-144x144-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-152x152-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-180x180-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="192x192"  href="<?php echo e(asset("pmar/assets/fiveicon/android-icon-192x192-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-32x32-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-96x96-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-16x16-2026.png")); ?>">
    <link rel="manifest" href="<?php echo e(asset("pmar/assets/fiveicon/manifest.json")); ?>">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="<?php echo e(asset("pmar/assets/fiveicon/ms-icon-144x144-2026.png")); ?>">
    <meta name="theme-color" content="#ffffff">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css">
    <link href='https://unpkg.com/boxicons@2.0.7/css/boxicons.min.css' rel='stylesheet'>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>

    
    <link rel="stylesheet" href="<?php echo e(asset('pmar/fontawesome/css/all.min.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/style.css')); ?>">
</head>
<?php /**PATH /var/www/html/portal/resources/views/layouts/window/elements/head.blade.php ENDPATH**/ ?>