<div class="mb-3">
    <label for="telefone" class="form-label text-bold">{{ __("Telefone da empresa") }}:</label>
    <input type="text" class="form-control @error('telefone') is-invalid @enderror" name="telefone" id="telefone" autocomplete="off" value="{{ old('telefone') }}">
                                @error('telefone')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="celular" class="form-label text-bold">{{ __("Celular da empresa") }}:</label>
    <input type="text" class="form-control @error('celular') is-invalid @enderror" name="celular" id="celular" autocomplete="off" value="{{ old('celular') }}">
                                @error('celular')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="email" class="form-label text-bold">{{ __("Email da empresa") }}: <span class="span-admin-create">*</span></label>
    <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" id="email" autocomplete="off" value="{{ old('email') }}">
                                @error('email')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="site" class="form-label text-bold">{{ __("Site da empresa") }}:</label>
    <input type="text" class="form-control @error('site') is-invalid @enderror" name="site" id="site" autocomplete="off" value="{{ old('site') }}">
                                @error('site')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
