@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Atualizar Registro de Dívida Ativa")
@section('content')

    <form action="{{ route('admin.dividaAtiva.update', $divida->id) }}" method="post" enctype="multipart/form-data">
        <div class="container mt-5 pb-5">
            <div class="row">
                <div class="col-12">
                    <div class="card shadow">
                        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
                            <h5 class="my-2">Atualizar Registro de Dívida Ativa</h5>
                        </div>
                        <div class="card-body">
                            @csrf
                            @method('PUT')
                            @include("errors.messageFlash")
                            
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="numInscricao" class="form-label text-bold">Número de inscrição:</label>
                                        <input type="text" class="form-control @error('numInscricao') is-invalid @enderror" name="numInscricao" id="numInscricao" value="{{ old('numInscricao', $registro->numInscricao) }}" oninput="this.value = this.value.replace(/[^0-9]/g, '')" autocomplete="off">
                                        @error('numInscricao')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="numImovel" class="form-label text-bold">Número do imóvel:</label>
                                        <input type="text" class="form-control @error('numImovel') is-invalid @enderror" name="numImovel" id="numImovel" value="{{ old('numImovel', $registro->numImovel) }}" oninput="this.value = this.value.replace(/[^0-9]/g, '')" autocomplete="off">
                                        @error('numImovel')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-6 d-flex justify-content-center align-items-center">
                                    <div class="form-check form-check-inline">
                                        <input class="form-check-input" type="radio" name="isPJ" id="isPessoaFisica" value="1" {{ old('isPJ', $registro->isPJ) == '1' ? 'checked' : '' }} onclick="javascript:isPessoaFisicaOuPessoaJuridica(this.value)">
                                        <label class="form-check-label" for="isPessoaFisica"> Pessoa física </label>
                                    </div>
                                    <div class="form-check form-check-inline">
                                        <input class="form-check-input" type="radio" name="isPJ" id="isPessoaJuridica" value="0" {{ old('isPJ', $registro->isPJ) == '0' ? 'checked' : '' }} onclick="javascript:isPessoaFisicaOuPessoaJuridica(this.value)">
                                        <label class="form-check-label" for="isPessoaJuridica"> Pessoa jurídica </label>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3 {{ old('isPJ', '1') == '0' ? 'd-none' : '' }}" id="pessoaFisica">
                                        <label for="cpf" class="form-label text-bold">CPF: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('cpf') is-invalid @enderror" name="cpf" id="cpf" autocomplete="off" value="{{ old('cpf', $registro->cpf) }}" oninput="javascript:aplicarMascaraCPF(this)" autocomplete="off">
                                        @error('cpf')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="mb-3 {{ old('isPJ', '1') == '1' ? 'd-none' : '' }}" id="pessoaJuridica">
                                        <label for="cnpj" class="form-label text-bold">CNPJ: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('cnpj') is-invalid @enderror" name="cnpj" id="cnpj" value="{{ old('cnpj', $registro->cnpj) }}" oninput="javascript:aplicarMascaraCNPJ(this)" autocomplete="off">
                                        @error('cnpj')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="nome" class="form-label text-bold">Nome ou razão social: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('nome') is-invalid @enderror" name="nome" id="nome" value="{{ old('nome', $registro->nome) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        @error('nome')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="origemDivida" class="form-label text-bold">Origem da dívida: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('origemDivida') is-invalid @enderror" list="optionsOrigemDivida" name="origemDivida" id="origemDivida" value="{{ old('origemDivida', $registro->origemDivida) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        <datalist id="optionsOrigemDivida">
                                            @foreach($origens as $origem)
                                                <option value="{{ $origem->origem }}"></option>
                                            @endforeach
                                        </datalist>
                                        @error('origemDivida')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="exercicio" class="form-label text-bold">Ano de abertura: <span class="span-admin-create">*</span></label>
                                        <input type="year" class="form-control @error('exercicio') is-invalid @enderror" name="exercicio" id="datepickerYear" autocomplete="off" value="{{ old('exercicio', $registro->exercicio) }}">
                                        @error('exercicio')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="dividaData" class="form-label text-bold">Data da dívida: <span class="span-admin-create">*</span></label>
                                        <input type="date" class="form-control @error('dividaData') is-invalid @enderror" name="dividaData" id="dividaData" value="{{ old('dividaData', $registro->dividaData) }}" autocomplete="off">
                                        @error('dividaData')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="numCertidao" class="form-label text-bold">Número da certidão: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('numCertidao') is-invalid @enderror" name="numCertidao" id="numCertidao" value="{{ old('numCertidao', $registro->numCertidao) }}" oninput="this.value = this.value.replace(/[^0-9]/g, '')" autocomplete="off">
                                        @error('numCertidao')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="dividaStatus" class="form-label text-bold">Status da dívida: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('dividaStatus') is-invalid @enderror" list="optionsDividaStatus" name="dividaStatus" id="dividaStatus" value="{{ old('dividaStatus', $registro->dividaStatus) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        <datalist id="optionsDividaStatus">
                                            <option value="BLOQUEADO PROTESTADO"></option>
                                            <option value="EM ANÁLISE"></option>
                                            <option value="NORMAL"></option>
                                            <option value="NORMAL PROTESTADO"></option>
                                        </datalist>
                                        @error('dividaStatus')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="dividaValorTotal" class="form-label text-bold">Valor da dívida:</label>
                                        <input type="text" class="form-control @error('dividaValorTotal') is-invalid @enderror"  name="dividaValorTotal" id="dividaValorTotal" value="{{ old('dividaValorTotal', $registro->dividaValorTotal) }}" oninput="javascript:mascaraMoeda(this);" autocomplete="off">
                                        @error('dividaValorTotal')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div class="mb-3">
                                        <label for="status" class="form-label text-bold">Status: <span class="span-admin-create">*</span></label>
                                        <select class="form-control @error('status') is-invalid @enderror" name="status" id="status">
                                            @foreach(App\Enums\StatusEnum::cases() as $status)
                                                <option value="{{ $status->name }}" {{ old("status", $registro->status) == $status->name ? "selected" : "" }}>{{ $status->value }}</option>
                                            @endforeach
                                        </select>
                                        @error('status')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <hr/>
                                        <div class="form-check mb-3">
                                            <input class="form-check-input" type="checkbox" name="dividaParcelado" id="dividaParcelado" {{ old('dividaParcelado', $registro->dividaParcelado) ? 'checked' : '' }}>
                                            <label class="form-check-label" for="dividaParcelado"> Esta divida foi parcelada? <small class="text-primary">se sim, selecione esta opção.</small></label>
                                        </div>
                                        <div class="form-check mb-3">
                                            <input class="form-check-input" type="checkbox" name="dividaProtestado" id="dividaProtestado" {{ old("dividaProtestado", $registro->dividaProtestado) ? "checked" : "" }}>
                                            <label class="form-check-label" for="dividaProtestado"> Esta divida foi protestada? <small class="text-primary">se sim, selecione esta opção.</small></label>
                                        </div>
                                        <div class="form-check mb-3">
                                            <input class="form-check-input" type="checkbox" name="dividaAjuizado" id="dividaAjuizado" {{ old("dividaAjuizado", $registro->dividaAjuizado) ? "checked" : "" }}>
                                            <label class="form-check-label" for="dividaAjuizado"> Esta divida foi ajuizada? <small class="text-primary">se sim, selecione esta opção.</small></label>
                                        </div>
                                    <hr/>
                                </div>
                                <div class="col-12">
                                    <div class="mb-3">
                                        <label for="informacoes" class="form-label text-bold">Informações adicionais: <small class="text-primary">(⚠️ <strong class="text-danger">Atenção, administrador</strong>: estas informações são internas e não serão visíveis para os usuários finais.)</small></label>
                                        <textarea class="form-control textarea-body @error('informacoes') is-invalid @enderror" style="height: 400px" name="informacoes" id="informacoes">{{ old('informacoes', $registro->status) }}</textarea>
                                        @error('informacoes')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                                @include('components.buttons._backAndSend', [
                                    'textBack' => 'Voltar', 
                                    'textSend' => 'Atualizar', 
                                    'routeBack' => 'admin.dividaAtiva.index'])
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </form>

    @endsection