<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'linhas',
    'linhaAtivaIdx' => null,
    'label' => __('Selecione a linha desejada para consultar os horários de saída.'),
    'placeholder' => __('Buscar por nº ou nome da linha...'),
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'linhas',
    'linhaAtivaIdx' => null,
    'label' => __('Selecione a linha desejada para consultar os horários de saída.'),
    'placeholder' => __('Buscar por nº ou nome da linha...'),
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    $linhaAtiva = $linhaAtivaIdx !== null ? $linhas[$linhaAtivaIdx] ?? null : null;
    $valorInicial = $linhaAtiva
        ? $linhaAtiva->codigo . ' - ' . $linhaAtiva->nome
        : '';
?>

<div class="mb-4 horarios-linha-select-wrap horarios-linha-combobox"
     id="horarios-linha-combobox"
     data-msg-sem-resultados="<?php echo e(__('Nenhuma linha encontrada.')); ?>">

    <label for="horarios-linha-search" class="form-label fw-semibold">
        <?php echo e($label); ?>

    </label>

    <div class="horarios-linha-combobox__control"
         role="combobox"
         aria-expanded="false"
         aria-haspopup="listbox"
         aria-owns="horarios-linha-listbox">

        <div class="horarios-linha-combobox__busca">
            <i class="fa-solid fa-magnifying-glass horarios-linha-combobox__icone" aria-hidden="true"></i>
            <input type="search"
                   id="horarios-linha-search"
                   class="form-control horarios-linha-combobox__input <?php echo e($linhaAtiva ? 'horarios-linha-combobox__input--ativo' : ''); ?>"
                   value="<?php echo e($valorInicial); ?>"
                   placeholder="<?php echo e($placeholder); ?>"
                   autocomplete="off"
                   aria-autocomplete="list"
                   aria-controls="horarios-linha-listbox"
                   aria-label="<?php echo e(__('Buscar linha')); ?>" />
        </div>

        <ul id="horarios-linha-listbox"
            class="horarios-linha-combobox__list d-none"
            role="listbox"
            aria-label="<?php echo e(__('Linhas')); ?>"
            tabindex="-1"></ul>
    </div>

    <select id="horarios-linha-combobox-source"
            class="d-none"
            aria-hidden="true"
            tabindex="-1">
        <?php $__currentLoopData = $linhas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $linha): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <option value="<?php echo e($linha->codigo); ?>"
                    data-linha-id="<?php echo e($linha->id); ?>"
                    data-codigo="<?php echo e($linha->codigo); ?>"
                    data-nome="<?php echo e($linha->nome); ?>"
                    data-label="<?php echo e($linha->codigo); ?> - <?php echo e($linha->nome); ?>">
                <?php echo e($linha->codigo); ?> - <?php echo e($linha->nome); ?>

            </option>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </select>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/horarios-linha-combobox.blade.php ENDPATH**/ ?>