<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.sei.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body id="page-top" class="animate__animated animate__fadeIn">
    <header>
        <?php echo $__env->make('layouts.sei.elements.defaultBar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <?php echo $__env->make('layouts.sei.elements.nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    </header>
    <?php echo $__env->make('layouts.sei.elements.modal', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->yieldContent('content'); ?>
    <footer class="footer-pmar">
        <?php echo $__env->make('layouts.sei.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </footer>

</body>

</html><?php /**PATH /var/www/html/portal/resources/views/layouts/sei/theme.blade.php ENDPATH**/ ?>