@props(['title', 'description' => null, 'icon' => 'fa-grid-2'])

<div class="section-header mb-4">
    <h2 class="section-title">
        <i class="fa-solid {{ $icon }} me-2"></i>
        {{ __($title) }}
    </h2>
    @if($description)
        <p class="section-description text-muted">{{ __($description) }}</p>
    @endif
</div>
