@php $empresa = $empresaTurismo->companhia @endphp
@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Lista de Embarcações da Empresa ' . $empresa->razaoSocial)
@section('content')

    @php
        $filterParams = \App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource::listFilterParamsFromRequest(request());
    @endphp

    <div class="card shadow-sm">

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __('Lista de Embarcações da empresa :empresa', ['empresa' => $empresa->razaoSocial ?? '-']),
            'routeBack' => 'admin.empresasDeTurismo.index',
            'routeBackParams' => $filterParams,
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.embarcacoes.create',
            'routeAddParams' => [$empresaTurismo->id],
            'nameAdd' => __('Nova embarcação'),
            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
        ])


        <div class="card-body">

            @include("errors.messageFlash")

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "cadastroDeEmpresas", 
                "placeholder" => "Pesquisar por embarcação..."
            ])

            <x-tables._table :thead="['Nome','Data de Cadastro','Categoria','Inscricao','RCI','Capacidade','Tipo','Status','Ações']" :pagination="$embarcacoes->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($embarcacoes as $embarcacao)
                        <tr>
                            <td>{{ $embarcacao->nome }}</td>
                            <td>{{ date("d/m/Y H:m", strtotime($embarcacao->created_at)) }}</td>
                            <td>
                                @include('components.tables._getEnumValue', [
                                "EnumClass" => App\Enums\StatusTipoCategoriaEmbarcacoesNavegueLegal::cases(),
                                "arg" => $embarcacao->categoria,
                                "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                            ])
                            </td>
                            <td>{{ $embarcacao->inscricao }}</td>
                            <td>{{ $embarcacao->rci }}</td>
                            <td>{{ $embarcacao->capacidade }}</td>
                            <td>
                                @if($embarcacao->categoria == "TAXI_BOATS")
                                    @include('components.tables._getEnumValue', [
                                    "EnumClass" => App\Enums\StatusTipoBoatsNavegueLegal::cases(),
                                    "arg" => $embarcacao->tipo,
                                    "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                                ])
                                @else
                                    @include('components.tables._getEnumValue', [
                                    "EnumClass" => App\Enums\StatusTipoEmbarcacoesNavegueLegal::cases(),
                                    "arg" => $embarcacao->tipo,
                                    "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                                ])
                                @endif
                            </td>
                            <td>
                                @include('components/buttons/_status', [
                                "index" => $index,
                                "route" => "admin.embarcacoes.status",
                                "id" => [$empresaTurismo->id, $embarcacao->id],
                                "status" => $embarcacao->status,
                                "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                            ])
                            </td>
                            <td>
                                <div class="btn-group" role="group">
                                    @include('components/buttons/_editButton', [
                                    "route" => "admin.embarcacoes.edit",
                                    "id" => [$empresaTurismo->id, $embarcacao->id],
                                    "fontawesome" => null,
                                    "title" => "Editar",
                                    "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                                ])

                                    @include('components/buttons/_deleteButton', [
                                    "message" => "* Esta empresa será excluída e esta ação não poderá ser desfeita?",
                                    "route" => "admin.embarcacoes.destroy",
                                    "id" => [$empresaTurismo->id, $embarcacao->id],
                                    "fontawesome" => null,
                                    "title" => "Excluir",
                                    "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                                ])
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection