<?php $__env->startSection("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção"); ?>
<?php $__env->startSection('content'); ?>

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>"><?php echo e(__("Portal")); ?></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.concursos.index")); ?>"><?php echo e(__("Concursos Públicos e Processos de Seleção")); ?></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>"><?php echo e(__("Andamento")); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page"><?php echo e(__("Convocações")); ?></li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: <?php echo e($concurso->ds_ano); ?></h1>

                    <hr>
                    
                    <h3 class="top30">CONVOCAÇÕES</h3>
                    
                    <div class="col-md-4"><i class="fa-solid fa-square text-primary"></i> <strong>Convocados</strong></div>
                    <div class="col-md-4"><i class="fa-solid fa-square text-danger"></i> <strong>Eliminados ou Desistentes</strong></div>
                    
                    <table class="table">
                        <thead>
                            <tr>
                                <th width="5%">*</th>
                                <th width="12%" class="centro">Inscrição</th>
                                <th class="centro">Nome</th>
                                <th width="12%" class="centro">TP</th>
                            </tr>
                        </thead>

                        <tbody>
                            <?php $count = 1; ?>
                            <?php $__currentLoopData = $candidatos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $candidato): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <tr>
                                    <td class="centro"><?php echo e($count); ?></td>
                                    <td class="centro"><?php echo e($candidato->nr_inscricao); ?></td>
                                    <td class="centro"><?php echo e($candidato->nm_candidato); ?></td>
                                    <td class="centro"><?php echo e($candidato->nr_total_pontos); ?>.00</td>
                                </tr>
                                <?php $count++; ?>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </tbody>
                    </table>


                </div>
            </div>
        </div>
    </section>


<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/concursos/convocacoes.blade.php ENDPATH**/ ?>