<?php $__env->startSection("title", env("APP_NAME") . " :: Vice-Prefeito"); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Vice-Prefeito de Angra dos Reis</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <h1>Vice-Prefeito de Angra dos Reis</h1>
                </div>
                <hr />
                <div class="col-12 col-sm-12 col-md-12 col-lg-9 col-xl-9 col-xxl-9 mb-5">
                    <div class="row">
                        <div class="col-sm-12 col-md-4">
                            <img src="<?php echo e(asset($vicePrefeito["managerPhoto"])); ?>" class="img-fluid img-thumbnail" alt="Vice-Prefeito de Angra dos Reis" title="Prefeito de Angra dos Reis" />
                        </div>
                        <div class="col-sm-12 col-md-8">
                            <h3><?php echo e($vicePrefeito["manager"]); ?></h3>
                            <div><?php echo $vicePrefeito["academicBackground"]; ?> </div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
                    <div class="row">
                        <div class="col-12">
                            <div class="card-slug mb-3">
                                <a>
                                    <div class="d-flex w-100 justify-content-between">
                                        <h5 class="my-3 slug-title"><?php echo e(__("Contato")); ?></h5>
                                    </div>
                                </a>
                                <div class="">
                                    <div class="">
                                        <h5 class="mb-1">
                                            <a class="text-decoration-none text-dark" href="<?php echo e(route("paginas.ouvidoria")); ?>"><?php echo e(__("Fale conosco")); ?></a>
                                        </h5>
                                    </div>
                                </div>
                            </div>
                            <div class="card-slug mb-3">
                                <a>
                                    <div class="d-flex w-100 justify-content-between">
                                        <h5 class="my-2 slug-title"><?php echo e(__("Secretarias, Fundações e Autarquias")); ?></h5>
                                    </div>
                                </a>
                            <?php $__currentLoopData = $secretarias; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $secretaria): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <hr class="fw-bold">
                                    <div class="d-flex w-100 justify-content-start">

                                        <h6 class="mb-1">
                                            <a class="text-decoration-none text-dark" href="<?php echo e(route("paginas.details", $secretaria["slug"])); ?>"><?php echo e($secretaria["name"]); ?></a>
                                        </h6>

                                    </div>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/vice-prefeito.blade.php ENDPATH**/ ?>