<?php $__env->startSection('title', env('APP_NAME') . ' :: ' . $secretaria->name); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container mb-4">
            <div class="row">
                <hr />
                <div class="col-12">
                    <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => \App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, $secretaria->manager)]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(\App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, $secretaria->manager))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
                </div>

                <div class="col-12 col-md-8 mt-4">
                    <div class="row mb-3">
                        <h1 class="name-secretario mb-3"><?php echo e($secretaria->pronunciation); ?></h1>
                        <div class="col-sm-12 col-md-4">
                            <img src="<?php echo e(asset($secretaria->managerPhoto)); ?>" class="img-fluid img-thumbnail"
                                alt="<?php echo e($secretaria->manager); ?>" title="<?php echo e($secretaria->manager); ?>"
                                style="border: none; border-radius: 0;" />
                        </div>
                        <div class="col-sm-12 col-md-8">
                            <?php $__currentLoopData = App\Enums\StructuresPronunciationStatusEnum::cases(); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $pronunciation): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <?php if($pronunciation->name == $secretaria->pronunciation): ?>
                                    <h3><?php echo e($secretaria->manager); ?></h3>
                                <?php endif; ?>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            <div><?php echo $secretaria->academicBackground; ?></div>
                        </div>
                    </div>
                </div>
                
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/secretario.blade.php ENDPATH**/ ?>