@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Visite Angra')

@section('content')

    <div class="card shadow-sm border-0">

        @php $headLine = "<i class='fa-solid fa-compass'></i> Visite Angra"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
        'headLine' => __($headLine),
        "permission" => "GERENCIADOR_VISITE_ANGRA",
    ])

        @include("components.cards._cardNavVisiteAngra")

    </div>

    {{-- Estilo para efeito hover --}}
    <style>
    .hover-card {
        transition: all 0.3s ease;
        border-radius: 0.75rem;
    }
    .hover-card:hover {
        transform: translateY(-5px);
        box-shadow: 0 0.5rem 1rem rgba(0,0,0,0.15);
    }
    </style>
@endsection
