<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'boletim' => null,
    'class' => 'small link-primary',
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'boletim' => null,
    'class' => 'small link-primary',
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php if($boletim && $boletim->nr_bo !== '-'): ?>
    <?php if($boletim->public_bo_pdf_url): ?>
        <a href="<?php echo e($boletim->public_bo_pdf_url); ?>"
            target="_blank"
            rel="noopener noreferrer"
            class="<?php echo \Illuminate\Support\Arr::toCssClasses([$class]); ?>"
            title="<?php echo e(__('Abrir Boletim Oficial nº :numero', ['numero' => $boletim->nr_bo])); ?>">
            <?php echo e($boletim->nr_bo); ?>

        </a>
    <?php else: ?>
        <span class="<?php echo \Illuminate\Support\Arr::toCssClasses([$class, 'text-muted']); ?>"><?php echo e($boletim->nr_bo); ?></span>
    <?php endif; ?>
<?php else: ?>
    <span class="text-muted">—</span>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/legislacao/_boletimNumeroLink.blade.php ENDPATH**/ ?>