<section>
    <div class="container-fluid">
        <div class="row">
            <div class="col-6">
                <div class="d-flex justify-content-start">
                    <small><img src="{{ asset("pmar/assets/fiveicon/favicon-16x16.png") }}" alt="{{ __("Prefeitura de Angra dos Reis") }}" title="{{ __("Prefeitura de Angra dos Reis") }}"/> <a href="{{ route("paginas.home") }}">{{ __("Prefeitura de Angra dos Reis") }}</a></small>
                </div>
            </div>
            <div class="col-6">
                <div class="d-flex justify-content-end">
                    <small><img src="{{ asset(auth()->user()->photo) }}" class="img-fluid img-thumbnail src-file-image" alt="{{ auth()->user()->firstName }} {{ auth()->user()->lastName }}" title="{{ auth()->user()->firstName }} {{ auth()->user()->lastName }}" width="25px"/></small> &nbsp;&nbsp;
                    <small>Olá {{ auth()->user()->firstName }}</small> &nbsp;&nbsp;|&nbsp;&nbsp;
                    <small><a href="{{ route("admin.profile") }}">{{ __("Perfil") }}</a></small> &nbsp;&nbsp;|&nbsp;&nbsp;
                    <small><a href="{{ route("admin.logout") }}">{{ __("Sair") }}</a></small>
                </div>
            </div>
        </div>
    </div>
</section>   