@extends('layouts.landing_pages.calendariodeeventos.theme')

@section('title', __('Calendário de Eventos 2026 em Angra dos Reis'))
@section('og_title', __('Calendário de Eventos 2026/2027'))

@section('content')
{{-- Header / Topo --}}
<header>
    <section class="topo-section">
        <div class="container">
            <div class="row align-items-center g-5 py-5 pb-sm-0">
                <div class="col d-flex justify-content-center align-items-center">
                    <img src="{{ asset('calendario-de-eventos/assets/images/calendario-eventos-2026.svg') }}"
                         class="img-titulo"
                         alt="{{ __('Calendário de Eventos de Angra dos Reis 2026') }}">
                </div>
            </div>
        </div>
    </section>
</header>

<main class="main-content">
    <section class="programacao-section">
        <div class="container">
            <div class="row">

                {{-- Janeiro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Janeiro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 01') }} - </strong> {{ __('Procissão Marítima') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span></p>
                    <p><strong class="data-evento">{{ __('Dia 05') }} - </strong> {{ __('Corrida Santos Reis') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 06') }} - </strong> {{ __('Aniversário da Cidade - 524 anos') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 20') }} - </strong> {{ __('Festa de São Sebastião') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span><br><span class="local-evento">{{ __('Vila do Abraão e Frade') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25') }} - </strong> {{ __('Festival de Verão Futebol Sub-13') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                </div>

                {{-- Fevereiro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Fevereiro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 02') }} - </strong> {{ __('Festa de Iemanjá') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 06 a 08') }} - </strong> {{ __('Pré-Carnaval & Sesc Verão') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11 a 17') }} - </strong> {{ __('Carnaval') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span></p>
                </div>

                {{-- Março --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Março') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 07') }} - </strong> {{ __('Regata do Bracuí') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 08') }} - </strong> {{ __('1º Encontro de Mulheres (Jiu-Jitsu)') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 16') }} - </strong> {{ __('TV Rio Sul de Futsal') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 23') }} - </strong> {{ __('Corrida São José do Operário') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 29 a 04') }} - </strong> {{ __('Semana Santa') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                </div>

                {{-- Abril --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Abril') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 02') }} - </strong> {{ __('Caminhada de Conscientização do Autismo') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p>
                        <strong class="data-evento">{{ __('Dia 03') }} - </strong> {{ __('Paixão de Cristo') }}
                        <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span>
                        <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span><br>
                        <span class="local-evento">{{ __('Centro') }}</span>
                    </p>
                    <p><strong class="data-evento">{{ __('Dia 06') }} - </strong> {{ __('Festa do Glorioso São Benedito') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p>
                        <strong class="data-evento">{{ __('Dia 18') }} - </strong> {{ __('Festa Peixe com Banana') }}
                        <span class="badge-evento badge-gastronomico" title="{{ __('Evento Gastronômico') }}">G</span>
                    </p>
                   
                    <p><strong class="data-evento">{{ __('Dia 23') }} - </strong> {{ __('Festa de São Jorge') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                </div>

                {{-- Maio --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Maio') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 01') }} - </strong> {{ __('Festa de São José Operário') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 01') }} - </strong> {{ __('1ª Etapa de Natação de Águas Abertas') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 03') }} - </strong> {{ __('Festa do Bonfim') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 09') }} - </strong> {{ __('1ª Etapa de Canoagem Oceânica') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 12 a 15') }} - </strong> {{ __('Semana dos Museus') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p>
                        <strong class="data-evento">{{ __('Dia 15 a 17') }} - </strong> {{ __('XTERRA Ilha grande') }}
                        <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span>
                    </p>
                    <p><strong class="data-evento">{{ __('Dia 16') }} - </strong> {{ __('1ª Etapa de Natação em Piscina') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 22 e 24') }} - </strong> {{ __('Festa do Divino Espírito Santo') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 23') }} - </strong> {{ __('Copa de Ginástica Artística') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 24') }} - </strong> {{ __('Aniversário do Centro Cultural Theóphilo Massad') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 24') }} - </strong> Semear <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 24') }} - </strong> Festa da Divina Sardinha <span class="badge-evento badge-gastronomico" title="{{ __('Evento Gastronômico') }}">G</span></p>
                    <p><strong class="data-evento">{{ __('Dia 31') }} - </strong> {{ __('Festa Santíssima Trindade') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                </div>

                {{-- Junho --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Junho') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 01 a 30') }} - </strong> {{ __('Semana Nacional do Meio Ambiente') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 04') }} - </strong> Corpus Christi <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 12') }} - </strong> {{ __('Sagrado Coração de Jesus Centro e Monsuaba') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 13') }} - </strong> {{ __('Quadrangular de Handebol') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 20 a 21') }} - </strong> {{ __('Festival do Mexilhão') }} <span class="badge-evento badge-gastronomico" title="{{ __('Evento Gastronômico') }}">G</span><br><span class="local-evento">{{ __('Araçatiba') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 27 a 28') }} - </strong> {{ __('Festival do Mexilhão') }} <span class="badge-evento badge-gastronomico" title="{{ __('Evento Gastronômico') }}">G</span><br><span class="local-evento">{{ __('Praia da Longa') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 29') }} - </strong> {{ __('Dia do Pescador') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                </div>

                {{-- Julho --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Julho') }}</h3>
                    <p>
                        <strong class="data-evento">{{ __('Dia 03 a 05') }} - </strong> {{ __('Festival de Música e Ecologia da Ilha Grande') }}
                        <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span><br>
                        <span class="local-evento">{{ __('Vila do Abraão') }}</span></p></p>
                    <p><strong class="data-evento">{{ __('Dia 09') }} - </strong> {{ __('Corrida da Defesa Civil') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11') }} - </strong> {{ __('Campeonato Municipal de Futebol Sub-15') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 16') }} - </strong> {{ __('Festa de Nossa Senhora do Carmo') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 17 a 20') }} - </strong> UJADESF <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p>
                        <strong class="data-evento">{{ __('Dia 17 a 19') }} - </strong> {{ __('Arraiá Du Abraão') }}
                        <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br>
                        <span class="local-evento">{{ __('Vila do Abraão') }}</span>
                    </p>
                    <p><strong class="data-evento">{{ __('Dia 23 a 26') }} - </strong> {{ __('28º Angra Moto Fest') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span><br><span class="local-evento">{{ __('Praia do Anil') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 28') }} - </strong> {{ __('Dia do Agricultor') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 31 a 02/08') }} - </strong> {{ __('Arraiá da Cidade') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                </div>

                {{-- Agosto --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Agosto') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 03') }} - </strong> {{ __('Corrida do Colégio Naval') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 13') }} - </strong> {{ __('Festa de Santa Dulce dos Pobres') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11 a 18') }} - </strong> {{ __('Semana da Juventude') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 15 a 17') }} - </strong> {{ __('Torneio Interestadual de Quadrilha') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 22') }} - </strong> {{ __('Quadrangular de Handebol') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 22 a 07/09') }} - </strong> {{ __('16ª FITA - Festa Internacional de Teatro de Angra') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25') }} - </strong> {{ __('Aniversário da Casa de Cultura Poeta Brasil dos Reis') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                </div>

                {{-- Setembro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Setembro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 07') }} - </strong> {{ __('Desfile Cívico da Independência') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 08') }} - </strong> {{ __('Nossa Senhora dos Remédios') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span><br><span class="local-evento">{{ __('Ribeira') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 05 a 07') }} - </strong> {{ __('Festa Country da Monsuaba') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Monsuaba') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 10 a 12') }} - </strong> {{ __('11ª Angra Expo') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11') }} - </strong> {{ __('Dia C de Cooperar') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 19') }} - </strong> {{ __('Campeonato dos Servidores') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 21') }} - </strong> {{ __('Meia Maratona do Parque Mambucaba') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span><br><span class="local-evento">{{ __('Vila Histórica de Mambucaba') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25 a 30') }} - </strong> {{ __('Encontro de Teatro de Rua') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 26') }} - </strong> {{ __('3ª Edição da Festa da Sardinha') }} <span class="badge-evento badge-gastronomico" title="{{ __('Evento Gastronômico') }}">G</span><br><span class="local-evento">{{ __('Praça do Mercado do Peixe') }}</span></p>

                </div>

                {{-- Outubro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Outubro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 05') }} - </strong> {{ __('Corrida de Nossa Senhora Aparecida') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span><br><span class="local-evento">{{ __('Cantagalo') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11') }} - </strong> {{ __('Festival das Crianças') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 11') }} - </strong> {{ __('Dia do Cooperar') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 12') }} - </strong> {{ __('Festa de Nossa Senhora Aparecida') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 24') }} - </strong> {{ __('Interpolo de Futevôlei') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25') }} - </strong> {{ __('Campeonato dos Servidores') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span><br><span class="local-evento">{{ __('Vila do Abraão') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25') }} - </strong> {{ __('Circuito Cervejeiro de Corrida') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span><br><span class="local-evento">{{ __('Vila do Abraão') }}</span></p>
                </div>

                {{-- Novembro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Novembro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 05') }} - </strong> {{ __('Dia Nacional da Cultura') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 15') }} - </strong> {{ __('4º Louvarte') }} <span class="badge-evento badge-religioso" title="{{ __('Evento Religioso') }}">R</span></p>
                    <p><strong class="data-evento">{{ __('Dia 20') }} - </strong> {{ __('Dia da Consciência Negra') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 22') }} - </strong> {{ __('Corrida RosAzul') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 25') }} - </strong> {{ __('Abertura da Vila Noel') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span></p>
                </div>

                {{-- Dezembro --}}
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes">{{ __('Dezembro') }}</h3>
                    <p><strong class="data-evento">{{ __('Dia 05') }} - </strong> {{ __('Natal sem Fome - Futebol') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 06') }} - </strong> {{ __('Interpolo de Handebol') }} <span class="badge-evento badge-esportivo" title="{{ __('Evento Esportivo') }}">E</span></p>
                    <p><strong class="data-evento">{{ __('Dia 08') }} - </strong> {{ __('Festa de Nossa Senhora da Conceição') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 12') }} - </strong> {{ __('Aniversário da Casa Laranjeiras') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span><br><span class="local-evento">{{ __('Centro') }}</span></p>
                    <p><strong class="data-evento">{{ __('Dia 13') }} - </strong> {{ __('Festa de Santa Luzia') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 15') }} - </strong> {{ __('Prêmio Movimenta Angra') }} <span class="badge-evento badge-cultural" title="{{ __('Evento Cultural') }}">C</span></p>
                    <p><strong class="data-evento">{{ __('Dia 21 a 23') }} - </strong> {{ __('Movimenta Angra Natal') }} <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span><br><span class="local-evento"></p>
                    <p><strong class="data-evento">{{ __('Dia 30 e 31') }} - </strong> Réveillon <span class="badge-evento badge-turistico" title="{{ __('Evento Turístico') }}">T</span><br><span class="local-evento">{{ __('Praia do Anil') }}</span></p>
                </div>

            </div>

            {{-- Legenda --}}
            <div class="row">
                <div class="col-12 d-flex justify-content-center legenda-section">
                    <p class="legenda">
                        {{ __('Legenda:') }}
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-cultural">C</span> {{ __('Cultural') }}</span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-turistico">T</span> {{ __('Turístico') }}</span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-esportivo">E</span> {{ __('Esportivo') }}</span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-gastronomico">G</span> {{ __('Gastronômico') }}</span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-religioso">R</span> {{ __('Religioso') }}</span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-corporativo">C</span> {{ __('Corporativo') }}</span>
                    </p>
                </div>
            </div>

        </div>
    </section>

    {{-- Botão Voltar ao Topo --}}
    <button id="btn-go-top" class="btn-go-top" aria-label="{{ __('Voltar ao topo') }}">
        <i class="fas fa-chevron-up" aria-hidden="true"></i>
    </button>
</main>

{{-- Footer --}}
<footer class="footer-eventos">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-lg-6 col-md-6 col-sm-12 mb-5 d-flex justify-content-center align-items-center">
                <img src="{{ asset('calendario-de-eventos/assets/images/Logo-prefeitura-footer-cor.svg') }}"
                     class="img-footer"
                     alt="{{ __('Prefeitura de Angra dos Reis') }}">
            </div>
        </div>
    </div>
</footer>
@endsection