@if (session('success'))
    <div class="alert alert-success">{{ session('success') }}</div>
@endif

@if (session('error'))
    <div class="alert alert-danger">{{ session('error') }}</div>
@endif

@if (session('info'))
    <div class="alert alert-info">{{ session('info') }}</div>
@endif
    
@if ($errors->any())    
    @foreach ($errors->all() as $error)
        <div class="alert alert-danger">
            {!! $error !!}
        </div>
    @endforeach
@endif