@extends('layouts.admin.theme')

@section('content')
    @php
        $ppModuleRoute = $ppModuleRoute ?? (!empty($painelDashboard) ? 'admin.dashboardEstrategico.projetosProgramas' : 'admin.projetosProgramas.index');
        $ppTabQueryKey = $ppTabQueryKey ?? 'tab';
    @endphp
    @include('admin.projetosProgramas.partials._index_conteudo')

    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-table.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-prioridades.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-dashboard.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-visualizar.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-mapa.css') }}">
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css">
    <link rel="stylesheet" href="https://unpkg.com/leaflet.markercluster@1.5.3/dist/MarkerCluster.css">
    <link rel="stylesheet" href="https://unpkg.com/leaflet.markercluster@1.5.3/dist/MarkerCluster.Default.css">
    <script src="{{ asset('pmar/js/projetos-programas.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-table.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-prioridades.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-visualizar.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-andamento-rapido.js') }}"></script>
    <script src="https://unpkg.com/leaflet@1.9.4/dist/leaflet.js"></script>
    <script src="https://unpkg.com/leaflet.markercluster@1.5.3/dist/leaflet.markercluster.js"></script>
    <script src="{{ asset('pmar/js/projetos-programas-mapa.js') }}?v={{ filemtime(public_path('pmar/js/projetos-programas-mapa.js')) }}"></script>
    @if(!empty($canDelete ?? false) && empty($painelDashboard ?? false))
        <script src="{{ asset('pmar/js/projetos-programas-modal-exclusao-massa.js') }}"></script>
    @endif
@endsection

@push('after-scripts')
    <script src="{{ asset('pmar/js/projetos-programas-dashboard.js') }}"></script>
@endpush
