<?php if(count($bannersSection3) > 0): ?>
    <div class="row">
        <div class="col-12">
            <div id="carouselSection3" class="carousel slide" data-bs-ride="carousel" data-bs-interval="4000">
                <div class="carousel-indicators">
                    <?php $__currentLoopData = $bannersSection3; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $banner): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <button type="button" data-bs-target="#carouselSection3" data-bs-slide-to="<?php echo e($index); ?>" 
                        class="<?php echo e($index == 0 ? 'active' : ''); ?>" 
                        aria-label="Slide <?php echo e($index + 1); ?>"></button>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </div>
                <div class="carousel-inner">
                    <?php $__currentLoopData = $bannersSection3; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $banner): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <div class="carousel-item <?php echo e($index == 0 ? 'active' : ''); ?>">
                            <a href="<?php echo e($banner->url); ?>" target="<?php echo e($banner->target); ?>" title="<?php echo e($banner->title); ?>">
                                <img src="<?php echo e(asset($banner->photo)); ?>" alt="<?php echo e($banner->title); ?>" title="<?php echo e($banner->title); ?>" class="d-block w-100">
                            </a>
                        </div>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </div>
                <button class="carousel-control-prev" type="button" data-bs-target="#carouselSection3" data-bs-slide="prev">
                    <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Previous</span>
                </button>
                <button class="carousel-control-next" type="button" data-bs-target="#carouselSection3" data-bs-slide="next">
                    <span class="carousel-control-next-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Next</span>
                </button>
            </div>
        </div>
    </div>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/partsHome/homebanners3.blade.php ENDPATH**/ ?>