<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="csrf-token" content="{{ csrf_token() }}">

    <title>@yield('title', __('MobiAngra') . ' - ' . config('app.name'))</title>

    <meta name="description"
        content="{{ __('Portal MobiAngra - consulte horários, itinerários e acompanhe o transporte coletivo de Angra dos Reis.') }}" />
    <meta name="robots" content="index, follow" />
    <meta name="author" content="{{ __('Prefeitura de Angra dos Reis') }}">

    <meta property="og:locale" content="pt_BR" />
    <meta property="og:type" content="website" />
    <meta property="og:title" content="@yield('title', __('MobiAngra') . ' - ' . config('app.name'))" />
    <meta property="og:description"
        content="{{ __('Mobilidade que conecta Angra. Consulte horários, itinerários e acompanhe seu ônibus em tempo real.') }}" />
    <meta property="og:url" content="{{ url()->current() }}" />
    <meta property="og:site_name" content="{{ __('Prefeitura de Angra dos Reis') }}" />
    <meta property="og:image" content="{{ asset('mobiangra-assets/images/logo_mobiangra_2.png') }}" />

    <link rel="icon" type="image/png" href="{{ asset('mobiangra-assets/images/logo_mobiangra_2.png') }}">
    <link rel="apple-touch-icon" href="{{ asset('mobiangra-assets/images/logo_mobiangra_2.png') }}">
    <meta name="theme-color" content="#21409a">

    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css"
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css"
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="preconnect" href="https://fonts.googleapis.com" />
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin />
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700;800&display=swap"
        rel="stylesheet" />

    <link rel="stylesheet" href="{{ asset('pmar/css/defaultBar.css') }}?v={{ time() }}">
    <link rel="stylesheet" href="{{ asset('mobiangra-assets/css/style.css') }}?v={{ time() }}">
    <link rel="stylesheet" href="{{ asset('mobiangra-assets/css/portal.css') }}?v={{ time() }}">

    @stack('styles')
</head>
