@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar Dados Pessais do Músico - Credenciamento")
@section('content')

    <div class="card shadow">

        @php $headLine = "<i class='fa-solid fa-guitar'></i> Editar Dados Pessais do Músico - Credenciamento"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                    ])

        <div class="card-body">
            <form action="{{ route('admin.cultura.credenciamentoMusicos.dadosPessoais.update', $musico->id) }}" method="post" enctype="multipart/form-data">

                @include("errors.messageFlash")
                @csrf
                @method('post')
                
                @include('components.modal._modelProfile')

                <hr>

                <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">

                    @include('components.lists._liLinkBtnNavInterna', [
                        'items' => [
                            ['class' => 'active bg-success disabled', 'hash' => 'primeiraSection', 'label' => 'Dados de Usuário'],
                            ['class' => 'active bg-success disabled', 'hash' => 'segundaSection', 'label' => 'Dados Pessoais'],
                            ['class' => 'disabled', 'hash' => 'terceiraSection', 'label' => 'Documentos'],
                            ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Endereço'],
                            ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Credenciamento'],
                            ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Integrantes'],
                            ['class' => 'disabled', 'hash' => 'setimaSection', 'label' => 'Arquivos'],
                        ]
                    ])

                </ul>

                <div class="tab-content">
                    
                    
                    <div class="row">
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Nome da mãe -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Nome da mãe completo",
                                "name" => "nomeMae",
                                "id" => null,
                                "required" => true,
                                "type" => null,
                                "old" => old('nomeMae', $pessoa?->nomeMae),
                                "oninput" => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\p{L}\s]+/gu, '').replace(/\s{2,}/g,' ').trimStart()",
                                "readonly" => false,
                                "small" => null,
                            ])
                        </div>
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Nome do Pai -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Nome do pai completo",
                                "name" => "nomePai",
                                "id" => null,
                                "required" => false,
                                "type" => null,
                                "old" => old('nomePai', $pessoa?->nomePai),
                                "oninput" => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\p{L}\s]+/gu, '').replace(/\s{2,}/g,' ').trimStart()",
                                "readonly" => false,
                                "small" => null,
                            ])
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Data de Nascimento -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Data de Nascimento",
                                "name" => "dtaNascimento",
                                "id" => null,
                                "required" => true,
                                "type" => "date",
                                "old" => old('dtaNascimento', $pessoa?->dtaNascimento),
                                "oninput" => "",
                                "readonly" => false,
                                "small" => null,
                            ])
                        </div>
                        <div class="col-sm-12 col-md-6">
                             <!-- Campo Sexo -->
                            @include('components.inputs._selectType', [
                                "for" => "sexo",
                                "label" => "Sexo",
                                "name" => "sexo",
                                "required" => true,
                                "readonly" => false,
                                "options" => collect(App\Enums\StatusSexo::cases())
                                    ->mapWithKeys(fn($status) => [$status->name => $status->value])
                                    ->toArray(),
                                "selected" => old('sexo', $pessoa?->sexo ?? 'NAO_INFORMADO'),
                                "placeholder" => "Selecione uma opção...",
                                "small" => "Informe o sexo.",
                                "onchange" => null
                            ])
                             
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="d-flex justify-content-between mt-4">
                            <a class="btn btn-outline-secondary" href="{{ route("admin.cultura.credenciamentoMusicos.edit", $musico->id) }}">
                                <i class="fa-solid fa-arrow-left-long"></i> {{ __("Anterior") }}
                            </a>
                            <button class="btn btn-primary d-inline" type="submit">
                                <i class="fa-solid fa-user-plus"></i> {{ __("Salvar e Prosseguir") }}
                            </button>
                        </div>
                    </div>
                </div>
            </form>

        </div>
    </div>

