@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção")
@section('content')

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.index") }}">{{ __("Concursos Públicos e Processos de Seleção") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">{{ __("Andamento") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Convocações") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: {{ $concurso->ds_ano }}</h1>

                    <hr>
                    
                    <h3 class="top30">CONVOCAÇÕES</h3>
                    
                    <div class="col-md-4"><i class="fa-solid fa-square text-primary"></i> <strong>Convocados</strong></div>
                    <div class="col-md-4"><i class="fa-solid fa-square text-danger"></i> <strong>Eliminados ou Desistentes</strong></div>
                    
                    <table class="table">
                        <thead>
                            <tr>
                                <th width="5%">*</th>
                                <th width="12%" class="centro">Inscrição</th>
                                <th class="centro">Nome</th>
                                <th width="12%" class="centro">TP</th>
                            </tr>
                        </thead>

                        <tbody>
                            @php $count = 1; @endphp
                            @foreach($candidatos as $candidato)
                                <tr>
                                    <td class="centro">{{ $count }}</td>
                                    <td class="centro">{{ $candidato->nr_inscricao }}</td>
                                    <td class="centro">{{ $candidato->nm_candidato }}</td>
                                    <td class="centro">{{ $candidato->nr_total_pontos }}.00</td>
                                </tr>
                                @php $count++; @endphp
                            @endforeach
                        </tbody>
                    </table>


                </div>
            </div>
        </div>
    </section>


@endsection