<div class="mb-3">
    <input type="hidden" name="papersResponsavelEmpresa" id="papers" value="EDIT"/>
    <input type="hidden" name="permissionResponsavelEmpresa" id="permission" value="GUEST"/>
    <input type="hidden" name="passwordResponsavelEmpresa" id="password" value="mudar123"/>
    <label for="fullNameResponsavelEmpresa" class="form-label text-bold">{{ __("Nome completo") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('fullNameResponsavelEmpresa') is-invalid @enderror" name="fullNameResponsavelEmpresa" id="fullNameResponsavelEmpresa" autocomplete="off" value="{{ old('fullNameResponsavelEmpresa') }}">
    @error('fullNameResponsavelEmpresa')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="cpfResponsavelEmpresa" class="form-label text-bold">{{ __("CPF") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('cpfResponsavelEmpresa') is-invalid @enderror" name="cpfResponsavelEmpresa" id="cpfResponsavelEmpresa" data-mask="cpf" value="{{ old('cpfResponsavelEmpresa') }}" autocomplete="off">
    @error('cpfResponsavelEmpresa')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="phoneNumberResponsavelEmpresa" class="form-label text-bold">{{ __("Telefone") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('phoneNumberResponsavelEmpresa') is-invalid @enderror" name="phoneNumberResponsavelEmpresa" id="phoneNumberResponsavelEmpresa" autocomplete="off" value="{{ old('phoneNumberResponsavelEmpresa') }}">
    @error('phoneNumberResponsavelEmpresa')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="emailResponsavelEmpresa" class="form-label text-bold">{{ __("Email") }}: <span class="span-admin-create">*</span></label>
    <input type="emailResponsavelEmpresa" class="form-control @error('emailResponsavelEmpresa') is-invalid @enderror" name="emailResponsavelEmpresa" id="emailResponsavelEmpresa" autocomplete="off" value="{{ old('emailResponsavelEmpresa') }}">
    @error('emailResponsavelEmpresa')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="photoResponsavelEmpresa" class="form-label text-bold">{{ __("Foto") }}:</label>
    <input type="file" class="form-control @error('photoResponsavelEmpresa') is-invalid @enderror" name="photoResponsavelEmpresa" id="photoResponsavelEmpresa" accept="image/jpeg,image/jpg,image/png,image/gif" />
    @error('photoResponsavelEmpresa')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
