<?php $__env->startSection('title', env('APP_NAME') . ' :: ' . __('Editar Licitação/Procedimento')); ?>

<?php $__env->startSection('content'); ?>
    <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <div class="card shadow-sm">
        <?php $headLine = "<i class='fa-solid fa-scale-balanced'></i> " . __('Licitações e Procedimentos'); ?>
        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.licitacoesProcedimentos.index',
            'routeBackParams' => request()->only(['ano', 'tipo_processo', 'tipo', 'status', 'nr_processo', 'page']),
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_LICITACOES_E_PROCEDIMENTOS',
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

        <div class="card-body">
            <form method="post" action="<?php echo e(route('admin.licitacoesProcedimentos.update', $registro->id)); ?>" enctype="multipart/form-data">
                <?php echo $__env->make('admin.licitacoesProcedimentos._form', ['registro' => $registro], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </form>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php $__env->startPush('scripts'); ?>
    <script src="<?php echo e(asset('pmar/js/admin/licitacoes-procedimentos.js')); ?>?v=<?php echo e(@filemtime(public_path('pmar/js/admin/licitacoes-procedimentos.js')) ?: time()); ?>"></script>
<?php $__env->stopPush(); ?>


<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/licitacoesProcedimentos/edit.blade.php ENDPATH**/ ?>