{{-- Aba Manifestações (incluída em admin.mobiangra.index) --}}
@php
    $mensagensNaoLidasPorChamado = $mensagensNaoLidasPorChamado ?? [];
@endphp
<div class="tab-pane fade {{ $tabAtual === 'manifestacoes' ? 'show active' : '' }}"
     id="tab-manifestacoes" role="tabpanel" aria-labelledby="tab-manifestacoes-btn">

    <div class="d-flex flex-wrap align-items-center justify-content-between gap-2 mb-3">
        <h5 class="mb-0">
            <i class="fa-solid fa-comments me-1"></i>{{ __('Manifestações') }}
            @if ($manifestacoes)
                <span class="badge bg-secondary ms-1">{{ $manifestacoes->total() }}</span>
            @endif
        </h5>
        <a href="{{ route('mobiangra.fale_conosco') }}" target="_blank" class="btn btn-sm btn-outline-primary">
            <i class="fa-solid fa-eye me-1"></i>{{ __('Ver formulário no site') }}
        </a>
    </div>

    @if ($manifestacoes && $manifestacoes->isNotEmpty())
        <div class="table-responsive">
            <table class="table table-hover align-middle mb-0">
                <thead class="table-light">
                    <tr>
                        <th scope="col" style="width:150px">{{ __('Nº registro') }}</th>
                        <th scope="col">{{ __('Data') }}</th>
                        <th scope="col">{{ __('Solicitante') }}</th>
                        <th scope="col">{{ __('Linha') }}</th>
                        <th scope="col" style="width:150px">{{ __('Status') }}</th>
                        <th scope="col" class="text-end">{{ __('Ações') }}</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($manifestacoes as $item)
                        <tr>
                            <td class="text-nowrap chamado-registro-numero-cell">
                                @if ($item->chamado)
                                    <x-chamados.registro-numero-badge
                                        :numero="$item->chamado->numeroChamado"
                                        :nao-lidas="$mensagensNaoLidasPorChamado[(string) $item->chamado->id] ?? 0" />
                                @else
                                    <span class="text-muted">-</span>
                                @endif
                            </td>
                            <td class="text-nowrap">{{ $item->created_at?->format('d/m/Y H:i') }}</td>
                            <td>{{ $item->identificacao }}</td>
                            <td>{{ $item->linha ?: '-' }}</td>
                            <td>
                                @if ($item->chamado)
                                    <span class="badge {{ $item->chamado->statusChamado === 'Finalizado' ? 'bg-secondary' : 'bg-primary' }}">
                                        {{ $item->chamado->statusChamado }}
                                    </span>
                                @else
                                    <span class="badge bg-warning text-dark">{{ __('Legado') }}</span>
                                @endif
                            </td>
                            <td class="text-end">
                                @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_MOBIANGRA')['visualizar'] ?? false)
                                    <a href="{{ route('admin.mobiangra.manifestacoes.show', $item) }}"
                                       class="btn btn-sm btn-outline-primary"
                                       title="{{ __('Visualizar') }}">
                                        <i class="fa-solid fa-eye"></i>
                                    </a>
                                @endif
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>

        <div class="mt-3">
            {{ $manifestacoes->withQueryString()->links() }}
        </div>
    @else
        <div class="alert alert-info mb-0">
            <i class="fa-solid fa-circle-info me-1"></i>
            {{ __('Nenhuma manifestação registrada até o momento.') }}
        </div>
    @endif
</div>
