@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Portal de Dados Abertos (API)")
@section('content')


    <div class="container mb-5">
        <div class="row">
            <div class="col-12 my-3">
                @include('servicos.parts.breadcrumb-dados-abertos', ['current' => __('Estrutura Organizacional (API)')])
            </div>

            <div class="col-12 mb-1">
                <div class="col-12 mb-3">
                    <h1 class="title">Estrutura Organizacional (API)</h1>
                </div>
            </div>
        </div>
    </div>

@endsection