<div class="row">
    <div class="col-sm-12 col-md-6">
        @include('admin.turisAngra.empresasDeTurismo.sections._documentosUploadFields', [
            'empresa' => $empresa ?? null,
        ])
    </div>

    <div class="col-sm-12 col-md-6">
        @include('components.inputs._selectType', [
            'for' => 'status',
            'label' => __('Status do cadastro'),
            'name' => 'status',
            'required' => true,
            'readonly' => false,
            'options' => collect(App\Enums\StatusEnum::cases())
                ->mapWithKeys(fn($status) => [$status->name => $status->value])
                ->toArray(),
            'selected' => old('status', $empresaTurismo->status ?? $empresa?->status ?? ''),
            'placeholder' => __('Selecione o status...'),
            'small' => __('Informe o status atual do cadastro.'),
            'onchange' => null,
        ])
    </div>
</div>
