<div class="alert alert-light border mt-4 mb-0" role="note" aria-labelledby="mobiangra-lgpd-titulo">
    <h2 id="mobiangra-lgpd-titulo" class="h6 fw-bold mb-2">
        <i class="fa-solid fa-shield-halved me-1 text-primary" aria-hidden="true"></i>
        {{ __('Proteção de dados pessoais (LGPD)') }}
    </h2>
    <p class="small mb-2">
        {{ __('Em conformidade com a Lei Geral de Proteção de Dados Pessoais (Lei nº 13.709/2018), informamos que os dados informados neste formulário serão utilizados exclusivamente para análise e resposta da sua manifestação sobre o transporte coletivo municipal.') }}
    </p>
    <p class="small mb-2">
        {{ __('Para preservar seu anonimato, você pode utilizar um nome fictício no campo de identificação (por exemplo: "Anônimo" ou "Cidadão"). O e-mail é solicitado apenas para eventual retorno da Prefeitura sobre o caso relatado.') }}
    </p>
    <p class="small mb-0">
        {{ __('Conheça a') }}
        <a href="{{ route('paginas.protecao-de-dados-lgpd') }}" target="_blank" rel="noopener noreferrer">
            {{ __('Política de Proteção de Dados') }}
        </a>
        {{ __('do município.') }}
    </p>
</div>
