<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'alertas' => collect(),
    'emptyMessage' => __('Nenhum alerta publicado no momento.'),
    'compact' => false,
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'alertas' => collect(),
    'emptyMessage' => __('Nenhum alerta publicado no momento.'),
    'compact' => false,
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php if($alertas->isNotEmpty()): ?>
    <ul class="ma-alerts__list">
        <?php $__currentLoopData = $alertas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $alerta): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <li class="ma-alerts__item">
                <span class="<?php echo \Illuminate\Support\Arr::toCssClasses(['ma-alerts__tag', $alerta->categoria->tagClass()]); ?>">
                    <?php echo e($alerta->categoria->label()); ?>

                </span>
                <h3 class="ma-alerts__item-title" title="<?php echo e($alerta->titulo); ?>">
                    <?php echo e($compact ? $alerta->titulo_resumido : $alerta->titulo); ?>

                </h3>
                <?php if($alerta->mensagem_exibicao): ?>
                    <p class="ma-alerts__item-text">
                        <?php echo e($compact ? $alerta->mensagem_resumida_exibicao : $alerta->mensagem_exibicao); ?>

                    </p>
                <?php endif; ?>
                <time class="ma-alerts__date" datetime="<?php echo e($alerta->publicado_em?->toIso8601String()); ?>">
                    <?php echo e($alerta->data_formatada); ?>

                </time>
            </li>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </ul>
<?php else: ?>
    <p class="ma-alerts__empty text-muted mb-0"><?php echo e($emptyMessage); ?></p>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/alertas-list.blade.php ENDPATH**/ ?>