<!-- Basic features section-->
<section id="legislacao">
    <div class="container px-5">

        <div class="row justify-content-center align-items-center g-2">
            <div
                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">

                <h2 class="display-4 lh-1 mb-4 my-3">Legislação</h2>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1816---Ed.-Extra_de_03-01-2024.pdf"
                            target="_blank"><strong>Decreto Nº 13.367, de 03 de Janeiro de 2024 <i
                                    class="bi-save2-fill me-2"></i></strong></a><br>
                        Estabelece o regulamento do Processo Eletrônico do município de Angra dos Reis.<br>
                        <small>Boletim Oficial N° 1816, página 14.</small>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1842_de_09-02-2024.pdf"
                            target="_blank"><strong>Decreto Nº 13.409, de 09 de Fevereiro de 2024 <i
                                    class="bi-save2-fill me-2"></i></strong></a><br>
                        Prorroga o prazo disposto no art. 21 do decreto Nº 13.367, de 03 de Janeiro de 2024.<br>
                        <small>Boletim Oficial N° 1842, página 72.</small>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1748_de_23-02-2024.pdf"
                            target="_blank"><strong>Decreto Nº 13.423, de 23 de Fevereiro de 2024 <i
                                    class="bi-save2-fill me-2"></i></strong></a><br>
                        Institui o Comitê Gestor do Sistema Eletrônico de Informações, os Pontos Focais e dispõe
                        sobre a produção e tramitação eletrônica de documentos e processos administrativos na
                        administração pública municipal e dá outras providências.<br>
                        <small>Boletim Oficial N° 1848, página 87.</small>
                    </p>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                        <a href="<?php echo e(asset("sei-angra/assets/docs/membros-cgsei.pdf")); ?>" target="_blank"><strong>Portaria Nº 004/2024 -
                                Designação de Comissão de Fiscalização, de 23 de Fevereiro de 2024 <i
                                    class="bi-save2-fill me-2"></i></strong></a><br>
                        Designa o Comitê Gestor do SEI-ANGRA (CGSEI), grupo que possui caráter estratégico, composto
                        por membros da Superintendência de Tecnologia da Informação (SPP.SUTIN), Controladoria-Geral
                        (CGM) e da Procuradoria-Geral (PGM) e tem como objetivo o gerenciamento e o acompanhamento
                        do Sistema Eletrônico de Informações (SEI-ANGRA) no Município de Angra dos Reis.<br>
                        <small> B.O. Nº 1848 de Fevereiro de 2024, página 110.</small>
                    </p>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1858_de_14-03-2024.pdf"
                            target="_blank"><strong>Decreto Nº 13.445 - Prorrogação de prazo para obrigatoriedade de
                                Processos de Despesa em meio Eletrônico, de 14 de Março de 2024 <i
                                    class="bi-save2-fill me-2"></i></strong></a><br>
                        Prorroga o prazo disposto no Artigo 21 do Decreto Nº 13.367, de Janeiro de 2024.<br>
                        <small> B.O. Nº 1858 de 14 de Março de 2024, página 27.</small>
                    </p>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1931_de_25-07-2024.pdf"
                            target="_blank"><strong>Portaria Nº 001/2024, de 25 de Julho de 2024
                                <i class="bi-save2-fill me-2"></i></strong></a><br>
                        A presidência da Câmara Municipal de Angra
                        Dos Reis, no uso de suas atribuições legais, resolve estabelecer o regulamento do processo
                        eletrônico.<br>
                        <small> B.O. Nº 1931 de 25 de Julho de 2024, página 19.</small>
                    </p>
                </div>

                <div class="my-5">
                    <p class="fw-normal text-muted mb-lg-0">
                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1933_de_30-07-2024.pdf" target="_blank"><strong>Portaria Nº 002/2024, de 30 de Julho de 2024
                                <i class="bi-save2-fill me-2"></i></strong></a><br>
                        A presidência da Câmara Municipal de Angra
                        dos Reis, no uso de suas atribuições legais, resolve instituir os Pontos Focais, bem como
                        dispor sobre a produção e tramitação eletrônica de documentos e processos administrativos na
                        Câmara Municipal de Angra dos Reis <br>
                        <small> B.O. Nº 1933 de 30 de Julho de 2024, página 83.</small>
                    </p>
                </div>

            </div>
            <div class="col-4 order-0 order-sm-0 order-md-0 order-lg-2 order-xl-2 order-xxl-2">
                <div>
                    <div class="px-5 px-sm-0"><img class="img-fluid rounded-circle" src="<?php echo e(asset("sei-angra/assets/img/maoredonda.png")); ?>"
                            alt="Ilustração de alguém utilizando meios digitais." /></div>
                </div>
            </div>
        </div>
    </div>
</section>
<!-- Call to action section--><?php /**PATH /var/www/html/portal/resources/views/sei/sections/legislacao.blade.php ENDPATH**/ ?>