<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.sei.elements.head')

<body id="page-top" class="animate__animated animate__fadeIn">
    <header>
        @include('layouts.sei.elements.defaultBar')
        @include('layouts.sei.elements.nav')

    </header>
    @include('layouts.sei.elements.modal')
    @yield('content')
    <footer class="footer-pmar">
        @include('layouts.sei.elements.footer')
    </footer>

</body>

</html>