<?php $__env->startSection('title', config('app.name').' :: '.__('Fale conosco').' — '.$secretaria->name); ?>

<?php $__env->startPush('styles'); ?>
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/paginas/org-fale-conosco.css')); ?>">
<?php $__env->stopPush(); ?>

<?php $__env->startSection('content'); ?>
    <div class="container">
        <div class="row">
            <div class="col-12 my-3">
                <?php
                    $breadcrumbItems = \App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Fale conosco'));
                    if (isset($secretaria->pertence->name)) {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->pertence->abbreviation;
                        $breadcrumbItems[2]['labelShort'] = $secretaria->abbreviation;
                    } else {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->abbreviation;
                    }
                ?>
                <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => $breadcrumbItems,'responsiveAbbreviation' => true]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($breadcrumbItems),'responsive-abbreviation' => true]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
            </div>
        </div>
    </div>

    <?php echo $__env->make('paginas.parts.headers', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <div class="container pb-5">
        <div class="row gx-4 gx-lg-5 gy-4">
            <section class="col-12 col-lg-9 order-1">
                <?php echo $__env->make('paginas.parts.org-fale-conosco-miolo', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </section>
            <aside class="col-12 col-lg-3 mt-4 mt-lg-0 order-2" aria-label="<?php echo e(__('Informações laterais do órgão')); ?>">
                <?php echo $__env->make('paginas.parts.org-fale-conosco-aside', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </aside>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/orgao-fale-conosco.blade.php ENDPATH**/ ?>