{{-- 
    @include("admin.components.avatar", [
        'imgURL' => "link da imagem",
        'id' => "id do serviço",
        'title' => "Titulo ou nome da imagem",
    ])
--}}
<img
    src="{{ asset($imgURL) }}"
    alt="{{ $title }}"
    title="{{ $title }}"
    class="rounded-2"
    style="width: 90px; height: 90px; object-fit: cover; cursor: pointer;"
    data-bs-toggle="modal"
    data-bs-target="#modalComponentsAvatar-{{ $id }}" />

<!-- Modal exclusivo para esse paciente -->
<div class="modal fade" id="modalComponentsAvatar-{{ $id }}" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-fullscreen">
        <div class="modal-content bg-dark">
            <div class="modal-header border-0">
                <button type="button" class="btn-close btn-close-white ms-auto" data-bs-dismiss="modal" aria-label="Fechar"></button>
            </div>
            <div class="modal-body d-flex justify-content-center align-items-center">
                <img src="{{ asset($imgURL) }}" alt="{{ $title }}" title="{{ $title }}" class="img-fluid rounded" style="max-height: 90vh;" />
            </div>
        </div>
    </div>
</div>