@foreach ($links as $link)
<li>
    <a class="dropdown-item"
        href="#"
        data-bs-toggle="{{ $link['toggle'] ?? '' }}"
        data-bs-target="#{{ $link['hashData'] ?? '' }}"
        @if(!empty($link['model']))
            onclick="abrirModalRelatorio('{{ $link['model'] }}')"
        @endif
    >
        <i class="fa-solid fa-file-pdf"></i> {{ $link['label'] }}
    </a>
</li>
@endforeach