{{-- Modal de visualização completa (aba Projetos — listagem SUPOP) --}}
@php
    $ppOdsDirPath = '';
    $ppOdsSampleUrl = asset('pmar/assets/img/ods/ods-01.png');
    $ppOdsParsedPath = parse_url($ppOdsSampleUrl, PHP_URL_PATH);
    if (is_string($ppOdsParsedPath) && $ppOdsParsedPath !== '') {
        $ppOdsDirPath = dirname($ppOdsParsedPath);
        if ($ppOdsDirPath === '.' || $ppOdsDirPath === '/') {
            $ppOdsDirPath = '';
        }
    }
@endphp
<div class="modal fade" id="modalVisualizarProjeto" tabindex="-1"
    aria-labelledby="modalVisualizarProjetoTitulo"
    aria-hidden="true"
    data-default-title="{{ __('Projeto') }}"
    data-numero-mapao-label="{{ __('Nº MAPÃO') }}"
    data-erro-carregar="{{ __('Não foi possível carregar os dados do projeto.') }}"
    data-ods-dir-path="{{ $ppOdsDirPath }}">
    <div class="modal-dialog modal-xl modal-dialog-scrollable modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <div class="w-100">
                    <h5 class="modal-title" id="modalVisualizarProjetoTitulo">{{ __('Projeto') }}</h5>
                    <p class="small text-muted mb-0 mt-1 d-none" id="modalVisualizarProjetoSub"></p>
                </div>
                <button type="button" class="btn-close" data-bs-dismiss="modal"
                    aria-label="{{ __('Fechar') }}"></button>
            </div>
            <div class="modal-body">
                <div class="d-none" id="modalVisualizarProjetoLoading" role="status">
                    <p class="text-muted small mb-0">{{ __('Carregando…') }}</p>
                </div>
                <div class="d-none alert alert-danger small" id="modalVisualizarProjetoErro" role="alert"></div>
                <div id="modalVisualizarProjetoConteudo"></div>
            </div>
            <div class="modal-footer d-flex flex-wrap gap-2 justify-content-end align-items-center">
                <button type="button" class="btn btn-outline-secondary" data-bs-dismiss="modal">{{ __('Fechar') }}</button>
            </div>
        </div>
    </div>
</div>
