@php
    $links = $links ?? [];
@endphp

<div class="dashboard-card">
    <div class="dashboard-card-header">
        <h3 class="dashboard-card-title">
            <i class="fa-solid fa-bolt me-2"></i>
            {{ __("Atalhos Rápidos") }}
        </h3>
    </div>
    <div class="dashboard-card-body">
        <div class="shortcuts-grid">
            @foreach($links as $link)
                @include('components.dashboard._shortcutItem', $link)
            @endforeach
        </div>
    </div>
</div>

