<thead class="table-light">
    <tr>
        <?php $__currentLoopData = $thead; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $th): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <th <?php if(!empty($theadWidths[$index])): ?> style="width: <?php echo e($theadWidths[$index]); ?>" <?php endif; ?>><?php echo e($th); ?></th>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </tr>
</thead><?php /**PATH /var/www/html/portal/resources/views/components/tables/_thead.blade.php ENDPATH**/ ?>