@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Lista Xpto'))
@section('content')
<div class="card shadow-sm">
@php $headLine = __('Lista Xpto'); @endphp
@include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.dashboard', 'nameBack' => __('Voltar'), 'routeAdd' => 'admin.meuTest.create', 'nameAdd' => __('Novo'), 'permission' => 'ADMIN'])
<div class="card-body">
<x-tables._table :thead="['#','Nome','Ações']" :pagination="$items->links()">
<x-slot name="body">
@foreach($items as $i)
<tr><td>{{ $loop->iteration }}</td><td>{{ $i->id }}</td><td></td></tr>
@endforeach
</x-slot>
</x-tables._table>
</div>
</div>
@endsection
