<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.pmar.elements.head')

<body class="escolas-climatizadas-app">
    <header id="escolas-barra-topo" aria-label="{{ __('Barra de navegação') }}">
        <a href="https://angra.rj.gov.br" target="_blank" rel="noopener noreferrer"
           aria-label="{{ __('Prefeitura de Angra dos Reis — Site Oficial') }}">
            <img src="{{ asset('pmar/assets/img/logo-pmar.png') }}"
                 alt="{{ __('Prefeitura de Angra dos Reis') }}">
        </a>
        <div class="escolas-barra-separador" aria-hidden="true"></div>
        <span class="escolas-barra-titulo">{{ __('ESCOLAS CLIMATIZADAS') }}</span>
    </header>

    <main class="escolas-climatizadas-main">
        @yield('content')
    </main>
</body>

</html>
