@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Verificar Guia Turístico")
@section('content')


    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                    <form action="{{ route('admin.guias.verify') }}" method="post" enctype="multipart/form-data">

                        @php $headLine = "<i class='fa-solid fa-left-right'></i> Verificar Guia Turístico"; @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'routeBack' => 'admin.guias.index',
                            'routeBackParams' => [], 
                            'nameBack' => __("Voltar"),
                        ])

                        <div class="card-body">
                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                            <div class="mb-3">
                                
                                <!-- Campo CPF -->
                                @include('components.inputs._inputType',[
                                    "for" => null,
                                    "label" => "CPF",
                                    "name" => "cpf",
                                    "id" => null,
                                    "required" => true,
                                    "type" => null,
                                    "old" => old('cpf'),
                                    "oninput" => "javascript:aplicarMascaraCPF(this)",
                                    "readonly" => false,
                                    "small" => null,
                                ])
                                
                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar', 
                                'textSend' => 'Verificar', 
                                'routeBack' => 'admin.guias.index'
                            ]
                        )
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>


@endsection