<head>
    <script async src="https://www.googletagmanager.com/gtag/js?id=UA-142766958-1"></script>
    <script>
        window.dataLayer = window.dataLayer || [];
        function gtag() { dataLayer.push(arguments); }
        gtag('js', new Date());

        gtag('config', 'UA-142766958-1');
    </script>

    <title>Parque Municipal da Mata Atlântica</title>

    <meta charset="utf-8">
    <meta http-equiv="Content-Language" content="pt-br">

    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <meta name="description" content="Parque Municipal da Mata Atlântica - Angra dos Reis">
    <meta name="author" content="Prefeitura de Angra dos Reis">

    <!-- Bootstrap 5.3 -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>


    <!-- LINK CSS -->
    <link rel="stylesheet" type="text/css" href="<?php echo e(asset('parquedacidade/asset/css/style.css')); ?>">

    <!-- LINK FONT AWESOME -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">

    <!-- Bootstrap Icons CDN -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">

    <!-- jQuery (obrigatório para o Bootstrap JS funcionar) -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>

    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-57x57.png')); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-60x60.png')); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-72x72.png')); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-76x76.png')); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-114x114.png')); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-120x120.png')); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-144x144.png')); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-152x152.png')); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('parquedacidade/asset/fav/apple-icon-180x180.png')); ?>">
    <link rel="icon" type="image/png" sizes="192x192"
        href="<?php echo e(asset('parquedacidade/asset/fav/android-icon-192x192.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('parquedacidade/asset/fav/favicon-32x32.png')); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset('parquedacidade/asset/fav/favicon-96x96.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('parquedacidade/asset/fav/favicon-16x16.png')); ?>">
    <link rel="manifest" href="<?php echo e(asset('parquedacidade/asset/fav/manifest.json')); ?>">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="asset/fav/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
</head><?php /**PATH /var/www/html/portal/resources/views/layouts/parquedacidade/elements/head.blade.php ENDPATH**/ ?>