<?php if(isset($custom_menu_links) && $custom_menu_links->isNotEmpty()): ?>
<div class="col-12 mb-3">
    <div class="row d-flex flex-column align-items-center">
        <div class="col">
            <div class="card-slug">
                <ul class="list-unstyled">
                    <?php $__currentLoopData = $custom_menu_links; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $link): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <li>
                            <a class="text-decoration-none text-dark link-secretarias" href="<?php echo e(url($link->link)); ?>" target="<?php echo e($link->status ?? '_SELF'); ?>">
                                <?php echo e($link->titulo); ?>

                                <i class="text-primary fa-solid fa-angle-right"></i>
                            </a>
                        </li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </ul>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/html-custom-menu.blade.php ENDPATH**/ ?>