@php
    $empresa = $empresa ?? null;
@endphp

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'contratoSocial',
    'label' => __('Contrato Social (ou Estatuto Social)'),
    'description' => __('Documento que descreve a criação da empresa e contém informações sobre sócios, capital social, atividades e regras.'),
    'currentPath' => $empresa?->contratoSocial,
    'currentLink' => $empresa?->contratoSocialLink,
    'downloadLabel' => __('Contrato Social'),
])

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'cartaoCNPJ',
    'label' => __('Cartão CNPJ'),
    'description' => __('O Cadastro Nacional da Pessoa Jurídica, emitido pela Receita Federal, é o RG da empresa.'),
    'currentPath' => $empresa?->cartaoCNPJ,
    'currentLink' => $empresa?->cartaoCNPJLink,
    'downloadLabel' => __('Cartão CNPJ'),
])

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'registroJuntaComercial',
    'label' => __('Registro na Junta Comercial'),
    'description' => __('É o registro do Contrato Social e a legalização da empresa na Junta Comercial do estado.'),
    'currentPath' => $empresa?->registroJuntaComercial,
    'currentLink' => $empresa?->registroJuntaComercialLink,
    'downloadLabel' => __('Registro na Junta Comercial'),
])

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'alvaraDeFuncionamento',
    'label' => __('Alvará de Funcionamento'),
    'description' => __('Emitido pela prefeitura, é a permissão para a empresa funcionar no local especificado.'),
    'currentPath' => $empresa?->alvaraDeFuncionamento,
    'currentLink' => $empresa?->alvaraDeFuncionamentoLink,
    'downloadLabel' => __('Alvará de Funcionamento'),
])

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'inscricaoEstadual',
    'label' => __('Inscrição Estadual'),
    'description' => __('Obrigatória para atividades de comércio, indústria e serviços de comunicação, transporte e energia.'),
    'currentPath' => $empresa?->inscricaoEstadual,
    'currentLink' => $empresa?->inscricaoEstadualLink,
    'downloadLabel' => __('Inscrição Estadual'),
])

@include('components.inputs._empresaTurismoDocumentoUpload', [
    'name' => 'inscricaoMunicipal',
    'label' => __('Inscrição Municipal'),
    'description' => __('Necessária para empresas que prestam serviços, permitindo a emissão de notas fiscais de serviço (ISS).'),
    'currentPath' => $empresa?->inscricaoMunicipal,
    'currentLink' => $empresa?->inscricaoMunicipalLink,
    'downloadLabel' => __('Inscrição Municipal'),
])
