<?php $__env->startSection("title", env("APP_NAME") . " :: " . __('Detalhes do Convênio')); ?>

<?php $__env->startSection('content'); ?>
<style>
    .bg-primary { background: linear-gradient(135deg, #0d6efd, #084298); }
    .landing-header {
        color: white;
        padding: 3rem 0 2.5rem 0;
        margin-bottom: 2rem;
        border-radius: 0 0 50px 50px;
        box-shadow: 0 10px 30px rgba(0,0,0,0.15);
        position: relative;
        overflow: hidden;
    }
    .landing-header.bg-primary::before {
        content: '';
        position: absolute;
        top: 0; left: 0; right: 0; bottom: 0;
        background: url('https://www.angra.rj.gov.br/uploads/2023/01/20230113110543.jpg') center/cover;
        opacity: 0.08;
        mix-blend-mode: overlay;
    }
    .detail-card {
        border-radius: 15px;
        box-shadow: 0 5px 20px rgba(0,0,0,0.08);
        border: none;
        overflow: hidden;
    }
    .detail-section-title {
        font-size: 1.1rem;
        font-weight: 700;
        color: #004e92;
        border-bottom: 2px solid #f0f2f5;
        padding-bottom: 10px;
        margin-bottom: 20px;
        margin-top: 10px;
    }
    .detail-label {
        font-size: 0.9rem;
        color: #6c757d;
        font-weight: 600;
        margin-bottom: 5px;
    }
    .detail-value {
        font-size: 1.05rem;
        color: #212529;
        font-weight: 500;
        margin-bottom: 20px;
    }
    .value-highlight {
        color: #004e92;
        font-weight: 700;
        font-size: 1.2rem;
    }
</style>

<div class="landing-header bg-primary text-center position-relative">
    <div class="container position-relative">
        <div class="d-flex justify-content-between align-items-start flex-wrap gap-3 mb-3">
            <div class="d-flex align-items-center gap-3">
                <div class="bg-white text-primary rounded-circle p-3 shadow-sm">
                    <i class="fa-solid fa-file-contract fa-2x"></i>
                </div>
                <div class="text-start">
                    <h2 class="h3 fw-bold mb-1 text-white"><?php echo e(__('Detalhes do Convênio')); ?></h2>
                    <p class="opacity-75 mb-0 text-white">
                        <?php echo e($convenio->show_proposta_id ? __('Proposta ID') . ': ' . ($convenio->proposta_id ?? 'N/D') : ''); ?>

                    </p>
                </div>
            </div>
            <div class="d-flex flex-wrap gap-2 ms-auto">
                <a href="<?php echo e(route('pppseconvenios')); ?>" class="btn btn-outline-light btn-sm rounded-pill">
                    <i class="fa-solid fa-arrow-left me-2"></i><?php echo e(__('Início')); ?>

                </a>
                <a href="<?php echo e(route('convenios.public.list')); ?>" class="btn btn-outline-light btn-sm rounded-pill">
                    <i class="fa-solid fa-list me-2"></i><?php echo e(__('Voltar à lista de Convênios')); ?>

                </a>
            </div>
        </div>
    </div>
</div>

<div class="container mb-5">
    <div class="row">
        <div class="col-lg-8">
            <div class="card detail-card p-4 mb-4">
                <?php if($convenio->show_objeto ?? true): ?>
                <div class="detail-section-title"><i class="fa-solid fa-align-left me-2"></i> <?php echo e(__('Objeto do Convênio')); ?></div>
                <p class="fs-5 text-dark"><?php echo e($convenio->objeto); ?></p>
                <?php endif; ?>
                <div class="detail-section-title mt-4"><i class="fa-solid fa-circle-info me-2"></i> <?php echo e(__('Informações Gerais')); ?></div>
                <div class="row">
                    <?php if($convenio->show_programa ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Programa')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->programa ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_tipo_programa ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Tipo de Programa')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->tipo_programa ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_programa_pac ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Programa Nº PAC')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->programa_pac ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_status_plataforma ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Status / Plataforma')); ?></div>
                        <div class="detail-value"><span class="badge bg-secondary"><?php echo e($convenio->status_plataforma ?? '-'); ?></span></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_andamento ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Andamento')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->andamento ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
            <div class="card detail-card p-4 mb-4">
                <div class="detail-section-title"><i class="fa-solid fa-file-signature me-2"></i> <?php echo e(__('Acompanhamento do Instrumento')); ?></div>
                <div class="row">
                    <?php if($convenio->show_numero_instrumento ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Número do instrumento')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->numero_instrumento ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_numero_processo_sei ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Número do processo SEI')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->numero_processo_sei ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_data_recebimento_recurso ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Data do recebimento do recurso')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->data_recebimento_recurso ? $convenio->data_recebimento_recurso->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_data_assinatura_instrumento ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Data de assinatura do instrumento')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->data_assinatura_instrumento ? $convenio->data_assinatura_instrumento->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_vigencia_clausula_suspensiva ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Vigência da cláusula suspensiva')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->vigencia_clausula_suspensiva ? $convenio->vigencia_clausula_suspensiva->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_vigencia_prazo_contratual ?? true): ?>
                    <div class="col-md-6">
                        <div class="detail-label"><?php echo e(__('Vigência do prazo de vigência contratual')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->vigencia_prazo_contratual ? $convenio->vigencia_prazo_contratual->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
            <div class="card detail-card p-4 mb-4">
                <div class="detail-section-title"><i class="fa-solid fa-location-dot me-2"></i> <?php echo e(__('Localização e Prazos')); ?></div>
                <div class="row">
                    <?php if($convenio->show_local ?? true): ?>
                    <div class="col-md-12">
                        <div class="detail-label"><?php echo e(__('Local')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->local ?? '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_data ?? true): ?>
                    <div class="col-md-4">
                        <div class="detail-label"><?php echo e(__('Data')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->data ? $convenio->data->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_prazo_cadastro ?? true): ?>
                    <div class="col-md-4">
                        <div class="detail-label"><?php echo e(__('Prazo de Cadastro')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->prazo_cadastro ? $convenio->prazo_cadastro->format('d/m/Y') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                    <?php if($convenio->show_prazo_execucao_meses ?? true): ?>
                    <div class="col-md-4">
                        <div class="detail-label"><?php echo e(__('Prazo de Execução (Meses)')); ?></div>
                        <div class="detail-value"><?php echo e($convenio->prazo_execucao_meses ? $convenio->prazo_execucao_meses . ' ' . __('meses') : '-'); ?></div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="card detail-card p-4 mb-4 bg-light border-0">
                <div class="detail-section-title"><i class="fa-solid fa-coins me-2"></i> <?php echo e(__('Valores Financeiros')); ?></div>
                <?php if($convenio->show_valor_global ?? true): ?>
                <div class="detail-label"><?php echo e(__('Valor Global')); ?></div>
                <div class="detail-value value-highlight text-success"><?php echo e($convenio->valor_global ?? '-'); ?></div>
                <hr>
                <?php endif; ?>
                <?php if($convenio->show_repasse ?? true): ?>
                <div class="detail-label"><?php echo e(__('Repasse')); ?></div>
                <div class="detail-value fw-bold"><?php echo e($convenio->repasse ?? '-'); ?></div>
                <?php endif; ?>
                <?php if($convenio->show_contrapartida ?? true): ?>
                <div class="detail-label"><?php echo e(__('Contrapartida')); ?></div>
                <div class="detail-value fw-bold"><?php echo e($convenio->contrapartida ?? '-'); ?></div>
                <?php endif; ?>
            </div>
            <div class="card detail-card p-4">
                <div class="detail-section-title"><i class="fa-solid fa-users me-2"></i> <?php echo e(__('Envolvidos')); ?></div>
                <?php if($convenio->show_concedente ?? true): ?>
                <div class="detail-label"><?php echo e(__('Concedente')); ?></div>
                <div class="detail-value"><?php echo e($convenio->concedente ?? '-'); ?></div>
                <?php endif; ?>
                <?php if($convenio->show_executor_ordenador ?? true): ?>
                <div class="detail-label"><?php echo e(__('Executor / Ordenador')); ?></div>
                <div class="detail-value"><?php echo e($convenio->executor_ordenador ?? '-'); ?></div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/pppseconvenios/show_convenio.blade.php ENDPATH**/ ?>