@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: ". $html->title)
@section('content')
    <div class="container">
        <div class="row">
            <div class="col-12 my-3">
                <x-portal.breadcrumb :items="\App\Support\PortalBreadcrumb::forServicosHtmlPage(
                    $secretaria,
                    $html->title,
                    ! empty($html->structure_id)
                )" />
            </div>
        </div>
    </div>

    <section class="internas-secretarias-home-title">
        <div class="container">
            <div class="row">
                <div class="col">
                    @if(isset($secretaria->pertence->name))
                        <h1>{{ $secretaria->name }}{{--  ({{ $secretaria->abbreviation }}) --}}</h1>
                        <p>{{ $secretaria->pertence->name }} ({{ $secretaria->pertence->abbreviation }})</p>
                    @else
                        <h1>{{ $secretaria->name }}</h1>
                        {{-- ({{ $secretaria->abbreviation }}) --}}
                    @endif
                    <h3 class="text-center">{{ $html->title }}</h3>
                    <p class="text-center">{!! $html->summary !!}</p>
                </div>
            </div>
        </div>
    </section>

    <div class="container">
        <div class="row gx-5 gy-5">
            <div class="internas-secretarias-home-news col-lg-9 col-md-9 col-sm-12">
                {!! $viewContent !!}
            </div>

            <div class="internas-secretarias-home-aside col-lg-3 col-md-3 col-sm-12">
                @include('paginas.parts.html-custom-menu')
                @include('paginas.parts.links')
                @include('paginas.parts.servicos')
                @include('paginas.parts.telefones')
            </div>
        </div>
    </div>

@endsection
