@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar Paciente com Fibromialgia - Anotações")
@section('content')

<div class="card shadow">

    @php $headLine = "<i class='fa-solid fa-user-injured'></i> Editar Paciente com Fibromialgia - Anotações"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
    'headLine' => __($headLine),
    "permission" => "GERENCIADOR_DO_CADASTRO_DE_PACIENTES_COM_FIBROMIALGIA",
    ])

    <div class="card-body">
        <form action="{{ route("admin.saude.fibromialgia.anotacoes", $paciente->id) }}" method="post" enctype="multipart/form-data">

            @include("errors.messageFlash")
            @csrf
            @method('post')

            @include('components.modal._modelProfile')

            <hr>

            <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">

                @include('components.lists._liLinkBtnNavFibromialgia', [
                'items' => [
                ['class' => '', 'route' => 'admin.saude.fibromialgia.edit', 'routeParams' => [$paciente->id], 'label' => 'Dados de Usuário'],
                ['class' => '', 'route' => 'admin.saude.fibromialgia.dadosPessoais', 'routeParams' => [$paciente->id], 'label' => 'Dados Pessoais'],
                ['class' => '', 'route' => 'admin.saude.fibromialgia.documentos', 'routeParams' => [$paciente->id], 'label' => 'Documentos'],
                ['class' => '', 'route' => 'admin.saude.fibromialgia.endereco', 'routeParams' => [$paciente->id], 'label' => 'Endereço'],
                ['class' => '', 'route' => 'admin.saude.fibromialgia.arquivos', 'routeParams' => [$paciente->id], 'label' => 'Arquivos'],
                ['class' => '', 'route' => 'admin.saude.fibromialgia.carteirinha', 'routeParams' => [$paciente->id], 'label' => 'Carteirinha'],
                ['class' => 'active bg-success', 'route' => 'admin.saude.fibromialgia.anotacoes', 'routeParams' => [$paciente->id], 'label' => 'Anotações'],
                ]
                ])

            </ul>

            <div class="tab-content">
                <div class="mb-3">

                    <div class="row">
                        <div class="col-12  text-wrap">

                            @csrf
                            @method('post')

                            <!-- Nova mensagem -->
                            @include('components.inputs._textarea', [
                            'label' => 'Anotações',
                            'name' => 'observacoes',
                            'id' => 'limiteCaracter',
                            'rows' => 5,
                            'required' => true,
                            'height' => '200px',
                            'class' => "textarea-body",
                            'style' => null,
                            "oninput" => null,
                            'value' => old('observacoes', $paciente->observacoes),
                            'small' => "As anotações feitas neste bloco é de uso exclusivo da secretaria, o paciente não tem acesso a esta informação",
                            ])
                            <small class="text-primary">As anotações feitas neste bloco é de uso exclusivo da secretaria, o paciente não tem acesso a esta informação.</small>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="d-flex justify-content-between mt-4">
                    <a class="btn btn-outline-secondary" href="{{ route("admin.saude.fibromialgia.carteirinha", $paciente->id) }}">
                        <i class="fa-solid fa-arrow-left-long"></i> {{ __("Anterior") }}
                    </a>
                    <button class="btn btn-primary d-inline" type="submit">
                        <i class="fa-solid fa-user-plus"></i> {{ __("Salvar e Finalizar") }}
                    </button>
                </div>
            </div>

        </form>
    </div>
</div>

@endsection
