@php
    $end = $secretaria->endereco;
@endphp

<article class="org-fale-conosco-miolo">
    <section class="org-fale-conosco-section" aria-labelledby="org-fale-conosco-endereco">
        <h2 id="org-fale-conosco-endereco" class="org-fale-conosco-section__title">{{ __('Endereço físico') }}</h2>
        <div class="org-fale-conosco-section__body">
            @if(filled($secretaria->address))
                <p><strong>{{ __('Endereço:') }}</strong> {{ e($secretaria->address) }}</p>
            @endif
            @if($end)
                <p><strong>{{ __('Logradouro:') }}</strong> {{ e($end->logradouro) }}{{ filled($end->numero) ? ', '.e($end->numero) : '' }}</p>
                @if(filled($end->complemento))
                    <p><strong>{{ __('Complemento:') }}</strong> {{ e($end->complemento) }}</p>
                @endif
                @if(filled($end->bairro))
                    <p><strong>{{ __('Bairro:') }}</strong> {{ e($end->bairro) }}</p>
                @endif
                @if(filled($end->cep))
                    <p><strong>{{ __('CEP:') }}</strong> {{ e($end->cep) }}</p>
                @endif
                @if(filled($end->cidade) || filled($end->uf))
                    <p>
                        <strong>{{ __('Cidade/UF:') }}</strong>
                        @php
                            $cidadeUf = trim(($end->cidade ?? '').((filled($end->cidade) && filled($end->uf)) ? ' / ' : '').($end->uf ?? ''));
                        @endphp
                        {{ e($cidadeUf) }}
                    </p>
                @endif
            @endif
            @if(!empty($mapEmbedSrc))
                <p>
                    <strong>{{ __('Local:') }}</strong>
                    <a href="{{ $mapEmbedSrc }}" target="_blank" rel="noopener noreferrer">{{ __('Mapa') }}</a>
                </p>
            @endif
            @if(filled($secretaria->phoneNumber))
                <p><strong>{{ __('Telefones:') }}</strong> {{ e($secretaria->phoneNumber) }}</p>
            @endif
            @if(filled($secretaria->email1))
                <p><strong>{{ __('E-mail:') }}</strong> <a href="mailto:{{ e($secretaria->email1) }}">{{ e($secretaria->email1) }}</a></p>
            @endif
            @if(filled($secretaria->email2))
                <p><strong>{{ __('E-mail (2):') }}</strong> <a href="mailto:{{ e($secretaria->email2) }}">{{ e($secretaria->email2) }}</a></p>
            @endif
            @if(filled($secretaria->email3))
                <p><strong>{{ __('E-mail (3):') }}</strong> <a href="mailto:{{ e($secretaria->email3) }}">{{ e($secretaria->email3) }}</a></p>
            @endif
            @if(filled($secretaria->openingHours))
                <p><strong>{{ __('Horário de Funcionamento:') }}</strong> {{ e($secretaria->openingHours) }}</p>
            @endif
            @if(filled($secretaria->serviceHours))
                <p><strong>{{ __('Horário de Atendimento:') }}</strong> {{ e($secretaria->serviceHours) }}</p>
            @endif
        </div>
    </section>

    @if(filled($secretaria->faleConoscoExtraInfo))
        <div
            class="org-fale-conosco-extra-info org-fale-conosco-section__body"
            role="complementary"
            aria-label="{{ __('Informações adicionais') }}">
            {!! \App\Helpers\HtmlSanitizer::sanitize($secretaria->faleConoscoExtraInfo) !!}
        </div>
    @endif

    @if(!empty($mapEmbedSrc))
        <section class="org-fale-conosco-section" aria-labelledby="org-fale-conosco-localizacao">
            <h2 id="org-fale-conosco-localizacao" class="org-fale-conosco-section__title">{{ __('Localização') }}</h2>
            <div class="org-fale-conosco-mapa ratio ratio-21x9">
                <iframe
                    title="{{ __('Mapa de localização de :org', ['org' => $secretaria->name]) }}"
                    src="{{ $mapEmbedSrc }}"
                    class="border-0"
                    loading="lazy"
                    referrerpolicy="no-referrer-when-downgrade"
                    allowfullscreen></iframe>
            </div>
        </section>
    @endif

    <section class="org-fale-conosco-section org-fale-conosco-section--ouvidoria" aria-labelledby="org-fale-conosco-ouvidoria">
        <h2 id="org-fale-conosco-ouvidoria" class="org-fale-conosco-section__title">{{ __('Ouvidoria - Fala.BR') }}</h2>
        <div class="org-fale-conosco-section__intro">
            <p>{{ __('A Ouvidoria é um canal para você apresentar sugestões, elogios, solicitações, reclamações, denúncias e outros tipos de manifestações. No serviço público, a Ouvidoria é uma espécie de "ponte" entre você e a Administração, neste caso, a Prefeitura de Angra dos Reis.') }}</p>
            <p>{{ __('A Ouvidoria recebe as manifestações dos cidadãos, de empresas e de entidades não-governamentais, analisa, orienta, encaminha às áreas responsáveis pelo tratamento ou apuração, responde ao manifestante e conclui a manifestação.') }}</p>
        </div>

        <x-org.falabr-manifestacao-grid :items="$falabrManifestacaoTypes" />

        <p class="org-falabr-footer-link">
            <strong>{{ __('Ainda está com dúvidas?') }}</strong>
            {{ __('Saiba mais sobre a') }}
            <a href="{{ $ouvidoriaInfoUrl }}" target="_blank" rel="noopener noreferrer" class="fw-semibold text-decoration-none">
                {{ __('Ouvidoria Externa - Fala.BR') }}
                <img src="{{ asset('pmar/assets/img/icons/falabr/falabr.png') }}" alt="">
            </a>
            {{ __('da Prefeitura de Angra dos Reis.') }}
        </p>
    </section>
</article>
