@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Editar arquivo de ') . $conselho->nome)
@section('content')
<div class="card shadow-sm">
    @php $headLine = <i class='fa-solid fa-paperclip'></i>" . __('Editar arquivo de ') . "<i class='fa-solid fa-people-group'></i> " . $conselho->nome; @endphp
    @include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.conselhosMunicipais.arquivos.index', 'routeBackParams' => [$conselho->id], 'nameBack' => __('Voltar'), 'permission' => 'GERENCIADOR_DE_CONSELHOS'])
    <div class="card-body">
        @include('errors.messageFlash')
        <form action="{{ route('admin.conselhosMunicipais.arquivos.update', [$conselho->id, $arquivo->id]) }}" method="POST" enctype="multipart/form-data">@csrf @method('PUT')

            <div class="mb-3">
                <label for="tipo" class="form-label text-bold">{{ __('Tipo de arquivo:') }} <span class="span-admin-create">*</span></label>
                <select class="form-control @error('tipo') is-invalid @enderror" name="tipo" id="tipo">
                    @foreach([
                    'Ata de sessão extraordinária','Ata de sessão ordinária','Carta Aberta','Comunicado','Convocação','Decreto','Deliberação','Edital','Legislação','Memorando','Moção','Ofício','Parecer','Plano de Ação','Portaria','Recomendação','Regimento Interno','Relatório','Resolução'] as $opt)
                    <option value="{{ $opt }}" {{ old('tipo', $arquivo->tipo) === $opt ? 'selected' : '' }}>{{ $opt }}</option>
                    @endforeach
                </select>
                @error('tipo')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            <div class="mb-3">
                <label for="link" class="form-label text-bold">{{ __('Arquivo:') }}</label>
                <input type="file" class="form-control @error('link') is-invalid @enderror" name="link" id="link" accept="application/pdf"/>
                @error('link')
                <small class="text-danger text-bold">{{ $message }}</small><br>
                @enderror
                <small class="text-info text-bold">{{ __('* Apenas documento em PDF') }}</small>
            </div>
            <hr/>

            @include('components.inputs._inputType', ['label'=>__('Nome do documento'),'name'=>'nome','required'=>true,'old'=> old('nome', $arquivo->nome ?? '') ])

            <div class="mb-3">
                <label for="evento_at" class="form-label text-bold">{{ __('Data do evento:') }} <span class="span-admin-create">*</span></label>
                <input type="date" class="form-control @error('evento_at') is-invalid @enderror" name="evento_at" id="evento_at" autocomplete="off" value="{{ old('evento_at', $arquivo->evento_at) }}">
                @error('evento_at')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            <div class="mb-3">
                <label for="status" class="form-label text-bold">{{ __('Status:') }} <span class="span-admin-create">*</span></label>
                <select class="form-control @error('status') is-invalid @enderror" name="status" id="status">
                    @foreach(App\Enums\StatusEnum::cases() as $status)
                    <option value="{{ $status->name }}" {{ old('status', $arquivo->status) == $status->name ? 'selected' : '' }}>{{ $status->value }}</option>
                    @endforeach
                </select>
                @error('status')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            @include('components.buttons._backAndSend', [
            'textBack' => __('Voltar'),
            'textSend' => __('Atualizar'),
            'routeBack' => 'admin.conselhosMunicipais.arquivos.index',
            'backId' => $conselho->id
            ])
        </form>
    </div>
</div>
@endsection
