<!DOCTYPE html
    PUBLIC '-//W3C//DTD XHTML 1.0 Transitional //EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>
<html xmlns='http://www.w3.org/1999/xhtml' xmlns:v='urn:schemas-microsoft-com:vml'
    xmlns:o='urn:schemas-microsoft-com:office:office'>



<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Cadastro Concluído</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #fff;
            margin: 0;
            padding: 0;
        }

        .container {
            max-width: 500px;
            background-color: #f7f7f7;
            padding: 40px;
            border-radius: 10px;
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.3);
            text-align: center;
            margin: 20px auto;
        }

        h1 {
            color: #0056b3;
            font-size: 24px;
            margin-bottom: 15px;
        }

        p {
            color: #444;
            font-size: 16px;
            line-height: 1.5;
        }

        .highlight {
            color: #0056b3;
            font-weight: bold;
        }

        .footer {
            margin-top: 20px;
            font-size: 13px;
            color: #666;
        }

        a {
            color: #fff !important;
        }

        .btn-custom {
            display: inline-block;
            background-color: #007BFF;
            color: #fff !important;
            padding: 12px 20px;
            text-decoration: none;
            border-radius: 6px;
            font-size: 16px;
            margin-top: 15px;
        }
    </style>
</head>

<body>
    <table width="100%" cellspacing="0" cellpadding="0" border="0">
        <tr>
            <td align="center">
                <div class="container">
                    <img src="https://angra.rj.gov.br/pmar/assets/fiveicon/brasao-angra-dos-reis.png" height="100"
                        alt="Brasão de Angra dos Reis" style="display:block;margin:0 auto;">
                    <h1>Bem-vindo(a), <span class="highlight">{{ $user->firstName }}</span>!</h1>
                    <p>Seu cadastro foi concluído com sucesso no Sistema de Fibromialgia da Prefeitura Municipal de
                        Angra dos Reis.</p>
                    <p>Agora, você pode acessar a plataforma para acompanhar seus registros e obter informações
                        importantes.</p>
                    <p>Se precisar de qualquer suporte, nossa equipe está à disposição para ajudá-lo(a).</p>
                  
                    <a href="https://angra.rj.gov.br/cadastro/fibromialgia" class="btn-custom" target="_blank">Acessar
                        Plataforma</a>
                    <div class="footer">
                        &copy; 2025 Prefeitura Municipal de Angra dos Reis. Todos os direitos reservados.
                    </div>
                </div>
            </td>
        </tr>
    </table>
</body>

</html>