@extends('layouts.parquedacidade.theme')
@section('title', 'Conselho Gestor do Parque da Cidade da Prefeitura Municipal de Angra dos Reis')
@section('content')

    <div class="page-title dark-background" data-aos="fade"
        style="background-image: url({{ asset('parquedacidade/imagens/img-fundo.jpg') }});">
        <div class="container position-relative">
            <h1 class="text-white">Conselho Gestor</h1>
        </div>
    </div>

    <div class="container">
        <div class="row internas mt-5">

            <div class="col-12 blog-post">

                <p class="lead">Dentre as diversas etapas previstas para a criação do parque da cidade, está a formação de um conselho
                    gestor, cujo o objetivo é envolver a comunidade na discussão das políticas públicas de forma consultiva,
                    com enfoque nas questões socioambientais. </p>
                <p class="lead">O Conselho gestor é formado por representantes do Poder Público e da sociedade civil, considerando as
                    peculiaridades da área, de forma paritária, indicados pelos órgãos ou colegiados que representarem.</p>
                <p class="lead">O Conselho do Parque da Cidade é constituído por 16 (dezesseis) membros efetivos, com os representantes
                    dos seguintes segmentos:</p>
                <p class="lead"><strong>I -</strong> 08 (oito) representantes dos órgãos do Poder Público, na forma seguinte:</p>
                <ol type="a">
                    <li>01 (um) representante da Secretaria Executiva do Meio Ambiente;</li>
                    <li>01 (um) representante da Fundação de Turismo de Angra dos Reis – TurisAngra;</li>
                    <li>01 (um) representante da Secretaria Executiva de Assistência Social;</li>
                    <li>01 (um) representante da Secretaria Executiva de Planejamento e Gestão Estratégica;</li>
                    <li>01 (um) representante da Secretaria Executiva de Proteção e Defesa Civil;</li>
                    <li>01 (um) representante da Secretaria de Desenvolvimento Urbano e Sustentabilidade - Programa
                        Comunidades de Angra;</li>
                    <li>01 (um) representante do Instituto Estadual do Ambiente - Superintendência da Baía da Ilha Grande
                        (SupBIG);</li>
                    <li>01 (um) representante da Câmara Municipal de Angra dos Reis - Comissão de Meio Ambiente.</li>
                </ol>
                <p class="lead"><strong>II -</strong> 08 (oito) representantes de entidades da Sociedade Civil, na forma seguinte:</p>
                <ol type="a">
                    <li>01 (um) representante de entidade do setor de Turismo;</li>
                    <li>01 (um) representante de entidade de profissionais que atuam no setor da construção civil;</li>
                    <li>01 (um) representante da Academia de Ensino;</li>
                    <li>02 (dois) representantes de Associações de Moradores;</li>
                    <li>01 (um) representante de Entidade Ambientalista;</li>
                    <li>01 (um) representante de Associação Esportiva;</li>
                    <li>01 (um) representante das Instituições de Ensino em Turismo e dos Guias de Turismo.</li>
                </ol>

                <p class="mt-5">
                    <a href="downloads/Decreto-12625-2022_.pdf" target="_blank">
                        <strong>
                            <i class="fas fa-download"></i> Decreto Nº 12.625, de 15 de junho de 2022 -
                        </strong>
                        <span class="preto">
                            Nomeia os membros para compor o Conselho Gestor do Parque Natural Municipal da Mata Atlântica –
                            PNMMA, para o biênio 2022/2024.
                        </span>
                    </a>
                </p>

                <p class="mt-5">
                    <a href="downloads/Edital-Chamamento-Publico-Conselho-Gestor-2021-2023.pdf" target="_blank">
                        <strong>
                            <i class="fas fa-download"></i> Edital de Chamamento Público Conselho Gestor 2021-2023 -
                        </strong>
                        <span class="preto">
                            Edital de chamamento público de representantes da sociedade civil para composição do Conselho
                            Gestor do Parque Natural Municipal da Mata Atlântica – PNMMA.
                        </span>
                    </a>
                </p>

                <p class="mt-5">
                    <a href="downloads/Edital-Chamamento-Publico-Conselho-Gestor-2021-2023-Prorrogacao.pdf" target="_blank">
                        <strong>
                            <i class="fas fa-download"></i> Edital de Chamamento Público Conselho Gestor 2021-2023 -
                            Prorrogação de Prazo Vaga Remanescente -
                        </strong>
                        <span class="preto">
                            Edital de chamamento público de representantes da sociedade civil para composição do Conselho
                            Gestor do Parque Natural Municipal da Mata Atlântica – PNMMA, vagas remanescentes.
                        </span>
                    </a>
                </p>

                <p class="mt-5">
                    <a href="downloads/DECRETO-11242-2019-CONSELHO-PNMMA.pdf" target="_blank">
                        <strong>
                            <i class="fas fa-download"></i> Decreto Nº 11242/2019 -
                        </strong>
                        <span class="preto">
                            Dispõe sobre a criação do Conselho Gestor do Parque Natural Municipal da Mata Atlântica - PNMMA
                            e dá outras providências.
                        </span>
                    </a>
                </p>

            </div>
        </div>
    </div>

@endsection