<?php $__env->startSection("title", env("APP_NAME") . " :: Alterar Endereços"); ?>
<?php $__env->startSection('content'); ?>
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="card shadow mx-0">  
                    <?php $headLine = "<i class='fa-solid fa-location-dot'></i> Alterar Endereços"; ?>

                    <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
                                'headLine' => __($headLine),
                                'routeAdd' => 'admin.perfilEnderecos.create',
                                'routeAddParams' => [$user->id], 
                                'nameAdd' => __('Novo endereço'),
                                "permission" => "GUEST",
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                    <div class="card-body">
                        
                        <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        <?php echo $__env->make('components.modal._modelProfile', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                        <hr/>

                        <?php if (isset($component)) { $__componentOriginal0650541a119648223455610148c86d0b = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal0650541a119648223455610148c86d0b = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.tables._table','data' => ['thead' => ['#', 'Criado em', 'Tipo de domicílio', 'Endereco', 'Fixar', 'Status', 'Ações'],'pagination' => $enderecos->links()]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('tables._table'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['thead' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(['#', 'Criado em', 'Tipo de domicílio', 'Endereco', 'Fixar', 'Status', 'Ações']),'pagination' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($enderecos->links())]); ?>
                             <?php $__env->slot('body', null, []); ?> 
                                <?php  $index = 0;  ?>
                                <?php $__currentLoopData = $enderecos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $endereco): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <tr>
                                        <td>
                                            <?php if(isset($endereco->id)): ?>
                                                <div style="width: 120px;">
                                                    <?php echo $__env->make('components.tables._openPhotoAndPdf',[
                                                        'asset' => $endereco->comprovante,
                                                        'alt' => "Comprovante de {$user->name}",
                                                        'title' => "Comprovante de {$user->name}",
                                                        'text' => 'Visualizar foto',
                                                        'index' => $index,
                                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                                </div>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo e(date("d/m/Y H:m", strtotime($endereco->created_at))); ?></td>
                                        <td>
                                            <?php echo $__env->make("components.tables._getEnumValue", [
                                                "EnumClass" => App\Enums\StatusDomicilio::cases(),
                                                "arg" => $endereco->domicilio,
                                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                        </td>
                                        <td>
                                            <?php echo $endereco->address; ?>

                                        </td>
                                        <td class="text-center align-middle">
                                            <?php echo $__env->make('components.buttons._status', [
                                                "index" => $index . $index,
                                                "route" => "admin.perfilEnderecos.fixar",
                                                "id" => $endereco->id,
                                                "status" => $endereco->fixed,
                                                "permission" => "GUEST",
                                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                        </td>
                                        <td class="text-center align-middle">

                                            <?php echo $__env->make('components/buttons/_status', [
                                                "index" => $index,
                                                "route" => "admin.perfilEnderecos.status",
                                                "id" => [$endereco->id],
                                                "status" => $endereco->status,
                                                "permission" => "GUEST",
                                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                                        </td>
                                        <td>
                                            <div class="btn-group" role="group">

                                                    <?php echo $__env->make('components/buttons/_editButton', [
                                                        "route" => "admin.perfilEnderecos.edit",
                                                        "id" => [$endereco->id],
                                                        "fontawesome" => null,
                                                        "title" => "Editar",
                                                        "permission" => "GUEST",
                                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                                                <?php if($index != 0): ?>
                                                    <?php echo $__env->make('components/buttons/_deleteButton', [
                                                        "message" => __("* Este endereço será excluído e esta ação não poderá ser desfeita, deseja continuar?"),
                                                        "route" => "admin.perfilEnderecos.destroy",
                                                        "id" => [$endereco->id],
                                                        "fontawesome" => null,
                                                        "title" => "Excluir",
                                                        "permission" => "GUEST",
                                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                                <?php endif; ?>
                                                
                                            </div>
                                        </td>
                                    </tr>
                                    <?php $index++; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                             <?php $__env->endSlot(); ?>
                         <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal0650541a119648223455610148c86d0b)): ?>
<?php $attributes = $__attributesOriginal0650541a119648223455610148c86d0b; ?>
<?php unset($__attributesOriginal0650541a119648223455610148c86d0b); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal0650541a119648223455610148c86d0b)): ?>
<?php $component = $__componentOriginal0650541a119648223455610148c86d0b; ?>
<?php unset($__componentOriginal0650541a119648223455610148c86d0b); ?>
<?php endif; ?>

                    </div>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/perfilEnderecos/index.blade.php ENDPATH**/ ?>