@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Portal de Dados Abertos")
@section('content')
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 my-3">
                @include('servicos.parts.breadcrumb', ['current' => __('Portal de Dados Abertos')])
            </div>

            <div class="col-12 mb-1">
                <div class="col-12 mb-3">
                    <h1 class="title">Portal de Dados Abertos de Angra dos Reis</h1>
                    <div class="card shadow-sm mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Estrutura Organizacional</h3>
                            <a href="{{ route("dadosAbertos.estruturaOrganizacional") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.estruturaOrganizacional") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                    <div class="card shadow-sm  mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Creches e ecolas públicas</h3>
                            <a href="{{ route("dadosAbertos.crechesEscolasPublicas") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.crechesEscolasPublicas") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                    <div class="card shadow-sm  mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Centros de referencias</h3>
                            <a href="{{ route("dadosAbertos.centrosDeReferencia") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.centrosDeReferencia") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                    <div class="card shadow-sm  mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Conselhos Municipais</h3>
                            <a href="{{ route("dadosAbertos.conselhosMunicipal") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.conselhosMunicipal") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                    <div class="card shadow-sm  mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Unidades de Saúde</h3>
                            <a href="{{ route("dadosAbertos.unidadesSaude") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.unidadesSaude") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                    <div class="card shadow-sm  mb-3">
                        <div class="card-body p-3">
                            <h3 class="mb-3">Parques e Jardins</h3>
                            <a href="{{ route("dadosAbertos.parquesJardins") }}" target="_blank" class="btn btn-lg btn-secondary d-inline"><i class="fa-solid fa-code"></i> .json</a>
                            <a href="{{ route("servicos.api.parquesJardins") }}" class="btn btn-lg btn-primary d-inline"><i class="fa-solid fa-file"></i> API</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection