<section class="bg-light" id="legislacao">
    <div class="container">
        <div class="row">
            <div class="col-10 offset-1">
                <h2 class=" mb-5 text-center">{{ __("Legislação") }}</h2>
            </div>
            <div class="col-10 offset-1 border border-dark-subtle border-end-0 border-bottom-0 p-3">
                <p class="fw-normal text-muted my-4">
                    <a href="{{ asset('pmar/assets/legislacao/BO_1703_de_30_06_2023-1.pdf') }}" target="_blank">
                        <strong>
                            {{ __("D E C R E T O Nº 13.055, DE 23 DE JUNHO DE 2023") }}
                            <i class="bi bi-stack"></i>
                        </strong>
                    </a>
                    <br>
                    <blockquote class="blockquote ">
                        {{ __("DISPÕE SOBRE A IMPLEMENTAÇÃO DO GOVERNO DIGITAL E REGULAMENTA A LEI FEDERAL Nº 14.129 DE 29 DE MARÇO DE 2021 NO MUNICÍPIO.") }}
                    </blockquote>
                    <small>{{ __("Boletim Oficial N° 1816, página 14.") }}</small>
                </p>
            </div>
        </div>
        <div class="row">
            <div class="col-10 offset-1 p-3">
                <p class="fw-normal text-muted my-4">
                    <a href="{{ asset('pmar/assets/legislacao/BO_1703_de_30_06_2023-1.pdf') }}" target="_blank">
                        <strong>
                            {{ __("DECRETO Nº 14.178, DE 16 DE JUNHO DE 2025") }}
                            <i class="bi bi-stack"></i>
                        </strong>
                    </a>
                    <br>
                    <blockquote class="blockquote ">
                        {{ __("DISPÕE SOBRE O FUNCIONAMENTO DO COMITÊ MUNICIPAL DE GOVERNANÇA DIGITAL, INSTITUÍDO PELO DECRETO Nº 13.055, DE 23 DE JUNHO DE 2023, E DÁ OUTRAS PROVIDÊNCIAS.") }}
                    </blockquote>
                    <small>{{ __("Boletim Oficial N° 1816, página 14.") }}</small>
                </p>
            </div>
        </div>
        <div class="row">
            <div class="col-10 offset-1  border border-top-0 border-start-0 p-3">
                <p class="fw-normal text-muted my-4" >
                    <a href="{{ asset('pmar/assets/legislacao/BO_1703_de_30_06_2023-1.pdf') }}" target="_blank">
                        <strong>
                            {{ __("DECRETO Nº 14.284, DE 14 DE AGOSTO DE 2025") }}
                            <i class="bi bi-stack"></i>
                        </strong>
                    </a>
                    <br>
                    <blockquote class="blockquote ">
                        {{ __("O PREFEITO DO MUNICÍPIO DE ANGRA DOS REIS, ESTADO DO RIO DE JANEIRO, no uso de sua atribuição legal que lhe confere o art. 87, inciso IX, da Lei Orgânica do Município; e CONSIDERANDO o disposto no Decreto nº 13.055, de 23 de junho de 2023, que cria o Comitê Municipal de Governança Digital(...)") }}
                    </blockquote>
                    <small>{{ __("Boletim Oficial N° 1816, página 14.") }}</small>
                </p>
            </div>
        </div>
    </div>
</section>