<div class="mb-3">
    <label for="<?php echo e($for ?? $name); ?>" class="form-label text-bold">
        <?php echo e(__($label)); ?>:
        <?php echo ($required ?? false) ? '<span class="span-admin-create">*</span>' : ''; ?>

    </label>

    <select 
        class="form-control <?php $__errorArgs = [$name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>"
        name="<?php echo e($name); ?>"
        id="<?php echo e($id ?? $name); ?>"
        <?php echo e(($required ?? false) ? 'required' : ''); ?>

        <?php echo e(($readonly ?? false) ? 'disabled' : ''); ?>

        onchange="<?php echo e($onchange ?? ''); ?>"
    >
        <?php if(!empty($placeholder)): ?>
            <option value=""><?php echo e(__($placeholder)); ?></option>
        <?php endif; ?>

        <?php $__currentLoopData = $options; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $value): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <option 
                value="<?php echo e($key); ?>" 
                <?php echo e(old($name, $selected ?? '') == $key ? 'selected' : ''); ?>

            >
                <?php echo e(__($value)); ?>

            </option>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </select>

    <?php if(isset($small) && $small): ?>
        <small class="text-secondary text-bold"><?php echo __($small); ?></small>
    <?php endif; ?>

    <?php $__errorArgs = [$name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
        <small class="text-danger text-bold"><?php echo e(__($message)); ?></small>
    <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/inputs/_selectType.blade.php ENDPATH**/ ?>