<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <meta name="site" content="https://angra.rj.gov.br">

    <title>@yield('title')</title>

    <meta name="description" content="TTS - Taxa de Turismo Sustentável de Angra dos Reis" />
    <meta name="robots" content="noodp" />

    <meta name="description" content="Descubra como a Taxa de Turismo Sustentável ajuda a manter Angra dos Reis encantadora, preservando suas ilhas, praias e belezas naturais para quem ama viajar com consciência." />
    <meta name="author" content="Prefeitura de Angra dos Reis">
    <meta name="keywords" content="Taxa de Turismo">
    <meta name="generator" content="Prefeitura de Angra dos Reis">
    <meta name="robots" content="index, follow" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />

    <!-- para o compartilhar -->
    <meta property="og:title" content="TTS - Taxa de Turismo Sustentável de Angra dos Reis" />
    <meta property="og:type" content="city" />
    <meta property="og:url" content="https://angra.rj.gov.br/tts" />
    <meta property="og:image" content="{{ asset('pmar/assets/img/tts/logo-angraviva2.png') }}" />
    <meta property="og:description" content="Saiba mais sobre a Taxa de Turismo Sustentável de Angra dos Reis" />
    <meta property="og:locale" content="pt_BR">

    <link rel="apple-touch-icon" sizes="57x57" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-57x57.png") }}">
    <link rel="apple-touch-icon" sizes="60x60" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-60x60.png") }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-72x72.png") }}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-76x76.png") }}">
    <link rel="apple-touch-icon" sizes="114x114" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-114x114.png") }}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-120x120.png") }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-144x144.png") }}">
    <link rel="apple-touch-icon" sizes="152x152" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-152x152.png") }}">
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset("sei-angra/assets/fiveicon/apple-icon-180x180.png") }}">
    <link rel="icon" type="image/png" sizes="192x192" href="{{ asset("sei-angra/assets/fiveicon/android-icon-192x192.png") }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset("sei-angra/assets/fiveicon/favicon-32x32.png") }}">
    <link rel="icon" type="image/png" sizes="96x96" href="{{ asset("sei-angra/assets/fiveicon/favicon-96x96.png") }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset("sei-angra/assets/fiveicon/favicon-16x16.png") }}">
    <link rel="manifest" href="{{ asset("sei-angra/assets/fiveicon/manifest.json") }}">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="{{ asset("sei-angra/assets/fiveicon/ms-icon-144x144.png") }}">
    <meta name="theme-color" content="#ffffff">

    <link rel="stylesheet" href="{{ asset('pmar/css/tts.css') }}">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.6.0/css/all.min.css" />

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Montserrat:ital,wght@0,100..900;1,100..900&display=swap" rel="stylesheet">
</head>