<div class="row justify-content-center">
    <h3 class="subtitle-home">{{ __("Pontos Turísticos de Angra dos Reis") }}</h3>
    <div class="col-12">
        <div id="cards-container" class="flex-container cards-container">
        </div>
    </div>
    <div class="col-12 col-sm-12 col-md-6 col-lg-6 col-xl-6 col-xxl-6 m-auto py-5 px-5">
        <a href="https://visite.angra.rj.gov.br" target="_blank" class="btn p-4 fw-bold btn-outline-primary rounded-5 fs-3">{{ __("Visite Angra") }}</a>
    </div>
</div>