<!-- Basic features section-->
<section id="consulta" class="bg-gradient-primary-to-secondary">
    <div class="container px-5">
        <div class="row justify-content-center align-items-center g-2">
            <div class="col-sm-5 col-md-4 mb-3 mx-5">
                <div class="px-5 px-sm-0"><img class="img-fluid rounded-circle" src="{{ asset('sei-angra/assets/img/repetition.jpg') }}" alt="Ilustração de alguém verificando documentos." />
                </div>
            </div>
            <div class="col p-2">
                <h3 class="shadow-text fs-2 my-3">Pesquisa Pública</h3>
                <p class="fs-5">
                    <a href="https://angra.sei.rj.gov.br/consultaprocessual" target="_blank"
                    class="bg-white fw-bolder p-2 rounded-5">Clique aqui</a> para fazer <strong>consultas
                processuais</strong> inerentes ao SEI-ANGRA.
            </p>
            <br>
            <h3 class="shadow-text fs-2 my-3">Validação de Documentos</h3>
            <p class="fs-5">

                <a href="https://angra.sei.rj.gov.br/validardocumento" target="_blank"
                class="bg-white fw-bolder p-2 rounded-5">Clique aqui</a> para <strong>validar
            documentos</strong> do SEI-ANGRA. Desta forma você confirma a veracidade do documento
                    desejado.
        </p>
    </div>
</div>
</section>
