@props(['stats' => []])

<div class="stats-row">
    @foreach($stats as $stat)
        <div class="stat-card">
            <div class="stat-icon {{ $stat['variant'] ?? 'primary' }}">
                <i class="{{ $stat['icon'] ?? 'fa-solid fa-chart-bar' }}"></i>
            </div>
            <div class="stat-content">
                <p class="stat-value">{{ number_format($stat['value'] ?? 0, 0, ',', '.') }}</p>
                <p class="stat-label">{{ __($stat['label'] ?? '') }}</p>
            </div>
        </div>
    @endforeach
</div>

