<?php
    $noticiasDestaque = $noticiasDestaque ?? collect();
    $noticiasStructureNome = $noticiasStructure?->name ?? $secretaria?->name;
    $verTodasUrl = ! empty($secretaria?->slug)
        ? route('paginas.details', $secretaria->slug)
        : route('paginas.noticias', ['secretaria_id' => config('mobiangra.structure_id')]);
?>

<section class="ma-news" aria-labelledby="ma-news-title">
    <div class="container">
        <div class="ma-news__header">
            <div class="ma-news__heading">
                <h2 id="ma-news-title" class="ma-news__title">
                    <i class="fa-solid fa-newspaper ma-news__title-icon" aria-hidden="true"></i>
                    <?php echo e(__('Notícias')); ?>

                </h2>
                <?php if(! empty($noticiasStructureNome)): ?>
                    <span class="badge rounded-pill ma-news__structure-badge"
                          title="<?php echo e(__('Fonte das notícias')); ?>">
                        <?php echo e($noticiasStructureNome); ?>

                    </span>
                <?php endif; ?>
            </div>
            <a href="<?php echo e($verTodasUrl); ?>" class="ma-news__see-all">
                <?php echo e(__('Ver todas')); ?>

                <i class="fa-solid fa-arrow-right" aria-hidden="true"></i>
            </a>
        </div>

        <?php if($noticiasDestaque->isNotEmpty()): ?>
            <div class="row g-4">
                <?php $__currentLoopData = $noticiasDestaque; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $noticia): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <div class="col-12 col-md-6 col-lg-4">
                        <?php if (isset($component)) { $__componentOriginal0502f6f8232e1a0a931ad4f34629e7a8 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal0502f6f8232e1a0a931ad4f34629e7a8 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.news-card','data' => ['noticia' => $noticia]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.news-card'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['noticia' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($noticia)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal0502f6f8232e1a0a931ad4f34629e7a8)): ?>
<?php $attributes = $__attributesOriginal0502f6f8232e1a0a931ad4f34629e7a8; ?>
<?php unset($__attributesOriginal0502f6f8232e1a0a931ad4f34629e7a8); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal0502f6f8232e1a0a931ad4f34629e7a8)): ?>
<?php $component = $__componentOriginal0502f6f8232e1a0a931ad4f34629e7a8; ?>
<?php unset($__componentOriginal0502f6f8232e1a0a931ad4f34629e7a8); ?>
<?php endif; ?>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
        <?php else: ?>
            <p class="ma-news__empty text-muted mb-0"><?php echo e(__('Nenhuma notícia publicada no momento.')); ?></p>
        <?php endif; ?>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/news.blade.php ENDPATH**/ ?>