@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Portal da Transparência')
@section('content')
    <section class="portal-da-transparencia">
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Portal da Transparencia</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <header class="article-header">
                        <h1 class="title" style="text-align: center;">Angra dos Reis</h1>
                        <p style="text-align: center; font-size: 14pt;">Transparente para todos.</p>
                    </header>

                    <main class="container my-5">
                        <div class="mb-4 text-center">
                            <input type="text" class="form-control w-50 mx-auto"
                                placeholder="O que você está procurando?">
                        </div>
                        <p style="font-size: 13pt; margin-top: 30px;">O <strong>Portal da Transparência</strong> é uma
                            ferramenta desenvolvida para permitir que a sociedade acompanhe o uso dos recursos públicos
                            e
                            tenha uma participação ativa na discussão das políticas públicas e no uso do dinheiro
                            público.
                        </p>
                        <p style="font-size: 13pt;">Com o objetivo de dar plena transparência aos dados do <strong>Poder
                                Executivo</strong>, disponibilizamos à sociedade uma ferramenta prática e intuitiva,
                            atendendo as recomendações dos órgãos de controle.</p>
                        <p style="font-size: 13pt;">Caso não encontre a informação que está buscando, entre em contato
                            conosco através de nossos canais de <strong><a
                                    href="{{ route('paginas.ouvidoria') }}">Ouvidoria</a></strong> e
                            do
                            <strong><a href="https://falabr.cgu.gov.br/web/home?modoOuvidoria=1&ouvidoriaInterna=false"
                                    target="_blank">Serviço de Informação ao Cidadão</a></strong>.
                        </p>

                        <div class="top20"></div>
                        <div class="section-title text-center mb-3 titulo-transparencia">Informações Orçamentárias e
                            Financeiras</div>
                        <div class="row g-3">

                            <div class="col-6 col-md-3 card-transparencia dropdown">
                                <a href="#receitas" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/receitas2.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>Receitas</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/comparativo-receita-prevista-com-arrecadada/"
                                            target="_blank">
                                            <li>Receita Prevista e Arrecadada</li>
                                        </a>
                                        <a href="{{ route('paginas.transparencia.renuncia-receita') }}">
                                            <li>Renúncias de Receitas</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-6 col-md-3 card-transparencia dropdown">
                                <a href="#despesas" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/despesas2.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>Despesas</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="{{ route('paginas.transparencia.QDD') }}">
                                            <li>QDD - Quadro de Detalhamento das Despesas</li>
                                        </a>
                                        <a
                                            href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-despesa-simplificado/" target="_blank">
                                            <li>Despesa Empenhada, Liquidada e Paga</li>
                                        </a>
                                        <a
                                            href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-liquidacoes-a-pagar/" target="_blank">
                                            <li>Ordem Cronológica de Pagamento</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-6 col-md-3 card-transparencia dropdown">
                                <a href="#convenios" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/convenios-uniao.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Convênios</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-convenio-concedido-recebido/"
                                            target="_blank">
                                            <li>Convênios</li>
                                        </a>
                                        <a href="https://portaldatransparencia.gov.br/convenios/consulta?paginacaoSimples=true&tamanhoPagina=&offset=&direcaoOrdenacao=asc&nomeMunicipio=ANGRA+DOS+REIS&colunasSelecionadas=linkDetalhamento%2CnumeroConvenio%2Cuf%2CmunicipioConvenente%2Csituacao%2CtipoTransferencia%2Cobjetivo%2CorgaoSuperior%2Corgao%2Cconcedente%2Cconvenente%2CdataInicioVigencia%2CdataFimVigencia%2CdataPublicacao%2CvalorLiberado%2CvalorCelebrado"
                                            target="_blank">
                                            <li>Convênios da União</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia dropdown">
                                <a href="#emendas" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/emendas.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>Emendas</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="{{ route('paginas.transparencia.emendas-impositivas') }}">
                                            <li>Emendas
                                                Impositivas</li>
                                        </a>
                                        <a href="{{ route('paginas.transparencia.emendas-parlamentares') }}">
                                            <li>Emendas
                                                Parlamentares</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia">
                                <a href="#" class="anchor">
                                    <img src="{{ asset('pmar/assets/transparencia/balancos-contabeis.png') }}"
                                        class="icone" alt="Imagem de Exemplo">
                                    <div>Balanços Contábeis</div>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia dropdown">
                                <a href="#leis-orcamentarias" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/leis-orcamentarias.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Leis Orçamentárias</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="transp-ppa.asp?IndexSigla=Transp">
                                            <li>PPA - Plano Plurianual</li>
                                        </a>
                                        <a href="transp-LDO.asp?IndexSigla=Transp">
                                            <li>LDO - Lei de Diretrizes Orçamentárias</li>
                                        </a>
                                        <a href="transp-LOA.asp?IndexSigla=Transp">
                                            <li>LOA - Lei Orçamentária Anual</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia">
                                <a href="#" class="anchor">
                                    <img src="{{ asset('pmar/assets/transparencia/leis-responsabilidade-fiscal.png') }}"
                                        class="icone" alt="Imagem de Exemplo">
                                    <div>RREO e RGF</div>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia dropdown">
                                <a href="#pareceres-previos-tce-rj" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/pareceres-previos-tce-rj.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Prestação de Contas</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="cgm-parecer-previo.asp?IndexSigla=cgm">
                                            <li>Parecer Pr&eacute;vio
                                                TCE-RJ</li>
                                        </a>
                                        <a href="transp-julgamento-contas.asp?IndexSigla=transp">
                                            <li>Julgamento das contas
                                                do Executivo pelo Legislativo</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia dropdown">
                                <a href="#audiencia-publica" class="anchor">
                                    <div class="button-content">
                                        <img src="{{ asset('pmar/assets/transparencia/audiencia-publica.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Audiências Públicas</div>
                                    </div>
                                    <ul class="dropdown-menu">
                                        <a href="transp-audiencia-publica-metas-fiscais.asp?IndexSigla=Transp">
                                            <li>Metas Fiscais</li>
                                        </a>
                                        <a href="transp-audiencia-publica-leis-orcamentarias.asp?IndexSigla=Transp">
                                            <li>Leis orçamentárias</li>
                                        </a>
                                    </ul>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia">
                                <a href="https://www.spe.angra.rj.gov.br/Capa.aspx" class="anchor" target="_blank">
                                    <img src="{{ asset('pmar/assets/transparencia/prefeitura-eletronica.png') }}"
                                        class="icone" alt="Imagem de Exemplo">
                                    <div>Prefeitura Eletrônica</div>
                                </a>
                            </div>

                            <div class="col-xl-3 col-lg-4 col-md-4 col-sm-6 col-12 card-transparencia">
                                <a href="#" class="anchor" target="_blank">
                                    <img src="{{ asset('pmar/assets/transparencia/divida-ativa.png') }}" class="icone"
                                        alt="Imagem de Exemplo">
                                    <div>Dívida Ativa</div>
                                </a>
                            </div>
                        </div>

                        <div class="top20"></div>
                        <div class="my-5">
                            <div class="section-title text-center mb-3 titulo-transparencia">Informações Institucionais
                            </div>
                            <div class="row g-3">

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#estrutura-organizacional" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/estrutura-organizacional.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Estrutura Organizacional</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="estrutura-organizacional.asp?IndexSigla=transp">
                                                <li>Informações das
                                                    Secretarias</li>
                                            </a>
                                            <a href="https://www.canva.com/design/DAFnNE4WjuY/tCXJal3yhq8ZwVj-qggO6w/view?website#2:prefeito"
                                                target="_blank">
                                                <li>Organograma</li>
                                            </a>
                                            <a href="downloads/Lista_Telefonica.pdf" target="_blank">
                                                <li>Lista
                                                    Telefônica</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/ouvidoria.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>Ouvidoria</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#saude" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/saude.png') }}" class="icone"
                                                alt="Imagem de Exemplo">
                                            <div>Saúde</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="fusar-plano-saude.asp?IndexSigla=SSA&vNomeLink=Plano Municipal de Saúde 2022 - 2025"
                                                target="_blank">
                                                <li>Plano Municipal de Saúde 2022 - 2025</li>
                                            </a>
                                            <a href="fusar-rag.asp?IndexSigla=SSA&vNomeLink=Relatório Anual de Gestão - RAG"
                                                target="_blank">
                                                <li>Relatórios de Gestão</li>
                                            </a>
                                            <a href="downloads/SSA/REMUME-ATUALIZADA-2022.pdf" target="_blank">
                                                <li>Relação de Medicamentos Essenciais</li>
                                            </a>
                                            <a href="ssa-unidades.asp?IndexSigla=SSA&vNomeLink=Unidades de Saúde"
                                                target="_blank">
                                                <li>Unidades de Saúde</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#educacao" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/educacao.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Educação</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="sec-consulta-pme-oficial.asp?IndexSigla=SEJIN">
                                                <li>Plano Municipal de Educação 2015 - 2025</li>
                                            </a>
                                            <a href="https://matriculadigital.angra.rj.gov.br/#/" target="_blank">
                                                <li>Matrícula Digital</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#esporte" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/esporte.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Esporte</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="sel-projetos-aprovados.asp?IndexSigla=SESL">
                                                <li>Projetos aprovados</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#cultura" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/cultura.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Cultura</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="transp-oficinas-cultura.asp?IndexSigla=transp">
                                                <li>Oficinas e exposições</li>
                                            </a>
                                            <a href="noticia.asp?IndexSigla=SCP&vid_noticia=54876" target="_blank">
                                                <li>Lei de Incentivo à Cultura</li>
                                            </a>
                                            <a href="secup-fundo-municipal-cultura.asp?IndexSigla=SCP" target="_blank">
                                                <li>Fundo Municipal de Cultura</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#conselhos-municipais" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/conselhos-municipais.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Conselhos Municipais</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="transp-conselhos.asp?IndexSigla=transp">
                                                <li>Conselhos</li>
                                            </a>
                                            <a href="transp-parecer-fundeb.asp?indexsigla=transp">
                                                <li>Parecer FUNDEB</li>
                                            </a>
                                            <a href="transp-parecer-saude.asp?indexsigla=transp">
                                                <li>Parecer RAG Saúde</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-acompanhamento-ppa" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/Metas-Projetos.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Metas e Projetos</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/perguntas-frequentes.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Perguntas Frequentes</div>
                                    </a>
                                </div>

                            </div>
                        </div>

                        <div class="top20"></div>
                        <div class="my-5">
                            <div class="section-title text-center mb-3 titulo-transparencia">Informações Administrativas
                            </div>
                            <div class="row g-3">

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#licitacoes" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/licitacoes.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Licitações</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a
                                                href="licitacoes-procedimentos.asp?indexsigla=transp&instituicao=0&status=0&modalidade=0&ano=2024">
                                                <li>Licitações e Procedimentos</li>
                                            </a>
                                            <a href="licitacoes_atas.asp?IndexSigla=seges">
                                                <li>Atas de Registro de Preço</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="{{ route('paginas.contratos') }}" class="anchor">
                                        <img src="{{ asset('pmar/assets/transparencia/contratos.png') }}" class="icone"
                                            alt="{{ __('Contratos') }}">
                                        <div>{{ __('Contratos') }}</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/legislacao-municipal.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Legislação Municipal</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/lgpd.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>LGPD - Lei Geral de Proteção de Dados</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/governo-digital.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Governo Digital</div>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="https://radar.tce.mt.gov.br/extensions/radar-da-transparencia-publica/radar-da-transparencia-publica.html" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/radar.png') }}" class="icone"
                                            alt="Imagem de Exemplo">
                                        <div>Radar da Transparência</div>
                                    </a>
                                </div>

                            </div>
                        </div>

                        <div class="top20"></div>
                        <div class="mb-5">
                            <div class="section-title text-center mb-3 titulo-transparencia">Informações de Recursos
                                Humanos</div>
                            <div class="row g-3">

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#remuneracoes-servidores" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/remuneracoes-servidores.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Remuneração de Servidores</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-folha-pagamento/"
                                                target="_blank">
                                                <li>Remunerações</li>
                                            </a>
                                            <a href="https://portaldoservidor.angra.rj.gov.br/tabela-salarial.asp"
                                                target="_blank">
                                                <li>Tabela Salarial</li>
                                            </a>
                                            <a href="https://portaldoservidor.angra.rj.gov.br/tabela-salarial.asp"
                                                target="_blank">
                                                <li>Teto Salarial</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia dropdown">
                                    <a href="#diarias-passagens" class="anchor">
                                        <div class="button-content">
                                            <img src="{{ asset('pmar/assets/transparencia/diarias-passagens.png') }}"
                                                class="icone" alt="Imagem de Exemplo">
                                            <div>Diárias e Passagens</div>
                                        </div>
                                        <ul class="dropdown-menu">
                                            <a href="https://angra.prodataweb.inf.br/sig/app.html#/transparencia/transparencia-diaria-passagem/"
                                                target="_blank">
                                                <li>Despesas com diárias e passagens</li>
                                            </a>
                                            <a href="downloads/legislacoes-pdf/472-2022119-1612.pdf" target="_blank">
                                                <li>Tabela de valores das diárias</li>
                                            </a>
                                        </ul>
                                    </a>
                                </div>

                                <div class="col-6 col-md-3 card-transparencia">
                                    <a href="#" class="anchor" target="_blank">
                                        <img src="{{ asset('pmar/assets/transparencia/concursos-publicos.png') }}"
                                            class="icone" alt="Imagem de Exemplo">
                                        <div>Concursos Públicos</div>
                                    </a>
                                </div>

                            </div>
                        </div>

                        <div class="top20"></div>
                        <div class="text-center">
                            <h4>Qual o seu nível de satisfação com essa página?</h4>
                            <div class="feedback-icons">
                                <i class="bi bi-emoji-frown-fill text-danger"></i>
                                <i class="bi bi-emoji-neutral-fill text-warning"></i>
                                <i class="bi bi-emoji-smile-fill text-success"></i>
                            </div>
                        </div>
                    </main>

                </div>
            </div>
        </div>
    </section>
@endsection