<div>
    <h3 class="text-center">
        <button type="button" data-bs-toggle="collapse" data-bs-target="#collapseUm" aria-expanded="false" aria-controls="collapseUm" class="border-0 bg-white">
            <strong>{{ __("Atas de Reunião") }}</strong>
            <i class="bi bi-chevron-down"></i>
        </button>
    </h3>    

    <div>
        @php 
        
            $array_atas = [
                
                [
                    'url' => __("asset('pmar/assets/atas/Ata_n_001-2025-sessao_extraordinaria_CMGD.pdf')"),
                    'target' => __('_blank'),
                    'numero' => __('001/2024'),
                    'data' => __('de 7 de Março de 2024'),
                    'fontawesome' => __('<i class="bi-save2-fill me-2"></i></strong></a>'),

                ], 
            ];
            $limite = 5;
        @endphp

        @forelse($array_atas as $atas)
            @include('components/lists/_divLinkAtas', $atas)
        @empty
            <div class="mt-5 mb-3">
                <p class="fw-normal text-muted mb-lg-0">
                    {{ __("Nenhuma ata encontrada") }}<br>
                </p>
            </div>
        @endforelse
    </div>
</div>