<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
    @include('layouts.landing_pages.tts.elements.head')
    <body class="animate__animated animate__fadeIn">
        @yield('content')
        @include('layouts.landing_pages.tts.elements.footer')
    </body>
</html>
