<!-- Infraestrutura e Urbanismo -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-primary">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-road fa-2x me-3"></i>
                <h5 class="card-title mb-0">Infraestrutura e Urbanismo</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-road me-2 text-muted"></i> Pavimentação de vias <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-lightbulb me-2 text-muted"></i> Iluminação pública <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-trash-alt me-2 text-muted"></i> Coleta de lixo <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-water me-2 text-muted"></i> Drenagem e esgotos <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-hard-hat me-2 text-muted"></i> <a href="https://obras.angra.rj.gov.br" target="_blank" class="text-dark">Andamentos de obras</a>
                </li>
            </ul>
        </div>
    </div>
</div>