<div class="d-flex">
    @if(isset($linkBack))
        <button class="btn btn-lg btn-secondary d-inline me-2" onclick="javascript:window.location.href='{{ route($linkBack) }}'" type="button">{{ __("Voltar") }}</button>
    @endif
    @if(isset($id))
        <button class="mobile-btn-atualizar btn btn-lg btn-primary d-inline"
                onclick="window.location.href='{{ route($route, $id) }}'">
            {!! $fontawesome !!} {{ $text }}
        </button>
    @else
        <button class="mobile-btn-atualizar btn btn-lg btn-primary d-inline"
                onclick="window.location.href='{{ route($route) }}'">
            {!! $fontawesome !!} {{ $text }}
        </button>
    @endif
</div>
