<div class="row justify-content-center">
	<h3 class="subtitle-home">{{ __("Um mar de oportunidades") }}</h3>
	<div class="col-12 d-flex justify-content-center">
        <div class="home-video-container">
            <iframe width="100%" height="506" src="https://www.youtube.com/embed/OvQqoxh2dHE?rel=0&showinfo=0&autoplay=0&controls=0" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen>
            </iframe>
          </div>
	</div>
</div>