<!-- Desenvolvimento Econômico -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-warning">
        <div class="card-header {{ $cor }} text-dark">
            <div class="d-flex align-items-center">
                <i class="fas fa-chart-line fa-2x me-3"></i>
                <h5 class="card-title mb-0">Desenvolvimento Econômico</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-store me-2 text-muted"></i> Incentivos ao comércio local <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-industry me-2 text-muted"></i> Atração de empresas <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-hands-helping me-2 text-muted"></i> Microcrédito <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-graduation-cap me-2 text-muted"></i> Capacitação empresarial <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-umbrella-beach me-2 text-muted"></i> Fomento ao turismo <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-user-tie me-2 text-muted"></i>  
                    <a href="https://bancodetalentos.angra.rj.gov.br" target="_blank" class="text-dark">Banco de talentos</a>
                </li>
                <li class="list-group-item"><i class="fas fa-user-tag me-2 text-muted"></i> Cadastro de ambulantes <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
    </div>
</div>