<aside id="cadastrarse" class="text-center bg-gradient-secondary-to-primary mt-5">
    <div class="container px-5">
        <div class="row gx-5 justify-content-center">
            <div class="col-xl-12">
                <div class="h2 fs-1 text-white mb-4">

                    <span class="shadow-text my-3">Quero me cadastrar no SEI!<br> <br></span>

                    <a data-bs-toggle="tooltip" data-bs-placement="bottom"
                        title="Servidores e Empresas Locadas na PMAR"
                        class="btn fs-5 btn-outline-light py-3 px-4 rounded-pill"
                        href="https://portaldoservidor.angra.rj.gov.br/informatica" target="_blank"><i
                            class="fa-solid fa-landmark p-2"></i>Cadastro Interno</a>

                    <a data-bs-toggle="tooltip" data-bs-placement="bottom" title="Munícipes de Angra dos Reis"
                        class="btn fs-5 btn-outline-light py-3 px-4 rounded-pill"
                        href="https://angra.sei.rj.gov.br/sei/controlador_externo.php?acao=usuario_externo_enviar_cadastro&id_orgao_acesso_externo=0"
                        target="_blank"><i class="fa-solid fa-globe p-2"></i>Cadastro Externo</a>

                </div>
            </div>
        </div>
    </div>
</aside>
<?php /**PATH /var/www/html/portal/resources/views/sei/sections/asideCadastrarse.blade.php ENDPATH**/ ?>