@if (!isset($permission) || auth()->user()->getPermissaoDetalhes($permission)['visualizar'])
    @php
        $embarcacaoUrl = route($route, $id);
        if (!empty($queryParams)) {
            $embarcacaoUrl .= (str_contains($embarcacaoUrl, '?') ? '&' : '?') . http_build_query($queryParams);
        }
    @endphp
    <a href="{{ $embarcacaoUrl }}" class="btn btn-sm btn-primary" title="{{ $title }}">
    @if($fontawesome == null)
        <i class="fa-solid fa-ship"></i>
    @else
        {!! $fontawesome !!}
    @endif
    </a>
@endif