<div class="secretario-footer-localizacao col-sm-12 col-md-12 col-lg-12 col-xl-9 col-xxl-9">
    <h4>Localização</h4>
    <iframe width="100%" height="300" frameborder="0" style="border:0; border-radius: 10px;"  referrerpolicy="no-referrer-when-downgrade" src="{{ $secretaria->map }}" allowfullscreen>
</iframe>
<address><strong>Endereço:</strong> {{ $secretaria->address }}</address>
<address><strong>Horário de atendimento ao público:</strong> {{ $secretaria->serviceHours }}</address>
</div>
