@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Lista de Músicos - Credenciamento')
@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-guitar'></i> Lista de Músicos - Credenciamento"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeAdd' => 'admin.cultura.credenciamentoMusicos.verify',
            'routeAddParams' => [], 
            'nameAdd' => __('Novo musico'),
            "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
        ])

        <div class="card-body">

            @include("errors.messageFlash")
            <div class="mb-2">
                <a class="btn btn-outline-secondary btn-sm me-1" href="{{ route('admin.cultura.credenciamentoMusicos.eventos.index') }}">{{ __('Eventos') }}</a>
                <a class="btn btn-outline-secondary btn-sm" href="{{ route('admin.cultura.credenciamentoMusicos.convocacoes.index') }}">{{ __('Convocações') }}</a>
            </div>

            <form method="get" action="{{ route('admin.cultura.credenciamentoMusicos.index') }}" class="mb-3">
                <div class="row g-2 align-items-end flex-wrap">
                    <div class="col-auto">
                        <label class="form-label small mb-0">{{ __('Pesquisar') }}</label>
                        <input type="text" name="q" class="form-control form-control-sm" placeholder="{{ __('Nome, e-mail, CPF...') }}" value="{{ request('q') }}">
                    </div>
                    <div class="col-auto">
                        <label class="form-label small mb-0">{{ __('Tipo') }}</label>
                        <select name="tipo_pessoa" class="form-select form-select-sm">
                            <option value="">{{ __('Todos') }}</option>
                            <option value="PF" {{ request('tipo_pessoa') === 'PF' ? 'selected' : '' }}>PF</option>
                            <option value="PJ" {{ request('tipo_pessoa') === 'PJ' ? 'selected' : '' }}>PJ</option>
                        </select>
                    </div>
                    <div class="col-auto">
                        <label class="form-label small mb-0">{{ __('Estilo') }}</label>
                        <select name="estilo_id" class="form-select form-select-sm">
                            <option value="">{{ __('Todos') }}</option>
                            @foreach($estilos ?? [] as $e)
                                <option value="{{ $e->id }}" {{ request('estilo_id') === $e->id ? 'selected' : '' }}>{{ $e->nome }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="col-auto">
                        <label class="form-label small mb-0">{{ __('Status') }}</label>
                        <select name="status_cadastro" class="form-select form-select-sm">
                            <option value="">{{ __('Todos') }}</option>
                            @foreach($statusCadastroList ?? [] as $val => $label)
                                <option value="{{ $val }}" {{ request('status_cadastro') === $val ? 'selected' : '' }}>{{ $label }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="col-auto">
                        <div class="form-check">
                            <input type="hidden" name="convocado" value="0">
                            <input type="checkbox" name="convocado" value="1" class="form-check-input" id="filtroConvocado" {{ request('convocado') ? 'checked' : '' }}>
                            <label class="form-check-label small" for="filtroConvocado">{{ __('Convocado') }}</label>
                        </div>
                    </div>
                    <div class="col-auto">
                        <label class="form-label small mb-0">{{ __('Ordenar') }}</label>
                        <select name="ordenar" class="form-select form-select-sm">
                            <option value="created_at" {{ request('ordenar', 'created_at') === 'created_at' ? 'selected' : '' }}>{{ __('Data cadastro') }}</option>
                            <option value="nome" {{ request('ordenar') === 'nome' ? 'selected' : '' }}>{{ __('Nome') }}</option>
                            <option value="id" {{ request('ordenar') === 'id' ? 'selected' : '' }}>{{ __('ID') }}</option>
                        </select>
                    </div>
                    <div class="col-auto">
                        <select name="ordem" class="form-select form-select-sm">
                            <option value="desc" {{ request('ordem', 'desc') === 'desc' ? 'selected' : '' }}>{{ __('Desc') }}</option>
                            <option value="asc" {{ request('ordem') === 'asc' ? 'selected' : '' }}>{{ __('Asc') }}</option>
                        </select>
                    </div>
                    <div class="col-auto">
                        <button type="submit" class="btn btn-sm btn-primary">{{ __('Filtrar') }}</button>
                        <a href="{{ route('admin.cultura.credenciamentoMusicos.index') }}" class="btn btn-sm btn-outline-secondary">{{ __('Limpar') }}</a>
                    </div>
                </div>
            </form>

            <x-tables._table :thead="['#','Nome', 'Email', 'Telefone', 'CPF', 'Situação Cadastral', 'Ações']" :pagination="$musicos->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($musicos as $musicos)
                        <tr>
                            <td>
                                <img src="{{ asset(optional($musicos->user)->photo ?? 'pmar/assets/img/icons/usuario.png') }}"
                             alt="Foto de {{ $musicos->user->firstName }}" class="rounded-circle"
                             style="width: 90px; height: 90px; object-fit: cover; cursor: pointer;"
                             data-bs-toggle="modal" data-bs-target="#modalFotoPaciente{{ $musicos->id }}" />

                                <div class="modal fade" id="modalFotoPaciente{{ $musicos->id }}" tabindex="-1"
                             aria-hidden="true">
                                    <div class="modal-dialog modal-fullscreen">
                                        <div class="modal-content bg-dark">
                                            <div class="modal-header border-0">
                                                <button type="button" class="btn-close btn-close-white ms-auto"
                                                data-bs-dismiss="modal" aria-label="Fechar"></button>
                                            </div>
                                            <div class="modal-body d-flex justify-content-center align-items-center">
                                                <img src="{{ asset(optional($musicos->user)->photo ?? 'pmar/assets/img/icons/usuario.png') }}"
                                             alt="Foto de {{ $musicos->user->firstName }}"
                                             class="img-fluid rounded" style="max-height: 90vh;" />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                            <td>{{ $musicos->user->name }}</td>
                            <td>{{ $musicos->user->email }}</td>
                            <td>{{ $musicos->user->phoneNumber }}</td>
                            <td>{{ $musicos->user->cpf }}</td>
                            <td class="text-start">
                                <div>
                                    <strong>Cadastro:</strong>
                                    <span class="badge bg-warning text-dark">{{ $musicos->statusCadastro }}</span>
                                </div>

                                <div>
                                    <strong>Status da carteirinha:</strong>
                                    <span class="badge bg-danger text-dark">{{ $musicos->carteirinha }}</span>
                                </div>
                            </td>
                            <td>
                                <div class="btn-group" role="group">

                                    @include('components.buttons._editButton', [
                                        "route" => "admin.cultura.credenciamentoMusicos.edit",
                                        "id" => $musicos->id,
                                        "title" => "Editar",
                                        "fontawesome" => null,
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                                    
                                    @include('components.buttons._navButton', [
                                        "route" => "admin.cultura.credenciamentoMusicos.convocacoes.historico",
                                        "id" => $musicos->id,
                                        "fontawesome" => '<i class="fa-solid fa-list" data-bs-toggle="tooltip" title="' . __('Convocações') . '"></i>',
                                        "title" => __("Convocações"),
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
                                    @include('components.buttons._navButton', [
                                        "route" => "admin.cultura.credenciamentoMusicos.chamados.index",
                                        "id" => $musicos->id,
                                        "fontawesome" => '<i class="fa-solid fa-comment-dots" data-bs-toggle="tooltip" title="Gerenciar Chamados"></i>',
                                        "title" => "Chamados",
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])

                                    @include('components.buttons._deleteButton', [
                                        "message" => __("* Este paciente será excluído do cadastro de pacientes com fibromialgia e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.cultura.credenciamentoMusicos.destroy",
                                        "id" => $musicos->id,
                                        "title" => "Excluir",
                                        "fontawesome" => null,
                                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                                    ])
    
                                    </div>
                                </td>
                            </tr>

                            @php $index++; @endphp
                        @endforeach

                    </x-slot>
                </x-tables._table>


            </div>
        </div>
    @endsection
