<section class="cta">
    <div class="cta-content">
        <div class="container px-5">
            <h2 class="text-white display-1 lh-1 mb-4">
                Sistema Eletrônico de Informações
            </h2>
            <a class="btn btn-outline-light py-3 px-4 rounded-pill" href="https://angra.sei.rj.gov.br/"  target="_blank"><i class="bi-door-open-fill me-2"></i> Acessar</a>
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/sei/sections/cta.blade.php ENDPATH**/ ?>