@props([
    'empresaTurismo',
])

@php
    use App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource;

    $mensagemVencido = EmpresaTurismoResource::cadasturMensagemVencidoGestor($empresaTurismo);
    $mensagemAlerta = EmpresaTurismoResource::cadasturMensagemAlertaVisualGestor($empresaTurismo);
@endphp

@if($mensagemVencido)
    <span
        class="badge bg-danger ms-1 align-middle"
        data-bs-toggle="tooltip"
        data-bs-placement="top"
        title="{{ $mensagemVencido }}"
        aria-label="{{ $mensagemVencido }}"
        role="status"
    >
        <i class="fa-solid fa-circle-exclamation" aria-hidden="true"></i>
        {{ __('Vencido') }}
    </span>
@elseif($mensagemAlerta)
    <span
        class="badge bg-warning text-dark ms-1 align-middle"
        data-bs-toggle="tooltip"
        data-bs-placement="top"
        title="{{ $mensagemAlerta }}"
        aria-label="{{ $mensagemAlerta }}"
        role="status"
    >
        <i class="fa-solid fa-triangle-exclamation" aria-hidden="true"></i>
        {{ __('Vencimento') }}
    </span>
@endif
