@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: " . __('Verificar Empresa'))
@section('content')

<form action="{{ route('admin.empresas.verify') }}" method="post" enctype="multipart/form-data">
    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">
                    @php $headLine = "<i class='fa-solid fa-building'></i> " . __('Verificar Empresa'); @endphp
                    @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        'routeBack' => 'admin.empresas.index',
                        'routeBackParams' => [],
                        'nameBack' => __("Voltar"),
                        "permission" => "GERENCIADOR_DE_EMPRESAS",
                    ])
                    <div class="card-body">
                        @include("errors.messageFlash")
                        @csrf
                        @method('post')

                        <div class="mb-3">
                            <label for="cnpj" class="form-label text-bold">{{ __("CNPJ") }}: <span class="span-admin-create">*</span></label>
                            <input type="text" class="form-control @error('cnpj') is-invalid @enderror" name="cnpj" id="cnpj" data-mask="cnpj" autocomplete="off" value="{{ old('cnpj') }}" required>
                            @error('cnpj')
                                <small class="text-danger text-bold">{{ $message }}</small>
                            @enderror
                        </div>

                        @include('components.buttons._backAndSend', [
                                'textBack' => __('Voltar'),
                                'textSend' => __('Verificar'),
                                'routeBack' => 'admin.empresas.index'
                            ]
                        )
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>

@endsection

@push('after-scripts')
    <script src="{{ asset('pmar/js/empresas/form.js') }}" defer></script>
@endpush
