<div class="accordion-item">
    <h2 class="accordion-header">
        <button class="accordion-button" type="button" data-bs-toggle="collapse" data-bs-target="#{{ $accordion['collapse'] }}" aria-expanded="{{ $accordion['TF'] }}" aria-controls="{{ $accordion['collapse'] }}">
            {!! $accordion['Titulo'] !!}
        </button>
    </h2>
    <div id="{{ $accordion['collapse'] }}" class="accordion-collapse collapse" data-bs-parent="#accordioncmgd">
        <div class="accordion-body">
            @foreach($itens as $item)
                <strong>{{ $item['nome'] }}</strong> {{ $item['matricula'] ? '(' . $item['matricula'] . ')' : null  }} {!! $item['cargo'] ? '- <i>' . $item['cargo'] . '</i>' : null !!} <br>
            @endforeach
        </div>
    </div>
</div>
