<div class="col-12 mb-3">
    <div class="row d-flex flex-column align-items-center">
        <div class="col">
            <div class="card-slug">
                <h2 class="slug-telefone">{{ __("Saiba mais") }}</h2>
                <ul class="list-unstyled">
                    <li>
                        <a class="text-decoration-none link-secretarias" href="{{ route("paginas.formacao-academica", $secretaria->slug) }}" target="_SELF">
                            <div class="text-dark">
                                @if ($secretaria->type == 'SECRETARIA')
                                    @if ($secretaria->pronunciation == 'SECRETARIO')
                                        {{ __('Secretário') }}
                                    @elseif($secretaria->pronunciation == 'PROCURADO_GERAL_DO_MUNICIPIO')
                                        {{ __('Procurador-Geral') }}
                                    @elseif($secretaria->pronunciation == 'CONTROLADOR_GERAL_DO_MUNICIPIO')
                                        {{ __('Controlador-Geral') }}
                                    @else
                                        {{ __('Secretária') }}
                                    @endif
                                @elseif($secretaria->type == 'FUNDACAO' || $secretaria->type == 'AUTARQUIA')
                                    {{ __('Presidente') }}
                                @elseif($secretaria->type == 'SUPERINTENDENCIA')
                                    {{ __('Superintendente') }} 
                                @elseif($secretaria->type == 'DIRETORIA')
                                    @if($secretaria->pronunciation == 'DIRETOR')
                                        {{ __('Diretor') }}
                                    @else($secretaria->pronunciation == 'DIRETORA')
                                        {{ __('Diretora') }} 
                                    @endif
                                @elseif($secretaria->type == 'SECRETARIA_EXECUTIVA')
                                    @if ($secretaria->pronunciation == 'SECRETARIO_EXECUTIVO')
                                        {{ __('Secretário Executivo') }}
                                    @else
                                        {{ __('Secretária Executiva') }}
                                    @endif
                                @endif
                            </div>
                            <i class="text-primary fa-solid fa-angle-right"></i>
                        </a>
                    </li>
                    <li>
                        <a class="text-decoration-none link-secretarias" href="{{ route("paginas.competencias-e-atribuicoes", $secretaria->slug) }}" target="_SELF">
                            Competências e atribuições
                            <svg class="svg-inline--fa fa-angle-right text-primary" aria-hidden="true" focusable="false" data-prefix="fas" data-icon="angle-right" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512" data-fa-i2svg=""><path fill="currentColor" d="M278.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-160 160c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L210.7 256 73.4 118.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l160 160z"></path></svg><!-- <i class="text-primary fa-solid fa-angle-right"></i> Font Awesome fontawesome.com -->
                        </a>
                    </li>
                    <li>
                        <a class="text-decoration-none link-secretarias"
                           href="{{ \App\Support\StructurePublicUrls::faleConoscoUrl($secretaria) }}"
                           @if(request()->routeIs('paginas.orgao.fale-conosco*')) aria-current="page" @endif>
                            <div class="text-dark">{{ __('Fale conosco') }}</div>
                            <i class="text-primary fa-solid fa-angle-right" aria-hidden="true"></i>
                        </a>
                    </li>
                    @foreach ($links as $link)
                        @if(\App\Support\StructurePublicUrls::isAdministrativeFaleConoscoTitulo($link['titulo'] ?? null))
                            @continue
                        @endif
                        <li>
                            <a class="text-decoration-none text-dark link-secretarias" href="{{ url($link['link']) }}" target="{{ $link['status'] }}">
                                {{ $link['titulo'] }}
                                <i class="text-primary fa-solid fa-angle-right"></i>
                            </a>
                        </li>
                    @endforeach
                </ul>
            </div>
        </div>
    </div>
</div>
