@extends('layouts.login.theme')
@section('title', env('APP_NAME').' :: '.__('Nova Senha'))
@section('content')

<section class="d-flex justify-content-center align-items-center min-vh-100">
    <div class="container d-flex justify-content-center">
        <div class="row justify-content-center w-100">
            <div class="card-admin-login p-5">
                @include('errors.messageFlash')
                <div class="text-center">
                    <img src="{{ asset("pmar/assets/img/logo-angra-branco.svg") }}" class="card-img-top" title="{{ __("Prefeitura Municipal de Angra dos Reis") }}" alt="{{ __("Prefeitura Municipal de Angra dos Reis") }}" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                </div>
                <style>
                    .form-label{
                        color: #FFF !important
                    }
                </style>
                <div class="card-body">
                    <h5 class="text-white card-title text-center">{{ __('Dados adicionais e nova senha') }}</h5>
                    <br>
                    <x-auth.new-password :token="$token" />
                </div>
            </div>
        </div>
    </div>
</section>
@endsection