<div class="container">
    <div class="row gx-4 gx-lg-5 gy-4">
        <section class="internas-secretarias-home-news org-secretarias-news col-12 col-lg-9 col-md-9 order-1">
            <?php echo $__env->make('paginas.parts.org-news-grid', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </section>

        <section class="internas-secretarias-home-aside col-12 col-lg-3 col-md-3 mt-4 mt-lg-0 order-2">
            <?php echo $__env->make('paginas.parts.links', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('paginas.parts.servicos', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('paginas.parts.telefones', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </section>
    </div>
</div>
<?php echo $__env->make('paginas.parts.secretario', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/noticias.blade.php ENDPATH**/ ?>