<?php $__env->startSection("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção"); ?>
<?php $__env->startSection('content'); ?>

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>"><?php echo e(__("Portal")); ?></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.concursos.index")); ?>"><?php echo e(__("Concursos Públicos e Processos de Seleção")); ?></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.concursos.andamento", $concurso->id_concurso)); ?>"><?php echo e(__("Andamento")); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page"><?php echo e(__("Editais de Publicação")); ?></li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: <?php echo e($concurso->ds_ano); ?></h1>

                    <hr>

                    <h3 class="top30">EDITAIS DE PUBLICAÇÃO</h3>

                    <ul>
                        <?php $__currentLoopData = $arquivos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $arquivo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li>
                                <a href="<?php echo e(url("/concursos/" . $arquivo->nm_arquivo)); ?>" target="_blank"><?php echo e($arquivo->ds_link_arquivo); ?> <i class="fa-solid fa-download"></i></a>
                                <br>
                                <?php echo e($arquivo->ds_arquivo); ?>

                            </li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>


                </div>
            </div>
        </div>
    </section>


<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/concursos/editaisPublicacoes.blade.php ENDPATH**/ ?>