@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Parque Tecnológico - Áreas'))

@section('content')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-layer-group'></i> " . __('Parque Tecnológico - Áreas'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine'   => $headLine,
            'routeBack'  => 'admin.parqueTecnologico.index',
            'nameBack'   => __('Voltar'),
            'routeAdd'   => 'admin.parqueTecnologico.areas.create',
            'nameAdd'    => __('Nova área'),
            'permission' => 'GERENCIADOR_DE_PARQUE_TECNOLOGICO',
        ])

        <div class="card-body pt-0">
            <form class="d-flex mb-3" method="get">
                <input type="text" class="form-control me-2" name="q"
                       placeholder="{{ __('Pesquisar por título ou descrição...') }}"
                       value="{{ request('q') }}">
                <button class="btn btn-outline-success" type="submit">
                    <i class="fa-solid fa-magnifying-glass"></i>
                </button>
            </form>

            <div class="table-responsive">
                <table class="table table-bordered table-hover table-striped align-middle text-center">
                    @include('components.tables._thead', [
                        'thead' => [__('Título'), __('Ordem'), __('Status'), __('Ações')]
                    ])
                    <tbody>
                    @forelse($areas as $area)
                        <tr>
                            <td class="text-start">{{ Str::limit($area->titulo, 80) }}</td>
                            <td>{{ $area->ordem }}</td>
                            <td>
                                <span class="badge {{ $area->status ? 'bg-success' : 'bg-secondary' }}">
                                    {{ $area->status ? __('Ativo') : __('Inativo') }}
                                </span>
                            </td>
                            <td class="text-nowrap text-center align-middle">
                                <div class="btn-group" role="group">
                                    <a href="{{ route('admin.parqueTecnologico.areas.edit', $area->id) }}"
                                       class="btn btn-sm btn-warning" title="{{ __('Editar') }}">
                                        <i class="fa-solid fa-pen-to-square"></i>
                                    </a>
                                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_PARQUE_TECNOLOGICO')['excluir'])
                                        <form class="d-inline"
                                              action="{{ route('admin.parqueTecnologico.areas.destroy', $area->id) }}"
                                              method="post" onsubmit="return confirmDelete(this)">
                                            @csrf
                                            @method('delete')
                                            <input type="hidden" name="confirm"
                                                   value="{{ __('Esta área será excluída. Deseja continuar?') }}">
                                            <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                <i class="fa-solid fa-trash"></i>
                                            </button>
                                        </form>
                                    @endif
                                </div>
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="4" class="text-muted fst-italic">
                                {{ __('Nenhuma área cadastrada.') }}
                            </td>
                        </tr>
                    @endforelse
                    </tbody>
                </table>
            </div>

            <div class="d-flex justify-content-center mt-3">
                {!! $areas->links() !!}
            </div>
        </div>
    </div>
@endsection

