<?php $__env->startSection("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção"); ?>
<?php $__env->startSection('content'); ?>

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>"><?php echo e(__("Portal")); ?></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.concursos.index")); ?>"><?php echo e(__("Concursos Públicos e Processos de Seleção")); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page"><?php echo e(__("Andamento")); ?></li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: <?php echo e($concurso->ds_ano); ?></h1>

                    <hr>
                    
                    <?php if($concurso->hasNivel(0)): ?>
                        <h3 class="top30">NÍVEL FUNDAMENTAL INCOMPLETO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 1): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                    
                    <?php if($concurso->hasNivel(1)): ?>
                        <h3 class="top30">NÍVEL FUNDAMENTAL</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 1): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </tbody>
                        </table>
                    <?php endif; ?>

                    <?php if($concurso->hasNivel(2)): ?>    
                        <h3 class="top30">NÍVEL MÉDIO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 2): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                            </tbody>
                        </table>
                    <?php endif; ?>

                    <?php if($concurso->hasNivel(3)): ?>
                        <h3 class="top30">NÍVEL SUPERIOR</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 3): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                            </tbody>
                        </table>
                    <?php endif; ?>

                    <?php if($concurso->hasNivel(4)): ?>
                        <h3 class="top30">NÍVEL MÉDIO TÉCNICO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 3): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                            </tbody>
                        </table>
                    <?php endif; ?>
                      
                        
                     <?php if($concurso->hasNivel(5)): ?>
                        <h3 class="top30">INDEFINIDO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                <?php $__currentLoopData = $concurso->cargos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $cargo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <?php if($cargo->cd_nivel == 3): ?>
                                        <tr>
                                            <td class="centro"><a href="<?php echo e(route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])); ?>"><?php echo e($cargo->nm_cargo); ?></a></td>
                                            <td class="centro"><?php echo e($cargo->nr_vagas_edital); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->totalCandidatos() - $cargo->totalConvocados()); ?></td>
                                            <td class="centro"><?php echo e($cargo->cadastroDisponivel()); ?></td>
                                        </tr>
                                    <?php endif; ?>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                            </tbody>
                        </table>
                    <?php endif; ?>
                        
                </div>
            </div>
        </div>
    </section>


<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/concursos/andamento.blade.php ENDPATH**/ ?>