<form id="formNovaConta" name="formNovaConta" autocomplete="off" method="post" action="{{ route('admin.novaContaStore', $token) }}">
    @csrf
    <input type="hidden" name="token" value="{{ $token }}">
    <input type="hidden" name="recaptcha" id="recaptchaNovaContaInput">
    <div class="mb-3">
        @include('components.inputs._inputType',[
            'for'=>null,
            'label'=>__('Nome completo'),
            'name'=>'fullName',
            'id'=>'fullName',
            'required'=>true,
            'type'=>null,
            'old'=>old('fullName'),
            'oninput'=>null,
            'readonly'=>false,
            'small'=>null,
        ])
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
            'for'=>null,
            'label'=>__('Telefone'),
            'name'=>'phoneNumber',
            'id'=>'phoneNumberNovaConta',
            'required'=>true,
            'type'=>null,
            'old'=>old('phoneNumber'),
            'oninput'=>'javascript:aplicarMascaraTelefone(this)',
            'readonly'=>false,
            'small'=>null,
        ])
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Senha'),
        'name'=>'password',
        'id'=>'passwordNovaConta',
        'required'=>true,
        'type'=>'password',
        'old'=> old('password'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Repetir senha'),
        'name'=>'password_repeat',
        'id'=>'passwordRepeatNovaConta',
        'required'=>true,
        'type'=>'password',
        'old'=> old('password_repeat'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
    </div>
    <div class="my-3">
        <button class="fs-5 rounded-4 btn m-auto btn-primary w-100" type="submit" id="submitNovaConta">{{ __('Salvar') }}</button>
    </div>
    <hr/>
    <div class="my-3 text-center">
        <a href="{{ route("admin.login") }}" class="text-white">Login</a> | <a href="{{ route("admin.esqueceuSenha") }}" class="text-white">Esqueceu senha?</a>
    </div>
</form>
