<?php $__env->startSection("title", env("APP_NAME") . " :: Verificar Cadastro de Tutor"); ?>
<?php $__env->startSection('content'); ?>

    <div class="container d-flex justify-content-center align-items-center min-vh-100">
        <div class="row w-100 justify-content-center">
            <div class="col-sm-12 col-md-8 col-lg-6">
                <div class="card shadow-lg">
                    <div class="card-header bg-primary text-white">
                        <h4 class="mb-0">Verificar Cadastro de Tutor
                        </h4>
                    </div>
                    <div class="card-body">
                        <div class="text-center my-3">
                            <img src="<?php echo e(asset("pmar/assets/img/logo-pmar.svg")); ?>" class="card-img-top" title="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" alt="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                        </div>
                    <?php if(session('success')): ?>
                            <div class="alert alert-success"><?php echo e(session('success')); ?></div>
                        <?php endif; ?>

                        <?php if(session('error')): ?>
                            <div class="alert alert-danger"><?php echo e(session('error')); ?></div>
                        <?php endif; ?>

                        <form action="<?php echo e(route('paginas.castracao.verified')); ?>" method="post">
                            <?php echo csrf_field(); ?>
                            <div class="mb-3">
                                <label for="cpf" class="form-label">CPF : <span class="span-admin-create">*</span></label>
                                <input type="text" class="form-control <?php $__errorArgs = ['cpf'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>" id="cpf" name="cpf" autocomplete="off" oninput="javascript:aplicarMascaraCPF(this)" autocomplete="off" value="<?php echo e(old('cep')); ?>" required/>
                           
                                <?php $__errorArgs = ['cpf'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                                    <small class="text-danger"><?php echo e($message); ?></small>
                                <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                            </div>
                            <div class="mb-3">
                                <div>
                                    <button class="btn btn-md btn-primary w-100" type="submit">Verificar</button>
                                </div>
                                <div class="mt-3">
                                    <button class="btn btn-md  btn-outline-secondary w-100" onclick="javascript:window.location.href='<?php echo e(route("paginas.castracao.esqueciSenha")); ?>'" type="button"><?php echo e(__("Esqueceu sua senha?")); ?></button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.window.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/castracao/verified.blade.php ENDPATH**/ ?>