{{-- Modal: lançar registro no histórico de andamentos (aba Projetos) — requer permissão de editar --}}
@php
    $legendaCores = $mapaoCoresLegenda ?? [];
    $hoje = now()->format('Y-m-d');
@endphp
<div class="modal fade" id="modalLancarAndamentoProjeto" tabindex="-1"
    aria-labelledby="modalLancarAndamentoProjetoTitulo"
    aria-hidden="true"
    data-msg-carregando="{{ __('Carregando…') }}"
    data-msg-vazio="{{ __('Nenhum registro no histórico ainda.') }}"
    data-msg-erro-lista="{{ __('Não foi possível carregar o histórico.') }}"
    data-msg-erro-rede="{{ __('Falha de comunicação. Tente novamente.') }}"
    data-lbl-view-anexo="{{ __('Visualizar anexo') }}"
    data-lbl-download-anexo="{{ __('Baixar') }}">
    <div class="modal-dialog modal-lg modal-dialog-scrollable modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <div class="w-100">
                    <h5 class="modal-title" id="modalLancarAndamentoProjetoTitulo">{{ __('Lançar andamento') }}</h5>
                    <p class="small text-muted mb-0 mt-1" id="modalLancarAndamentoProjetoSub" aria-live="polite"></p>
                </div>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="{{ __('Fechar') }}"></button>
            </div>
            <div class="modal-body">
                <h6 class="h6">{{ __('Histórico existente') }}</h6>
                <div id="modalLancarAndamentoListaLoading" class="small text-muted mb-2 d-none" role="status"></div>
                <div id="modalLancarAndamentoListaErro" class="alert alert-danger small d-none" role="alert"></div>
                <div class="table-responsive mb-4" style="max-height: 220px;">
                    <table class="table table-sm table-bordered align-middle mb-0" aria-describedby="modalLancarAndamentoHistoricoDesc">
                        <caption id="modalLancarAndamentoHistoricoDesc" class="visually-hidden">
                            {{ __('Registros anteriores do histórico de andamento do projeto') }}</caption>
                        <thead class="table-light">
                            <tr>
                                <th scope="col">{{ __('Data') }}</th>
                                <th scope="col">{{ __('Status') }}</th>
                                <th scope="col">{{ __('Texto') }}</th>
                                <th scope="col">{{ __('Anexos') }}</th>
                            </tr>
                        </thead>
                        <tbody id="modalLancarAndamentoListaBody">
                            <tr>
                                <td colspan="4" class="text-center text-muted small py-3">{{ __('Abra o formulário a partir de um projeto para carregar o histórico.') }}</td>
                            </tr>
                        </tbody>
                    </table>
                </div>

                <h6 class="h6">{{ __('Novo lançamento') }}</h6>
                <form id="formLancarAndamentoProjeto" method="post" action="#" enctype="multipart/form-data">
                    @csrf
                    <div class="row g-3">
                        <div class="col-md-4">
                            <label class="form-label" for="pp_historico_data">{{ __('Data') }}</label>
                            <input type="date" class="form-control" name="data" id="pp_historico_data"
                                value="{{ $hoje }}" autocomplete="off">
                        </div>
                        <div class="col-md-8">
                            <label class="form-label" for="pp_historico_status">{{ __('Status') }}</label>
                            <input type="text" class="form-control" name="status" id="pp_historico_status"
                                maxlength="255" autocomplete="off"
                                placeholder="{{ __('Situação resumida (opcional)') }}">
                        </div>
                        <div class="col-12">
                            <label class="form-label" for="pp_historico_texto">{{ __('Texto') }}</label>
                            <textarea class="form-control" name="texto" id="pp_historico_texto" rows="4" required
                                minlength="2" maxlength="65535" autocomplete="off"
                                placeholder="{{ __('Descreva o andamento ou observação') }}"></textarea>
                        </div>
                        <div class="col-12">
                            @include('components.projetosProgramas._historicoAnexosInput', [
                                'name' => 'anexos[]',
                                'inputId' => 'pp_historico_anexos',
                                'describedBy' => 'pp_historico_anexos_ajuda',
                            ])
                        </div>
                        <div class="col-12">
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="sincronizar_andamento_mapao"
                                    id="pp_historico_sinc_mapao" value="1" checked>
                                <label class="form-check-label" for="pp_historico_sinc_mapao">
                                    {{ __('Atualizar também o texto e a legenda de andamento exibidos na coluna Andamento do MAPÃO') }}
                                </label>
                            </div>
                            <span id="pp_historico_legenda_legend" class="form-label d-block mb-2">{{ __('Legenda do andamento (MAPÃO)') }}</span>
                            <div class="d-flex flex-column gap-2" role="radiogroup" aria-labelledby="pp_historico_legenda_legend">
                                @foreach($legendaCores as $valor => $legenda)
                                    @php
                                        $tone = match ((string) $valor) {
                                            'verde' => 'success',
                                            'amarelo' => 'warning',
                                            'vermelho' => 'danger',
                                            default => 'light',
                                        };
                                    @endphp
                                    <div class="form-check">
                                        <input class="form-check-input" type="radio" name="andamento_cor"
                                            id="pp_hist_and_cor_{{ $valor }}" value="{{ $valor }}">
                                        <label class="form-check-label d-flex align-items-center gap-2 flex-wrap"
                                            for="pp_hist_and_cor_{{ $valor }}">
                                            <span class="rounded border d-inline-block p-2 bg-{{ $tone }}"
                                                aria-hidden="true"></span>
                                            <span>{{ $legenda }}</span>
                                        </label>
                                    </div>
                                @endforeach
                                <div class="form-check">
                                    <input class="form-check-input" type="radio" name="andamento_cor"
                                        id="pp_hist_and_cor_nenhum" value="" checked>
                                    <label class="form-check-label d-flex align-items-center gap-2 flex-wrap"
                                        for="pp_hist_and_cor_nenhum">
                                        <span class="rounded border d-inline-block p-2 bg-light" aria-hidden="true"></span>
                                        <span>{{ __('Sem legenda (neutro)') }}</span>
                                    </label>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
            <div class="modal-footer d-flex flex-wrap gap-2 justify-content-end align-items-center">
                <button type="button" class="btn btn-outline-secondary" data-bs-dismiss="modal">{{ __('Cancelar') }}</button>
                <button type="submit" class="btn btn-green" form="formLancarAndamentoProjeto">
                    <i class="fa fa-save me-1" aria-hidden="true"></i>{{ __('Salvar') }}
                </button>
            </div>
        </div>
    </div>
</div>
