<?php $__env->startSection("title", env("APP_NAME") . " :: Boletim Oficial"); ?>
<?php $__env->startSection('content'); ?>

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>"><?php echo e(__("Portal")); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">
                                <?php echo e(__("Boletim Oficial do Município de Angra dos Reis")); ?></li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12 pb-5 text-primary">
                    <h1><?php echo e(__("Boletim Oficial do Município de Angra dos Reis")); ?></h1>
                </div>
            </div>
        </div>
    </section>

    <section>
        <div class="container">
            <div class="row">
                <div class="col-12 col-sm-12 col-md-12 col-lg-12 col-xl-9 col-xxl-9">
                    <div class="row">
                        <article class="article-main">
                            <div class="mb-3 bg-gray border-0 rounded-4 shadow-sm p-3">
                                <div class="text-center fs-6">Pesquisar por:</div>
                                <ul class="nav nav-tabs border-bottom-0" id="myTab" role="tablist">
                                    <li class="nav-item" role="presentation">
                                        <button
                                            class="nav-link <?php if(request()->has('q') || request()->all() == []): ?> active <?php endif; ?> border-0 rounded-5"
                                            id="termos-tab" data-bs-toggle="tab" data-bs-target="#termos" type="button"
                                            role="tab" aria-controls="termos" aria-selected="true">Termos</button>
                                    </li>
                                    <li class="nav-item" role="presentation">
                                        <button
                                            class="nav-link <?php if(request()->has('dataInicio') && request()->has('dataFim')): ?> active <?php endif; ?> border-0 rounded-5"
                                            id="data-tab" data-bs-toggle="tab" data-bs-target="#data" type="button"
                                            role="tab" aria-controls="data" aria-selected="false">Data</button>
                                    </li>
                                    <li class="nav-item" role="presentation">
                                        <button class="nav-link <?php if(request()->has('n')): ?> active <?php endif; ?> border-0 rounded-5"
                                            id="number-tab" data-bs-toggle="tab" data-bs-target="#number" type="button"
                                            role="tab" aria-controls="number" aria-selected="false">Número</button>
                                    </li>
                                    <li class="nav-item" role="presentation">
                                        <button class="nav-link <?php if(request()->has('y')): ?> active <?php endif; ?> border-0 rounded-5"
                                            id="year-tab" data-bs-toggle="tab" data-bs-target="#year" type="button"
                                            role="tab" aria-controls="year" aria-selected="false">Ano</button>
                                    </li>
                                </ul>
                                <div class="tab-content" id="myTabContent">
                                    <div class="tab-pane fade <?php if(request()->has('q') || request()->all() == []): ?> show active <?php endif; ?>"
                                        id="termos" role="tabpanel" aria-labelledby="termos-tab">
                                        <form action="<?php echo e(route("paginas.boletim-oficial-ajax")); ?>"
                                            class="d-flex pesquisarBoletim" method="post">
                                            <?php echo csrf_field(); ?>
                                            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
                                            <input type="text" class="form-control me-2 border-0" name="q"
                                                placeholder="Buscar na publicação" aria-label="Pesquisar">
                                            <button class="btn btn-success text-secondary fw-bold px-4 py-2 rounded-4"
                                                type="submit">Buscar</button>
                                        </form>
                                    </div>
                                    <div class="tab-pane fade <?php if(request()->has('dataInicio') && request()->has('dataFim')): ?> show active <?php endif; ?>"
                                        id="data" role="tabpanel" aria-labelledby="data-tab">
                                        <form action="<?php echo e(route("paginas.boletim-oficial-ajax")); ?>"
                                            class="d-flex pesquisarBoletim" method="post">
                                            <?php echo csrf_field(); ?>
                                            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
                                            <input type="date" class="form-control me-2 border-0" name="dataInicio"
                                                placeholder="Data início" aria-label="Pesquisar">
                                            <input type="date" class="form-control me-2 border-0" name="dataFim"
                                                placeholder="Data fim" aria-label="Pesquisar">
                                            <button class="btn btn-success text-secondary fw-bold px-4 py-2 rounded-4"
                                                type="submit">Buscar</button>
                                        </form>
                                    </div>
                                    <div class="tab-pane fade <?php if(request()->has('n')): ?> show active <?php endif; ?>" id="number"
                                        role="tabpanel" aria-labelledby="number-tab">
                                        <form action="<?php echo e(route("paginas.boletim-oficial-ajax")); ?>"
                                            class="d-flex pesquisarBoletim" method="post">
                                            <?php echo csrf_field(); ?>
                                            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
                                            <input type="number" class="form-control me-2 border-0" name="n"
                                                placeholder="2025" aria-label="Pesquisar">
                                            <button class="btn btn-success text-secondary fw-bold px-4 py-2 rounded-4"
                                                type="submit">Buscar</button>
                                        </form>
                                    </div>
                                    <div class="tab-pane fade <?php if(request()->has('y')): ?> show active <?php endif; ?>" id="year"
                                        role="tabpanel" aria-labelledby="year-tab">
                                        <form action="<?php echo e(route("paginas.boletim-oficial-ajax")); ?>"
                                            class="d-flex pesquisarBoletim" method="post">
                                            <?php echo csrf_field(); ?>
                                            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
                                            <input type="number" class="form-control me-2 border-0" name="y"
                                                placeholder="1996" aria-label="Pesquisar">
                                            <button class="btn btn-success text-secondary fw-bold px-4 py-2 rounded-4"
                                                type="submit">Buscar</button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </article>
                    </div>
                    <div id="getResultAjaxHTML" class="row">
                        <article class="article-main">
                            <div class="table-responsive mt-4">
                                <table id="bulletinsTable" class="table">
                                    <tr>
                                        <th>Data de Publicação</th>
                                        <th>Mês</th>
                                        <th>Número</th>
                                        <th>Título</th>
                                        <th>Tipo de Edição</th>
                                        <th></th>
                                    </tr>
                                    <?php
                                        $index = 0;
                                    ?>
                                    <?php $__currentLoopData = $boletins; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $boletim): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                        <tr>
                                            <td><?php echo e(date("d/m/Y", strtotime($boletim->publicationDate))); ?></td>
                                            <td>
                                                <?php $__currentLoopData = App\Enums\StatusMonth::cases(); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $status): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                                    <?php if($status->name == $boletim->month): ?>
                                                        <?php echo e($status->value); ?>

                                                    <?php endif; ?>
                                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                            </td>
                                            <td><?php echo e($boletim->number); ?></td>
                                            <td><?php echo e($boletim->title); ?></td>
                                            <td>
                                                <?php if($boletim->extraordinaryEdition): ?>
                                                    Edição Extraordinária
                                                <?php else: ?>
                                                    ---
                                                <?php endif; ?>
                                            </td>
                                            <td class="d-flex flex-row justify-content-center align-items-center">

                                                <a data-toggle="tooltip" data-placement="top" title="Ver Boletim"
                                                    class="text-center text-secondary bg-white p-3 py-2 rounded-5 text-decoration-none d-inline fs-6 mx-2"
                                                    href='<?php echo e(asset($boletim->url)); ?>' target="_blank"><i
                                                        class="fa-solid fa-eye"></i>
                                                    <div class="bulletinsButton"> Visualizar </div>
                                                </a>

                                                <a download="Boletim <?php echo e($boletim->number); ?> de <?php echo e($boletim->publicationDate); ?>.pdf"
                                                    data-toggle="tooltip" data-placement="top"
                                                    title="Baixar arquivo de <?php echo e($boletim->fileSizeKB); ?> KB"
                                                    class="text-center text-secondary bg-white p-3 py-2 rounded-5 text-decoration-none d-inline fs-6 mx-2"
                                                    href='<?php echo e(asset($boletim->url)); ?>' target="_blank"><i
                                                        class="text-secondary fa-solid fa-download"></i>
                                                    <div class="bulletinsButton"> Download </div>
                                                </a>

                                            </td>
                                        </tr>
                                        <?php
                                            $index++;
                                        ?>
                                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                </table>
                            </div>
                            <div id="hiddenPagination" class="row">
                                <div class="col-12 my-3">
                                    <div class="d-flex justify-content-center"><?php echo $boletins->links(); ?> </div>
                                </div>
                            </div>
                        </article>
                    </div>
                </div>
                <div class="col">
                    <div class="card-slug">
                        <h2 class="slug-title">Leia Mais</h2>
                        <?php $__currentLoopData = $noticias; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $noticia): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <div class="my-4">
                                <!-- <span class="news-label"><?php echo e($noticia->title); ?></span> -->
                                <h5 class="slug-summary mt-3">
                                    <a
                                        href="<?php echo e(route('paginas.slug', [date('d-m-Y', strtotime($noticia->created_at)), $noticia->slug])); ?>">
                                        <?php echo e(Str::limit(html_entity_decode($noticia->summary), 50)); ?>

                                    </a>
                                </h5>
                            </div>
                            <hr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                        <a href="<?php echo e(route("paginas.noticias")); ?>"
                            class="mt-5 px-4 py-2 btn border-1 bg-blue-gradient text-white text-start text-center rounded-5"><?php echo e(__("Ver
                                    Mais")); ?>

                        </a>
                    </div>
                </div>
            </div>
        </div>

    </section>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/boletim-oficial.blade.php ENDPATH**/ ?>