<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <title>{{ __('Resultado do recurso') }}</title>
</head>
<body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">
<table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
    <tr><td align="center">
        <table width="600" cellpadding="0" cellspacing="0" style="background:#fff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">
            <tr><td style="background:#007bc3; padding:20px; color:#fff; text-align:center;">{{ env('APP_NAME') }} – {{ __('Credenciamento de Músicos') }}</td></tr>
            <tr><td style="padding:30px; color:#333; font-size:15px; line-height:1.6;">
                <p>{{ __('Olá!') }}</p>
                <div style="background:#d4edda; border:1px solid #c3e6cb; color:#155724; padding:15px; border-radius:6px; margin:15px 0;">
                    <strong>{{ __('Resultado do recurso administrativo') }}</strong><br>
                    {{ __('O chamado nº :numero foi finalizado. Status: :status', ['numero' => $chamado->numeroChamado ?? $chamado->id, 'status' => $chamado->statusChamado ?? __('Finalizado')]) }}
                </div>
                <p>{{ __('Acesse a área de Chamados para ver o resultado completo.') }}</p>
                <p style="margin-top:25px;"><strong>{{ __('Equipe de Cultura') }}</strong></p>
            </td></tr>
            <tr><td style="background:#f7f7f7; text-align:center; padding:15px; font-size:12px; color:#999;">{{ __('E-mail automático. Não responda.') }}</td></tr>
        </table>
    </td></tr>
</table>
</body>
</html>
