<?php $__env->startSection("title", env("APP_NAME") . " :: Recuperar senha"); ?>
<?php $__env->startSection('content'); ?>

    <div class="container d-flex justify-content-center align-items-center min-vh-100">
        <div class="row w-100 justify-content-center">
            <div class="col-sm-12 col-md-8 col-lg-6">
                <div class="card shadow-lg">
                    <div class="card-header bg-primary text-white">
                        <h4 class="mb-0">Recuperar senha</h4>
                    </div>
                    <div class="card-body">
                        <div class="text-center my-3">
                            <img src="<?php echo e(asset("pmar/assets/img/logo-pmar.svg")); ?>" class="card-img-top" title="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" alt="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                        </div>
                        <h2>Esqueceu sua senha?</h2>
                        <div class="mb-3">
                            <small class="text-primary">(*) Informe seu e-mail para receber um link de redefinição de senha.</small>
                        </div>
                        <?php if(session('success')): ?>
                            <div class="alert alert-success"><?php echo e(session('success')); ?></div>
                        <?php endif; ?>

                        <?php if($errors->any()): ?>
                            <div class="alert alert-danger">
                                <?php $__currentLoopData = $errors->all(); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $error): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <p><?php echo e($error); ?></p>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </div>
                        <?php endif; ?>
                        <form action="<?php echo e(route('paginas.castracao.esqueciSenha')); ?>" method="POST">
                            <?php echo csrf_field(); ?>
                            <div class="my-3">
                                <label for="email">CPF:</label>
                                <input type="cpf" name="cpf" id="cpf" class="form-control" required value="<?php echo e(old('cpf')); ?>">
                            </div>
                            <div class="mb-3">
                                <label for="email">E-mail:</label>
                                <input type="email" name="email" id="email" class="form-control" required
                                   value="<?php echo e(old('email')); ?>">
                            </div>
                            <div class="row mb-3">
                                <div>
                                    <button type="submit" class="btn btn-primary w-100">Enviar Código de Redefinição</button>
                                </div>
                                <div class="col-12 mt-3">
                                    <a class="btn btn-outline-secondary"
                                   href="<?php echo e(route('paginas.fibromialgia.verified')); ?>">
                                    Cadastrar-se
                                    </a>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.window.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/castracao/esqueciSenha.blade.php ENDPATH**/ ?>