@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: ' . __('PCA - Monitoramento de Ocorrências'))

@section('content')
    <div class="card shadow-lg">
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __('Acompanhamento Individual'),
            'routeBack' => 'admin.ocorrencias-pca.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
        ])

        <div class="card-body">
            <div class="mb-3 mt-5">
                <form method="GET" action="{{ route('admin.ocorrencias-pca.acompanhamento') }}" class="mb-3">
                    <div class="input-group">
                        <input type="text" name="busca" value="{{ request('busca') }}" class="form-control"
                            placeholder="{{ __('Buscar usuários...') }}">
                        <button class="btn btn-primary" type="submit">{{ __('Buscar') }}</button>
                        <a href="{{ route('admin.ocorrencias-pca.acompanhamento') }}"
                            class="btn btn-outline-secondary">{{ __('Limpar') }}</a>
                    </div>
                </form>
            </div>

            <div class="table-responsive">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>{{ __('Usuário') }}</th>
                            <th>{{ __('Total de Chamados') }}</th>
                            <th class="text-end" style="width: 80px;">{{ __('Ações') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @include('admin.ocorrencias-pca.partials._acompanhamentoTableBody', [
                            'dadosUsuarios' => $dadosUsuarios,
                        ])
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection
