@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Fluxo de Ônibus - Lista Ônibus de Turismo'))
@section('content')
    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-bus-simple'></i> " . __('Fluxo de Ônibus - Lista Ônibus de Turismo'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine, 
//            'routeBack' => 'admin.dashboard', 
//            'nameBack' => __('Voltar'), 
            'routeAdd' => 'admin.turisAngra.fluxoDeOnibus.onibusTurismo.verify', 
            'nameAdd' => __('Novo agendamento'), 
            'permission' => 'GERENCIADOR_DE_FLUXO_DE_ONIBUS'])

        <div class="card-body">

        </div>
</div>
@endsection
