<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<meta name="description"  content="O Plano Municipal de Redução de Riscos é um instrumento voltado à prevenção e mitigação de riscos no município de Angra dos Reis">
<meta name="author" content="Prefeitura de Angra dos Reis">
<meta name="viewport" content="width=device-width, initial-scale=1">

<!-- theme meta -->
<meta name="theme-name" content="orbitor" />
<title>@yield('title')</title>
<link rel="canonical" href="https://angra.rj.gov.br/pmrr" />

<meta property="og:locale" content="pt_BR" />
<meta property="og:type" content="government" />
<meta property="og:title" content="Plano Municipal de Redução de Riscos" />
<meta property="og:description" content="O Plano Municipal de Redução de Riscos é um instrumento voltado à prevenção e mitigação de riscos no município de Angra dos Reis" />
<meta property="og:url" content="https://angra.rj.gov.br/pmmr" />
<meta property="og:site_name" content="Plano Municipal de Redução de Riscos" />
<meta property="og:image" content="{{ asset('rderiscos/assets/images/thumb.jpg') }}" />

<!-- Favicon -->
<link rel="apple-touch-icon" sizes="57x57" href="{{ asset('pmar/assets/fav/apple-icon-57x57-2026.png') }}">
<link rel="apple-touch-icon" sizes="60x60" href="{{ asset('pmar/assets/fav/apple-icon-60x60-2026.png') }}">
<link rel="apple-touch-icon" sizes="72x72" href="{{ asset('pmar/assets/fav/apple-icon-72x72-2026.png') }}">
<link rel="apple-touch-icon" sizes="76x76" href="{{ asset('pmar/assets/fav/apple-icon-76x76-2026.png') }}">
<link rel="apple-touch-icon" sizes="114x114" href="{{ asset('pmar/assets/fav/apple-icon-114x114-2026.png') }}">
<link rel="apple-touch-icon" sizes="120x120" href="{{ asset('pmar/assets/fav/apple-icon-120x120-2026.png') }}">
<link rel="apple-touch-icon" sizes="144x144" href="{{ asset('pmar/assets/fav/apple-icon-144x144-2026.png') }}">
<link rel="apple-touch-icon" sizes="152x152" href="{{ asset('pmar/assets/fav/apple-icon-152x152-2026.png') }}">
<link rel="apple-touch-icon" sizes="180x180" href="{{ asset('pmar/assets/fav/apple-icon-180x180-2026.png') }}">
<link rel="icon" type="image/png" sizes="192x192" href="{{ asset('pmar/assets/fav/android-icon-192x192-2026.png') }}">
<link rel="icon" type="image/png" sizes="32x32" href="{{ asset('pmar/assets/fav/favicon-32x32-2026.png') }}">
<link rel="icon" type="image/png" sizes="96x96" href="{{ asset('pmar/assets/fav/favicon-96x96-2026.png') }}">
<link rel="icon" type="image/png" sizes="16x16" href="{{ asset('pmar/assets/fav/favicon-16x16-2026.png') }}">

<!-- FontAwesome -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css">

<!-- Bootstrap Icons CDN -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">

<!-- Bootstrap CSS  -->
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">

<!-- Main CSS File -->
<link href="{{ asset('rderiscos/assets/css/style.css') }}" rel="stylesheet" media="all" />

<!-- Swiper CSS -->
<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
<!-- Swiper CSS -->
<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@10/swiper-bundle.min.css" />
