<label for="<?php echo e($for); ?>" class="form-label text-bold d-block" style="width:100%">
    <strong><?php echo e($label); ?>:</strong> 
    <?php echo e($text); ?>

</label>
<?php /**PATH /var/www/html/portal/resources/views/components/inputs/_label.blade.php ENDPATH**/ ?>