<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@if (Route::currentRouteName() === 'paginas.slug')
    @include('layouts.pmar.elements.headNoticia')
@else
    @include('layouts.pmar.elements.head')
@endif

<body class="fade-in">
    <header>
        @include('layouts.pmar.elements.defaultBar')
        @include('layouts.pmar.elements.nav')
    </header>
    <main>
        @yield('content')
    </main>
    <footer class="footer-pmar">
        @include('layouts.pmar.elements.modal')
        @include('layouts.pmar.elements.defaultFooter')
    </footer>
    @stack('scripts')
</body>

</html>
