<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
    @include('layouts.landing_pages.calendariodeeventos.elements.head')
    <body class="calendario-eventos">
        @yield('content')
        @include('layouts.landing_pages.calendariodeeventos.elements.footer')
    </body>
</html>
