<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <meta name="site" content="https://angra.rj.gov.br">

    <title><?php echo $__env->yieldContent('title'); ?></title>

    <meta name="description" content="Portal oficial do SEI da Prefeitura Municipal de Angra dos Reis." />
    <meta name="robots" content="noodp" />

    <meta name="description" content="Confira a programação do Carnaval 2025 em Angra dos Reis, com blocos de rua, shows, desfiles e muita folia nas praias e bairros da cidade." />
    <meta name="author" content="Prefeitura de Angra dos Reis">
    <meta name="keywords" content="SCarnaval 2025, Angra dos Reis, blocos de rua, shows na Praia do Anil, programação musical, festas nos bairros, Bloco Feliz Idade, Brasil dos Reis, samba de 1975, TurisAngra, apoio cultural, artistas locais, segurança pública, turismo, cultura local, folia, desfiles, atrações musicais, eventos gratuitos, infraestrutura, transporte público, economia local, tradição carnavalesca, celebração popular.">
    <meta name="generator" content="Prefeitura de Angra dos Reis">
    <meta name="robots" content="index, follow" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />

    <!-- para o compartilhar -->
    <meta property="og:title" content="Carnaval 2025 em Angra dos Reis" />
    <meta property="og:type" content="city" />
    <meta property="og:url" content="https://angra.rj.gov.br/carnaval2025" />
    <meta property="og:image" content="https://angra.rj.gov.br/carnaval2025/assets/logo_carnaval.svg" />
    <meta property="og:description" content="Confira a programação do Carnaval 2025 em Angra dos Reis, com blocos de rua, shows, desfiles e muita folia nas praias e bairros da cidade." />
    <meta property="og:locale" content="pt_BR">


    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-57x57.png")); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-60x60.png")); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-72x72.png")); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-76x76.png")); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-114x114.png")); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-120x120.png")); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-144x144.png")); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-152x152.png")); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset("sei-angra/assets/fiveicon/apple-icon-180x180.png")); ?>">
    <link rel="icon" type="image/png" sizes="192x192" href="<?php echo e(asset("sei-angra/assets/fiveicon/android-icon-192x192.png")); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset("sei-angra/assets/fiveicon/favicon-32x32.png")); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset("sei-angra/assets/fiveicon/favicon-96x96.png")); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset("sei-angra/assets/fiveicon/favicon-16x16.png")); ?>">
    <link rel="manifest" href="<?php echo e(asset("sei-angra/assets/fiveicon/manifest.json")); ?>">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="<?php echo e(asset("sei-angra/assets/fiveicon/ms-icon-144x144.png")); ?>">
    <meta name="theme-color" content="#ffffff">

    <link rel="stylesheet" href="<?php echo e(asset('carnaval-2025-angra/assets/css/styles.css')); ?>">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <!--  -->
</head><?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/carnaval2025/elements/head.blade.php ENDPATH**/ ?>