<!-- Portais -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-secondary">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-globe fa-2x me-3"></i>
                <h5 class="card-title mb-0">Portais</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item">
                    <i class="fas fa-tint me-2 text-muted"></i>
                    <a href="https://maisagua.angra.rj.gov.br" target="_blank" class="text-dark">Mais água em Angra</a> 
                </li>
                <li class="list-group-item">
                    <i class="fa-solid fa-eye text-muted"></i>
                    <a href="https://observa.angra.rj.gov.br" target="_blank" class="text-dark">Observa Angra</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-handshake me-2 text-muted"></i>
                    <a href="https://ppp.angra.rj.gov.br" target="_blank" class="text-dark">PPP's</a>
                </li>
            </ul>
        </div>
    </div>
</div>
