@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: " . __('Licitações e Procedimentos'))
@section('content')
@php
    use App\Models\LicitacoesProcedimentos\Processo;

    $tiposLicitacaoJson = json_encode(
        collect(Processo::TIPOS_LICITACAO)->mapWithKeys(fn (string $label, int $codigo) => [$codigo => __($label)])->all(),
        JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_AMP | JSON_HEX_QUOT | JSON_UNESCAPED_UNICODE
    );
    $tiposProcedimentoJson = json_encode(
        collect(Processo::TIPOS_PROCEDIMENTO)->mapWithKeys(fn (string $label, int $codigo) => [$codigo => __($label)])->all(),
        JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_AMP | JSON_HEX_QUOT | JSON_UNESCAPED_UNICODE
    );
@endphp
<link rel="stylesheet" href="{{ asset('pmar/css/paginas/licitacoes-publicas.css') }}">

<div class="lp-hero lp-wrap"><div class="lp-hero-inner">
    <div class="container">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a href="{{ route("paginas.home") }}">Portal</a>
                </li>
                <li class="breadcrumb-item active" aria-current="page">Licitações e Procedimentos</li>
            </ol>
        </nav>

        <div class="lp-hero-body">
            <div class="lp-hero-icon">
                <i class="fa-solid fa-gavel text-primary"></i>
            </div>
            <div>
                <h1 class="lp-hero-title text-primary">{{ __('Licitações e Procedimentos') }}</h1>
                <p class="lp-hero-sub text-primary">{{ __('Consulte processos licitatórios e procedimentos administrativos') }}</p>
            </div>
        </div>
    </div>
    <div class="lp-hero-bar"></div>
</div>

<section class="lp-main lp-wrap">
    <div class="container">

        <div class="lp-filter-card">
            <div class="lp-filter-header">
                <div class="lp-filter-header-left">
                    <div class="lp-filter-icon">
                        <i class="fa-solid fa-sliders"></i>
                    </div>
                    <span class="lp-filter-title">{{ __('Filtros') }}</span>
                    <span class="lp-filter-sub">{{ __('Refine sua pesquisa') }}</span>
                </div>
                <button class="btn-lp-clear" id="btn-limpar-filtros" type="button">
                    <i class="fa-solid fa-xmark"></i>{{ __('Limpar filtros') }}
                </button>
            </div>

            <div class="lp-filter-body">
                <form id="form-filtros-licitacoes-procedimentos">
                    <div class="lp-filter-grid-top">
                        <div>
                            <label for="filtro-instituicao" class="lp-field-label">{{ __('Instituição') }}</label>
                            <div class="lp-field-wrap">
                                <select class="form-select" id="filtro-instituicao" name="instituicao">
                                    <option value="">{{ __('Todos') }}</option>
                                </select>
                                <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                            </div>
                        </div>

                        <div>
                            <label for="filtro-tipo-processo" class="lp-field-label">{{ __('Tipo de processo') }}</label>
                            <div class="lp-field-wrap">
                                <select class="form-select" id="filtro-tipo-processo" name="tipo_processo">
                                    <option value="">{{ __('Todos') }}</option>
                                    <option value="licitacao">{{ __('Licitação') }}</option>
                                    <option value="procedimento">{{ __('Procedimento') }}</option>
                                </select>
                                <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                            </div>
                        </div>

                        <div>
                            <label for="filtro-tipo" class="lp-field-label">{{ __('Tipo') }}</label>
                            <div class="lp-field-wrap">
                                <select
                                    class="form-select"
                                    id="filtro-tipo"
                                    name="tipo"
                                    disabled
                                    data-tipos-licitacao="{{ $tiposLicitacaoJson }}"
                                    data-tipos-procedimento="{{ $tiposProcedimentoJson }}"
                                    data-empty-label="{{ __('Todos') }}"
                                >
                                    <option value="">{{ __('Todos') }}</option>
                                </select>
                                <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                            </div>
                        </div>

                        <div>
                            <label for="filtro-status" class="lp-field-label">{{ __('Status') }}</label>
                            <div class="lp-field-wrap">
                                <select class="form-select" id="filtro-status" name="status">
                                    <option value="">{{ __('Todos') }}</option>
                                </select>
                                <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                            </div>
                        </div>

                        <div>
                            <label for="filtro-ano" class="lp-field-label">{{ __('Ano') }}</label>
                            <div class="lp-field-wrap">
                                <select class="form-select" id="filtro-ano" name="ano">
                                    <option value="">{{ __('Todos') }}</option>
                                </select>
                                <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                            </div>
                        </div>
                    </div>

                    <div class="lp-filter-grid-bottom">
                        <div>
                            <label for="filtro-busca" class="lp-field-label">{{ __('Nº do processo ou palavra-chave') }}</label>
                            <div class="lp-field-wrap lp-has-icon">
                                <span class="lp-field-icon"><i class="fa-solid fa-magnifying-glass"></i></span>
                                <input id="filtro-busca"
                                    name="busca"
                                    type="search"
                                    class="form-control"
                                    placeholder="{{ __('Ex: 001/2025, pavimentação...') }}">
                            </div>
                        </div>

                        <div>
                            <label for="filtro-favorecido" class="lp-field-label">{{ __('Favorecido') }}</label>
                            <div class="lp-field-wrap lp-has-icon">
                                <span class="lp-field-icon"><i class="fa-solid fa-user"></i></span>
                                <input id="filtro-favorecido"
                                    name="favorecido"
                                    type="search"
                                    class="form-control"
                                    placeholder="{{ __('Nome da empresa ou pessoa...') }}">
                            </div>
                        </div>

                        <div class="d-flex align-items-end">
                            <button class="btn-lp-apply" type="submit">
                                <i class="fa-solid fa-filter"></i>
                                {{ __('Aplicar filtros') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <div class="lp-result-bar-wrap">
            <p class="lp-result-bar mb-0" id="total-resultados-texto">
                {{ __('Carregando resultados...') }}
            </p>
            <a href="#" class="lp-download-link" id="btn-download-csv" aria-label="{{ __('Download em CSV') }}">
                <i class="fa-solid fa-download"></i>{{ __('Download em CSV') }}
            </a>
        </div>

        <div id="licitacoes-procedimentos-lista" aria-live="polite"></div>

        <div id="licitacoes-procedimentos-paginacao"
             class="lp-pagination d-flex justify-content-center mt-4">
        </div>

        <div id="licitacoes-procedimentos-estado-vazio" class="lp-empty d-none" role="status">
            <i class="fa-regular fa-folder-open"></i>
            <p>{{ __('Nenhum resultado encontrado para os filtros informados.') }}</p>
        </div>

        <div id="licitacoes-procedimentos-erro" class="lp-error d-none" role="alert">
            <i class="fa-solid fa-triangle-exclamation"></i>
            {{ __('Não foi possível carregar os dados no momento. Tente novamente em instantes.') }}
        </div>

    </div>
</section>

<div id="licitacoes-procedimentos-config"
    class="d-none"
    data-endpoint-lista="{{ url('/api/licitacoes-procedimentos') }}"
    data-endpoint-filtros="{{ url('/api/licitacoes-procedimentos/filtros') }}"
    data-url-detalhe-template="{{ url('/licitacoes-e-procedimentos') }}/__ID__"
    data-url-upload-download-template="{{ url('/licitacoes-e-procedimentos') }}/__LICITACAO_ID__/uploads/__UPLOAD_ID__/download"
    data-texto-modalidade="{{ __('Modalidade:') }}"
    data-texto-numero="{{ __('Licitação Nº:') }}"
    data-texto-data="{{ __('Data:') }}"
    data-texto-hora="{{ __('Hora:') }}"
    data-texto-status="{{ __('Status') }}"
    data-texto-objeto="{{ __('Objeto') }}"
    data-texto-instituicao="{{ __('Instituição') }}"
    data-texto-processo="{{ __('Processo') }}"
    data-texto-memorando="{{ __('Memorando') }}"
    data-texto-favorecido="{{ __('Favorecido') }}"
    data-texto-arquivos="{{ __('Arquivos') }}"
    data-texto-baixar="{{ __('Baixar') }}"
    data-texto-sem-arquivos="{{ __('Sem arquivos vinculados.') }}"
    data-texto-pagina-anterior="{{ __('Anterior') }}"
    data-texto-proxima-pagina="{{ __('Próxima') }}"
    data-texto-documentos-encontrados="{{ __('documento(s) encontrado(s)') }}"
    data-texto-tipo-processo-licitacao="{{ __('Licitação') }}"
    data-texto-tipo-processo-procedimento="{{ __('Procedimento') }}">
</div>

<script src="{{ asset('pmar/js/paginas/licitacoes-procedimentos.js') }}?v={{ @filemtime(public_path('pmar/js/paginas/licitacoes-procedimentos.js')) ?: time() }}"></script>
@endsection