@props([
    'name' => 'anexos[]',
    'inputId' => null,
    'describedBy' => null,
])

@php
    $fieldId = $inputId ?? ('historico_anexos_' . uniqid());
@endphp

<label class="form-label small mb-1" for="{{ $fieldId }}">{{ __('Anexos') }}</label>
<input type="file"
    class="form-control form-control-sm"
    name="{{ $name }}"
    id="{{ $fieldId }}"
    multiple
    accept=".pdf,.doc,.docx,.xls,.xlsx,.jpg,.jpeg,.png"
    @if($describedBy) aria-describedby="{{ $describedBy }}" @endif>
<p class="form-text small text-muted mb-0" @if($describedBy) id="{{ $describedBy }}" @endif>
    {{ __('PDF, Word, Excel ou imagens. Máx. 50 MB por arquivo.') }}
</p>
