@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Novo arquivo para ') . $conselho->nome)
@section('content')
<div class="card shadow-sm">
    @php $headLine = <i class='fa-solid fa-paperclip'></i>" . __('Novo arquivo para ') . "<i class='fa-solid fa-people-group'></i> " . $conselho->nome; @endphp
    @include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.conselhosMunicipais.arquivos.index', 'routeBackParams' => [$conselho->id], 'nameBack' => __('Voltar'), 'permission' => 'GERENCIADOR_DE_CONSELHOS'])
    <div class="card-body">
        @include('errors.messageFlash')
        <form action="{{ route('admin.conselhosMunicipais.arquivos.store', $conselho->id) }}" method="POST" enctype="multipart/form-data">@csrf

            <div class="mb-3">
                <label for="tipo" class="form-label text-bold">{{ __('Tipo de arquivo:') }} <span class="span-admin-create">*</span></label>
                <select class="form-control @error('tipo') is-invalid @enderror" name="tipo" id="tipo">
                    <option value="Ata de sessão extraordinária">Ata de sessão extraordinária</option>
                    <option value="Ata de sessão ordinária">Ata de sessão ordinária</option>
                    <option value="Carta Aberta">Carta Aberta</option>
                    <option value="Comunicado">Comunicado</option>
                    <option value="Convocação">Convocação</option>
                    <option value="Decreto">Decreto</option>
                    <option value="Deliberação">Deliberação</option>
                    <option value="Edital">Edital</option>
                    <option value="Legislação">Legislação</option>
                    <option value="Memorando">Memorando</option>
                    <option value="Moção">Moção</option>
                    <option value="Ofício">Ofício</option>
                    <option value="Parecer">Parecer</option>
                    <option value="Plano de Ação">Plano de Ação</option>
                    <option value="Portaria">Portaria</option>
                    <option value="Recomendação">Recomendação</option>
                    <option value="Regimento Interno">Regimento Interno</option>
                    <option value="Relatório">Relatório</option>
                    <option value="Resolução">Resolução</option>
                </select>
                @error('tipo')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            <div class="mb-3">
                <label for="link" class="form-label text-bold">{{ __('Arquivo:') }}</label>
                <input type="file" class="form-control @error('link') is-invalid @enderror" name="link" id="link" accept="application/pdf"/>
                @error('link')
                <small class="text-danger text-bold">{{ $message }}</small><br>
                @enderror
                <small class="text-info text-bold">{{ __('* Apenas documento em PDF') }}</small>
            </div>
            <hr/>

            @include('components.inputs._inputType', ['label'=>__('Nome do documento'),'name'=>'nome','required'=>true])

            <div class="mb-3">
                <label for="evento_at" class="form-label text-bold">{{ __('Data do evento:') }} <span class="span-admin-create">*</span></label>
                <input type="date" class="form-control @error('evento_at') is-invalid @enderror" name="evento_at" id="evento_at" autocomplete="off" value="{{ old('evento_at') }}">
                @error('evento_at')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            <div class="mb-3">
                <label for="status" class="form-label text-bold">{{ __('Status:') }} <span class="span-admin-create">*</span></label>
                <select class="form-control @error('status') is-invalid @enderror" name="status" id="status">
                    @foreach(App\Enums\StatusEnum::cases() as $status)
                    <option value="{{ $status->name }}">{{ $status->value }}</option>
                    @endforeach
                </select>
                @error('status')
                <small class="text-danger text-bold">{{ $message }}</small>
                @enderror
            </div>

            @include('components.buttons._backAndSend', [
            'textBack' => __('Voltar'),
            'textSend' => __('Cadastrar'),
            'routeBack' => 'admin.conselhosMunicipais.arquivos.index',
            'backId' => $conselho->id
            ])
        </form>
    </div>
</div>
@endsection
