<?php $__env->startSection('title', 'Notícias do Parque da Cidade da Prefeitura Municipal de Angra dos Reis'); ?>
<?php $__env->startSection('content'); ?>

    <div class="page-title dark-background" data-aos="fade"
        style="background-image: url(<?php echo e(asset('parquedacidade/imagens/img-fundo.jpg')); ?>);">
        <div class="container position-relative">
            <h1 class="text-white">Notícias</h1>
        </div>
    </div>

    <div class="container">
        <div class="row">

            <div class="col-12 blog-body">

                <% vSql="SELECT *, T2.DT_ANO + T2.DT_MES + T2.DT_DIA AS TADA FROM TB_SOPA_NOTICIAS_CATEGORIAS T1 INNER JOIN TB_SOPA_NOTICIAS T2 ON T1.NC_ID_NOTICIA = T2.ID_NOTICIA WHERE T1.NC_ID_CATEGORIA = "
                    & "66" & " AND T2.CD_STATUS = 'B' ORDER BY TADA DESC" Set myRst=Server.CreateObject("ADODB.Recordset")
                    SqlExecute myRst, vSql dim oMes() redim oMes(13) oMes(1)="Janeiro" oMes(2)="Fevereiro" oMes(3)="Março"
                    oMes(4)="Abril" oMes(5)="Maio" oMes(6)="Junho" oMes(7)="Julho" oMes(8)="Agosto" oMes(9)="Setembro"
                    oMes(10)="Outubro" oMes(11)="Novembro" oMes(12)="Dezembro" do while not myRst.eof set
                    objFSO=Server.CreateObject("Scripting.FileSystemObject") aZimagem=Server.MapPath(".")
                    aImg=Server.MapPath(".") oNum=cstr(InStr(aZimagem,"angra.rj.gov.br")) oMid=oNum + 15
                    zArq=mid(aZimagem,1,oMid) vID=myRst.fields("id_noticia") vTitulo=myRst.fields("ds_titulo")
                    vResumo=myRst.fields("ds_resumo") vDia=myRst.fields("dt_dia") vMes=myRst.fields("dt_mes")
                    vAno=myRst.fields("dt_ano") vImagem="" vvArquivo1=zArq & "httpdocs\sopa\fotos\noticias\" &
                    myRst.fields("id_noticia") & "_S.jpg" vvArquivo2=zArq & "httpdocs\sopa\fotos\noticias\" &
                    myRst.fields("id_noticia") & "_I.jpg" set objFSO=Server.CreateObject("Scripting.FileSystemObject") if
                    objFSO.FileExists(vvArquivo1)=true then vImagem="http://www.angra.rj.gov.br/sopa/fotos/noticias/" &
                    myRst.fields("id_noticia") & "_S.jpg" else if objFSO.FileExists(vvArquivo2)=true then
                    vImagem="http://www.angra.rj.gov.br/sopa/fotos/noticias/" & myRst.fields("id_noticia") & "_I.jpg" end if
                    end if set objFSO=nothing %>

                    <div class="row noticias">
                        <div class="col-md-5">
                            <div class="about-img">
                                <img src="<%=vImagem%>" class="img-responsive" alt="">

                            </div>
                        </div>
                        <div class="col-md-7 blog-post">
                            <h1 class="post-title"><a href="http://parquedacidade.angra.rj.gov.br/noticia.asp?n=<%=vID%>">
                                    <%=vTitulo%>
                                </a></h1>

                            <ul class="post-meta">
                                <li><i class="fa fa-clock-o"></i>
                                    <%=vDia%> de <%=oMes(vMes)%> de <%=vAno%>
                                </li>
                            </ul>

                            <p class="post-content">
                                <%=vResumo%>
                            </p>
                            <a href="http://parquedacidade.angra.rj.gov.br/noticia.asp?n=<%=vID%>"
                                class="btn btn-primary readmore">Saiba Mais... <i class="fa fa-angle-right"></i></a>

                        </div>
                    </div>

                    <% myRst.movenext loop %>
            </div>

        </div>
    </div>
    
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.parquedacidade.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/parque-da-cidade/noticias.blade.php ENDPATH**/ ?>