@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Sobre")
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <x-portal.breadcrumb :items="\App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Formação acadêmica'))" />
                </div>
                <div class="col-12">
                    <h1>Sobre</h1>
                </div>
                <hr />
                <div class="col-12 col-sm-12 col-md-12 col-lg-9 col-xl-9 col-xxl-9 mb-5">
                    <div class="row">
                        <div class="col-sm-12 col-md-4">
                            <img src="{{ asset($secretaria->managerPhoto) }}" class="img-fluid img-thumbnail" alt="{{ $secretaria->manager }}" title="{{ $secretaria->manager }}" class="img-fluid img-thumbnail">
                        </div>
                        <div class="col-sm-12 col-md-8">
                            <h3>{{ $secretaria->manager }}</h3>
                            <div class="pdown">{!! $secretaria->academicBackground !!}</div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
                    <div class="row">
                        <div class="col-12">
                            @include('paginas.parts.links')
                            @include('paginas.parts.servicos')
                            @include('paginas.parts.telefones')
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection


 