<form id="<?php echo e($id); ?>" class="d-flex mb-4 pt-4" method="get" action="<?php echo e(request()->url()); ?>">
    <input type="hidden" name="page" value="1">
    <input type="text" class="form-control me-2" name="q" placeholder="<?php echo e($placeholder); ?>"
        value="<?php echo e(request()->input('q')); ?>">
    <button class="btn btn-outline-success" type="submit"><i class="fa-solid fa-magnifying-glass"></i></button>
</form><?php /**PATH /var/www/html/portal/resources/views/components/forms/_filtroPesquisaDefault.blade.php ENDPATH**/ ?>