@extends('layouts.window.theme')
@section("title", env("APP_NAME") . " :: Recuperar senha")
@section('content')

    <div class="container d-flex justify-content-center align-items-center min-vh-100">
        <div class="row w-100 justify-content-center">
            <div class="col-sm-12 col-md-8 col-lg-6">
                <div class="card shadow-lg">
                    <div class="card-header bg-primary text-white">
                        <h4 class="mb-0">Recuperar senha</h4>
                    </div>
                    <div class="card-body">
                        <div class="text-center my-3">
                            <img src="{{ asset("pmar/assets/img/logo-pmar.svg") }}" class="card-img-top" title="{{ __("Prefeitura Municipal de Angra dos Reis") }}" alt="{{ __("Prefeitura Municipal de Angra dos Reis") }}" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                        </div>
                        <h2>Esqueceu sua senha?</h2>
                        <div class="mb-3">
                            <small class="text-primary">(*) Informe seu e-mail para receber um link de redefinição de senha.</small>
                        </div>
                        @if (session('success'))
                            <div class="alert alert-success">{{ session('success') }}</div>
                        @endif

                        @if ($errors->any())
                            <div class="alert alert-danger">
                                @foreach ($errors->all() as $error)
                                    <p>{{ $error }}</p>
                                @endforeach
                            </div>
                        @endif
                        <form action="{{ route('paginas.fibromialgia.esqueciSenha') }}" method="POST">
                            @csrf
                            <div class="my-3">
                                <label for="email">CPF:</label>
                                <input type="cpf" name="cpf" id="cpf" class="form-control" required value="{{ old('cpf') }}">
                            </div>
                            <div class="mb-3">
                                <label for="email">E-mail:</label>
                                <input type="email" name="email" id="email" class="form-control" required
                                   value="{{ old('email') }}">
                            </div>
                            <div class="row mb-3">
                                <div>
                                    <button type="submit" class="btn btn-primary w-100">Enviar Código de Redefinição</button>
                                </div>
                                <div class="col-12 mt-3">
                                    <a class="btn btn-outline-secondary"
                                   href="{{ route('paginas.castracao.verified') }}">
                                    Cadastrar-se
                                    </a>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection