@extends('layouts.pmar.app')

@section('title', 'Login - Credenciamento de Músicos')

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title text-center">Credenciamento de Músicos</h3>
                </div>
                <div class="card-body">
                    <form method="POST" action="{{ route('paginas.credenciamento-musico.login') }}">
                        @csrf
                        
                        <div class="form-group">
                            <label for="login">E-mail, CPF ou Matrícula *</label>
                            <input type="text" name="login" id="login" class="form-control @error('login') is-invalid @enderror" 
                                   value="{{ old('login') }}" required autofocus>
                            @error('login')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="form-group">
                            <label for="password">Senha *</label>
                            <input type="password" name="password" id="password" class="form-control @error('password') is-invalid @enderror" required>
                            @error('password')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="form-group">
                            <div class="form-check">
                                <input type="checkbox" name="remember" id="remember" class="form-check-input">
                                <label for="remember" class="form-check-label">Lembrar-me</label>
                            </div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary btn-block">
                                <i class="fas fa-sign-in-alt"></i> Entrar
                            </button>
                        </div>
                        
                        <div class="text-center">
                            <a href="{{ route('paginas.credenciamento-musico.esqueciSenha') }}" class="btn btn-link">
                                Esqueci minha senha
                            </a>
                        </div>
                    </form>
                </div>
                <div class="card-footer text-center">
                    <p class="mb-0">Não tem cadastro? <a href="{{ route('paginas.credenciamento-musico.verified') }}">Cadastre-se aqui</a></p>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
