<div id="collapseDois" class="collapse">
    <p class="text-muted text-center">
        <a href="{!! $url !!}" target="{{ $target }}">
            <strong>
                {{ $nome }},
                <span style="color: #696969; cursor: pointer;">{{ $data }}</span>
                {!! $fontawesome !!}
            </strong>
        </a>
    </p>
</div>