@if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar'])
    <form class="del d-inline" action="{{ route($route, $id)}}" method="post">
        @csrf
        <button class="text-danger text-decoration-none border-0 bg-transparent fs-5" type="submit">
            <span class="material-symbols-outlined"> 
                @if($fontawesome == null)
                    <i class="text-danger fa-solid fa-rotate-left d-inline fs-5"></i> 
                @else
                    {!! $fontawesome !!}
                @endif
            </span>
        </button>
    </form>
@endif
