@php
    $filterParams = $filterParams ?? [];
@endphp

<form method="get" action="{{ route('admin.empresasDeTurismo.index') }}" class="row g-3 mb-3">
    <div class="col-12 col-lg-4">
        <label class="form-label" for="filtro_empresas_turismo_q">{{ __('Busca geral') }}</label>
        <input
            type="search"
            class="form-control"
            name="q"
            id="filtro_empresas_turismo_q"
            value="{{ request('q') }}"
            placeholder="{{ __('Razão social, fantasia, CNPJ, e-mail, telefone ou embarcação...') }}"
            autocomplete="off"
        >
    </div>
    <div class="col-12 col-md-6 col-lg-2">
        <label class="form-label" for="filtro_empresas_turismo_cnpj">{{ __('CNPJ') }}</label>
        <input
            type="text"
            class="form-control"
            name="cnpj"
            id="filtro_empresas_turismo_cnpj"
            value="{{ request('cnpj') }}"
            placeholder="{{ __('00.000.000/0000-00') }}"
            oninput="javascript:aplicarMascaraCNPJ(this)"
        >
    </div>
    <div class="col-12 col-md-6 col-lg-2">
        <label class="form-label" for="filtro_empresas_turismo_cadastur">{{ __('Cadastur') }}</label>
        <input
            type="text"
            class="form-control"
            name="cadastur"
            id="filtro_empresas_turismo_cadastur"
            value="{{ request('cadastur') }}"
            placeholder="{{ __('Número do Cadastur') }}"
            oninput="javascript:this.value = this.value.replace(/\D/g, '')"
        >
    </div>
    <div class="col-12 col-md-6 col-lg-2">
        <label class="form-label" for="filtro_empresas_turismo_status">{{ __('Status') }}</label>
        <select class="form-select" name="status" id="filtro_empresas_turismo_status">
            <option value="">{{ __('Todos') }}</option>
            <option value="ATIVADO" @selected(request('status') === 'ATIVADO')>{{ __('ATIVADO') }}</option>
            <option value="DESATIVADO" @selected(request('status') === 'DESATIVADO')>{{ __('DESATIVADO') }}</option>
        </select>
    </div>
    <div class="col-12 col-md-6 col-lg-2">
        <label class="form-label" for="filtro_empresas_turismo_whatsapp">{{ __('WhatsApp') }}</label>
        <select class="form-select" name="possui_whatsapp" id="filtro_empresas_turismo_whatsapp">
            <option value="">{{ __('Todos') }}</option>
            <option value="1" @selected(request('possui_whatsapp') === '1')>{{ __('Sim') }}</option>
            <option value="0" @selected(request('possui_whatsapp') === '0')>{{ __('Não') }}</option>
        </select>
    </div>
    <div class="col-12 col-md-6 col-lg-3">
        <label class="form-label" for="filtro_empresas_turismo_cadastur_situacao">{{ __('Situação CADASTUR') }}</label>
        <select class="form-select" name="cadastur_situacao" id="filtro_empresas_turismo_cadastur_situacao">
            <option value="">{{ __('Todas') }}</option>
            <option value="vigente" @selected(request('cadastur_situacao') === 'vigente')>{{ __('Vigente') }}</option>
            <option value="vence_30" @selected(request('cadastur_situacao') === 'vence_30')>{{ __('Vence em 30 dias') }}</option>
            <option value="vencido" @selected(request('cadastur_situacao') === 'vencido')>{{ __('Vencido') }}</option>
            <option value="sem_vencimento" @selected(request('cadastur_situacao') === 'sem_vencimento')>{{ __('Sem vencimento informado') }}</option>
        </select>
    </div>
    <div class="col-12 d-flex justify-content-end gap-2">
        <a href="{{ route('admin.empresasDeTurismo.index') }}" class="btn btn-outline-secondary px-4">{{ __('Limpar') }}</a>
        <button class="btn btn-success px-4" type="submit">{{ __('Filtrar') }}</button>
    </div>
</form>
