<div class="col-sm-6 col-md-4 col-lg-3 mb-3">
    <div class="card my-3">
        <div class="card-body">
            <p class="card-text">
                <span class="d-inline-block w-100"><i class="fa-regular fa-user"></i> <?php echo e($cargo); ?></span>
            </p>
            <h5 class="card-title" style="font-size: 15px; height: 40px"><?php echo e($nome); ?></h5>
            <p class="card-text">
                <span class="badge badge-info fs-6 d-inline-block w-100" style="background-color: #007cbf !important"><strong><?php echo e(__("Órgão")); ?></strong>: <?php echo e($sigla); ?></span>
            </p>
            <hr>
            <p class="card-text">
                <strong><?php echo e(__("Matrícula")); ?></strong>: <?php echo e($matricula); ?> <br>
            </p>
        </div>
    </div>
</div><?php /**PATH /var/www/html/portal/resources/views/components/cards/_cardComiteGestor.blade.php ENDPATH**/ ?>