<h3 class="subtitle-home"><?php echo e(__("Galeria de Fotos")); ?></h3><!-- Título -->

<div class="row bg-waves">

	<div class="swiper">
		<div class="card-wrapper col-12 col-sm-12 col-md-8 col-lg-6 col-xl-6 col-xxl-6">
			<ul class="card-list swiper-wrapper" id="album-list">
				<!-- Itens serão carregados dinamicamente aqui -->
			</ul>
			<div class="swiper-slide-button swiper-button-prev"></div>
			<div class="swiper-slide-button swiper-button-next"></div>
		</div>
	</div>

	<div class="col-12 col-sm-12 col-md-5 col-lg-5 col-xl-5 col-xxl-5 m-auto pt-5 px-5">
		<a href="https://www.flickr.com/photos/prefeituradeangradosreis/albums" target="_blank"
			class="btn p-4 fw-bold btn-outline-galery rounded-5 fs-3"><?php echo e(__("Ver todas as galerias")); ?></a>
	</div>

</div>
<?php /**PATH /var/www/html/portal/resources/views/paginas/partsHome/galeriaDeFotos.blade.php ENDPATH**/ ?>