@props([
    'numero' => null,
    'chamadoUrl' => null,
])

@if ($numero && $chamadoUrl)
    <div class="alert alert-success" role="status">
        <p class="mb-2">
            {{ __('Manifestação enviada com sucesso. Seu número de registro é :numero.', ['numero' => $numero]) }}
        </p>
        <a href="{{ $chamadoUrl }}" class="alert-link fw-semibold">
            {{ __('Acompanhar meu chamado na Conta Angra') }}
            <i class="fa-solid fa-arrow-right ms-1" aria-hidden="true"></i>
        </a>
    </div>
@endif
