@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Lista de Centros de Referências CRAS e CREAS')
@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-house-chimney-user'></i> Lista de Centros de Referências CRAS e CREAS"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
//            'routeBack' => 'admin.turismoNautico.index',
//            'routeBackParams' => [],
//            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.acaoSocial.centrosDeReferencia.create',
            'routeAddParams' => [],
            'nameAdd' => __('Novo centro de referência'),
            "permission" => "GERENCIADOR_DE_CENTROS_REFERENCIA",
        ])

        <div class="card-body">

            @include("errors.messageFlash")

             @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "centrosReferenciasCRASCREAS", 
                "placeholder" => "Pesquisar por centro de referencia..."])
            
            <x-tables._table :thead="['Foto', 'Criado em', 'Nome', 'Pertence a', 'Bairro', 'Email', 'Telefone', 'Tipo', 'Possui Recursos Multifuncionais', 'Status', 'Ações']" :pagination="$centros->links()">
                <x-slot name="body">
                    @php 
                        $pathSystem = $_SERVER['DOCUMENT_ROOT'] . "/";
                        $angraDefault = asset("/pmar/assets/img/icons/centro_referencia.png");
                    @endphp
                    @php $index = 0; @endphp
                     @foreach($centros as $centro)
                        <tr>
                            <td style="width:150px">
                                @include('components.tables._openPhoto', [
                                    'asset' => file_exists( $pathSystem . $centro->foto ) ? asset($centro->foto) : asset($angraDefault),
                                    'alt' => $centro->nome,
                                    'title' => $centro->nome,
                                    'text' => 'Visualizar foto',
                                ])
                            </td>
                            <td>{{ date("d/m/Y H:i", strtotime($centro->created_at)) }}</td>
                            <td>{{ $centro->nome }}</td>
                            <td>{{ $centro->pertence->name }}</td>
                            <td>{{ $centro->endereco->bairro }}</td>
                            <td>{{ $centro->email }}</td>
                            <td style="white-space: nowrap;">{{ $centro->telefone }}</td>
                            <td>{{ $centro->tipoCentroReferencia }}</td>
                            <td>
                                @if($centro->possuiRecursosMultifuncionais)
                                    <i class="fa-solid fa-circle-check text-success"></i>
                                @else
                                    <i class="fa-solid fa-circle-xmark text-danger"></i>
                                @endif
                            </td>
                            <td class="text-center align-middle">
                                @include('components.buttons._status', [
                                    "index" => $index,
                                    "route" => "admin.acaoSocial.centrosDeReferencia.status",
                                    "id" => $centro->id,
                                    "status" => $centro->status,
                                    "permission" => "GERENCIADOR_DE_CENTROS_REFERENCIA",
                                ])
                            </td>
                            <td>
                                <div class="d-flex gap-2 justify-content-center">

                                    @include('components.buttons._editButton', [
                                        "route" => "admin.acaoSocial.centrosDeReferencia.edit",
                                        "id" => $centro->id,
                                        "title" => "Editar",
                                        "fontawesome" => null,
                                        "permission" => "GERENCIADOR_DE_CENTROS_REFERENCIA",
                                    ])

                                    @include('components.buttons._deleteButton', [
                                        "message" => __("* Este centro de referância será excluído e esta ação não poderá ser desfeita, deseja continuar?"),
                                        "route" => "admin.acaoSocial.centrosDeReferencia.destroy",
                                        "id" => $centro->id,
                                        "title" => "Excluir",
                                        "fontawesome" => null,
                                        "permission" => "GERENCIADOR_DE_CENTROS_REFERENCIA",
                                    ])
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>

        </div>
    </div>

@endsection