<div class="row home-institucionais-row gy-5">
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.location.href='<?php echo e(route('paginas.boletim-oficial')); ?>'">
		<img src="<?php echo e(asset('pmar/assets/img/icons/boletim.svg')); ?>" alt="Boletim Oficial do Município">
		<h4><?php echo e(__("Boletim Oficial")); ?></h4>
		<p><?php echo e(__("Acesse as edições do B.O. de Angra dos Reis")); ?></p>
	</div>
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.location.href='https://siarm.angra.rj.gov.br'">
		<img src="<?php echo e(asset('pmar/assets/img/icons/contribuinte_corrigido.svg')); ?>"
			alt="Licitações e Procedimentos do Município">
		<h4><?php echo e(__("Portal do Contribuinte")); ?></h4>
		<p><?php echo e(__("Informações tributárias no âmbito Municipal")); ?></p>
	</div>
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.location.href='https://angra.rj.gov.br/licitacoes-e-procedimentos'">
		<img src="<?php echo e(asset('pmar/assets/img/icons/licitacoes.svg')); ?>"
			alt="Licitações e Procedimentos do Município">
		<h4><?php echo e(__("Licitações e Procedimentos")); ?></h4>
		<p><?php echo e(__("Editais e calendário das licitações da PMAR")); ?></p>
	</div>
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.location.href='https://portal.angra.rj.gov.br/transparencia.asp?indexsigla=transp'">
		<img src="<?php echo e(asset('pmar/assets/img/icons/transparencia.svg')); ?>" alt="Portal da Transparência">
		<h4><?php echo e(__("Portal da Transparência")); ?></h4>
		<p><?php echo e(__("Orçamento, contratos, responsabilidade fiscal etc.")); ?></p>
	</div>
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.open('https://visite.angra.rj.gov.br/', '_blank');">
		<img src="<?php echo e(asset('pmar/assets/img/icons/turismo.svg')); ?>" alt="Visite Angra">
		<h4><?php echo e(__("Visite Angra")); ?></h4>
		<p><?php echo e(__("Tudo sobre as atrações que aguardam os turistas em Angra")); ?></p>
	</div>
	<div class="home-institucionais-item col-xl-2 col-lg-4 col-md-6 col-sm-12 col-12" onclick="javascript:window.open('https://portaldoservidor.angra.rj.gov.br/', '_blank');">
		<img src="<?php echo e(asset('pmar/assets/img/icons/portaldoservidor.svg')); ?>" alt="Portal do Servidor">
		<h4><?php echo e(__("Portal do Servidor")); ?></h4>
		<p><?php echo e(__("Informações de Recursos Humanos da PMAR")); ?></p>
	</div>
</div><?php /**PATH /var/www/html/portal/resources/views/paginas/partsHome/linksInstitucionais.blade.php ENDPATH**/ ?>