<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <meta name="site" content="https://angra.rj.gov.br">

    <title><?php echo $__env->yieldContent('title'); ?></title>

    <meta name="description" content="Portal oficial do SEI da Prefeitura Municipal de Angra dos Reis." />
    <meta name="robots" content="noodp" />

    <meta name="description" content="SEI - Sistema Eletrônico de Informações de Angra dos Reis">
    <meta name="author" content="Prefeitura de Angra dos Reis">
    <meta name="keywords" content="SEI, Angra dos Reis, Sistema Eletrônico de Informações, Processo Digital">
    <meta name="generator" content="Prefeitura de Angra dos Reis">
    <meta name="robots" content="index, follow" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />

    <!-- para o compartilhar -->
    <meta property="og:title" content="SEI - Angra dos Reis" />
    <meta property="og:type" content="city" />
    <meta property="og:url" content="https://angra.rj.gov.br/sei" />
    <meta property="og:image" content="https://angra.rj.gov.br/sei/thumb.jpg" />
    <meta property="og:description" content="SEI - Sistema Eletrônico de Informações de Angra dos Reis" />
    <meta property="og:locale" content="pt_BR">


    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset('pmar/assets/fav/apple-icon-57x57-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset('pmar/assets/fav/apple-icon-60x60-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset('pmar/assets/fav/apple-icon-72x72-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset('pmar/assets/fav/apple-icon-76x76-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset('pmar/assets/fav/apple-icon-114x114-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset('pmar/assets/fav/apple-icon-120x120-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset('pmar/assets/fav/apple-icon-144x144-2026.png')); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('pmar/assets/fav/apple-icon-180x180-2026.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('pmar/assets/fav/favicon-32x32-2026.png')); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset('pmar/assets/fav/favicon-96x96-2026.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('pmar/assets/fav/favicon-16x16-2026.png')); ?>">
    <link rel="manifest" href="<?php echo e(asset('sei-angra/assets/fiveicon/manifest.json')); ?>">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="<?php echo e(asset('pmar/assets/fav/ms-icon-144x144-2026.png')); ?>">
    <meta name="theme-color" content="#ffffff">

    <!-- Bootstrap icons-->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css" rel="stylesheet" />

    <!-- Google fonts-->
    <link rel="preconnect" href="https://fonts.gstatic.com" />
    <link href="https://fonts.googleapis.com/css2?family=Newsreader:ital,wght@0,600;1,600&amp;display=swap"
        rel="stylesheet" />
    <link
        href="https://fonts.googleapis.com/css2?family=Mulish:ital,wght@0,300;0,500;0,600;0,700;1,300;1,500;1,600;1,700&amp;display=swap"
        rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Kanit:ital,wght@0,400;1,400&amp;display=swap"
        rel="stylesheet" />

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" rel="stylesheet" />
    <link rel="stylesheet" href="<?php echo e(asset('comite-municipal-governca-digital/css/style.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('sei-angra/css/style.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('comite-municipal-governca-digital/css/defaultBar.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('comite-municipal-governca-digital/css/scripts.css')); ?>">

</head><?php /**PATH /var/www/html/portal/resources/views/layouts/cmgd/elements/head.blade.php ENDPATH**/ ?>