@extends('layouts.pmar.theme')

@section('title', config('app.name').' :: '.__('Fale conosco').' — '.$secretaria->name)

@push('styles')
    <link rel="stylesheet" href="{{ asset('pmar/css/paginas/org-fale-conosco.css') }}">
@endpush

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-12 my-3">
                @php
                    $breadcrumbItems = \App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Fale conosco'));
                    if (isset($secretaria->pertence->name)) {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->pertence->abbreviation;
                        $breadcrumbItems[2]['labelShort'] = $secretaria->abbreviation;
                    } else {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->abbreviation;
                    }
                @endphp
                <x-portal.breadcrumb
                    :items="$breadcrumbItems"
                    :responsive-abbreviation="true"
                />
            </div>
        </div>
    </div>

    @include('paginas.parts.headers')

    <div class="container pb-5">
        <div class="row gx-4 gx-lg-5 gy-4">
            <section class="col-12 col-lg-9 order-1">
                @include('paginas.parts.org-fale-conosco-miolo')
            </section>
            <aside class="col-12 col-lg-3 mt-4 mt-lg-0 order-2" aria-label="{{ __('Informações laterais do órgão') }}">
                @include('paginas.parts.org-fale-conosco-aside')
            </aside>
        </div>
    </div>
@endsection
