@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Observatório - Mapas'))

@section('content')
    @include('admin.observatorio.partials._assets')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-map'></i> " . __('Observatório - Mapas'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.observatorio.indicadores.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.observatorio.mapas.create',
            'routeAddParams' => request()->only(['q', 'mapa_tema_id', 'page']),
            'nameAdd' => __('Novo mapa'),
            'permission' => 'GERENCIADOR_DO_OBSERVATORIO',
        ])

        <div class="card-body">
            <form method="get" class="row g-2 mb-3">
                <div class="col-md-7">
                    <input type="text" class="form-control" name="q" value="{{ request('q') }}" placeholder="{{ __('Buscar mapa') }}">
                </div>
                <div class="col-md-3">
                    <select class="form-select" name="mapa_tema_id">
                        <option value="">{{ __('Todos os temas') }}</option>
                        @foreach($temas as $tema)
                            <option value="{{ $tema->id }}" @selected((string) request('mapa_tema_id') === (string) $tema->id)>{{ $tema->nome }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="col-md-2 d-flex align-items-end">
                    <button class="btn btn-success w-100" type="submit">{{ __('Filtrar') }}</button>
                </div>
            </form>

            <x-tables._table :thead="[__('Título'), __('Tema'), __('Link'), __('Status'), __('Ações')]" :pagination="$registros->links()">
                <x-slot name="body">
                    @forelse($registros as $registro)
                        <tr>
                            <td class="text-start">{{ $registro->titulo }}</td>
                            <td>{{ $registro->tema->nome ?? '-' }}</td>
                            <td class="text-start"><a href="{{ $registro->link }}" target="_blank" rel="noopener">{{ \Illuminate\Support\Str::limit($registro->link, 50) }}</a></td>
                            <td><span class="badge {{ $registro->status === 'ATIVADO' ? 'bg-primary' : 'bg-secondary' }}">{{ __($registro->status) }}</span></td>
                            <td>
                                <div class="d-flex justify-content-center gap-2">
                                    @if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DO_OBSERVATORIO')['editar'])
                                        <a class="btn btn-sm btn-warning" href="{{ route('admin.observatorio.mapas.edit', [$registro->id] + request()->only(['q', 'mapa_tema_id', 'page'])) }}"><i class="fa-solid fa-pen-to-square"></i></a>
                                    @endif
                                    @if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DO_OBSERVATORIO')['excluir'])
                                        <form class="d-inline" action="{{ route('admin.observatorio.mapas.destroy', $registro->id) }}" method="post" data-confirm-delete>
                                            @csrf
                                            @method('delete')
                                            @foreach(request()->only(['q', 'mapa_tema_id', 'page']) as $key => $value)
                                                <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                            @endforeach
                                            <input type="hidden" name="confirm" value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                            <button type="submit" class="btn btn-sm btn-danger"><i class="fa-solid fa-trash"></i></button>
                                        </form>
                                    @endif
                                </div>
                            </td>
                        </tr>
                    @empty
                        <tr><td colspan="5" class="text-center">{{ __('Nenhum registro encontrado.') }}</td></tr>
                    @endforelse
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection
