<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.arte-sacra.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body class="fade-in">
    <header>
        <?php echo $__env->make('layouts.arte-sacra.elements.nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <!-- <?php if(Route::currentRouteName() == 'museu-de-arte-sacra.index'): ?>
        <?php echo $__env->make('layouts.arte-sacra.elements.nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <?php else: ?>
        <?php endif; ?> -->
    </header>
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>
    <footer class="footer-pmar">
        <?php echo $__env->make('layouts.arte-sacra.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </footer>
</body>

</html><?php /**PATH /var/www/html/portal/resources/views/layouts/arte-sacra/theme.blade.php ENDPATH**/ ?>