<button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#mapModal" style="height: 2.7rem">
    {{ __("Selecionar Ponto no Mapa") }}
</button>

<div class="modal fade" id="mapModal" tabindex="-1" aria-labelledby="mapModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="mapModalLabel">{{ __($label) }}</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Fechar"></button>
            </div>
            <div class="modal-body">
                <div id="map"></div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary me-3" data-bs-dismiss="modal">Cancelar</button>
                <button type="button" class="btn btn-success" id="okBtn" data-bs-dismiss="modal">OK</button>
            </div>
        </div>
    </div>
</div>