@if (! empty($secretaria))
    <section class="ma-org-info" aria-label="{{ __('Informações do órgão') }}">
        <div class="container">
            <div class="row g-4 align-items-start">
                <div class="col-12 col-lg-6">
                    <x-mobiangra.saiba-mais-links :secretaria="$secretaria" :links="$links ?? collect()" />
                </div>
                <div class="col-12 col-lg-6">
                    <x-mobiangra.contatos-list :telefones="$telefones ?? []" />
                </div>
            </div>
        </div>
    </section>
@endif
