@extends('layouts.sei.theme')
@section('title', 'SEI - Lives Angra dos Reis')
@section('content')
    <section class="mt-5" id="treinamento">
        <div class="container px-5">
            <div class="row gx-5 align-items-center justify-content-center justify-content-lg-between">
                <div class="col-12">
                    <h2 class="display-4 lh-1 mb-4 text-center">Treinamentos e Guia para utilização do SEI</h2>
                </div>
            </div>
        </div>
    </section>

    <!-- Basic features section-->
    <section class="bg-light">
        <div class="container px-5">
            <div class="row justify-content-center align-items-center g-2">
                <div class="col d-flex justify-content-center">
                    <div class="card border-0 shadow" style="width: 18rem;">
                        <img class="card-img-top img-fluid d-block" src="{{ asset("sei-angra/assets/img/lives.jpg") }}" alt="Card image cap">
                        <div class="card-body px-3">
                            <h5 class="card-title">Lives de Treinamento SEI Angra dos Reis</h5>
                            <p class="card-text">Treinamento sobre o SEI Angra, que ocorreu nos dias 08 e 09 de janeiro.
                            </p>
                            <a href="lives.html" class="btn btn-primary">Assistir</a>
                        </div>
                    </div>
                </div>
                <div class="col d-flex justify-content-center">
                    <div class="card border-0 shadow" style="width: 18rem;">
                        <img class="card-img-top img-fluid d-block" src="{{ asset("sei-angra/assets/img/usar.png") }}" alt="Card image cap">
                        <div class="card-body px-3">
                            <h5 class="card-title">Curso Livre - SEI! USAR (ENAP)</h5>
                            <p class="card-text">Curso online gratuito, oferecido pela Escola Nacional de Administração
                                Pública (ENAP).</p>
                            <a href="https://www.escolavirtual.gov.br/curso/74" class="btn btn-primary">Fazer Curso</a>
                        </div>
                    </div>
                </div>
                <div class="col d-flex justify-content-center">
                    <div class="card border-0 shadow" style="width: 18rem;">
                        <img class="card-img-top img-fluid d-block" src="{{ asset("sei-angra/assets/img/wiki.jpg") }}" alt="Card image cap">
                        <div class="card-body px-3">
                            <h5 class="card-title">Wiki SEI-RJ</h5>
                            <p class="card-text">Todas as informações sobre o funcionamento do sistema, como manuais,
                                FAQs e procedimentos operacionais (POP's).</p>
                            <a href="https://wikisei.rj.gov.br/P%C3%A1gina_principal" class="btn btn-primary">Acessar</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection
