@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Perguntas Frequentes da Ouvidoria')
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.ouvidoria') }}">Ouvidoria</a>
                            </li>
                        </ol>
                    </nav>
                </div>
                <section class="col-md-12 nopadding single-article espaco_conteudo">
                    <header class="article-header">
                        <!-- Title -->
                        <h1 class="title">Perguntas Frequentes sobre a Ouvidoria</h1>
                        <!-- Excerpt -->
                    </header>
                    <article class="article-main">

                        <div class="clear"></div>
                        <p style="margin-top: 30px;">Abaixo, algumas perguntas e respostas frequentes que podem esclarecer
                            possíveis dúvidas sobre o processo de registro de manifestações da Ouvidoria.</p>

                        <div class="clear"></div>

                        <details>
                            <summary>O que é uma manifestação?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        A manifestação é uma forma de o cidadão expressar para a Ouvidoria seus anseios,
                                        angústias, dúvidas, opiniões ou sua satisfação/insatisfação com um atendimento ou
                                        serviço recebido. Assim, pode auxiliar a Prefeitura a aprimorar a gestão de
                                        políticas e
                                        serviços, ou a combater a prática de atos ilícitos.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Quais são os tipos de manifestação?</summary>
                            <ul class="project-info">
                                <li>
                                    <ul class="olist_normal">
                                        <li><strong>Pedido de acesso à informação:</strong> se você quer ter acesso à
                                            informação
                                            pública (por exemplo, cópia de documentos ou dúvidas)
                                            <br>
                                            <b>OBS.:</b> Os pedidos de informação devem abordar preferencialmente, um tema
                                            por
                                            vez, isso facilita a sua compreensão e seu andamento;
                                        </li>
                                        <li><strong>Reclamação:</strong> demonstração de insatisfação relativa a algum
                                            serviço
                                            e/ou atendimento;</li>
                                        <li><strong>Denúncia:</strong> comunicação de prática de ato ilícito cuja solução
                                            dependa da atuação de órgão de controle interno ou externo;</li>
                                        <li><strong>Sugestão:</strong> apresentação de uma ideia ou formulação de proposta
                                            de
                                            aprimoramento de políticas e serviços prestados pela Prefeitura;</li>
                                        <li><strong>Elogio:</strong> demonstração ou reconhecimento ou satisfação sobre o
                                            serviço oferecido ou atendimento recebido;</li>
                                        <li><strong>Solicitação de providência:</strong> pedido de atendimento ou
                                            requerimento
                                            de adoção de providência por parte da Prefeitura;</li>
                                    </ul>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Quem pode se manifestar?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>Qualquer pessoa, natural (física) ou jurídica. No entanto, segue abaixo a descrição
                                        do
                                        público-alvo da Prefeitura:</p>
                                    <ul class="olist_normal">
                                        <li>Cidadãos de Angra dos Reis e de outras cidades;</li>
                                        <li>Agentes políticos; </li>
                                        <li>Conselheiros tutelares;</li>
                                        <li>Usuários da Prefeitura e de suas Secretarias;</li>
                                        <li>Fornecedores e parceiros;</li>
                                        <li>Agentes do Poder Público externo. </li>
                                    </ul>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Quais dados são necessários para o registro?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Para registro na Plataforma Fala.BR, basta acessar o link: <a
                                            href="https://falabr.cgu.gov.br/publico/RJ/AngradosReis/Manifestacao/RegistrarManifestacao"
                                            target="_blank">https://falabr.cgu.gov.br/publico/RJ/AngradosReis/Manifestacao/RegistrarManifestacao</a>
                                        e fazer sua manifestação (são fundamentais o nome, o CPF e um e-mail pessoal e
                                        válido).
                                    </p>
                                    <p>Para o registro de uma denúncia, deve-se ter o máximo de informações possíveis que
                                        possibilitem a apuração dos fatos. As informações prestadas na denúncia devem
                                        responder
                                        às seguintes perguntas: quem?, como?, onde?, quando? e por quê?. Outras informações
                                        também podem contribuir para a apuração da denúncia, tais como:
                                    </p>
                                    <ul class="olist_normal">
                                        <li>nomes de pessoas e empresas envolvidas;</li>
                                        <li>tempo em que se deu o fato e se, ainda, ocorre;</li>
                                        <li>se a pessoa pode comprová-lo;</li>
                                        <li>documentação que possa corroborar com a apuração;</li>
                                        <li>se há mais alguém que possa ser procurado para falar sobre o assunto; e</li>
                                        <li>• se presenciou a situação que está denunciando ou apenas ouviu falar.</li>
                                    </ul>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>O que é o Fala.BR (e-OUV + e-SIC + Simplifique!)?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        O Fala.BR é um canal integrado para encaminhamento de todas as manifestações do
                                        usuário
                                        de serviços públicos. Esse sistema integra todas as Ouvidorias que estão ligadas à
                                        Rede
                                        Nacional de Ouvidorias, sob a coordenação da Controladoria-Geral da União (CGU).
                                        Está
                                        disponível na internet no endereço: <a
                                            href="https://falabr.cgu.gov.br/publico/RJ/AngradosReis/Manifestacao/RegistrarManifestacao"
                                            target="_blank">https://falabr.cgu.gov.br/publico/RJ/AngradosReis/Manifestacao/RegistrarManifestacao</a>
                                        <br>Funciona 24 horas.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Preciso me identificar para fazer uma manifestação ou posso fazer de forma anônima?
                            </summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        As manifestações do tipo Simplifique, Sugestão, Elogio, Solicitação de Providências
                                        e
                                        Acesso à Informação necessitam necessariamente da realização de cadastro no sistema.
                                    </p>
                                    <p>Já as manifestações do tipo Denúncia e Reclamação podem ser realizadas tanto mediante
                                        cadastro como de forma anônima, sendo que <b>o manifestante que optar pelo anonimato
                                            não
                                            obterá um número de protocolo e nem receberá uma resposta da Ouvidoria sobre os
                                            desdobramentos de sua manifestação</b>.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Quais as garantias de proteção à minha identidade?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Por força da Lei Federal nº. 12.527/2011 (Lei de Acesso à Informação) e da Lei
                                        Federal
                                        nº. 13.460/2017 (Código de Defesa dos Direitos do Usuário dos Serviços Públicos), os
                                        órgãos e entidades públicas devem proteger suas informações pessoais, restringindo o
                                        acesso a quaisquer dados relativos à intimidade, vida privada, honra e imagem, a não
                                        ser
                                        que você autorize expressamente o acesso a essas informações.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>O que acontece com minha manifestação após o registro na Assessoria de Ouvidoria
                                Externa?
                            </summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Quando você registra a manifestação, é feita uma avaliação do caso para identificar
                                        a
                                        melhor forma de tratá-lo. A Ouvidoria poderá responder sua manifestação; solicitar
                                        que
                                        você a complemente; prestar orientações; encaminhar para a unidade interna
                                        responsável
                                        por resolver a questão ou poderá também encaminhar para outro órgão/entidade,
                                        dependendo
                                        do caso. Você sempre será comunicado sobre o andamento adotado.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Qual o prazo para receber a resposta?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Temos prazos diferentes:
                                    </p>
                                    <ul class="olist_normal">
                                        <li>Para manifestações de reclamação, sugestão, denúncia, elogio, solicitação, o
                                            prazo
                                            para resposta é de 30 (trinta) dias, prorrogável por mais 30 (trinta) dias,
                                            mediante
                                            justificativa; </li>
                                        <li>Para pedidos de acesso à informação, o prazo é de 20 (vinte) dias, podendo ser
                                            prorrogado por mais 10 (dez) dias, mediante justificativa.</li>
                                    </ul>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Como acompanhar o andamento da minha manifestação ou ver a resposta da minha
                                manifestação?
                            </summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Acesse o sistema e clique em "Consultar Manifestação". Se você for cadastrado,
                                        acesse o
                                        sistema, informando o seu e-mail e senha, ou CPF e senha. O sistema apresentará a
                                        lista
                                        das suas manifestações já realizadas. Clique em "Detalhar" para visualizar o
                                        andamento
                                        da manifestação.</p>
                                    <p>Se você não tiver ativado o seu cadastrado (que pode ser feito clicando no link que
                                        foi
                                        para o seu e-mail), na tela principal do sistema, informe o número de protocolo e o
                                        código de acesso gerado durante o registro da manifestação. Clique em consultar para
                                        visualizar o andamento da manifestação.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>É possível alterar minha manifestação depois que foi enviada?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Não é possível alterar a sua manifestação após o envio. Porém, se a Ouvidoria
                                        solicitar
                                        uma complementação, você poderá complementar sua manifestação, oferecendo
                                        informações
                                        e/ou anexos adicionais. Para isso, é necessário acessar o sistema, detalhar sua
                                        manifestação e clicar em "Complementar".
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Escrevi um texto longo na minha manifestação e “o sistema caiu”. O que fazer?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Quando se passam 30 minutos do início do seu acesso, a sessão expira. Por isso, "o
                                        sistema cai". Se você tiver muitas informações e acreditar que vai levar um tempo
                                        maior
                                        para digitá-las, escreva em um documento e inclua como anexo.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>É possível incluir anexos na manifestação?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Sim. Você pode incluir documentos de texto, imagens, planilhas, arquivos no formato
                                        PDF,
                                        áudios (somente no formato mp3) e vídeos, limitados a 10 anexos por manifestação. Os
                                        anexos juntos também não podem superar o tamanho total de 30 mb.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Posso denunciar vários fatos em uma só denúncia?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Sim. No entanto, a fim de agilizar as apurações, é aconselhável que sejam
                                        registradas
                                        manifestações para cada fato/área temática denunciada (saúde, educação, cultura
                                        entre
                                        outros).
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Posso desistir de denúncia feita por mim? O que devo fazer?</summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Sim. Você poderá enviar uma nova manifestação ou e-mail, mencionando o número de
                                        protocolo da denúncia – exemplo: (01670.000XXX.2021-XX), informando da sua
                                        desistência.
                                        No entanto, a Prefeitura poderá utilizar de tais informações, caso entenda
                                        relevante,
                                        preservando a identidade do denunciante.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>

                        <details>
                            <summary>Onde posso encontrar dados e/ou informações estatísticas sobre a Ouvidoria Geral?
                            </summary>
                            <ul class="project-info">
                                <li>
                                    <p>
                                        Atualmente, estatísticas referentes ao atendimento das manifestações registradas no
                                        Fala.BR podem ser consultadas no Painel Resolveu (<a
                                            href="http://paineis.cgu.gov.br/resolveu/index.htm"
                                            target="_blank">http://paineis.cgu.gov.br/resolveu/index.htm</a>) - Esfera
                                        Municipal. As informações que constam no Painel são atualizadas diariamente.
                                    </p>
                                </li>
                            </ul>
                            <hr>
                        </details>



                    </article>

                </section>
            </div>
        </div>
    </section>
@endsection
