<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.mobiangra.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body id="mobiangra-page" class="ma-body">
    <?php echo $__env->make('layouts.mobiangra.elements.defaultBar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <header class="ma-header">
        <?php echo $__env->make('layouts.mobiangra.elements.header', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </header>

    <main class="ma-main" id="main-content">
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    <?php if (! empty(trim($__env->yieldContent('help-bar')))): ?>
        <?php echo $__env->yieldContent('help-bar'); ?>
    <?php else: ?>
        <?php echo $__env->make('mobiangra.sections.help-bar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php endif; ?>

    <footer class="ma-footer">
        <?php echo $__env->make('layouts.mobiangra.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </footer>

    <?php echo $__env->make('layouts.mobiangra.elements.bottom-nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <?php echo $__env->yieldPushContent('scripts'); ?>
    <script src="<?php echo e(asset('mobiangra-assets/js/portal.js')); ?>?v=<?php echo e(time()); ?>"></script>
</body>

</html>
<?php /**PATH /var/www/html/portal/resources/views/layouts/mobiangra/theme.blade.php ENDPATH**/ ?>