<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames((['linha']));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter((['linha']), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    $periodosOrdem = ['seg_sex', 'sabado', 'dom_feriado'];
    $coresLegenda = [
        'azul'     => __('Azul'),
        'vermelho' => __('Vermelho'),
        'verde'    => __('Verde'),
        'laranja'  => __('Laranja'),
        'amarelo'  => __('Amarelo'),
        'preto'    => __('Preto'),
    ];
?>

<div class="horarios-linha-conteudo">
    <div class="horarios-linha-acoes mb-4">
        <a href="<?php echo e(route('mobiangra.mapa', ['linha' => $linha->codigo])); ?>"
            class="btn btn-primary btn-sm"
            aria-label="<?php echo e(__('Ver no mapa a linha :linha', ['linha' => $linha->codigo])); ?>">
            <i class="fa-solid fa-map-location-dot me-1" aria-hidden="true"></i><?php echo e(__('Ver no mapa')); ?>

        </a>
    </div>

    <?php if($linha->tarifa || $linha->tarifa_cidadao): ?>
        <div class="horarios-linha-tarifas-texto mb-4">
            <?php if($linha->tarifa): ?>
                <p class="mb-1">
                    <strong><?php echo e(__('Tarifa')); ?>:</strong>
                    R$ <?php echo e(number_format($linha->tarifa, 2, ',', '.')); ?>

                </p>
            <?php endif; ?>
            <?php if($linha->tarifa_cidadao): ?>
                <p class="mb-0">
                    <strong><?php echo e(__('Passageiro Cidadão')); ?>:</strong>
                    R$ <?php echo e(number_format($linha->tarifa_cidadao, 2, ',', '.')); ?>

                </p>
            <?php endif; ?>
        </div>
    <?php endif; ?>

    <?php $__currentLoopData = $linha->secoes; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $secao): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
        <?php
            $gradesPorPeriodo = $secao->grades->keyBy('periodo');
            $gradesVisiveis = collect($periodosOrdem)
                ->map(fn ($key) => $gradesPorPeriodo->get($key))
                ->filter(fn ($grade) => $grade && count($grade->horariosItens()) > 0);
        ?>

        <?php if($gradesVisiveis->isEmpty()): ?>
            <?php continue; ?>
        <?php endif; ?>

        <section class="horarios-secao-bloco" aria-labelledby="secao-titulo-<?php echo e($secao->id); ?>">
            <div class="horarios-secao-barra" id="secao-titulo-<?php echo e($secao->id); ?>">
                <?php echo e($secao->titulo); ?>

            </div>

                            <?php if($gradesVisiveis->isNotEmpty()): ?>
                                <div class="horarios-grade-colunas row g-0">
                                    <?php $__currentLoopData = $gradesVisiveis; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $grade): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                        <div class="<?php echo \Illuminate\Support\Arr::toCssClasses([
                                            'horarios-grade-col',
                                            'col-12' => true,
                                            'col-md-6' => $gradesVisiveis->count() === 2,
                                            'col-md-4' => $gradesVisiveis->count() === 3,
                                        ]); ?>">
                                            <div class="horarios-periodo-header"><?php echo e($grade->label); ?></div>
                                            <div class="horarios-periodo-grid" role="list" aria-label="<?php echo e($grade->label); ?>">
                                                <?php $__currentLoopData = $grade->horariosItens(); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                                    <span class="<?php echo \Illuminate\Support\Arr::toCssClasses([
                                                        'horarios-hora',
                                                        'horarios-hora--' . $item['c'] => ! empty($item['c']),
                                                    ]); ?>" role="listitem"><?php echo e($item['h']); ?></span>
                                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                            </div>
                                        </div>
                                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                </div>
                            <?php endif; ?>
        </section>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

    <?php if($linha->legendas->isNotEmpty()): ?>
        <div class="horarios-legendas-texto">
            <?php $__currentLoopData = $linha->legendas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $leg): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <p class="<?php echo \Illuminate\Support\Arr::toCssClasses([
                    'horarios-legenda-linha',
                    'horarios-legenda-linha--' . $leg->cor => $leg->cor,
                ]); ?>">
                    <strong><?php echo e(__('Horário em :cor:', ['cor' => $coresLegenda[$leg->cor] ?? ucfirst($leg->cor)])); ?></strong>
                    <?php echo e($leg->descricao); ?>

                </p>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        </div>
    <?php endif; ?>

    <?php if($linha->integracoes->isNotEmpty()): ?>
        <section class="horarios-integracoes-bloco" aria-labelledby="integracao-titulo-<?php echo e($linha->id); ?>">
            <div class="horarios-integracao-barra" id="integracao-titulo-<?php echo e($linha->id); ?>">
                <?php echo e(__('ESTA LINHA FAZ INTEGRAÇÃO COM:')); ?>

            </div>

            <p class="horarios-integracao-descricao">
                <em><?php echo e(__('Integração é quando o passageiro utiliza dois ônibus ou mais (dependendo da linha) pagando apenas uma única passagem.')); ?></em>
            </p>

            <?php $__currentLoopData = $linha->integracoes; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $integ): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <div class="horarios-integracao-item">
                    <ol class="horarios-integracao-rotas list-unstyled"
                        aria-label="<?php echo e(__('Linhas integradas')); ?>">
                        <?php $__currentLoopData = $integ->linhas_envolvidas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $lenv): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li class="horarios-integracao-rota">
                                <span class="horarios-integracao-rota__linha">
                                    <span class="horarios-integracao-codigo"><?php echo e($lenv['codigo'] ?? ''); ?></span>
                                    <span class="horarios-integracao-nome"><?php echo e($lenv['nome'] ?? ''); ?></span>
                                </span>
                            </li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ol>
                    <p class="horarios-integracao-tempo mb-0">
                        <i class="fa-regular fa-clock me-1" aria-hidden="true"></i>
                        <?php echo e(__('Tempo de Integração: :min minutos', ['min' => $integ->tempo_minutos])); ?>

                    </p>
                </div>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

            <div class="horarios-como-usar-box">
                <div class="horarios-como-usar-box__icone" aria-hidden="true">?</div>
                <div class="horarios-como-usar-box__conteudo">
                    <h3 class="horarios-como-usar-box__titulo"><?php echo e(__('Como usar a Integração???')); ?></h3>
                    <ol class="horarios-como-usar-box__lista">
                        <li><?php echo e(__('Pague a passagem no primeiro ônibus com o seu cartão Passageiro Cidadão ou BonfimCard')); ?></li>
                        <li><?php echo e(__('O tempo de integração começa a contar a partir do momento que a roleta é liberada')); ?></li>
                        <li><?php echo e(__('Embarque no segundo ônibus dentro do tempo de integração e encoste o cartão no validador')); ?></li>
                        <li><?php echo e(__('Vai aparecer na tela do validador a palavra "INTEGRAÇÃO" e a roleta vai ser liberada!')); ?></li>
                    </ol>
                </div>
            </div>
        </section>
    <?php endif; ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/horarios-linha.blade.php ENDPATH**/ ?>