<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8">
    <title>Relatório de Candidatos</title>
    <style>
        body {
            font-family: DejaVu Sans, sans-serif;
            font-size: 12px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }

        th,
        td {
            border: 1px solid #000;
            padding: 6px;
            text-align: left;
        }
    </style>
</head>

<body>
    <h2>Relatório de Candidatos por Status</h2>

    <table>
        <thead>
            <tr>
                <th>Nome</th>
                <th>E-mail</th>
                <th>Status</th>
                <th>Data do Status</th>
            </tr>
        </thead>
        <tbody>
            @forelse ($resultados as $candidato)
                <tr>
                    <td>{{ $candidato->candidate->name ?? 'Desconhecido' }}</td>
                    <td>{{ $candidato->candidate->email ?? 'Desconhecido' }}</td>
                    <td>{{ $candidato->status }}</td>
                    <td>{{ \Carbon\Carbon::parse($candidato->status_date)->format('d/m/Y') }}</td>
                </tr>
            @empty
                <tr>
                    <td colspan="4">Nenhum candidato encontrado.</td>
                </tr>
            @endforelse
        </tbody>
    </table>
</body>

</html>
