<?php $__env->startSection("title", env("APP_NAME") . " :: Sobre"); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => \App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Formação acadêmica'))]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(\App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Formação acadêmica')))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
                </div>
                <div class="col-12">
                    <h1>Sobre</h1>
                </div>
                <hr />
                <div class="col-12 col-sm-12 col-md-12 col-lg-9 col-xl-9 col-xxl-9 mb-5">
                    <div class="row">
                        <div class="col-sm-12 col-md-4">
                            <img src="<?php echo e(asset($secretaria->managerPhoto)); ?>" class="img-fluid img-thumbnail" alt="<?php echo e($secretaria->manager); ?>" title="<?php echo e($secretaria->manager); ?>" class="img-fluid img-thumbnail">
                        </div>
                        <div class="col-sm-12 col-md-8">
                            <h3><?php echo e($secretaria->manager); ?></h3>
                            <div class="pdown"><?php echo $secretaria->academicBackground; ?></div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
                    <div class="row">
                        <div class="col-12">
                            <?php echo $__env->make('paginas.parts.links', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                            <?php echo $__env->make('paginas.parts.servicos', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                            <?php echo $__env->make('paginas.parts.telefones', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>


 
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/formacao-academica.blade.php ENDPATH**/ ?>