{{-- Célula MAPÃO: prazo de implantação (mês/ano do cadastro + dias). --}}
@php
    $mesAno = $mesAno ?? null;
    $dias = $dias ?? null;
    $temMesAno = filled($mesAno);
    $temDias = $dias !== null && $dias !== '';
@endphp
@if($temMesAno || $temDias)
    {{-- Classes próprias: o MAPÃO impresso não carrega Bootstrap (d-flex não surte efeito). --}}
    <div class="pp-prazo-implantacao-celula">
        @if($temMesAno)
            <span class="pp-prazo-implantacao-celula__mes">{{ $mesAno }}</span>
        @endif
        @if($temDias)
            <span class="pp-prazo-implantacao-celula__dias">{{ $dias }} {{ __('dias') }}</span>
        @endif
    </div>
@endif
