<div class="card-body">
    <div class="row">
        <div class="col-12">
            @include("errors.messageFlash")
        </div>
    </div>
    <div class="row">

        {{-- Corredores Turísticos --}}
        <div class="col-md-6 col-lg-3">
            <a href="{{ route('admin.visiteAngra.corredores.index') }}" class="text-decoration-none">
                <div class="card h-100 shadow-sm hover-card text-center border-0">
                    <div class="card-body">
                        <div class="mb-3 text-primary">
                            <i class="fa-solid fa-route fa-2x"></i>
                        </div>
                        <h6 class="fw-bold text-dark">{{ __("Corredores Turísticos") }}</h6>
                        <p class="text-muted small mb-0">{{ __("Gerencie os corredores turísticos cadastrados") }}</p>
                    </div>
                </div>
            </a>
        </div>

        {{-- Categorias --}}
        <div class="col-md-6 col-lg-3">
            <a href="{{ route('admin.visiteAngra.categorias.index') }}" class="text-decoration-none">
                <div class="card h-100 shadow-sm hover-card text-center border-0">
                    <div class="card-body">
                        <div class="mb-3 text-success">
                            <i class="fa-solid fa-layer-group fa-2x"></i>
                        </div>
                        <h6 class="fw-bold text-dark">{{ __("Categorias") }}</h6>
                        <p class="text-muted small mb-0">{{ __("Gerencie as categorias de atrativos") }}</p>
                    </div>
                </div>
            </a>
        </div>

        {{-- Pontos Turísticos --}}
        <div class="col-md-6 col-lg-3">
            <a href="{{ route('admin.visiteAngra.pontos.index') }}" class="text-decoration-none">
                <div class="card h-100 shadow-sm hover-card text-center border-0">
                    <div class="card-body">
                        <div class="mb-3 text-warning">
                            <i class="fa-solid fa-map-location-dot fa-2x"></i>
                        </div>
                        <h6 class="fw-bold text-dark">{{ __("Pontos Turísticos") }}</h6>
                        <p class="text-muted small mb-0">{{ __("Cadastre e atualize pontos turísticos") }}</p>
                    </div>
                </div>
            </a>
        </div>

        {{-- Atrativos --}}
        <div class="col-md-6 col-lg-3">
            <a href="{{ route('admin.visiteAngra.atrativos.index') }}" class="text-decoration-none">
                <div class="card h-100 shadow-sm hover-card text-center border-0">
                    <div class="card-body">
                        <div class="mb-3 text-danger">
                            <i class="fa-solid fa-umbrella-beach fa-2x"></i>
                        </div>
                        <h6 class="fw-bold text-dark">{{ __("Atrativos") }}</h6>
                        <p class="text-muted small mb-0">{{ __("Gerencie os atrativos turísticos") }}</p>
                    </div>
                </div>
            </a>
        </div>

    </div>
</div>