<?php $__env->startSection('title', env('APP_NAME') . ' :: Página inicial'); ?>
<?php $__env->startSection('content'); ?>
<section class="home-noticias bg-waves">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.headlineNoticias', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

<section class="home-banners-1">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.homebanners1', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

<section class="home-links-institucionais">
    <div class="container mx-auto px-4 ">
        <?php echo $__env->make('paginas.partsHome.linksInstitucionais', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

    <section class="home-banners-2">
        <div class="container">
            <?php echo $__env->make('paginas.partsHome.homebanners2', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </section>

    <section class="home-guia-rapido">
        <div class="container">
            <?php echo $__env->make('paginas.partsHome.comoPodemosAjudar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </section>

    <section class="home-banners-3">
        <div class="container">
            <?php echo $__env->make('paginas.partsHome.homebanners3', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </section>

<!-- Seção: Destaques de Redes Sociais -->
<section class="home-redes-sociais bg-waves-blue">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.redesSociais', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

<!-- Seção: Tópicos mais Buscados -->
<section class="home-mais-buscados">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.topicoMaisBuscados', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

<!-- Seção: Tópicos mais Buscados 
<section class="home-VideoInstitucional">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.home-VideoInstitucional', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>
-->

<!-- Seção: Galeria de Fotos -->
<section class="home-galeria-fotos bg-waves">
    <div class="container-full">
        <?php echo $__env->make('paginas.partsHome.galeriaDeFotos', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>

<!-- Seção: Pontos Turísticos -->
<section class="home-pontos-turisticos">
    <div class="container">
        <?php echo $__env->make('paginas.partsHome.pontosTuristicos', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
</section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/home.blade.php ENDPATH**/ ?>