<?php $__currentLoopData = $linhasHorarios; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $lh): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
<tr>
    <td><span class="badge bg-primary"><?php echo e($lh->codigo); ?></span></td>
    <td><?php echo e($lh->nome); ?></td>
    <td class="text-center">
        <?php if($lh->tarifa): ?>
            R$ <?php echo e(number_format($lh->tarifa, 2, ',', '.')); ?>

        <?php else: ?>
            <span class="text-muted">-</span>
        <?php endif; ?>
    </td>
    <td class="text-center">
        <span class="badge bg-secondary"><?php echo e($lh->secoes_count); ?></span>
    </td>
    <td class="text-center">
        <?php if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_MOBIANGRA')['editar'] ?? false): ?>
        <div class="d-flex justify-content-center">
        <form class="m-0" action="<?php echo e(route('admin.mobiangra.horarios.linhas.status', $lh)); ?>" method="post">
            <?php echo csrf_field(); ?>
            <input type="hidden" name="tab" value="horarios">
            <button type="submit" class="btn btn-sm <?php echo e($lh->publicada ? 'btn-success' : 'btn-secondary'); ?>" title="<?php echo e($lh->publicada ? __('Publicada') : __('Oculta')); ?>">
                <i class="fa-solid <?php echo e($lh->publicada ? 'fa-eye' : 'fa-eye-slash'); ?>"></i>
            </button>
        </form>
        </div>
        <?php else: ?>
            <span class="badge <?php echo e($lh->publicada ? 'bg-success' : 'bg-secondary'); ?>">
                <?php echo e($lh->publicada ? __('Publicada') : __('Oculta')); ?>

            </span>
        <?php endif; ?>
    </td>
    <td class="text-center">
        <div class="d-flex justify-content-center align-items-center gap-2 flex-nowrap">
        <?php if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_MOBIANGRA')['editar'] ?? false): ?>
        <a href="<?php echo e(route('admin.mobiangra.horarios.linhas.edit', $lh)); ?>" class="btn btn-sm btn-outline-primary" title="<?php echo e(__('Editar')); ?>">
            <i class="fa-solid fa-pen"></i>
        </a>
        <?php endif; ?>
        <?php if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_MOBIANGRA')['excluir'] ?? false): ?>
        <form class="d-inline m-0" action="<?php echo e(route('admin.mobiangra.horarios.linhas.destroy', $lh)); ?>" method="post"
              onsubmit="return confirm('<?php echo e(__('Excluir a linha :cod e todos seus horários?', ['cod' => $lh->codigo])); ?>')">
            <?php echo csrf_field(); ?> <?php echo method_field('DELETE'); ?>
            <input type="hidden" name="tab" value="horarios">
            <button type="submit" class="btn btn-sm btn-outline-danger" title="<?php echo e(__('Excluir')); ?>">
                <i class="fa-solid fa-trash"></i>
            </button>
        </form>
        <?php endif; ?>
        </div>
    </td>
</tr>
<?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
<?php /**PATH /var/www/html/portal/resources/views/admin/mobiangra/horarios/_linhas_tbody.blade.php ENDPATH**/ ?>