@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar Unidade de Saúde")
@section('content')

    <form action="{{ route('admin.unidadesSaude.update', $unidade->id) }}" method="post" enctype="multipart/form-data">
        <div class="container">
            <div class="row">
                <div class="col-sm-12 col-md-6">
                    <div class="card shadow">
                        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center mb-3">
                            <h5 class="my-2">Editar Unidade de Saúde</h5>    
                        </div>
                        <div class="card-body">
                            @csrf
                            @method('PUT')
                            @include("errors.messageFlash")

                            <div class="mb-3">
                                <label for="type" class="form-label text-bold">Pertence a: <span
                                class="span-admin-create">*</span></label>
                                <select class="form-control @error('structure_id') is-invalid @enderror" name="structure_id"
                                    id="structureID">
                                    @foreach($secretarias as $secretaria)
                                        <option value="{{ $secretaria->id }}" {{ old('structure_id', $unidade->structure_id ?? '') == $secretaria->id ? 'selected' : '' }}>
                                            {{ $secretaria->name }} ({{ $secretaria->abbreviation }})
                                        </option>
                                    @endforeach
                                </select>
                                @error('structure_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                            <hr />
                            <div class="mb-3">
                                <label for="type" class="form-label text-bold">Tipo de unidade: <span
                                class="span-admin-create">*</span></label>
                                <select class="form-control" name="tipoUnidadeSaude" id="tipoUnidadeSaude">
                                    <option value="CEM" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'CEM' ? 'selected' : '' }}>CEM</option>
                                    <option value="CEREST BIG" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'CEREST BIG' ? 'selected' : '' }}>CEREST BIG</option>
                                    <option value="Centro de Reabilitação" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Centro de Reabilitação' ? 'selected' : '' }}>Centro de Reabilitação</option>
                                    <option value="Clínica" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Clínica' ? 'selected' : '' }}>Clínica</option>
                                    <option value="Coordenação de Centro Odontológico" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Coordenação de Centro Odontológico' ? 'selected' : '' }}>Coordenação de Centro Odontológico</option>
                                    <option value="COVSA" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'COVSA' ? 'selected' : '' }}>COVSA</option>
                                    <option value="CVEPI" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'CVEPI' ? 'selected' : '' }}>CVEPI</option>
                                    <option value="ESF" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'ESF' ? 'selected' : '' }}>ESF</option>
                                    <option value="HMJ" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'HMJ' ? 'selected' : '' }}>HMJ</option>
                                    <option value="Imunização" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Imunização' ? 'selected' : '' }}>Imunização</option>
                                    <option value="NASF" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'NASF' ? 'selected' : '' }}>Nasf</option>
                                    <option value="Programa Melhor em Casa" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Programa Melhor em Casa' ? 'selected' : '' }}>Programa Melhor em Casa</option>
                                    <option value="Sala Lilas" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Sala Lilas' ? 'selected' : '' }}>Sala Lilas</option>
                                    <option value="SAMU" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'SAMU' ? 'selected' : '' }}>SAMU</option>
                                    <option value="SPA" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'SPA' ? 'selected' : '' }}>Creche</option>
                                    <option value="UPA" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'UPA' ? 'selected' : '' }}>UPA</option>
                                    <option value="Vigilância Ambiental" {{ old('tipoUnidadeSaude', $unidade->tipoUnidadeSaude ?? '') == 'Vigilância Ambiental' ? 'selected' : '' }}>Vigilância Ambiental</option>

                                </select>
                            </div>
                            <hr />

                            <div class="mb-3">
                                <label for="foto" class="form-label text-bold">Foto da unidade:</label>
                                <input type="file" class="form-control" name="foto" id="foto"
                                   accept="image/jpeg,image/jpg,image/png,image/gif" />
                            </div>
                            <hr />

                            <div class="mb-3">
                                <label for="nome" class="form-label text-bold">Nome da unidade de saúde: <span
                                class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('nome') is-invalid @enderror" name="nome"
                                   id="nome" autocomplete="off" value="{{ old('nome', $unidade->nome) }}">
                                @error('nome')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="telefone" class="form-label text-bold">Telefone:</label>
                                <input type="text" class="form-control @error('telefone') is-invalid @enderror"
                                   name="telefone" id="telefone" autocomplete="off"
                                   value="{{ old('telefone', $unidade->telefone) }}">
                                @error('telefone')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="email" class="form-label text-bold">Email:</label>
                                <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" id="email" autocomplete="off" value="{{ old('email', $unidade->email) }}">
                                @error('email')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            <div class="mb-3">
                                <label for="domicilio" class="form-label text-bold">Tipo de imóvel: <span
                                class="span-admin-create">*</span></label>
                                <select class="form-control @error('domicilio') is-invalid @enderror" name="domicilio"
                                    id="domicilio">
                                    @foreach(App\Enums\StatusDomicilio::cases() as $status)
                                        <option value="{{ $status->name }}" {{ old('domicilio', $unidade->endereco->domicilio ?? '') == $status->name ? 'selected' : '' }}>
                                            {{ $status->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('domicilio')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="cep" class="form-label">CEP <span class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('cep') is-invalid @enderror" name="cep"
                                   id="zipCode" oninput="aplicarMascaraCEP(this)" autocomplete="off"
                                   value="{{ old('cep', $unidade->endereco->cep) }}" required>
                                @error('cep')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="logradouro" class="form-label">Logradouro <span
                                class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('logradouro') is-invalid @enderror"
                                   name="logradouro" id="street" autocomplete="off"
                                   value="{{ old('logradouro', $unidade->endereco->logradouro) }}">
                                @error('logradouro')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="numero" class="form-label">Número</label>
                                <input type="text" class="form-control @error('numero') is-invalid @enderror" name="numero"
                                   id="numero" value="{{ old('numero', $unidade->endereco->numero) }}">
                                @error('numero')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="complemento" class="form-label">Complemento</label>
                                <input type="text" class="form-control" name="complemento" id="complemento"
                                   value="{{ old('complemento', $unidade->endereco->complemento) }}">
                            </div>
                            <div class="mb-3">
                                <label for="cidade" class="form-label">Cidade <span
                                class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('cidade') is-invalid @enderror" name="cidade"
                                   id="city" autocomplete="off" value="{{ old('cidade', $unidade->endereco->cidade) }}">
                                @error('cidade')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="bairro" class="form-label">Bairro <span
                                class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('bairro') is-invalid @enderror" name="bairro"
                                   id="neighborhood" autocomplete="off"
                                   value="{{ old('bairro', $unidade->endereco->bairro) }}">
                                @error('bairro')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="uf" class="form-label">UF <span class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('uf') is-invalid @enderror" name="uf"
                                   id="state" maxlength="2" autocomplete="off"
                                   value="{{ old('uf', $unidade->endereco->uf) }}">
                                @error('uf')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="latitude" class="form-label">Latitude </label>
                                <input type="text" class="form-control @error('latitude') is-invalid @enderror" name="latitude" id="latitude" value="{{ old('latitude', $unidade->endereco->latitude) }}" autocomplete="off">
                                @error('latitude')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="longitude" class="form-label">Longitude </label>
                                <input type="text" class="form-control @error('longitude') is-invalid @enderror" name="longitude" id="longitude" value="{{ old('longitude', $unidade->endereco->longitude) }}" autocomplete="off">
                                @error('longitude')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="informacoes" class="form-label text-bold">Informações:</label>
                                <textarea class="form-control textarea-body @error('informacoes') is-invalid @enderror"
                                      style="height: 400px" name="informacoes"
                                    id="informacoes">{{ old('informacoes', $unidade->informacoes) }}</textarea>
                                @error('informacoes')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <div class="mb-3">
                                <label for="status" class="form-label text-bold">Status: <span
                                class="span-admin-create">*</span></label>
                                <select class="form-control @error('status') is-invalid @enderror" name="status"
                                    id="status">
                                    @foreach(App\Enums\StatusEnum::cases() as $status)
                                        <option value="{{ $status->name }}" {{ old('status', $unidade->status) === $status->name ? 'selected' : '' }}>
                                            {{ $status->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('status')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            @include('components.buttons._backAndSend', [
                                    'textBack' => 'Voltar', 
                                    'textSend' => 'Atualizar', 
                                    'routeBack' => 'admin.escolas.index'
                                ]
                            )
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </form>

@endsection