{{-- Persiste filtros de listagem em formulários do módulo Empresas --}}
@php $filterParams = $filterParams ?? []; @endphp
@if(!empty($filterParams['q']))
    <input type="hidden" name="q" value="{{ $filterParams['q'] }}">
@endif
@if(!empty($filterParams['page']))
    <input type="hidden" name="page" value="{{ $filterParams['page'] }}">
@endif
