<!-- Basic features section-->
<section id="capacitacao">
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 p-3 text-center">
                <h1>Capacitação Sei</h1>
            </div>
        </div>
    </div>

    <div class="container px-3 px-md-5">
        <div class="row justify-content-center gx-2 gy-3">

            <!-- Card 0 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/manual-boas-praticas-sei.png') }}"
                        alt="Capa do Manual de Boas Práticas do SEI">
                    <div class="card-body px-2 py-3">
                        <div class="badge-novo">NOVIDADE</div>
                        <h5 class="card-title">Manual de Boas Práticas do SEI</h5>
                        <p class="card-text">Guia de uso do sistema, com foco na responsabilidade do usuário na classificação, preenchimento e tramitação.</p>
                    </div>
                    <div class="card-footer">
                        <a href="{{ asset('sei-angra/assets/docs/manual-de-boas-praticas-do-sei.pdf') }}" target="_blank"
                            class="btn btn-primary w-100">Ver PDF</a>
                    </div>
                </div>
            </div>

            <!-- Card 1 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/wiki-5.0.jpg') }}"
                        alt="Wiki Sei RJ">
                    <div class="card-body px-2 py-3">
                        <div class="badge-novo">NOVIDADE</div>
                        <h5 class="card-title">Conheça a Versão 5.0 do SEI-RJ</h5>
                        <p class="card-text">Página WIKI SEI-RJ com todas as novas funcionalidades da versão 5.0 do sistema SEI-RJ.</p>
                    </div>
                    <div class="card-footer">
                        <a href="https://wikisei.rj.gov.br/SEI_versão_5.0"
                            class="btn btn-primary w-100" target="_blank">Acessar</a>
                    </div>
                </div>
            </div>


            <!-- Card 2 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/SEI-USAR.jpg') }}"
                        alt="Curso Livre Sei">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Curso Livre - SEI! USAR (ENAP)</h5>
                        <p class="card-text">Curso online gratuito, oferecido pela Escola Nacional de Administração
                            Pública (ENAP).</p>
                    </div>
                    <div class="card-footer">
                        <a href="https://www.escolavirtual.gov.br/curso/74" target="_blank"
                            class="btn btn-primary w-100">Fazer Curso</a>
                    </div>
                </div>
            </div>

            <!-- Card 3 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/videoaulas.jpg') }}"
                        alt="Videoaulas - SEI Angra dos Reis">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Videoaulas - SEI 4.1</h5>
                        <p class="card-text">Treinamento em vídeos sobre o SEI de Angra dos Reis.</p>
                    </div>
                    <div class="card-footer">
                        <a href="{{ route('sei.videoaulas') }}" target="_blank"
                            class="btn btn-primary w-100">Assistir</a>
                    </div>
                </div>
            </div>

            <!-- Card 4 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/lives.jpg') }}"
                        alt="Treinamento Sei Angra dos Reis">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Lives de Treinamento do SEI 4.1</h5>
                        <p class="card-text">Treinamento sobre o SEI Angra, que ocorreu nos dias 08 e 09 de janeiro.</p>
                    </div>
                    <div class="card-footer">
                        <a href="{{ route('sei.lives') }}" class="btn btn-primary w-100">Assistir</a>
                    </div>
                </div>
            </div>

            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/wiki.jpg') }}"
                        alt="Wiki Sei RJ">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Wiki SEI-RJ</h5>
                        <p class="card-text">Todas as informações sobre o funcionamento do sistema, como manuais, FAQs e
                            POP's.</p>
                    </div>
                    <div class="card-footer">
                        <a href="https://wikisei.rj.gov.br"
                            class="btn btn-primary w-100" target="_blank">Acessar</a>
                    </div>
                </div>
            </div>

            <!-- Card 5 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/sei-pdf.png') }}"
                        alt="Guia Básico do SEI em PDF">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Guia Básico do SEI 4.1 em .PDF</h5>
                        <p class="card-text">Baixe o material oficial de apoio ao Curso Básico do SEI para estudo
                            offline.</p>
                    </div>
                    <div class="card-footer">
                        <a href="{{ asset('sei-angra/assets/docs/Curso_Basico_do_SEI.pdf') }}" target="_blank"
                            class="btn btn-primary w-100">Ver PDF</a>
                    </div>
                </div>
            </div>

            <!-- Card 6 -->
            <div class="col-12 col-sm-6 col-md-6 col-lg-4 d-flex justify-content-center mb-5">
                <div class="card border-0 shadow h-100" style="width: 100%; max-width: 18rem;">
                    <img class="card-img-top img-fluid" src="{{ asset('sei-angra/assets/img/manual.jpg') }}"
                        alt="Treinamento Sei Angra dos Reis">
                    <div class="card-body px-2 py-3">
                        <h5 class="card-title">Manual do Usuário Externo do SEI</h5>
                        <p class="card-text">Destinado aos Munícipes e Representantes de Empresas.</p>
                    </div>
                    <div class="card-footer">
                        <a href="{{ route('sei.manual') }}" class="btn btn-primary w-100">Acessar</a>
                    </div>
                </div>
            </div>

        </div>
    </div>
</section>
