<h3>{{ __('Configurações') }}</h3>

<div class="mb-4">
    <h5 class="text-muted border-bottom pb-2 mb-3">
        <i class="fa-solid fa-file-contract me-1"></i> {{ __('Módulo de Contratos') }}
    </h5>

    <div class="card border bg-light">
        <div class="card-body">
            <div class="d-flex align-items-start justify-content-between gap-3">
                <div>
                    <label for="contratos_acesso_global" class="form-label text-bold mb-1">
                        {{ __('Permitir acesso a todos os contratos') }}
                    </label>
                    <p class="text-muted small mb-0">
                        {{ __('Quando ativado, usuários vinculados a esta Secretaria poderão visualizar, criar, editar e excluir contratos de qualquer Secretaria do sistema.') }}
                    </p>
                    <p class="text-muted small mb-0 mt-1">
                        {{ __('Quando desativado, os usuários terão acesso somente aos contratos pertencentes à própria Secretaria.') }}
                    </p>
                </div>
                <div class="form-check form-switch mt-1 flex-shrink-0">
                    <input
                        class="form-check-input form-check-input-lg"
                        type="checkbox"
                        role="switch"
                        name="contratos_acesso_global"
                        id="contratos_acesso_global"
                        value="1"
                        {{ old('contratos_acesso_global') ? 'checked' : '' }}
                    >
                </div>
            </div>
        </div>
    </div>

    @error('contratos_acesso_global')
        <small class="text-danger text-bold d-block mt-1">{{ $message }}</small>
    @enderror
</div>
