<div class="card mb-3 w-100">
    <div class="card-body">
        <h6 class="card-subtitle mb-2 text-body-secondary">
            @if (auth()->user()->getPermissaoDetalhes("GERENCIADOR_DE_SECRETARIAS")['adicionar'])
                @include('components.buttons._newButton', [
                    'url' => 'admin.secretarias.create', 'text' => 'Novo Órgão'
                ])
            @endif
        </h6>
        <div class="table-responsive">
            <table class="table table-bordered table-hover table-striped align-middle text-center">
                <thead class="table-light">
                    @include('admin.secretarias.sections.headTable')
                </thead>
                @php $index = 0; @endphp
                @foreach($secretarias as $secretaria)
                    @include('admin.secretarias.sections.table')
                    @php $index++; @endphp
                @endforeach
            </table>
        </div>
    </div>
</div>