@props(['value', 'label', 'icon', 'iconBg' => 'bg-primary'])

<div class="stat-item">
    <div class="stat-icon {{ $iconBg }}">
        <i class="{{ $icon }}"></i>
    </div>
    <div class="stat-content">
        <h3 class="stat-value">{{ number_format((int) $value, 0, ',', '.') }}</h3>
        <p class="stat-label">{{ __($label) }}</p>
    </div>
</div>

