<ul class="list-group">
    <li class="list-group-item"><h4>Serviços</h4></li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.dashboard") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.dashboard") text-white @else text-dark @endif" href="{{ route("admin.dashboard") }}">{{ __("Dashboard") }}</a>
    </li>
    @if(auth()->user()->permission == "SYSADMIN")
        <li class="list-group-item @if(Route::currentRouteName() == "admin.contas.index") active @endif">
            <a class="text-decoration-none @if(Route::currentRouteName() == "admin.contas.index") text-white @else text-dark @endif" href="{{ route("admin.contas.index") }}">{{ __("Usuários") }}</a>
        </li>
        <li class="list-group-item @if(Route::currentRouteName() == "admin.contas.create") active @endif">
            <a class="text-decoration-none @if(Route::currentRouteName() == "admin.contas.create") text-white @else text-dark @endif" href="{{ route("admin.contas.create") }}">{{ __("Novo Usuário") }}</a>
        </li>
        <li class="list-group-item @if(Route::currentRouteName() == "admin.secretarias.index" || Route::currentRouteName() == "admin.secretarias.edit" || Route::currentRouteName() == "admin.telefones.index" || Route::currentRouteName() == "admin.telefones.index" || Route::currentRouteName() == "admin.links.index") active @endif">
            <a class="text-decoration-none @if(Route::currentRouteName() == "admin.secretarias.index" || Route::currentRouteName() == "admin.secretarias.edit" || Route::currentRouteName() == "admin.telefones.index" || Route::currentRouteName() == "admin.telefones.index" || Route::currentRouteName() == "admin.links.index") text-white @else text-dark @endif" href="{{ route("admin.secretarias.index") }}">{{ __("Secretarias") }}</a>
        </li>
        <li class="list-group-item @if(Route::currentRouteName() == "admin.secretarias.create") active @endif">
            <a class="text-decoration-none @if(Route::currentRouteName() == "admin.secretarias.create") text-white @else text-dark @endif" href="{{ route("admin.secretarias.create") }}">{{ __("Nova Secretaria") }}</a>
        </li>
    @endif
    <li class="list-group-item @if(Route::currentRouteName() == "admin.noticias.index" || Route::currentRouteName() == "admin.noticias.edit") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.noticias.index" || Route::currentRouteName() == "admin.noticias.edit") text-white @else text-dark @endif" href="{{ route("admin.noticias.index") }}">{{ __("Notícias") }}</a>
    </li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.noticias.create") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.noticias.create") text-white @else text-dark @endif" href="{{ route("admin.noticias.create") }}">{{ __("Nova Notícia") }}</a>
    </li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.profile") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.profile") text-white @else text-dark @endif" href="{{ route("admin.profile") }}">{{ __("Perfil") }}</a>
    </li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.password") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.password") text-white @else text-dark @endif" href="{{ route("admin.password") }}">{{ __("Alterar Senha") }}</a>
    </li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.photo") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.photo") text-white @else text-dark @endif" href="{{ route("admin.photo") }}">{{ __("Alterar Foto") }}</a>
    </li>
    <li class="list-group-item @if(Route::currentRouteName() == "admin.logout") active @endif">
        <a class="text-decoration-none @if(Route::currentRouteName() == "admin.logout") text-white @else text-dark @endif" href="{{ route("admin.logout") }}">{{ __("Sair") }}</a>
    </li>
</ul>