@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Abrir recurso administrativo'))
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-gavel'></i> " . __('Recurso Administrativo – Credenciamento Artístico'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => ($perfil ?? false) ? route('admin.cultura.credenciamentoMusicos.perfil.chamados.index', $musico) : route('admin.cultura.credenciamentoMusicos.chamados.index', $musico),
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'permission' => null,
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            @if(!$temReprovacao)
                <div class="alert alert-info">
                    {{ __('O recurso administrativo é destinado a casos de reprovação (documental ou na avaliação artística). Se ainda não houve reprovação, utilize o canal de Chamados gerais para outras dúvidas.') }}
                </div>
            @endif
            <p>{{ __('Ao clicar em "Abrir chamado", você será redirecionado para o formulário de atendimento com o assunto "Recurso Administrativo – Credenciamento Artístico" já preenchido. O chamado ficará vinculado a este credenciamento.') }}</p>
            <form action="{{ ($perfil ?? false) ? route('admin.cultura.credenciamentoMusicos.perfil.chamados.store', $musico) : route('admin.cultura.credenciamentoMusicos.chamados.store', $musico) }}" method="post">
                @csrf
                <button type="submit" class="btn btn-primary">{{ __('Abrir chamado') }}</button>
            </form>
        </div>
    </div>
@endsection
