@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Fale conosco")
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <div class="col-5">
                    <div class="col-12">
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route("paginas.home") }}">Portal</a>
                                </li>
                                <li class="breadcrumb-item active" aria-current="page">Fale conosco</li>
                            </ol>
                        </nav>
                    </div>
                    <h1>Fale conosco</h1>
                    <hr/>
                    <article>
                        <h3>{{ __("Prefeitura de Angra dos Reis") }}</h3>
                        <div>
                        <address>
                            <ul>
                                <li>Praça Nilo Peçanha, 186</li>
                                <li>Centro - Angra dos Reis/RJ</li>
                                <li><strong>CEP:</strong> 23900-901</li>
                                <li><hr/></li>
                                <li><strong>Telefones:</strong> (24) 3377-8311</li>
                                <li><strong>E-mail:</strong> ouvidoria@angra.rj.gov.br</li>
                                <li><strong>Horário de Funcionamento:</strong> 8h30 às 17hs</li>
                                <li><strong>Horário de Atendimento:</strong> 9h30 às 16hs</li>
                            </ul>
                        </address>
                    </div>
                </article>
            </div>
            <div class="col-7 mt-3">

                <div class="card">
                    <img src="{{ asset("pmar/assets/img/noticias/70447_D.jpg") }}" class="card-img-top" alt="{{ __("Prefeitura de Angra dos Reis") }}">
                    <div class="card-body">
                        <form action="" method="post" enctype="multipart/form-data">
                            @csrf
                            @if (session('success'))
                                <div class="alert alert-success">{{ session('success') }}</div>
                            @endif
                            @if (session('error'))
                                <div class="alert alert-danger">{{ session('error') }}</div>
                            @endif
                            <div class="mb-3">
                                <label class="form-label text-bold">* Seu nome</label>
                                <input type="text" class="form-control @error('name') is-invalid @enderror" name="name" id="name" value="{{ old('name') }}">
                                @error('name')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label class="form-label text-bold">* Seu email</label>
                                <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" id="email" value="{{ old('email') }}">
                                @error('email')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label class="form-label text-bold">* Seu número de telefone</label>
                                <input type="tel" class="form-control @error('phone') is-invalid @enderror" name="phone" id="phone" value="{{ old('phone') }}">
                                @error('phone')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label class="form-label text-bold">* Assunto</label>
                                <input type="text" class="form-control @error('subject') is-invalid @enderror" name="subject" id="subject" value="{{ old('subject') }}">
                                @error('subject')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3 text-wrap">
                                <label class="form-label text-bold">* Mensagem</label>
                                <textarea class="form-control textarea-comments @error('message') is-invalid @enderror" name="message" id="message">{{ old('message') }}</textarea>
                                @error('message')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <button class="btn btn-lg btn-primary">Enviar</button>
                            </div>
                        </form>
                    </div>
                </div>


            </div>

        </div>
    </div>
    </section>
    <section class="py-3">
        <div class="container-fluid m-0 p-0">
            <div class="row">
                <div class="col-12">
                <iframe
                    width="100%"
                    height="250"
                    frameborder="0" style="border:0"
                    referrerpolicy="no-referrer-when-downgrade"
                    src="https://www.google.com/maps/d/embed?mid=1hzQkXGvMdE607zSWKhcyr9KSmtE&ehbc=2E312F"
                    allowfullscreen>
                </iframe>
            </div>
        </div>
    </div>
    </section>
@endsection
