@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Castração Animal - Lista de Tutores')

@section('content')

<div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-paw'></i> Castração Animal - Lista de Tutores"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
//            'routeBack' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
//            'routeBackParams' => [],
//            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.meioAmbiente.castracaoAnimal.verify',
            'routeAddParams' => [],
            'nameAdd' => __('Novo tutor'),
            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
            "tabs" => [
                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.caes', 'class' => 'fa-solid fa-dog', 'label' => 'Lista de cães', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.gatos', 'class' => 'fa-solid fa-cat', 'label' => 'Lista de gatos', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
            ],
        ])
        
        <div class="card-body">
            
            @include("errors.messageFlash")
            
            <div class="mb-3">
                <span class="badge bg-primary fs-6">
                    <i class="fa-solid fa-users me-1"></i>
                    {{ __('Total de tutores') }}: <strong>{{ number_format($totalTutores, 0, ',', '.') }}</strong>
            </span>
            

            @include('components/forms/_filtroPesquisaDefault', [
                    "id" => "cadastroDeUsuario",
                    "placeholder" => "Pesquisar tutor por nome, CPF, e-mail, telefone..."
                ])

            <div>
                    
                <x-tables._table :thead="['#','Criado em','Usuário','CPF', 'Tipo', 'E-mail','Status','Ações']" :pagination="$tutores->links()">
                    <x-slot name="body">
                        @php $index = 0; @endphp
                            @foreach($tutores as $tutor)
                            <tr>
                                <td style="width:150px">
                                    @include('components.tables._openPhoto', [
                                        'asset' => $tutor->user->photo,
                                        'alt' => $tutor->user->name,
                                        'title' => $tutor->user->name,
                                        'text' => 'Visualizar foto',
                                    ])
                                </td>
                                <td>{{ date("d/m/Y H:i", strtotime($tutor->user->created_at)) }}</td>
                                <td>
                                    {{ $tutor->user->name }}
                                </td>
                                <td>{{ $tutor->user->cpf }}</td>
                                <td class="text-start">
                                    <div>
                                        <strong>Cadastro:</strong>
                                        <span class="badge bg-warning text-dark">{{ $tutor->tipo_tutor_label }}</span>
                                    </div>
                                </td>
                                <td>{{ $tutor->user->email }}</td>
                                <td class="text-center align-middle">
                                    @include('components.buttons._status', [
                                        "index" => $index,
                                        "route" => "admin.meioAmbiente.castracaoAnimal.tutores.status",
                                        "id" => $tutor->id,
                                        "status" => $tutor->status,
                                        "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                    ])
                                </td>
                                <td>
                                    <div class="d-flex gap-2 justify-content-center">
                                        
                                        @include('components.buttons._editButton', [
                                            "route" => "admin.meioAmbiente.castracaoAnimal.tutores.edit",
                                            "id" => $tutor->id,
                                            "title" => "Editar",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                        @include('components.buttons._deleteButton', [
                                            "message" => __("* Este tutor será excluído e esta ação não poderá ser desfeita, deseja continuar?"),
                                            "route" => "admin.meioAmbiente.castracaoAnimal.tutores.destroy",
                                            "id" => $tutor->id,
                                            "title" => "Excluir",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                        @include('components.buttons._navButton', [
                                            "route" => "admin.meioAmbiente.castracaoAnimal.animais.index",
                                            "id" => $tutor->id,
                                            "fontawesome" => '<i class="fa-solid fa-list" data-bs-toggle="tooltip" title="Gerenciar Endereços"></i>',
                                            "title" => "Lista de animais",
                                        ])

                                        @include('components.buttons._navButton', [
                                            "route" => "admin.meioAmbiente.castracaoAnimal.animais.create",
                                            "id" => $tutor->id,
                                            "fontawesome" => '<i class="fa-solid fa-paw" data-bs-toggle="tooltip" title="Gerenciar Endereços"></i>',
                                            "title" => "Novo animal",
                                        ])
                                        
                                    </div>

                                </td>
                            </tr>
                            @php $index++; @endphp
                        @endforeach
                    </x-slot>
                </x-tables._table>  
            </div>
        </div>
    </div>
</div>
@endsection