@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Arte Sacra - Nova Arte Sacra')

@section('content')
    <div class="card border-0 shadow-sm">
        @php $headLine = "<i class='fa-solid fa-church'></i> Arte Sacra - Nova Arte Sacra"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            "headLine" => __($headLine),
            "routeBack" => "admin.cultura.arteSacra.index",
            "routeBackParams" => [],
            "fontawesomeBack" => '<i class="fa-solid fa-rectangle-list"></i>',
            "nameBack" => __("Lista de Peças"),
            "routeAdd" => "admin.cultura.arteSacra.create",
            "routeAddParams" => [],
            "nameAdd" => __("Nova peça"),
            "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
            "tabs" => [
                [
                    'route' => 'admin.cultura.arteSacra.options', 
                    'class' => 'fa-list', 
                    'label' => 'Edição de Opções', 
                    'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA',
                ],
                [
                    'route' => 'admin.cultura.arteSacra.report', 
                    'class' => 'fa-list-check', 
                    'label' => 'Relatório Geral', 
                    'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA',
                ],
                [
                    'route' => 'admin.cultura.arteSacra.trash', 
                    'class' => 'fa-trash', 
                    'label' => 'Lixeira', 
                    'permission' => 'DIRETOR_DE_ARTE_SACRA',
                ],
                [
                    'route' => 'admin.cultura.arteSacra.logs.usuarios', 
                    'class' => 'fa-user-secret', 
                    'label' => 'Logs de Usuários', 
                    'permission' => 'DIRETOR_DE_ARTE_SACRA',
                ],
            ],
        ])

        @include('errors.messageFlash')

        <form action="{{ route('admin.cultura.arteSacra.store') }}" method="POST" enctype="multipart/form-data"
            class="needs-validation" novalidate>
            <div class="card-body">
                @csrf

                <!-- Seção 1: Identificação e Classificação -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-tag text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Identificação e Classificação</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-floating">
                                <input type="text" class="form-control @error('codigo_acervo') is-invalid @enderror"
                                    name="codigo_acervo" id="codigo_acervo" value="{{ old('codigo_acervo') }}"
                                    placeholder=" " required>
                                <label for="codigo_acervo" class="fw-semibold small">
                                    <i class="fas fa-barcode me-1 text-muted"></i> Código Acervo <span
                                        class="text-danger">*</span>
                                </label>
                                @error('codigo_acervo')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-8">
                            <div class="form-floating">
                                <input type="text" name="nome_peca" id="nome_peca"
                                    class="form-control @error('nome_peca') is-invalid @enderror"
                                    value="{{ old('nome_peca') }}" placeholder=" " required>
                                <label for="nome_peca" class="fw-semibold small">
                                    <i class="fas fa-heading me-1 text-muted"></i> Nome da Peça <span
                                        class="text-danger">*</span>
                                </label>
                                @error('nome_peca')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>

                    <div class="row mt-3">
                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="tipo_id" id="tipo_id"
                                    class="form-select @error('tipo_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($tipos as $id => $tipo)
                                        <option value="{{ $id }}" {{ old('tipo_id') == $id ? 'selected' : '' }}>
                                            {{ $tipo }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="tipo_id" class="fw-semibold small">
                                    <i class="fas fa-shapes me-1 text-muted"></i> Tipo
                                </label>
                                @error('tipo_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="classe_id" id="classe_id"
                                    class="form-select @error('classe_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($classes as $id => $classe)
                                        <option value="{{ $id }}"
                                            {{ old('classe_id') == $id ? 'selected' : '' }}>
                                            {{ $classe }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="classe_id" class="fw-semibold small">
                                    <i class="fas fa-layer-group me-1 text-muted"></i> Classe
                                </label>
                                @error('classe_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="designacao_id" id="designacao_id"
                                    class="form-select @error('designacao_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($designacoes as $id => $designacao)
                                        <option value="{{ $id }}"
                                            {{ old('designacao_id') == $id ? 'selected' : '' }}>
                                            {{ $designacao }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="designacao_id" class="fw-semibold small">
                                    <i class="fas fa-cross me-1 text-muted"></i> Uso
                                </label>
                                @error('designacao_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Seção 2: Origem e Autoria -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-history text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Origem e Autoria</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating">
                                <input type="text" class="form-control @error('autoria') is-invalid @enderror"
                                    name="autoria" id="autoria" value="{{ old('autoria') }}" placeholder=" ">
                                <label for="autoria" class="fw-semibold small">
                                    <i class="fas fa-signature me-1 text-muted"></i> Autoria
                                </label>
                                @error('autoria')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-3">
                            <div class="form-floating">
                                <input type="number" name="ano_arte" id="ano_arte"
                                    class="form-control @error('ano_arte') is-invalid @enderror"
                                    value="{{ old('ano_arte') }}" min="1000" max="{{ date('Y') }}"
                                    placeholder=" ">
                                <label for="ano_arte" class="fw-semibold small">
                                    <i class="fas fa-calendar-alt me-1 text-muted"></i> Ano da Peça
                                </label>
                                @error('ano_arte')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-3">
                            <div class="form-floating">
                                <input type="text" class="form-control @error('periodo_peca') is-invalid @enderror"
                                    name="periodo_peca" id="periodo_peca" value="{{ old('periodo_peca') }}"
                                    placeholder=" ">
                                <label for="periodo_peca" class="fw-semibold small">
                                    <i class="fas fa-hourglass-half me-1 text-muted"></i> Período da Peça
                                </label>
                                @error('periodo_peca')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>

                    <div class="row mt-3">
                        <div class="col-md-6">
                            <div class="form-floating">
                                <select name="modo_aquisicao_id" id="modo_aquisicao_id"
                                    class="form-select @error('modo_aquisicao_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($modosAquisicao as $id => $modo)
                                        <option value="{{ $id }}"
                                            {{ old('modo_aquisicao_id') == $id ? 'selected' : '' }}>
                                            {{ $modo }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="modo_aquisicao_id" class="fw-semibold small">
                                    <i class="fas fa-hand-holding-usd me-1 text-muted"></i> Modo de Aquisição
                                </label>
                                @error('modo_aquisicao_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-6">
                            <div class="form-floating">
                                <select name="permitir_exibicao" id="permitir_exibicao"
                                    class="form-select @error('permitir_exibicao') is-invalid @enderror" required>
                                    <option value=""></option>
                                    @foreach (\App\Enums\ExpoArteSacra::cases() as $option)
                                        <option value="{{ $option->value }}"
                                            {{ old('permitir_exibicao') === $option->value ? 'selected' : '' }}>
                                            {{ $option->value }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="permitir_exibicao" class="fw-semibold small">
                                    <i class="fas fa-eye me-1 text-muted"></i> Permitir exibição pública? <span
                                        class="text-danger">*</span>
                                </label>
                                @error('permitir_exibicao')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Seção 3: Características Físicas -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-ruler-combined text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Características Físicas</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="material_id" id="material_id"
                                    class="form-select @error('material_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($materiais as $id => $material)
                                        <option value="{{ $id }}"
                                            {{ old('material_id') == $id ? 'selected' : '' }}>
                                            {{ $material }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="material_id" class="fw-semibold small">
                                    <i class="fas fa-cubes me-1 text-muted"></i> Material
                                </label>
                                @error('material_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="tecnica_id" id="tecnica_id"
                                    class="form-select @error('tecnica_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($tecnicas as $id => $tecnica)
                                        <option value="{{ $id }}"
                                            {{ old('tecnica_id') == $id ? 'selected' : '' }}>
                                            {{ $tecnica }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="tecnica_id" class="fw-semibold small">
                                    <i class="fas fa-paint-brush me-1 text-muted"></i> Técnica
                                </label>
                                @error('tecnica_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="roca" id="roca"
                                    class="form-select @error('roca') is-invalid @enderror">
                                    <option value="0" {{ old('roca') == '0' ? 'selected' : '' }}>Não</option>
                                    <option value="1" {{ old('roca') == '1' ? 'selected' : '' }}>Sim</option>
                                </select>
                                <label for="roca" class="fw-semibold small">
                                    <i class="fas fa-archway me-1 text-muted"></i> Roca
                                </label>
                                @error('roca')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>

                    <div class="row mt-3">
                        <div class="col-md-4">
                            <div class="form-floating">
                                <select name="tombamento_id" id="tombamento_id"
                                    class="form-select @error('tombamento_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($tombamentos as $id => $tombamento)
                                        <option value="{{ $id }}"
                                            {{ old('tombamento_id') == $id ? 'selected' : '' }}>
                                            {{ $tombamento }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="tombamento_id" class="fw-semibold small">
                                    <i class="fas fa-landmark me-1 text-muted"></i> Tombamento
                                </label>
                                @error('tombamento_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Seção 4: Localização e Propriedade -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-map-marker-alt text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Localização e Propriedade</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating">
                                <select name="proprietario_id" id="proprietario_id"
                                    class="form-select @error('proprietario_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($proprietarios as $id => $proprietario)
                                        <option value="{{ $id }}"
                                            {{ old('proprietario_id') == $id ? 'selected' : '' }}>
                                            {{ $proprietario }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="proprietario_id" class="fw-semibold small">
                                    <i class="fas fa-user-tie me-1 text-muted"></i> Proprietário
                                </label>
                                @error('proprietario_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-6">
                            <div class="form-floating">
                                <select name="localizacao_id" id="localizacao_id"
                                    class="form-select @error('localizacao_id') is-invalid @enderror">
                                    <option value=""></option>
                                    @foreach ($proprietarios as $id => $proprietario)
                                        <option value="{{ $id }}"
                                            {{ old('localizacao_id') == $id ? 'selected' : '' }}>
                                            {{ $proprietario }}
                                        </option>
                                    @endforeach
                                </select>
                                <label for="localizacao_id" class="fw-semibold small">
                                    <i class="fas fa-location-arrow me-1 text-muted"></i> Localização
                                </label>
                                @error('localizacao_id')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Seção 5: Dimensões -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-ruler text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Dimensões</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="row">
                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('altura') is-invalid @enderror" name="altura"
                                    id="altura" value="{{ old('altura') }}" placeholder=" ">
                                <label for="altura" class="fw-semibold small">
                                    <i class="fas fa-arrows-alt-v me-1 text-muted"></i> Altura (cm)
                                </label>
                                @error('altura')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('largura') is-invalid @enderror" name="largura"
                                    id="largura" value="{{ old('largura') }}" placeholder=" ">
                                <label for="largura" class="fw-semibold small">
                                    <i class="fas fa-arrows-alt-h me-1 text-muted"></i> Largura (cm)
                                </label>
                                @error('largura')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('comprimento') is-invalid @enderror" name="comprimento"
                                    id="comprimento" value="{{ old('comprimento') }}" placeholder=" ">
                                <label for="comprimento" class="fw-semibold small">
                                    <i class="fas fa-ruler-horizontal me-1 text-muted"></i> Comprimento (cm)
                                </label>
                                @error('comprimento')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('diametro') is-invalid @enderror" name="diametro"
                                    id="diametro" value="{{ old('diametro') }}" placeholder=" ">
                                <label for="diametro" class="fw-semibold small">
                                    <i class="fas fa-circle-notch me-1 text-muted"></i> Diâmetro (cm)
                                </label>
                                @error('diametro')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('profundidade') is-invalid @enderror" name="profundidade"
                                    id="profundidade" value="{{ old('profundidade') }}" placeholder=" ">
                                <label for="profundidade" class="fw-semibold small">
                                    <i class="fas fa-box-open me-1 text-muted"></i> Profundidade (cm)
                                </label>
                                @error('profundidade')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-2">
                            <div class="form-floating">
                                <input type="number" step="0.01"
                                    class="form-control @error('peso') is-invalid @enderror" name="peso"
                                    id="peso" value="{{ old('peso') }}" placeholder=" ">
                                <label for="peso" class="fw-semibold small">
                                    <i class="fas fa-weight-hanging me-1 text-muted"></i> Peso (kg)
                                </label>
                                @error('peso')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Seção 6: Descrição -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-align-left text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Descrição</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="form-floating">
                        <textarea class="form-control @error('descricao') is-invalid @enderror" name="descricao" id="descricaoArte"
                            style="height: 400px !important">{{ old('descricao') }}</textarea>
                        <label for="descricaoArte" class="fw-semibold small" style="top: -14px;">
                            <i class="fas fa-file-alt me-1 text-muted"></i> Descrição detalhada
                        </label>
                        <div class="text-muted mt-1 text-end">
                            <small><span id="charCount">0</span> caracteres</small>
                        </div>
                        @error('descricao')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <!-- Seção 7: Mídia -->
                <div class="mb-4">
                    <div class="d-flex align-items-center mb-3">
                        <div class="bg-primary rounded-circle py-1 px-2 me-3">
                            <i class="fas fa-image text-white"></i>
                        </div>
                        <h5 class="mb-0 text-primary">Mídia</h5>
                    </div>
                    <hr class="mt-0 mb-4">

                    <div class="form-group">
                        <label for="imagem" class="form-label fw-semibold">
                            <i class="fas fa-camera me-1 text-muted"></i> Imagem da Peça
                        </label>
                        <div class="custom-file">
                            <input type="file" name="imagem" id="imagem"
                                class="form-control @error('imagem') is-invalid @enderror"
                                accept="image/jpeg, image/png, image/jpg">
                            <div class="form-text text-muted">Formatos aceitos: JPEG, PNG, JPG. Tamanho máximo: 2MB.
                            </div>
                            @error('imagem')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>
                </div>
            </div>

            <!-- Rodapé do Card -->
            <div class="card-footer bg-white border-top-0 py-3">
                <div class="d-flex justify-content-between">
                    <button type="reset" class="btn btn-outline-secondary">
                        <i class="fas fa-eraser me-2"></i> Limpar
                    </button>
                    <button type="submit" class="btn btn-primary px-4">
                        <i class="fas fa-save me-2"></i> Cadastrar Peça
                    </button>
                </div>
            </div>
        </form>
    </div>
@endsection