<?php $__env->startSection("title", env("APP_NAME") . " :: Departamentos de Finanças"); ?>
<?php $__env->startSection('content'); ?>
    <section class="py-5 bg-light">
        <div class="container">
            <div class="row">
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route("paginas.home")); ?>">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(url('/secretarias/secretaria-de-financas')); ?>"><?php echo e(__('Secretaria de Finanças (SFI)')); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Departamentos de Finanças</li>
                        </ol>
                    </nav>
                </div>

                <div class="col-12 mb-4">
                    <h1 class="mt-5 titulo-departamentos">Departamentos de Finanças - Angra dos Reis</h1>
                </div>

                <div class="col-12 mb-4">
                    <div class="card shadow-sm">
                        <div class="card-body">
                            <h3 class="card-title text-primary">Departamento de Tributos Mobiliário</h3>
                            <p><strong>Endereço:</strong><br> Praça Nilo Peçanha, nº 186, Centro, Angra dos Reis / RJ -
                                Cep.: 23.900.901</p>
                            <p><strong>E-mail:</strong><br>
                                <a href="mailto:sfi.corca@angra.rj.gov.br">sfi.corca@angra.rj.gov.br</a><br>
                                <a href="mailto:sfi.deate@angra.rj.gov.br">sfi.deate@angra.rj.gov.br</a>
                            </p>
                            <p><strong>Telefone:</strong><br> (24) 3365-3978 / (24) 3365-4259</p>
                            <p><strong>Horário de Funcionamento:</strong><br> 08:30 às 17:00h</p>
                            <p><strong>Horário de Atendimento ao Público:</strong><br> 09:00h às 16:00h</p>
                        </div>
                    </div>
                </div>

                <div class="col-12 mb-4">
                    <div class="card shadow-sm">
                        <div class="card-body">
                            <h3 class="card-title text-primary">Departamento de Tributos Imobiliário</h3>
                            <p><strong>Endereço:</strong><br> Praça Nilo Peçanha, nº 8 e 10, Centro, Angra dos Reis / RJ</p>
                            <p><strong>E-mail:</strong><br>
                                <a href="mailto:sfi.cavav@angra.rj.gov.br">sfi.cavav@angra.rj.gov.br</a><br>
                                <a href="mailto:sfi.gda@angra.rj.gov.br">sfi.gda@angra.rj.gov.br</a>
                            </p>
                            <p><strong>Telefone:</strong><br>
                                (24) 3377-7712 / (24) 3377-7702<br>
                                (24) 3377-7733 / (24) 3377-7753
                            </p>
                            <p><strong>Horário de Funcionamento:</strong><br> 08:30 às 17:00h</p>
                            <p><strong>Horário de Atendimento ao Público:</strong><br> 09:00h às 16:00h</p>
                        </div>
                    </div>
                </div>

                <div class="col-12 mb-4">
                    <div class="card shadow-sm">
                        <div class="card-body">
                            <h3 class="card-title text-primary">Departamento de Crédito Tributário</h3>
                            <p><strong>Endereço:</strong><br> Praça Nilo Peçanha, nº 186, Centro, Angra dos Reis / RJ -
                                Cep.: 23.900.901</p>
                            <p><strong>E-mail:</strong><br>
                                <a
                                    href="mailto:parcelamentocategoria@angra.rj.gov.br">parcelamentocategoria@angra.rj.gov.br</a>
                            </p>
                            <p><strong>Telefone:</strong><br> (24) 3377-8837</p>
                            <p><strong>WhatsApp:</strong><br> (24) 3365-6536</p>
                            <p><strong>Horário de Funcionamento:</strong><br> 08:30 às 17:00h</p>
                            <p><strong>Horário de Atendimento ao Público:</strong><br> 09:00h às 16:00h</p>
                        </div>
                    </div>
                </div>

            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/departamentos/sfi.blade.php ENDPATH**/ ?>