@extends('layouts.window.theme')
@section("title", env("APP_NAME") . " :: Redefinir Senha")
@section('content')

    <div class="container d-flex justify-content-center align-items-center min-vh-100">
        <div class="row w-100 justify-content-center">
            <div class="col-sm-12 col-md-8 col-lg-6">
                <div class="card shadow-lg">
                    <div class="card-header bg-primary text-white">
                        <h4 class="mb-0">Redefinir Senha</h4>
                    </div>
                    <div class="card-body">
                        <div class="text-center my-3">
                            <img src="{{ asset("pmar/assets/img/logo-pmar.svg") }}" class="card-img-top" title="{{ __("Prefeitura Municipal de Angra dos Reis") }}" alt="{{ __("Prefeitura Municipal de Angra dos Reis") }}" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                        </div>
                        <div class="mb-3">
                            <small class="text-primary">(*)Digite sua nova senha abaixo.</small>
                        </div>
                        @if (session('error'))
                            <div class="alert alert-danger">{{ session('error') }}</div>
                        @endif

                        @if (session('success'))
                            <div class="alert alert-success">{{ session('success') }}</div>
                        @endif

                        <form action="{{ route('paginas.castracao.redefinirSenha') }}" method="POST">
                            @csrf
                            <div class="mb-3">
                                <label for="password">Nova Senha:</label>
                                <input type="password" name="password" id="password" class="form-control" required>
                            </div>
                            <div class="mb-3">
                                <label for="password_confirmation">Confirme a Senha:</label>
                                <input type="password" name="password_confirmation" id="password_confirmation" class="form-control" required>
                            </div>
                            <div>
                                <button class="btn btn-md btn-primary w-100" type="submit">Redefinir Senha</button>
                            </div>
                            <div class="mt-3">
                                <button class="btn btn-md  btn-outline-secondary w-100" onclick="javascript:window.location.href='{{ route("paginas.castracao.login") }}'" type="button">{{ __("Sair") }}</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection