{{-- Preserva filtros, paginação e ordenação da listagem ao submeter formulários do cadastro --}}
@php
    $query = $query ?? [];
@endphp
@if(is_array($query))
    @foreach($query as $key => $value)
        @if(is_scalar($value) && $value !== '' && $value !== null)
            <input type="hidden" name="pp_listagem[{{ $key }}]" value="{{ $value }}">
        @endif
    @endforeach
@endif
