@extends('layouts.mobiangra.theme')

@section('title', __('MobiAngra - Transporte Coletivo') . ' - ' . config('app.name'))

@section('content')
    @include('mobiangra.sections.hero')
    @include('mobiangra.sections.feature-grid')
    @include('mobiangra.sections.map-preview')
    @include('mobiangra.sections.alerts-promo')
    @include('mobiangra.sections.news')
    @include('mobiangra.sections.org-info')
@endsection

@push('scripts')
    @if (($linhas ?? collect())->isNotEmpty())
        <script>
            window.mobiangraHorariosConfig = {
                navigateUrl: @json(route('mobiangra.horarios')),
            };
        </script>
        <script src="{{ asset('mobiangra-assets/js/mobiangra_busca_linhas.js') }}?v={{ time() }}"></script>
        <script src="{{ asset('mobiangra-assets/js/horarios.js') }}?v={{ time() }}"></script>
    @endif
    @if (($alertasDestaque ?? collect())->count() > 1)
        <script src="{{ asset('mobiangra-assets/js/feature-alertas-rotator.js') }}?v={{ time() }}"></script>
    @endif
    <script src="{{ asset('mobiangra-assets/js/nearby-lines.js') }}?v={{ time() }}"></script>
@endpush
