@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Verificar Músico - Credenciamento")
@section('content')


    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-guitar'></i> Verificar Músico - Credenciamento"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.cultura.credenciamentoMusicos.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.cultura.credenciamentoMusicos.verify',
            'routeAddParams' => [], 
            'nameAdd' => __('Novo paciente'),
            "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
        ])

        <div class="card-body">

            @include("errors.messageFlash")

            <form action="{{ route('admin.cultura.credenciamentoMusicos.verify') }}" method="post">
                @csrf
                <div class="mb-3">
                <!-- Campo CPF -->
                    @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "CPF",
                                "name" => "cpf",
                                "id" => null,
                                "required" => true,
                                "type" => null,
                                "old" => old('cpf'),
                                "oninput" => "javascript:aplicarMascaraCPF(this)",
                                "readonly" => false,
                                "small" => null,
                            ])

                </div>
                 <div class="mb-3">
                      @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar', 
                                'textSend' => 'Verificar', 
                                'routeBack' => 'admin.cultura.credenciamentoMusicos.verify'
                            ])
                </div>

               


            </form>

        </div>
    </div>
@endsection
