@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Consulta de Processos')
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ url('/secretarias/secretaria-de-administracao') }}">{{ __("Secretaria de Administração") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Consulta de Processos") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <div id="conteudo" class="content mediapress">
                        <!-- Content -->

                        <section class="col-md-9 nopadding single-article espaco_conteudo mt-4">
                            <header class="article-header">
                                <!-- Title -->
                                <h1 class="title">{{ __("Consulta de Processos") }}</h1>
                                <!-- Excerpt -->
                            </header>
                            <article class="article-main mt-3">
                                <p>{{ __("Aqui voc&ecirc; pode acompanhar o andamento do seu processo em todas as secretarias
                                    da PMAR,
                                    Funda&ccedil;&otilde;es e Autarquias. ") }}</p>
                                <p>{{ __("Todos os processos abertos pelos setores de protocolo da Prefeitura, inclusive os
                                    anteriores
                                    a 2015, est&atilde;o dispon&iacute;veis para a consulta.") }}</p>
                                <p>{{ __("A consulta pode ser efetuada de duas maneiras:") }} </p>
                                <div class="list_down">
                                    <ul>
                                        <li>{{ __("Pelo n&uacute;mero do processo - Digite no campo &ldquo;Processo:&rdquo; o
                                            ano e o
                                            n&uacute;mero do seu processo, conforme o
                                            exemplo:&nbsp;<strong>2015000001</strong>
                                            (S&atilde;o 4 d&iacute;gitos para o ano do processo e 6 d&iacute;gitos para
                                            o
                                            n&uacute;mero do processo);") }}</li>
                                        <li class="top10">{{ __("Pelo CNPJ/CPF do interessado (Requerente) - Desta forma
                                            voc&ecirc;
                                            poder&aacute; ver todos os seus processos.") }}</li>
                                    </ul>
                                </div>
                                <h4><a href="https://angra.prodataweb.inf.br/sig/app.html#/servicosonline/andamento-processo/"
                                        target="_blank" class="button mb-5"
                                        style="float:left; padding:5px 0; margin-right:30px">{{ __("Clique para
                                        consultar") }}</a></h4>

                                <div class="bottom30"></div>

                            </article>

                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

