<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">
<html lang='pt-br'>
    <head>
        <title>{{ __("Fale conosco :: Prefeitura Municipal de Angra dos Reis") }}</title>
        <style type="text/css">
            @import url('https://fonts.googleapis.com/css2?family=Roboto:wght@300&display=swap');
        </style>
    </head>
    <body style="padding: 0; margin: 0;">
    <h3>{{ __("Olá") }} {{ $data["name"] }} {{ __("recebemos a sua mensagem! Breve entraremos em contato.") }}</h3>
    <ul>
        <li>
            <strong>{{ __("Nome:") }} </strong>{{ $data["name"] }}
        </li>
        <li>
            <strong>{{ __("Email: ") }}</strong>{{ $data["email"] }}
        </li>
        <li>
            <strong>{{ __("Telefone:") }} </strong>{{ $data["phone"] }}
        </li>
        <li>
            <strong>{{ __("Assunto:") }} </strong>{{ $data["subject"] }}
        </li>
        <li>
            <strong>{{ __("Mensagem:") }} </strong>{{ $data["message"] }}
        </li>
    </ul>
</body>
</html>
