@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Página de Acompanhamento - Paciente com Fibromialgia - Documentos")
@section('content')
<div class="card shadow">
    @php $headLine = "<i class='fa-solid fa-user-injured'></i> Página de Acompanhamento - Paciente com Fibromialgia - Documentos"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
    'headLine' => __($headLine),
    "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
    ])

    <div class="card-body">
        <form action="{{ route("admin.saude.fibromialgia.perfil.documentosUpdate", [$paciente->id]) }}" method="post" enctype="multipart/form-data">

            @include("errors.messageFlash")
            @csrf
            @method('post')

            @include('components.modal._modelProfile')

            <div class="tab-content">


                <div class="row">
                    <div class="col-sm-12 col-md-4">

                        <!-- Campo Número da carteira de identidade" -->
                        @include('components.inputs._inputType',[
                        "for" => null,
                        "label" => "Número da carteira de identidade",
                        "name" => "numeroCI",
                        "id" => null,
                        "required" => true,
                        "type" => null,
                        "old" => old('numeroCI', $pessoa?->numeroCI),
                        "oninput" => "this.value = this.value.toUpperCase().replace(/[^A-Z0-9.-]/g, '');",
                        "readonly" => false,
                        "small" => null,
                        ])

                    </div>
                    <div class="col-sm-12 col-md-4">

                        <!-- Campo Órgão expedidor -->
                        @include('components.inputs._inputType',[
                        "for" => null,
                        "label" => "Órgão expedidor",
                        "name" => "orgaoExp",
                        "id" => null,
                        "required" => false,
                        "type" => null,
                        "old" => old('orgaoExp', $pessoa?->orgaoExp),
                        "oninput" => "javascript:this.value = this.value.toUpperCase()",
                        "readonly" => false,
                        "small" => null,
                        "listName" => "orgaoExpList",
                        "arrayList" => [
                        'SSP/AC – Secretaria de Segurança Pública do Acre',
                        'SSP/AL – Secretaria de Segurança Pública de Alagoas',
                        'SSP/AM – Secretaria de Segurança Pública do Amazonas',
                        'SSP/AP – Secretaria de Segurança Pública do Amapá',
                        'SSP/BA – Secretaria de Segurança Pública da Bahia',
                        'SSP/CE – Secretaria de Segurança Pública do Ceará',
                        'SSP/DF – Secretaria de Segurança Pública do Distrito Federal',
                        'SSP/ES – Secretaria de Segurança Pública do Espírito Santo',
                        'SSP/GO – Secretaria de Segurança Pública de Goiás',
                        'SSP/MA – Secretaria de Segurança Pública do Maranhão',
                        'SSP/MG – Secretaria de Segurança Pública de Minas Gerais',
                        'SSP/MS – Secretaria de Segurança Pública do Mato Grosso do Sul',
                        'SSP/MT – Secretaria de Segurança Pública do Mato Grosso',
                        'SSP/PA – Secretaria de Segurança Pública do Pará',
                        'SSP/PB – Secretaria de Segurança Pública da Paraíba',
                        'SSP/PE – Secretaria de Segurança Pública de Pernambuco',
                        'SSP/PI – Secretaria de Segurança Pública do Piauí',
                        'SSP/PR – Secretaria de Segurança Pública do Paraná',
                        'SSP/RJ – Secretaria de Segurança Pública do Rio de Janeiro',
                        'SSP/RN – Secretaria de Segurança Pública do Rio Grande do Norte',
                        'SSP/RO – Secretaria de Segurança Pública de Rondônia',
                        'SSP/RR – Secretaria de Segurança Pública de Roraima',
                        'SSP/RS – Secretaria de Segurança Pública do Rio Grande do Sul',
                        'SSP/SC – Secretaria de Segurança Pública de Santa Catarina',
                        'SSP/SE – Secretaria de Segurança Pública de Sergipe',
                        'SSP/SP – Secretaria de Segurança Pública de São Paulo',
                        'SSP/TO – Secretaria de Segurança Pública do Tocantins',
                        'PM – Polícia Militar',
                        'CBM – Corpo de Bombeiros Militar',
                        'EXERC – Exército Brasileiro',
                        'FAB – Força Aérea Brasileira',
                        'MB – Marinha do Brasil',
                        'DGPM – Diretoria-Geral do Pessoal da Marinha',
                        'DPF – Departamento de Polícia Federal',
                        'DPRF / PRF – Polícia Rodoviária Federal',
                        'PC – Polícia Civil',
                        'OAB – Ordem dos Advogados do Brasil',
                        'CRM – Conselho Regional de Medicina',
                        'CRF – Conselho Regional de Farmácia',
                        'CRO – Conselho Regional de Odontologia',
                        'COREN – Conselho Regional de Enfermagem',
                        'CRP – Conselho Regional de Psicologia',
                        'CRQ – Conselho Regional de Química',
                        'CREA – Conselho Regional de Engenharia e Agronomia',
                        'CRBio – Conselho Regional de Biologia',
                        'CRB – Conselho Regional de Biblioteconomia',
                        'CRMV – Conselho Regional de Medicina Veterinária',
                        'CRA – Conselho Regional de Administração',
                        'CRC – Conselho Regional de Contabilidade',
                        'CRFa – Conselho Regional de Fonoaudiologia',
                        'CREF – Conselho Regional de Educação Física',
                        'CRESS – Conselho Regional de Serviço Social',
                        'TJ – Tribunal de Justiça',
                        'TRT – Tribunal Regional do Trabalho',
                        'TRE – Tribunal Regional Eleitoral',
                        'TRF – Tribunal Regional Federal',
                        'STM – Superior Tribunal Militar',
                        'STJ – Superior Tribunal de Justiça',
                        'STF – Supremo Tribunal Federal',
                        'DETRAN – Departamento Estadual de Trânsito',
                        'DETRAN-UF (ex.: DETRAN-SP, DETRAN-RJ etc.)',
                        'IBAMA – Instituto Brasileiro do Meio Ambiente',
                        'ICMBio – Instituto Chico Mendes',
                        'MTE / TEM – Ministério do Trabalho e Emprego (carteiras antigas)',
                        'FUNAI – Fundação Nacional dos Povos Indígenas',
                        'PF – Polícia Federal',
                        'SUSEP – Superintendência de Seguros Privados',
                        'INSS – Instituto Nacional do Seguro Social',
                        'IF / CEFET – Institutos Federais em emissões específicas',
                        'Prefeituras (PM) – raros casos de carteiras funcionais',
                        'Universidades Públicas (UF / UFF / UFRJ etc.) – carteiras funcionais',
                        ],
                        ])

                    </div>
                    <div class="col-sm-12 col-md-4">

                        <!-- Campo Data de expedição -->
                        @include('components.inputs._inputType',[
                        "for" => null,
                        "label" => "Data de expedição",
                        "name" => "dtaExpedicao",
                        "id" => null,
                        "required" => false,
                        "type" => "date",
                        "old" => old('dtaExpedicao', $pessoa->dtaExpedicao),
                        "oninput" => "",
                        "readonly" => false,
                        "small" => null,
                        ])


                    </div>
                </div>
                <div class="row">

                    <div class="col-sm-12 col-md-4">

                        <!-- Campo Nº do Cartão SUS (opcional) -->
                        @include('components.inputs._inputType',[
                        "for" => null,
                        "label" => "Nº do Cartão SUS (CNS)",
                        "name" => "numeroSus",
                        "id" => null,
                        "required" => false,
                        "type" => null,
                        "old" => old('numeroSus', $pessoa->numeroSUS),
                        "oninput" => "this.value = this.value.replace(/[^0-9]/g, '');",
                        "readonly" => false,
                        "small" => "Opcional.",
                        ])

                    </div>


                    <div class="col-sm-12 col-md-4">

                        <!-- Campo ESF de referência -->
                        @include('components.inputs._selectType', [
                        "for" => "esfReferencia",
                        "label" => "ESF de referência",
                        "name" => "esfReferencia",
                        "required" => true,
                        "readonly" => false,
                        "options" => collect(App\Enums\EsfCadastro::cases())
                        ->mapWithKeys(fn($status) => [$status->name => $status->value])
                        ->toArray(),
                        "selected" => old('esfReferencia', $paciente->esfReferencia),
                        "placeholder" => "Selecione o ESF...",
                        "small" => "Informe a ESF de referência.",
                        "onchange" => null
                        ])

                    </div>
                    <div class="col-sm-12 col-md-4">

                        <!-- Campo Data do diagnóstico -->
                        @include('components.inputs._inputType',[
                        "for" => null,
                        "label" => "Data do Diagnóstico",
                        "name" => "dt_Diagnostico",
                        "id" => null,
                        "required" => true,
                        "type" => "date",
                        "old" => old('dt_Diagnostico', $paciente->dt_Diagnostico),
                        "oninput" => "",
                        "readonly" => false,
                        "small" => null,
                        ])

                    </div>
                </div>

                <div class="row">
                    <div class="d-flex justify-content-between mt-4">
                        <a class="btn btn-outline-secondary" href="{{ route("admin.saude.fibromialgia.perfil.show", $paciente->id) }}">
                            <i class="fa-solid fa-arrow-left-long"></i> {{ __("Voltar") }}
                        </a>
                        <button class="btn btn-primary d-inline" type="submit">
                            <i class="fa-solid fa-user-plus"></i> {{ __("Salvar") }}
                        </button>
                    </div>
                </div>
            </div>
        </form>

    </div>
</div>

@endsection