<!-- Mashead header-->
<header class="masthead">
    <div class="container px-5">
        <div class="row gx-5 align-items-center">
            <div class="col-lg-6">
                <!-- Mashead text and app badges-->
                <div class="mb-5 mb-lg-0 text-center text-lg-start">
                    <h1 class="display-1 lh-1 mb-3">Sistema Eletrônico de Informações</h1>
                    <p class="lead fw-normal text-muted mb-5">A gestão de documentos e processos da Prefeitura de
                        Angra dos Reis, agora é 100% digital.</p>
                </div>
            </div>
            <div class="col-lg-6">
                <!-- Masthead device mockup feature-->
                <div class="masthead-device-mockup">
                    <svg class="circle" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
                        <defs>
                            <linearGradient id="circleGradient" gradientTransform="rotate(45)">
                                <stop class="gradient-start-color" offset="0%"></stop>
                                <stop class="gradient-end-color" offset="100%"></stop>
                            </linearGradient>
                        </defs>
                        <circle cx="50" cy="50" r="50"></circle>
                    </svg><img class="img-fluid" src="{{ asset("sei-angra/assets/img/note.png2wbmp()") }}" alt="" style="position: absolute; z-index: 1;">
                </div>
            </div>
        </div>
    </div>
</header>