{{-- Aba Dados: resumo (KPIs), gráficos e últimos históricos de andamento --}}
<div class="pp-tab-dashboard" data-pp-chart-empty="{{ __('Sem dados para exibir com os filtros atuais.') }}">
    @if(empty($ppPainelEmbutidoDashboard))
        @php
            $ppUrlRelatorioPersonalizado = route(
                !empty($painelDashboard)
                    ? 'admin.dashboardEstrategico.projetosProgramas.relatorio'
                    : 'admin.projetosProgramas.relatorio',
                request()->except(['columns', 'group1', 'group2', 'group3'])
            );
        @endphp
        <p class="text-muted small mb-2">
            <a href="{{ $ppUrlRelatorioPersonalizado }}">
                {{ __('Abrir relatórios personalizados') }}
            </a>
        </p>
    @endif

    @include('admin.projetosProgramas.partials._projetos_resumo_kpis')

    <script type="application/json" id="pp-dashboard-charts-json">
        @json($ppDashboardCharts ?? [])
    </script>

    <div class="row g-2 mb-2">
        <div class="col-lg-4">
            <div class="card border-0 shadow-sm h-100">
                <div class="card-header py-1 px-2 bg-light border-0">
                    <h6 class="mb-0 small fw-semibold">{{ __('MAPÃO — situação do orçamento') }}</h6>
                </div>
                <div class="card-body p-2">
                    <div class="pp-dash-chart-wrap pp-dash-chart-wrap--compact">
                        <canvas id="ppDashChartOrcamento" width="320" height="200"
                            aria-label="{{ __('Gráfico: situação do orçamento no MAPÃO') }}"></canvas>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="card border-0 shadow-sm h-100">
                <div class="card-header py-1 px-2 bg-light border-0">
                    <h6 class="mb-0 small fw-semibold">{{ __('Prazo (dias)') }}</h6>
                </div>
                <div class="card-body p-2">
                    <div class="pp-dash-chart-wrap pp-dash-chart-wrap--compact">
                        <canvas id="ppDashChartPrazo" width="320" height="200"
                            aria-label="{{ __('Gráfico: faixas de prazo em dias') }}"></canvas>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="card border-0 shadow-sm h-100">
                <div class="card-header py-1 px-2 bg-light border-0">
                    <h6 class="mb-0 small fw-semibold">{{ __('Histórico — lançamentos por mês (12 meses)') }}</h6>
                </div>
                <div class="card-body p-2">
                    <div class="pp-dash-chart-wrap pp-dash-chart-wrap--compact">
                        <canvas id="ppDashChartHistoricoMes" width="320" height="200"
                            aria-label="{{ __('Gráfico: quantidade de lançamentos no histórico por mês') }}"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row g-2 mb-2">
        <div class="col-12">
            <div class="card border-0 shadow-sm">
                <div class="card-header py-1 px-2 bg-light border-0">
                    <h6 class="mb-0 small fw-semibold">{{ __('Projetos por secretaria (top 12)') }}</h6>
                </div>
                <div class="card-body p-2">
                    <div class="pp-dash-chart-wrap pp-dash-chart-wrap--secretarias">
                        <canvas id="ppDashChartSecretarias" width="400" height="240"
                            aria-label="{{ __('Gráfico: quantidade de projetos por secretaria') }}"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="card border-0 shadow-sm mb-2">
        <div class="card-header py-1 px-2 bg-light border-0 d-flex flex-wrap justify-content-between align-items-center gap-2">
            <h6 class="mb-0 small fw-semibold">{{ __('Últimos andamentos (histórico)') }}</h6>
            <span class="badge text-bg-secondary">{{ __('Conjunto filtrado') }}</span>
        </div>
        <div class="card-body p-0">
            @php
                $ultimos = $ppDashboardUltimosHistoricos ?? collect();
            @endphp
            @if($ultimos->isEmpty())
                <p class="text-muted small mb-0 p-2">{{ __('Nenhum histórico de andamento encontrado para os filtros atuais.') }}</p>
            @else
                <div class="table-responsive">
                    <table class="table table-sm table-striped mb-0 align-middle">
                        <thead class="table-light">
                            <tr>
                                <th scope="col">{{ __('Data') }}</th>
                                <th scope="col">{{ __('Projeto') }}</th>
                                <th scope="col">{{ __('Status') }}</th>
                                <th scope="col">{{ __('Andamento') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($ultimos as $h)
                                <tr>
                                    <td class="text-nowrap small">{{ $h['data'] }}</td>
                                    <td class="small">
                                        @if(!empty($h['projeto_id']))
                                            <button type="button" class="btn btn-link btn-sm text-start p-0 text-decoration-none"
                                                data-bs-toggle="modal" data-bs-target="#modalVisualizarProjeto"
                                                data-projeto-visualizar-url="{{ route('admin.projetosProgramas.visualizar', $h['projeto_id']) }}">
                                                {{ $h['projeto'] }}
                                            </button>
                                        @else
                                            {{ $h['projeto'] }}
                                        @endif
                                    </td>
                                    <td class="small">{{ $h['status'] }}</td>
                                    <td class="small text-break">{{ $h['texto'] }}</td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            @endif
        </div>
    </div>
</div>
