@props(['title', 'subtitle' => null, 'icon' => 'fa-gauge-high'])

<div class="dashboard-header mb-4">
    <h1 class="dashboard-title">
        <i class="fa-solid {{ $icon }} me-2"></i>
        {{ __($title) }}
    </h1>
    @if($subtitle)
    <p class="dashboard-subtitle text-muted">{{ __($subtitle) }}</p>
    @endif
</div>
