<?php if(config('recaptcha.enabled')): ?>
<script src="https://www.google.com/recaptcha/api.js?onload=onloadCallback&render=explicit" async defer type="text/x-javascript"></script>
<?php endif; ?>
<script src="<?php echo e(asset('pmar/js/jquery-3.7.1.min.js')); ?>"></script>

<script src="<?php echo e(asset('pmar/build/bootstrap/js/bootstrap.bundle.min.js')); ?>"></script>
<?php if(Route::currentRouteName() == 'admin.login'): ?>
<script src="<?php echo e(asset('pmar/js/login.js')); ?>"></script>
<?php endif; ?>
<?php if(Route::currentRouteName() == 'admin.esqueceuSenha'): ?>
<script src="<?php echo e(asset('pmar/js/mascaras.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/auth-masks.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/auth-forgot-recaptcha.js')); ?>"></script>
<?php endif; ?>
<?php if(Route::currentRouteName() == 'admin.contas.publicas.create'): ?>
<script src="<?php echo e(asset('pmar/js/mascaras.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/auth-create-recaptcha.js')); ?>"></script>
<?php endif; ?>
<?php if(Route::currentRouteName() == 'admin.novaConta'): ?>
<script src="<?php echo e(asset('pmar/js/mascaras.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/auth-nova-conta-recaptcha.js')); ?>"></script>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/layouts/login/elements/footer.blade.php ENDPATH**/ ?>