@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: ". $secretaria->name)
@section('content')
    <div class="container">
        <div class="row">
            <div class="col-12 my-3">
                @php
                    $breadcrumbItems = \App\Support\PortalBreadcrumb::forOrgHome($secretaria);
                    if (isset($secretaria->pertence->name)) {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->pertence->abbreviation;
                        $breadcrumbItems[2]['labelShort'] = $secretaria->abbreviation;
                    } else {
                        $breadcrumbItems[1]['labelShort'] = $secretaria->abbreviation;
                    }
                @endphp
                <x-portal.breadcrumb
                    :items="$breadcrumbItems"
                    :responsive-abbreviation="isset($secretaria->pertence->name) || filled($secretaria->abbreviation)"
                />
            </div>
        </div>
    </div>
    @include('paginas.parts.headers')

    @if(($pageContentType ?? 'NOTICIAS') === 'HTML')
        @include('paginas.parts.details-html')
        @include('paginas.parts.secretario')
    @elseif(($pageContentType ?? 'NOTICIAS') === 'HTML_NOTICIAS')
        @include('paginas.parts.details-html')
        @include('paginas.parts.secretario')
    @else
        @include('paginas.parts.noticias')
    @endif

    {{-- @include('paginas.parts.google-maps') --}}
    {{-- @include('paginas.parts.address') --}}

@endsection
