<!-- Água e Esgoto -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-info">
        <div class="card-header {{ $cor }} text-dark">
            <div class="d-flex align-items-center">
                <i class="fas fa-faucet-drip fa-2x me-3"></i>
                <h5 class="card-title mb-0">Água e Esgoto</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-tint me-2 text-muted"></i> Ligação de água  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-pipe me-2 text-muted"></i> Ligação de esgoto  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-toolbox me-2 text-muted"></i> Consertos e vazamentos  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-file-invoice-dollar me-2 text-muted"></i> Contas e tarifas  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-ban me-2 text-muted"></i> Corte e religação  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-flask me-2 text-muted"></i> Qualidade da água  <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-recycle me-2 text-muted"></i> Programas de conservação  <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
        <div class="card-footer bg-transparent">
            <small class="text-muted">Serviço essencial - Saneamento básico</small>
        </div>
    </div>
</div>