@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Registros de Dívidas Ativas")
@section('content')

    <div class="card shadow-sm">
        
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __("Registros de Dívidas Ativas"),
//            'routeBack' => 'admin.turismoNautico.index',
//            'routeBackParams' => [], 
//            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.dividaAtiva.create',
            'routeAddParams' => [], 
            'nameAdd' => __('Novo registro'),
            'routeCSV' => "admin.dividaAtiva.planilhas",
            'nameCSV' => __('Importar planilha'),
            'nameDeleteAll' => __('Limpar base de dados'),
            'messageDeleteAll' => __('* Os registros serão excluídos da dívida ativa e esta ação não poderá ser desfeita, deseja continuar?'),
            'routeDeleteAll' => __('admin.dividaAtiva.cleanAll'),
            'permission' => 'GERENCIADOR_REGISTROS_DE_DIVIDA_ATIVA',
        ])
        
        <div class="card-body">
            
            @include("errors.messageFlash")
            
            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "cadastroDeUsuario", 
                "placeholder" => "Pesquisar por divida ativa..."
            ])
                        
            <div class="row">
                <div class="col-12">
                    <x-tables._table :thead="['Criado em','Número de inscrição','Número do imóvel','Informações','Parcelado','Protestado','Ajuizado','Status','Ações']" :pagination="$dividas->links()">
                        <x-slot name="body">
                            @php $index = 0; @endphp
                            @forelse($dividas as $divida)
                                <tr>
                                    <td>{{ date("d/m/Y H:m", strtotime($divida->created_at)) }}</td>
                                        <td>{{ $divida->registro->numInscricao ?? "Não informado" }}</td>
                                        <td>{{ $divida->registro->numImovel ?? "Não informado" }}</td>
                                        <td class="text-start">
                                            <div><strong>CPF ou CNPJ</strong></div>
                                            <div class="mb-2">{{ $divida->registro->isPJ ? $divida->registro->cnpj ?? "Não informado" : $divida->registro->cpf ?? "Não informado" }}</div>
                                            <div><strong>Nome ou Razão Social</strong></div>
                                            <div class="mb-2">{{ $divida->registro->nome }}</div>
                                            <div><strong>Origem da dívida</strong></div>
                                            <div class="mb-2">{{ $divida->registro->origemDivida }}</div>
                                            <div><strong>Exercício</strong></div>
                                            <div class="mb-2">{{ $divida->registro->exercicio }}</div>
                                            <div><strong>Data da dívida ativa</strong></div>
                                            <div class="mb-2">{{ date("d/m/Y", strtotime($divida->registro->dividaStatus)) }}</div>
                                            <div><strong>Valor da dívida</strong></div>
                                            <div class="mb-2">{{ $divida->registro->dividaStatus }}</div>
                                            <div><strong>Status da dívida ativa</strong></div>
                                            <div><span style="color: #dc3545;" class="text-bold">{{ $divida->registro->dividaValorTotal }}</span></div>
                                        </td>
                                        <td>{{ $divida->registro->dividaParcelado ? "Sim" : "Não" }}</td>
                                        <td>{{ $divida->registro->dividaProtestado ? "Sim" : "Não"  }}</td>
                                        <td>{{ $divida->registro->dividaAjuizado ? "Sim" : "Não"  }}</td>
                                        <td class="text-center align-middle">
                                            
        @include('components/buttons/_status', [
            "index" => $index,
            "route" => "admin.dividaAtiva.status",
            "id" => $divida->id,
            "status" => $divida->status,
            "permission" => "GERENCIADOR_REGISTROS_DE_DIVIDA_ATIVA",
        ])
                                            
                                        </td>
                                        <td>
                                            <div class="d-flex gap-2 d-flex justify-content-center align-items-center">
                                                
                                                @include('components/buttons/_editButton', [
                                                    "route" => "admin.dividaAtiva.edit",
                                                    "id" => $divida->id,
                                                    "fontawesome" => null,
                                                    "title" => "Editar",
                                                    "permission" => "GERENCIADOR_REGISTROS_DE_DIVIDA_ATIVA",
                                                ])

                                                @include('components/buttons/_deleteButton', [
                                                    "message" => __("* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?"),
                                                    "route" => "admin.dividaAtiva.destroy",
                                                    "id" => $divida->id,
                                                    "fontawesome" => null,
                                                    "title" => "Excluir",
                                                    "permission" => "GERENCIADOR_REGISTROS_DE_DIVIDA_ATIVA",
                                                ])
                                                
                                            </div>
                                        </td>

                                    </tr>
                                    @php $index++; @endphp
                                @empty
                                    <tr>
                                        <td colspan="9">* Nenhum registro encontrado</td>
                                    </tr>
                                @endforelse
                        </x-slot>
                    </x-tables._table>
                </div>
            </div>
            
        </div>
    </div>
@endsection
