@extends('layouts.parquedacidade.theme')
@section('title', 'Página de Contato - Parque da Cidade da Prefeitura Municipal de Angra dos Reis')
@section('content')

<style>
    .dadoscontato {
        list-style: none;
        padding-left: 0;
        font-size: 1.1rem;
    }

    .dadoscontato li {
        margin-bottom: 15px;
        display: flex;
        align-items: center;
    }

    .dadoscontato li i {
        margin-right: 10px;
        color: #2a7d2e;
        font-size: 1.3rem;
        width: 25px;
        text-align: center;
    }

    .contato-box {
        background-color: #f8f9fa;
        padding: 40px 30px;
        border-radius: 10px;
        box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
        margin-top: 30px;
    }

    .contato-box h3 {
        font-weight: bold;
        color: #333;
    }

    @media (max-width: 767.98px) {
        .contato-box img {
            width: 100%;
            margin-top: 20px;
        }

        .col-6 {
            margin-bottom: 20px;
        }
    }
</style>

    <div class="page-title dark-background" data-aos="fade"
        style="background-image: url({{ asset('parquedacidade/imagens/img-fundo.jpg') }});">
        <div class="container position-relative">
            <h1 class="text-white">Contato</h1>
        </div>
    </div>

    <section id="contact" class="contact">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-lg-10 contato-box">
                    <h3 class="mb-5 text-center" style="text-transform: none;">
                        Instituto Municipal do Ambiente de Angra dos Reis
                    </h3>
                    <div class="row align-items-center">
                        <div class="col-md-6 wow fadeInLeft">
                            <ul class="dadoscontato">
                                <li><i class="fa fa-home"></i>Rua do Comércio, 17 - Centro</li>
                                <li><i class="fa fa-envelope"></i><a
                                        href="mailto:imaar.supma@angra.rj.gov.br">imaar.supma@angra.rj.gov.br</a></li>
                                <li><i class="fa fa-phone"></i><a href="tel:02433684435">+55 24 3368-4435</a></li>
                                <li><i class="fa fa-globe"></i><a href="http://angra.rj.gov.br"
                                        target="_blank">angra.rj.gov.br</a></li>
                            </ul>
                        </div>
                        <div class="col-md-6 text-center wow fadeInRight">
                            <img src="asset/images/logo-imaar.png" alt="Logo IMAAR" style="width: 360px;" class="img-fluid">
                        </div>
                    </div>
                </div>
            </div>
            <div class="row mt-5">
                <div class="col-lg-12">
                    <div class="section-title text-center wow fadeInDown" data-wow-duration="2s" data-wow-delay="50ms">
                        <h2>Envie-nos uma mensagem</h2>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-lg-12">
                    <form name="FormContato" id="FormContato" novalidate method="post" action="contato.asp"
                        onSubmit="return ValidarCampos(this)">
                        <div class="row">
                            <div class="col-md-6 wow fadeInLeft" data-wow-duration="2s" data-wow-delay="600ms">
                                <div class="form-group">
                                    <input type="text" class="form-control" placeholder="Nome *" id="fNome" name="fNome"
                                        required data-validation-required-message="Informe seu nome">
                                    <p class="help-block text-danger"></p>
                                </div>
                                <div class="form-group">
                                    <input type="email" class="form-control" placeholder="E-mail *" id="fEmail"
                                        name="fEmail" required data-validation-required-message="Informe seu e-mail">
                                    <p class="help-block text-danger"></p>
                                </div>
                                <div class="form-group">
                                    <input type="tel" class="form-control" placeholder="Telefone *" id="fTelefone"
                                        name="fTelefone" required data-validation-required-message="Informe seu telefone">
                                    <p class="help-block text-danger"></p>
                                </div>
                            </div>
                            <div class="col-md-6 wow fadeInRight" data-wow-duration="2s" data-wow-delay="600ms">
                                <div class="form-group">
                                    <textarea class="form-control" placeholder="Sua Mensagem *" id="fMensagem"
                                        name="fMensagem" required
                                        data-validation-required-message="Escreva uma mensagem"></textarea>
                                    <p class="help-block text-danger"></p>
                                </div>
                            </div>
                            <div class="clearfix"></div>
                            <div class="col-lg-12 text-center wow zoomIn" data-wow-duration="1s" data-wow-delay="600ms">
                                @if (config('recaptcha.enabled'))
                                <div class="g-recaptcha" data-callback="recaptchaCallback"
                                    data-sitekey="6Lf75TkUAAAAAEHgXPyCVl20Eh1qfSabxJh8exoX"></div>
                                <script src="https://www.google.com/recaptcha/api.js?hl=pt-BR" async defer></script>
                                @endif
                            </div>
                            <div class="col-lg-12 text-center wow zoomIn" data-wow-duration="1s" data-wow-delay="600ms">
                                <div id="success"></div>
                                <button type="submit" @if (config('recaptcha.enabled')) disabled @endif class="btn btn-primary" id="btnsubmit">Enviar
                                    mensagem</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>

    </section>

@endsection