<header id="header" id="home">
    <div class="container">
        <div class="row align-items-center justify-content-between d-flex">
            <div id="logo">
                <a href="https://angra.rj.gov.br/">
                    <img src="<?php echo e(asset('pmar/assets/img/logo-angra-branco.svg')); ?>" height="30"
                        alt="Prefeitura de Angra dos Reis - Site Oficial" class="logo-topo-padrao">
                </a>
            </div>
            <nav id="nav-menu-container">
                <ul class="nav-menu">
                    <li class="menu-active"><a href="<?php echo e(route("paginas.cultura.arteSacra.index")); ?>">Início</a></li>
                    <li><a href="<?php echo e(route("paginas.cultura.arteSacra.sobre")); ?>">Sobre</a></li>
                    <li><a href="<?php echo e(route("paginas.cultura.arteSacra.galeria")); ?>">Galeria</a></li>
                </ul>
            </nav>
        </div>
    </div>
</header><?php /**PATH /var/www/html/portal/resources/views/layouts/arte-sacra/elements/nav.blade.php ENDPATH**/ ?>