<td style="text-align:center;padding:6px 4px;background:{{ $bg ?? '#f4f4f4' }};border:1px solid #d1d5db;width:{{ $width ?? '25%' }};">
    <strong style="display:block;font-size:15px;color:{{ $color ?? '#111' }};">{{ $value }}</strong>
    <span style="font-size:7.5px;color:#6b7280;">{{ $label }}</span>
</td>
