@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Unidades de Saúde")
@section('content')
    <div class="container my-4">
        <div class="row mb-4">
            <div class="col-12 my-3">
                @include('servicos.parts.breadcrumb', ['current' => __('Unidades de Saúde')])
            </div>
            <div class="col-12 mb-1">
                <div class="col-12 mb-3">
                    <h1 class="title">Unidades de Saúde</h1>
                    <div class="card shadow-sm">
                        <div class="card-body p-3">
                            <div class="row align-items-center g-2"> <!-- Garante alinhamento central -->
                            <!-- Campo de Pesquisa -->
                                <div class="col-md-6">
                                    <div class="input-group" style="height: 38px;"> <!-- Altura fixa -->
                                        <span class="input-group-text bg-primary text-white">
                                            <i class="fas fa-search"></i>
                                        </span>
                                        <input type="text" 
                                           id="searchInput" 
                                           class="form-control"
                                           placeholder="Nome da unidade de saúde...">
                                    </div>
                                </div>

                            <!-- Filtro por Bairro -->
                                <div class="col-md-5">
                                    <select id="bairroFilter" class="form-select" style="height: 38px;"> <!-- Altura fixa -->
                                        <option value="">Todos os bairros</option>
                                    </select>
                                </div>

                            <!-- Botão Limpar -->
                                <div class="col-md-1">
                                    <button id="clearFilters" class="btn btn-outline-secondary w-100" style="height: 38px;">
                                        <i class="fas fa-times"></i>
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="row mb-3">
            <div class="col-12">
                <div class="alert alert-light">
                    <span id="resultCount">0</span> unidades de saúde encontradas
                </div>
            </div>
        </div>

        <div class="row" id="unidadesContainer">
            @foreach($unidadesSaude as $unidade)
                <div class="col-md-6 col-lg-4 mb-4 unidade-card" 
             data-nome="{{ strtolower($unidade->nome) }}" 
             data-bairro="{{ strtolower($unidade->endereco->bairro) }}"
             data-recursos="{{ $unidade->possuiRecursosMultifuncionais ? 'sim' : 'nao' }}">
                    <div class="card h-100 shadow-sm">
                        <img src="{{ asset($unidade->foto) }}" class="card-img-top" alt="{{ $unidade->nome }}" style="height: 180px; object-fit: cover;">
                        <div class="card-body">
                            <h5 class="card-title">{{ $unidade->tipoUnidadeSaude }} - {{ $unidade->nome }}</h5>
                            <p class="card-text">
                                <i class="fas fa-map-marker-alt text-muted me-1 text-danger"></i>
                                {{ $unidade->endereco->bairro }}
                            </p>
                        </div>
                        <div class="card-footer bg-white">
                            <button type="button" class="btn btn-sm btn-primary w-100" data-bs-toggle="modal" data-bs-target="#modalUnidadeSaude{{ $unidade->id }}">
                                <i class="fas fa-info-circle me-1"></i> Detalhes
                            </button>
                        </div>

                        <div class="modal fade" id="modalUnidadeSaude{{ $unidade->id }}" tabindex="-1" aria-hidden="true">
                            <div class="modal-dialog modal-fullscreen">
                                <div class="modal-content bg-dark">
                                    <div class="modal-header border-0">
                                        <button type="button" class="btn-close btn-close-white ms-auto" data-bs-dismiss="modal" aria-label="Fechar"></button>
                                    </div>
                                    <div class="modal-body p-0 d-flex flex-column">
                                        <div class="flex-grow-1 overflow-auto p-4">
                                            <div class="card shadow-sm border-0 mx-auto" style="max-width: 800px;">
                                                <div class="position-relative overflow-hidden" style="height: 300px;">
                                                    <img src="{{ asset($unidade->foto ?? 'pmar/assets/img/icons/unidade_saude.png') }}" 
                                                 class="img-fluid w-100 h-100 object-fit-cover transition-transform"
                                                 alt="{{ $unidade->nome }}"
                                                 style="transition: transform 0.3s ease;">

                                                    <div class="top-0 start-0 w-100 h-100 bg-dark bg-opacity-25"></div>


                                                    <div class="position-absolute bottom-0 start-0 p-3 text-white">
                                                        <h2 class="card-title mb-0 text-shadow">{{ $unidade->tipoUnidadeSaude }} - {{ $unidade->nome }}</h2>
                                                        <p class="mb-0 text-shadow text-white">{{ $unidade->endereco->bairro }} {{ $unidade->endereco->complemento != "" ? ', ' . $unidade->endereco->complemento : '' }} - Angra dos Reis/RJ</p>
                                                    </div>
                                                </div>

                                                <div class="card-body pb-2">
                                                    <div class="mb-2">
                                                        <div>
                                                            <p class="card-text mb-0">
                                                                <i class="fas fa-map-marker-alt text-danger mt-1 me-2 fs-5"></i> <strong>Endereço:</strong> {{ $unidade->endereco->logradouro }}, {{ $unidade->endereco->numero }} - CEP: {{ $unidade->endereco->cep ?? 'Não informado' }}
                                                            </p>

                                                        </div>
                                                    </div>

                                                    <div class="mb-2">

                                                        <div>
                                                            <p class="card-text mb-0">
                                                                <i class="fas fa-envelope text-primary mt-1 me-2 fs-5"></i> <strong>E-mail:</strong> 
                                        @if($unidade->email)
                                                                    <a href="mailto:{{ $unidade->email }}" class="text-decoration-none">{{ $unidade->email }}</a>
                                                                @else
                                                                    <span class="badge bg-secondary bg-opacity-10 text-secondary">Não informado</span>
                                                                @endif
                                                            </p>
                                                        </div>
                                                    </div>

                                                    <div class="mb-3">
                                                        <div>
                                                            <p class="card-text mb-0">
                                                                <i class="fas fa-phone-alt text-success mt-1 me-2 fs-5"></i> <strong>Telefone:</strong> 
                                        @if($unidade->telefone)
                                                                    <a href="tel:+55{{ $unidade->telefone }}" class="text-decoration-none">
                                                                        {{ preg_replace('/(\d{2})(\d{4,5})(\d{4})/', '($1) $2-$3', $unidade->telefone) }}
                                                                    </a>
                                                                @else
                                                                    <span class="badge bg-secondary bg-opacity-10 text-secondary">Não informado</span>
                                                                @endif
                                                            </p>
                                                            @if($unidade->informacoes != "")
                                                                <hr>
                                                                <p class="my-3">{!! $unidade->informacoes !!}<p>
                                                                    @endif
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="border-top border-secondary" style="height: 300px; flex-shrink: 0;">
                                                    @if($unidade->endereco->latitude && $unidade->endereco->longitude)
                                    <iframe 
                                        width="100%" 
                                        height="100%" 
                                        frameborder="0" 
                                        scrolling="no" 
                                        marginheight="0" 
                                        marginwidth="0" 
                                        src="https://maps.google.com/maps?q={{ $unidade->endereco->latitude }},{{ $unidade->endereco->longitude }}&z=17&output=embed"
                                        style="border: none;"
                                        allowfullscreen>
                                                    </iframe>
                                                @else
                                                    <div class="h-100 d-flex justify-content-center align-items-center bg-light bg-opacity-10 text-white">
                                                        <i class="fas fa-map-marker-alt fa-3x me-3"></i>
                                                        <h4 class="mb-0">Localização não disponível</h4>
                                                    </div>
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                @endforeach
            </div>

            <div id="noResults" class="row d-none">
                <div class="col-12">
                    <div class="alert alert-warning text-center py-4">
                        <i class="fas fa-school fa-3x mb-3"></i>
                        <h4>Nenhuma unidade encontrada</h4>
                        <p class="mb-0">Tente ajustar os filtros de pesquisa</p>
                    </div>
                </div>
            </div>
        </div>

    @endsection