<?php $__env->startSection('title', env('APP_NAME') . ' :: Estágio na Prefeitura'); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => [
                        \App\Support\PortalBreadcrumb::home(),
                        \App\Support\PortalBreadcrumb::secretariaBySlug('secretaria-de-administracao', __('Secretaria de Administração')),
                        \App\Support\PortalBreadcrumb::current(__('Estágio na Prefeitura')),
                    ]]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute([
                        \App\Support\PortalBreadcrumb::home(),
                        \App\Support\PortalBreadcrumb::secretariaBySlug('secretaria-de-administracao', __('Secretaria de Administração')),
                        \App\Support\PortalBreadcrumb::current(__('Estágio na Prefeitura')),
                    ])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
                </div>
                <div class="col-md-9 nopadding single-article espaco_conteudo">
                    <header class="article-header">
                        <!-- Title -->
                        <h1 class="title"><?php echo e(__("Como estagiar na Prefeitura")); ?></h1>
                        <!-- Excerpt -->
                    </header>
                    <article class="article-main">
                        <p><?php echo e(__("A Prefeitura Municipal de Angra dos Reis, por meio do Est&aacute;gio de Estudantes, atende
                            estudantes de educa&ccedil;&atilde;o superior, educa&ccedil;&atilde;o profissional e ensino
                            m&eacute;dio.")); ?></p>
                        <p><?php echo e(__("O est&aacute;gio tem o objetivo de proporcionar a forma&ccedil;&atilde;o do educando, mediante a
                            aprendizagem de compet&ecirc;ncias pr&oacute;prias da atividade profissional e a
                            contextualiza&ccedil;&atilde;o curricular, possibilitando seu desenvolvimento para a vida
                            cidad&atilde; e para o trabalho.")); ?></p>
                        <p><?php echo e(__("O estudante interessado em participar dever&aacute; manter seu cadastro atualizado e acompanhar a
                            abertura de oferta de vaga desta Prefeitura, liberada em seu perfil se cadastrando no site do
                            CIEE - Centro de Integra&ccedil;&atilde;o Empresa Escola no link:")); ?> <a
                                href="https://web.ciee.org.br/login" target="_blank">https://web.ciee.org.br/login</a> .
                        </p>
                        <h3><?php echo e(__("Avaliação de perfil em vaga de estágio")); ?></h3>
                        <p><?php echo e(__("A Prefeitura admite estudantes com idade m&iacute;nima de 16 anos, estejam regularmente
                            matriculados e frequentes em suas institui&ccedil;&otilde;es de ensino.")); ?></p>
                        <h3><?php echo e(__("Observa&ccedil;&otilde;es importantes")); ?></h3>
                        <ol class="olist_normal" style="margin-bottom:0">
                            <li><?php echo e(__("")); ?>Os cadastros s&atilde;o realizados somente pela internet no link <a
                                    href="https://web.ciee.org.br/login" target="_blank">https://web.ciee.org.br/login</a>;
                            </li>
                            <li><?php echo e(__("")); ?>A Prefeitura oferta vagas atrav&eacute;s do Agente de Integra&ccedil;&atilde;o Conveniado,
                                CIEE - Centro de Integra&ccedil;&atilde;o Empresa Escola e este as disponibiliza no perfil
                                dos estudantes cadastrados no site;</li>
                            <li><?php echo e(__("")); ?>A participa&ccedil;&atilde;o n&atilde;o garante o acesso autom&aacute;tico &agrave;s vagas
                                do Est&aacute;gio;</li>
                            <li><?php echo e(__("")); ?>Os cadastrados em vagas ofertadas ser&atilde;o convocados pelo agente de
                                Integra&ccedil;&atilde;o conveniado, para participa&ccedil;&atilde;o de uma
                                avalia&ccedil;&atilde;o de perfil, onde ser&atilde;o analisadas compet&ecirc;ncias
                                t&eacute;cnicas e comportamentais dos estudantes;</li>
                            <li><?php echo e(__("")); ?>O cadastro as ofertas de vagas ser&atilde;o disponibilizadas nos perfis dos estudantes
                                sempre que esta Prefeitura dispor vagas junto ao Agente de Integra&ccedil;&atilde;o, sendo
                                necess&aacute;rio que o candidato interessado proceda com sua atualiza&ccedil;&atilde;o
                                cadastral e acompanhe seu perfil observando a oferta aberta para se cadastrar;</li>
                            <li><?php echo e(__("")); ?>A carga hor&aacute;ria do est&aacute;gio &eacute; de 20 horas semanais;</li>
                            <li><?php echo e(__("")); ?>O valor da Bolsa &eacute; de:<br>
                                <strong>a)</strong> Ensino Superior: R$ 704,70 para 04 horas<br>
                                <strong>b)</strong> Ensino M&eacute;dio e Profissionalizante: R$ 563,75 para 04 horas<br>
                                <strong>c)</strong> O Aux&iacute;lio-transporte ser&aacute; concedido, proporcionalmente aos
                                dias efetivamente estagiados. .
                            </li>
                        </ol>


                        <div>
                            <p><?php echo e(__("")); ?>Em caso de d&uacute;vidas, ligue:&nbsp;<br>
                                &nbsp; &nbsp; &nbsp; &nbsp; (24) 3323-3916 - CIEE - Centro de Integra&ccedil;&atilde;o
                                Empresa Escola<br>
                                &nbsp; &nbsp; &nbsp; &nbsp; (24) 3365-7766 - Superintend&ecirc;ncia de Gest&atilde;o de
                                Pessoas </p>
                        </div>


                    </article>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo e(__("")); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/estagio-prefeitura.blade.php ENDPATH**/ ?>