@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Enquete Pública da Saúde")
@section('content')


<div class="container my-5">
    <div class="row p-2">
        <div class="col-12">
            <h1 class="display-4">Enquete Pública da Saúde</h1>
            <p class="lead text-soft">
                Contribua com a construção do <strong>Plano Municipal de Saúde 2026–2029</strong>. Sua participação é essencial!
            </p>
            <p class="text-soft fs-5 py-3">23 de maio 2025</p>
        </div>
    </div>
    <div class="row p-2">
        <div class="col-12 col-sm-12 col-md-9 col-xl-9 col-xxl-9">
            <div class="row-12">
                <div class="col-12">
                    <img src="{{ asset('pmar/assets/img/saude/agentes-de-saude.jpg') }}" class="d-block w-100 rounded-3" alt="...">
                </div>
                <div class="col-12 my-2">
                    <a href="https://forms.gle/p2pC8BUqN8QzyoCd7" target="_blank" class="btn btn-secondary btn-lg my-3 fs-3">
                        Acessar Enquete
                    </a>
                    <p class=" mb-3">
                        A Prefeitura Municipal de Angra dos Reis, por meio da Secretaria de Saúde, convida toda a população a participar da <strong>Enquete Pública da Saúde</strong>. Essa consulta é parte fundamental da construção do novo <strong>Plano Municipal de Saúde 2026–2029</strong>, e tem como objetivo ouvir diretamente os usuários do SUS sobre os serviços de saúde oferecidos no município.
                    </p>

                    <p class="mb-3">
                    Através deste questionário, você poderá compartilhar suas experiências, apontar dificuldades no acesso ao atendimento, e contribuir com sugestões que podem transformar a saúde pública de Angra dos Reis. Sua opinião será analisada de forma técnica pela equipe da Coordenação de Planejamento da Saúde e ajudará a definir prioridades e estratégias mais eficazes para o atendimento à população.
                    </p>

                    <p class="mb-3">
                        A participação popular é essencial para promover um sistema de saúde mais justo, humano e eficiente. <strong>Participe da enquete</strong> e ajude a construir um futuro melhor para nossa cidade. O questionário pode ser acessado até o dia <strong>8 de junho de 2025</strong>, por meio do link:
                        <br>
                    </p>

                    <p class="text-muted mb-3">
                        As informações coletadas estão protegidas pela <strong>Lei Geral de Proteção de Dados (LGPD)</strong> e serão utilizadas exclusivamente para fins de planejamento de políticas públicas.
                    </p>

                    <h3 class="fw-bold text-soft my-4 opacity-75">
                        Faça parte da mudança. Sua voz importa!
                    </h3>
                </div>

                <div class="col-12">
                </div>
            </div>
        </div>
        <div class="col-12 col-sm-12 col-md-3 col-xl-3 col-xxl-3">
            <img src="{{ asset('pmar/assets/img/saude/banner-enquete-saude.jpg') }}" class=" rounded shadow w-100 " alt="Banner Enquete">
            <div id="carouselExampleAutoplaying" class="carousel slide my-5" data-bs-ride="carousel">
                <div class="carousel-inner">
                    <div class="carousel-item active">
                        <img src="{{ asset('pmar/assets/img/saude/equipe-saude-1.jpg') }}" class="d-block w-100 rounded-3" alt="...">
                    </div>
                    <div class="carousel-item">
                        <img src="{{ asset('pmar/assets/img/saude/equipe-saude-2.jpg') }}" class="d-block w-100 rounded-3" alt="...">
                    </div>
                    <div class="carousel-item">
                        <img src="{{ asset('pmar/assets/img/saude/equipe-saude-3.jpg') }}" class="d-block w-100 rounded-3" alt="...">
                    </div>
                </div>
                <button class="carousel-control-prev" type="button" data-bs-target="#carouselExampleAutoplaying" data-bs-slide="prev">
                    <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Previous</span>
                </button>
                <button class="carousel-control-next" type="button" data-bs-target="#carouselExampleAutoplaying" data-bs-slide="next">
                    <span class="carousel-control-next-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Next</span>
                </button>
            </div>
        </div>
    </div>
</div>

@endsection