@php
    /** @var \App\Models\ProjetosProgramas\ProjetoPrograma|null $project */
    $project = $project ?? null;

    $nomeProjeto = old('denominacao', $project->denominacao ?? null);
    $nomePrograma = $project?->programa?->nome;
    $nomeObjetivo = $project?->objetivo?->nome;

    $hasAny = (bool) ($nomeProjeto || $nomePrograma || $nomeObjetivo);
@endphp

@if($hasAny)
    <div class="sticky-top bg-white border rounded shadow-sm p-2 mb-3 text-start" role="status" aria-live="polite">
        <div class="d-flex flex-column gap-1">
            @if($nomePrograma)
                <div class="small text-muted">
                    <span class="fw-semibold">{{ __('Programa') }}:</span>
                    <span>{{ $nomePrograma }}</span>
                </div>
            @endif

            @if($nomeObjetivo)
                <div class="small text-muted">
                    <span class="fw-semibold">{{ __('Objetivo') }}:</span>
                    <span>{{ $nomeObjetivo }}</span>
                </div>
            @endif

            @if($nomeProjeto)
                <div class="small">
                    <span class="fw-semibold">{{ __('Projeto/Ação') }}:</span>
                    <span>{{ $nomeProjeto }}</span>
                </div>
            @endif
        </div>
    </div>
@endif

