@foreach ($tabs as $tab)
    <button class="btn btn-lg btn-primary d-inline text-white m-2 fs-5 novo-arquivo"
        onclick="window.location.href='{{ route($tab['url']) }}'">
        <i class="fa-solid {{ $tab['class'] }}"></i> {{ __($tab['label']) }}
    </button>
@endforeach
