<section id="features">
    <div class="container px-5">
        <div class="row container-fluid align-items-center">
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-person-check icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Menos burocracia</h3>
                    <p class="text-muted mb-0">Facilidade para abertura e consulta de processos</p>
                </div>
            </div>
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-search icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Transparência</h3>
                    <p class="text-muted mb-0">Velocidade no acesso à informações</p>
                </div>
            </div>
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-laptop icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Praticidade</h3>
                    <p class="text-muted mb-0">Consulta ao sistema via internet</p>
                </div>
            </div>
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-stopwatch icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Velocidade</h3>
                    <p class="text-muted mb-0">Mais agilidade, eficiência e celeridade aos processos</p>
                </div>
            </div>
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-currency-dollar icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Economia e Sustentabilidade</h3>
                    <p class="text-muted mb-0">Economia de papel e material de escritório</p>
                </div>
            </div>
            <div class="col-md-4 mb-5">
                <!-- Feature item-->
                <div class="text-center">
                    <i class="bi-folder-check icon-feature text-gradient d-block mb-3"></i>
                    <h3 class="font-alt">Integração</h3>
                    <p class="text-muted mb-0">Comunicação interna 100% digital entre os setores públicos</p>
                </div>
            </div>
        </div>
    </div>
</section>