<?php echo $__env->make('paginas.parts.telefones', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<?php echo $__env->make('paginas.parts.links', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/org-fale-conosco-aside.blade.php ENDPATH**/ ?>