@props(['userName', 'userPhoto', 'title' => 'Conta Angra', 'subtitle' => null])

<div class="dashboard-header mb-4">
    <div class="welcome-section">
        <div class="welcome-avatar">
            <img src="{{ asset($userPhoto) }}" alt="{{ $userName }}" class="avatar-img">
        </div>
        <div class="welcome-content">
            <h1 class="dashboard-title">
                <i class="fa-solid fa-user-tag me-2"></i>
                {{ __($title) }}
            </h1>
            <p class="dashboard-subtitle text-muted">
                {{ __("Seja bem-vindo(a)") }}, <strong>{{ $userName }}</strong>
            </p>
        </div>
    </div>
</div>

