<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'secretaria' => null,
    'links' => collect(),
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'secretaria' => null,
    'links' => collect(),
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php if($secretaria): ?>
    <article class="ma-org-card ma-org-card--links">
        <h2 class="ma-org-card__title"><?php echo e(__('Saiba mais')); ?></h2>

        <ul class="ma-org-links list-unstyled mb-0">
            <li>
                <a class="ma-org-links__item" href="<?php echo e(route('paginas.formacao-academica', $secretaria->slug)); ?>">
                    <span class="ma-org-links__text">
                        <?php if($secretaria->type == 'SECRETARIA'): ?>
                            <?php if($secretaria->pronunciation == 'SECRETARIO'): ?>
                                <?php echo e(__('Secretário')); ?>

                            <?php elseif($secretaria->pronunciation == 'PROCURADO_GERAL_DO_MUNICIPIO'): ?>
                                <?php echo e(__('Procurador-Geral')); ?>

                            <?php elseif($secretaria->pronunciation == 'CONTROLADOR_GERAL_DO_MUNICIPIO'): ?>
                                <?php echo e(__('Controlador-Geral')); ?>

                            <?php else: ?>
                                <?php echo e(__('Secretária')); ?>

                            <?php endif; ?>
                        <?php elseif($secretaria->type == 'FUNDACAO' || $secretaria->type == 'AUTARQUIA'): ?>
                            <?php echo e(__('Presidente')); ?>

                        <?php elseif($secretaria->type == 'SUPERINTENDENCIA'): ?>
                            <?php echo e(__('Superintendente')); ?>

                        <?php elseif($secretaria->type == 'DIRETORIA'): ?>
                            <?php if($secretaria->pronunciation == 'DIRETOR'): ?>
                                <?php echo e(__('Diretor')); ?>

                            <?php else: ?>
                                <?php echo e(__('Diretora')); ?>

                            <?php endif; ?>
                        <?php elseif($secretaria->type == 'SECRETARIA_EXECUTIVA'): ?>
                            <?php if($secretaria->pronunciation == 'SECRETARIO_EXECUTIVO'): ?>
                                <?php echo e(__('Secretário Executivo')); ?>

                            <?php else: ?>
                                <?php echo e(__('Secretária Executiva')); ?>

                            <?php endif; ?>
                        <?php endif; ?>
                    </span>
                    <i class="fa-solid fa-angle-right ma-org-links__icon" aria-hidden="true"></i>
                </a>
            </li>
            <li>
                <a class="ma-org-links__item" href="<?php echo e(route('paginas.competencias-e-atribuicoes', $secretaria->slug)); ?>">
                    <span class="ma-org-links__text"><?php echo e(__('Competências e atribuições')); ?></span>
                    <i class="fa-solid fa-angle-right ma-org-links__icon" aria-hidden="true"></i>
                </a>
            </li>
            <li>
                <a class="ma-org-links__item"
                    href="<?php echo e(\App\Support\StructurePublicUrls::faleConoscoUrl($secretaria)); ?>">
                    <span class="ma-org-links__text"><?php echo e(__('Fale conosco')); ?></span>
                    <i class="fa-solid fa-angle-right ma-org-links__icon" aria-hidden="true"></i>
                </a>
            </li>
            <?php $__currentLoopData = $links; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $link): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <?php if(\App\Support\StructurePublicUrls::isAdministrativeFaleConoscoTitulo($link->titulo ?? null)): ?>
                    <?php continue; ?>
                <?php endif; ?>
                <li>
                    <a class="ma-org-links__item" href="<?php echo e(url($link->link)); ?>" target="<?php echo e($link->status); ?>">
                        <span class="ma-org-links__text"><?php echo e($link->titulo); ?></span>
                        <i class="fa-solid fa-angle-right ma-org-links__icon" aria-hidden="true"></i>
                    </a>
                </li>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        </ul>
    </article>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/saiba-mais-links.blade.php ENDPATH**/ ?>