<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'empresasTurismo' => collect(),
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'empresasTurismo' => collect(),
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    use App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource;

    $empresasComAlerta = $empresasTurismo->filter(function ($empresaTurismo) {
        return EmpresaTurismoResource::cadasturMensagemAlertaVisual($empresaTurismo) !== null;
    })->values();

    $totalAlertas = $empresasComAlerta->count();
?>

<?php if($totalAlertas > 0): ?>
    <div class="ca-cadastur-alert mb-4" role="alert" aria-live="polite">
        <div class="alert alert-warning border-0 shadow-sm mb-0">
            <div class="d-flex align-items-start">
                <div class="flex-shrink-0">
                    <div class="ca-cadastur-alert__icon-wrap bg-warning bg-opacity-25 rounded-circle d-flex align-items-center justify-content-center">
                        <i class="fa-solid fa-calendar-xmark text-warning fs-5" aria-hidden="true"></i>
                    </div>
                </div>
                <div class="flex-grow-1 ms-3 min-w-0">
                    <div class="d-flex align-items-center justify-content-between mb-2 flex-wrap gap-2">
                        <h2 class="h5 alert-heading mb-0 fw-bold text-dark">
                            <i class="fa-solid fa-bell text-danger me-2" aria-hidden="true"></i>
                            <?php echo e(__('Vencimento do CADASTUR')); ?>

                        </h2>
                        <span class="badge bg-warning text-dark rounded-pill">
                            <?php echo e($totalAlertas); ?>

                        </span>
                    </div>

                    <p class="mb-3 text-dark">
                        <i class="fa-solid fa-info-circle me-2" aria-hidden="true"></i>
                        <?php if($totalAlertas === 1): ?>
                            <?php echo e(__('Você possui 1 empresa com CADASTUR próximo do vencimento. Providencie a renovação junto aos órgãos competentes.')); ?>

                        <?php else: ?>
                            <?php echo e(__('Você possui :count empresas com CADASTUR próximo do vencimento. Providencie a renovação junto aos órgãos competentes.', ['count' => $totalAlertas])); ?>

                        <?php endif; ?>
                    </p>

                    <ul class="list-unstyled mb-0 d-flex flex-column gap-2">
                        <?php $__currentLoopData = $empresasComAlerta; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $empresaTurismo): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php
                                $mensagem = EmpresaTurismoResource::cadasturMensagemAlertaVisual($empresaTurismo);
                                $nomeEmpresa = $empresaTurismo->companhia?->razaoSocial
                                    ?: $empresaTurismo->companhia?->nomeFantasia
                                    ?: __('Empresa de Turismo');
                                $diasRestantes = EmpresaTurismoResource::cadasturDiasRestantes($empresaTurismo);
                                $vencimentoFormatado = $empresaTurismo->cadastur_vencimento?->format('d/m/Y');
                            ?>
                            <li class="ca-cadastur-alert__item">
                                <div class="d-flex align-items-start justify-content-between gap-2 flex-wrap">
                                    <div class="min-w-0">
                                        <p class="ca-cadastur-alert__empresa mb-1 fw-semibold text-dark">
                                            <?php echo e($nomeEmpresa); ?>

                                        </p>
                                        <p class="ca-cadastur-alert__mensagem mb-0 small text-secondary">
                                            <?php echo e($mensagem); ?>

                                        </p>
                                    </div>
                                    <?php if($diasRestantes !== null): ?>
                                        <span class="badge ca-cadastur-alert__dias-badge rounded-pill flex-shrink-0">
                                            <?php if($diasRestantes === 0): ?>
                                                <?php echo e(__('Vence hoje')); ?>

                                            <?php elseif($diasRestantes === 1): ?>
                                                <?php echo e(__('1 dia')); ?>

                                            <?php else: ?>
                                                <?php echo e(__(':count dias', ['count' => $diasRestantes])); ?>

                                            <?php endif; ?>
                                        </span>
                                    <?php endif; ?>
                                </div>
                                <div class="ca-cadastur-alert__meta d-flex flex-wrap gap-2 mt-2">
                                    <span class="badge bg-light text-dark border">
                                        <?php echo e(__('Cadastur')); ?>: <?php echo e($empresaTurismo->cadastur); ?>

                                    </span>
                                    <?php if($vencimentoFormatado): ?>
                                        <span class="badge bg-light text-dark border">
                                            <?php echo e(__('Vencimento')); ?>: <?php echo e($vencimentoFormatado); ?>

                                        </span>
                                    <?php endif; ?>
                                </div>
                            </li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                </div>
            </div>
        </div>
    </div>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/alerts/_cadasturVencimentoContaAngra.blade.php ENDPATH**/ ?>