<?php $__env->startSection('title', env('APP_NAME') . ' :: Credenciamento de Músicos de Angra dos Reis'); ?>
<?php $__env->startSection('content'); ?>
<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a href="<?php echo e(route('paginas.home')); ?>"><?php echo e(__('Portal')); ?></a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <?php echo e(__('Credenciamento de Músicos de Angra dos Reis')); ?>

                        </li>
                    </ol>
                </nav>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <h1 class="mb-3"><?php echo e(__('Credenciamento de Músicos de Angra dos Reis')); ?></h1>

                <p class="mb-3"><?php echo e(__("Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.")); ?></p>
                <p class="mb-3"><?php echo e(__("Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.")); ?></p>
                <p class="mb-3"><?php echo e(__("O acompanhamento do processo é de responsabilidade do músico, e a retirada do cartão deverá ser feita presencialmente na sede da Secretaria de Cultura.")); ?></p>
                <p class="mb-3"><?php echo e(__("De acordo com a ")); ?><strong><?php echo e(__("Lei Municipal nº 0.0000, de xx de novembro de xxxx")); ?></strong><?php echo e(__(", desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for.")); ?></p>

                <p class="mb-3"><?php echo e(__("Antes de iniciar o preenchimento, certifique-se de ter em mãos toda a documentação digitalizada necessária para emissão do cartão de identificação.")); ?></p>

                <ol class="list-group list-group-numbered mb-3">
                    <li class="list-group-item"><?php echo e(__("Laudo Médico com a descrição da condição de fibromialgia (CID10 M79.7);")); ?></li>
                    <li class="list-group-item"><?php echo e(__("01 foto tamanho 3x4;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("Comprovante de residência;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("RG;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("CPF e;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("Cartão SUS.")); ?></li>
                </ol>

                <p class="alert alert-info mb-3"><?php echo e(__("Lembramos que é de responsabilidade do usuário acompanhar pelo sistema o andamento do processo e a retirada do cartão deverá ser feita na Secretaria de Cultura.")); ?></p>

                <hr>

                <div class="mb-3">
                    <a class="btn btn-lg btn-primary" href="<?php echo e(route('admin.cultura.credenciamentoMusicos.perfil.index')); ?>"></a>
                    <?php echo e(__("Sim, desejo fazer a adesão ao Credenciamento de Músicos de Angra dos Reis.")); ?>

                    </a>
                </div>

            </div>
        </div>
    </div>
</section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/cultura/credenciamentoMusicos.blade.php ENDPATH**/ ?>