<?php $__env->startSection("title", env("APP_NAME") . " :: Página de Acompanhamento - Paciente com Fibromialgia - Dados Pessais"); ?>
<?php $__env->startSection('content'); ?>

    <div class="card shadow">

        <?php $headLine = "<i class='fa-solid fa-user-injured'></i> Página de Acompanhamento - Paciente com Fibromialgia - Dados Pessais"; ?>

        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

        <div class="card-body">
            <form action="<?php echo e(route("admin.saude.fibromialgia.perfil.dadosPessoaisUpdate", [$paciente->id, $pessoa->id])); ?>" method="post" enctype="multipart/form-data">

                <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                <?php echo csrf_field(); ?>
                <?php echo method_field('post'); ?>
                
                <?php echo $__env->make('components.modal._modelProfile', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                <div class="tab-content">
                    
                    
                    <div class="row">
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Nome da mãe -->
                            <?php echo $__env->make('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Nome da mãe completo",
                                "name" => "nomeMae",
                                "id" => null,
                                "required" => true,
                                "type" => null,
                                "old" => old('nomeMae', $pessoa?->nomeMae),
                                "oninput" => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\p{L}\s]+/gu, '').replace(/\s{2,}/g,' ').trimStart()",
                                "readonly" => false,
                                "small" => null,
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        </div>
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Nome do Pai -->
                            <?php echo $__env->make('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Nome do pai completo",
                                "name" => "nomePai",
                                "id" => null,
                                "required" => false,
                                "type" => null,
                                "old" => old('nomePai', $pessoa?->nomePai),
                                "oninput" => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\p{L}\s]+/gu, '').replace(/\s{2,}/g,' ').trimStart()",
                                "readonly" => false,
                                "small" => null,
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-sm-12 col-md-6">
                            <!-- Campo Data de Nascimento -->
                            <?php echo $__env->make('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Data de Nascimento",
                                "name" => "dtaNascimento",
                                "id" => null,
                                "required" => true,
                                "type" => "date",
                                "old" => old('dtaNascimento', $pessoa?->dtaNascimento),
                                "oninput" => "",
                                "readonly" => false,
                                "small" => null,
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                        </div>
                        <div class="col-sm-12 col-md-6">
                             <!-- Campo Sexo -->
                            <?php echo $__env->make('components.inputs._selectType', [
                                "for" => "sexo",
                                "label" => "Sexo",
                                "name" => "sexo",
                                "required" => true,
                                "readonly" => false,
                                "options" => collect(App\Enums\StatusSexo::cases())
                                    ->mapWithKeys(fn($status) => [$status->name => $status->value])
                                    ->toArray(),
                                "selected" => old('sexo', $pessoa?->sexo ?? 'NAO_INFORMADO'),
                                "placeholder" => "Selecione uma opção...",
                                "small" => "Informe o sexo.",
                                "onchange" => null
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                             
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="d-flex justify-content-between mt-4">
                            <a class="btn btn-outline-secondary" href="<?php echo e(route("admin.saude.fibromialgia.perfil.show", $paciente->id)); ?>">
                                <i class="fa-solid fa-arrow-left-long"></i> <?php echo e(__("Voltar")); ?>

                            </a>
                            <button class="btn btn-primary d-inline" type="submit">
                                <i class="fa-solid fa-user-plus"></i> <?php echo e(__("Salvar")); ?>

                            </button>
                        </div>
                    </div>
                </div>
            </form>

        </div>
    </div>

<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/saude/fibromialgia/perfil/dadosPessoais.blade.php ENDPATH**/ ?>