<section class="exibition-area section-gap" id="exhibitions">
    <div class="container">
        <div class="row d-flex justify-content-center">
            <div class="menu-content pb-60 col-lg-10">
                <div class="title text-center">
                    <h1 class="mb-10">Ongoing Exhibitions from the scratch</h1>
                    <p>Who are in extremely love with eco friendly system.</p>
                </div>
            </div>
        </div>
        @if ($acervos->isEmpty())
            <p class="text-center text-muted">Nenhum item disponível para exibição no momento.</p>
        @else
            <div class="row">
                <div class="active-exibition-carusel">
                    @foreach ($acervos as $arte)
                        <div class="single-exibition item">
                            @if ($arte->imagem && $arte->imagem !== 'default.jpg')
                                <img src="{{ asset('pmar/assets/img/arte_sacra/' . $arte->imagem) }}" alt="{{ $arte->nome_peca }}"
                                    height="250" class="w-100" style="object-fit: cover;">
                            @else
                                <img src="{{ asset('pmar/assets/img/arte_sacra/default.jpg') }}" alt="Imagem não disponível"
                                    class="w-100" style="height: 250px; object-fit: cover;">
                            @endif
                            <ul class="tags">
                                <li><a href="#">Travel</a></li>
                                <li><a href="#">Life style</a></li>
                            </ul>
                            <a href="#">
                                <h4>Portable latest blog for women</h4>
                            </a>
                            <p>
                                Lorem ipsum dolor sit amet, consec teturadip isicing elit, sed do eiusmod tempor.
                            </p>
                            <h6 class="date">31st January, 2018</h6>
                        </div>
                    @endforeach
                </div>
            </div>
        @endif
    </div>
</section>