@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Arte Sacra - Reciclagem ou Exclusão de Peças')

@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-church'></i> Arte Sacra - Reciclagem ou Exclusão de Peças"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            "headLine" => __($headLine),
            "routeBack" => "admin.cultura.arteSacra.index",
            "routeBackParams" => [],
            "fontawesomeBack" => '<i class="fa-solid fa-rectangle-list"></i>',
            "nameBack" => __("Lista de Peças"),
            "routeAdd" => "admin.cultura.arteSacra.create",
            "routeAddParams" => [],
            "nameAdd" => __("Nova peça"),
            "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
            "tabs" => [
                [
                    'route' => 'admin.cultura.arteSacra.options', 
                    'class' => 'fa-list', 
                    'label' => 'Edição de Opções', 
                    'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA',
                ],
                [
                    'route' => 'admin.cultura.arteSacra.report', 
                    'class' => 'fa-list-check', 
                    'label' => 'Relatório Geral', 
                    'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA',
                ],
                [
                    'route' => 'admin.cultura.arteSacra.logs.usuarios', 
                    'class' => 'fa-user-secret', 
                    'label' => 'Logs de Usuários', 
                    'permission' => 'DIRETOR_DE_ARTE_SACRA',
                ],
            ],
        ])


        <div class="card-body">
            @include('errors.messageFlash')

            @include('components.buttons._searchAndClean', [
                'url' => 'admin.cultura.arteSacra.trash', 'label1' => 'Buscar', 'label2' => 'Limpar', 'search' => 'busca', 'placeholder' => 'Buscar peças...'
            ])

            <x-tables._table :thead="['Imagem', 'Data de Cadastro', 'Código Acervo', 'Nome da Peça', 'Ano da Peça', 'Tipo', 'Modo de Aquisição', 'Material', 'Proprietário', 'Localização', 'Exibição Publica', 'Ações']" :pagination="$artes->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($artes as $arte)
                        <tr>
                            <td style="width:150px">

                                @include('components.tables._openPhotoAndPdf',[
                                    'asset' => file_exists($arte->imagem) ? $arte->imagem : 'pmar/assets/img/icons/default.png',
                                    'alt' => $arte->nome_peca,
                                    'title' => $arte->nome_peca,
                                    'text' => 'Foto',
                                    'index' => $index,
                                ])
                            </td>
                            <td>{{ date('d/m/Y H:m:s', strtotime($arte->created_at)) }}</td>
                            <td>{{ $arte->codigo_acervo }}</td>
                            <td>{{ $arte->nome_peca }}</td>
                            <td>{{ $arte->ano_arte }}</td>
                            <td>{{ optional($arte->tipo)->tipo ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->modoAquisicao)->modo_aquisicao ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->material)->material ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->proprietario)->proprietario ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->localizacao)->proprietario ?? 'Não informado' }}</td>
                            <td>{{ $arte->permitir_exibicao }}</td>
                            <td class="text-nowrap text-center align-middle">
                                <form id="form-ativar" method="POST" style="display: none;">
                                    @csrf
                                </form>
                                <form id="form-excluir" method="POST" style="display: none;">
                                    @csrf
                                    @method('DELETE')
                                </form>
                                <div class="d-flex gap-2 justify-content-center">
                                    
                                    @include('components.buttons._deleteButton', [
                                        "message" => __("* Confirma a ativação desta peça?"),
                                        "route" => "admin.cultura.arteSacra.inativarOuAtivar",
                                        "id" => $arte->id,
                                        "title" => "Ativar",
                                        "method" => "post",
                                        "fontawesome" => '<i class="fa-solid fa-rotate-left"></i>',
                                        "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
                                    ])

                                    @include('components.buttons._deleteButton', [
                                        "message" => __("* Confirma a exclusão permanente desta peça?\n\nEssa ação não poderá ser desfeita."),
                                        "route" => "admin.cultura.arteSacra.destroy",
                                        "id" => $arte->id,
                                        "title" => "Excluir",
                                        "fontawesome" => '<i class="fa-solid fa-trash"></i>',
                                        "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
                                    ])
                                </td>
                            </tr>
                            @php $index++; @endphp
                        @endforeach
                    </x-slot>
                </x-tables._table>

            </div>
        </div>
@endsection
