<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'numero',
    'naoLidas' => 0,
    'monospace' => true,
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'numero',
    'naoLidas' => 0,
    'monospace' => true,
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    $totalNaoLidas = max(0, (int) $naoLidas);
    $rotuloNaoLidas = $totalNaoLidas > 99 ? '99+' : (string) $totalNaoLidas;
?>

<div class="chamado-registro-numero">
    <span class="<?php echo \Illuminate\Support\Arr::toCssClasses([
        'chamado-registro-numero__pill',
        'badge bg-light text-dark border',
        'font-monospace' => $monospace,
    ]); ?>"><?php echo e($numero); ?></span>

    <?php if($totalNaoLidas > 0): ?>
        <span class="chamado-registro-numero__novas"
              title="<?php echo e(__(':count nova(s) mensagem(ns)', ['count' => $totalNaoLidas])); ?>"
              aria-label="<?php echo e(__(':count nova(s) mensagem(ns)', ['count' => $totalNaoLidas])); ?>">
            <?php echo e($rotuloNaoLidas); ?>

        </span>
    <?php endif; ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/chamados/registro-numero-badge.blade.php ENDPATH**/ ?>