@if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['adicionar'])
    <tr class="filter-row {{ $type }}-row">
        <td>
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">{{ __($title) }}</h5>
                    <form method="POST" action="{{ route('admin.cultura.arteSacra.options.store', ['type' => $type]) }}">
                        <div class="input-group mb-3">
                            @csrf
                            <input type="text" name="name" class="form-control" placeholder="{{ __($title) }}" required>
                            <button type="submit" class="btn btn-outline-secondary">{{ __("Adicionar") }}</button>
                        </div>                            
                    </form> 
                </div>
            </div>
        </td>
        <td> </td>
    </tr>
@endif