<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.mobiangra.elements.head')

<body id="mobiangra-page" class="ma-body">
    @include('layouts.mobiangra.elements.defaultBar')

    <header class="ma-header">
        @include('layouts.mobiangra.elements.header')
    </header>

    <main class="ma-main" id="main-content">
        @yield('content')
    </main>

    @hasSection('help-bar')
        @yield('help-bar')
    @else
        @include('mobiangra.sections.help-bar')
    @endif

    <footer class="ma-footer">
        @include('layouts.mobiangra.elements.footer')
    </footer>

    @include('layouts.mobiangra.elements.bottom-nav')

    @stack('scripts')
    <script src="{{ asset('mobiangra-assets/js/portal.js') }}?v={{ time() }}"></script>
</body>

</html>
