<?php $__env->startSection('title', env('APP_NAME').' :: '.__('Recuperar Senha')); ?>
<?php $__env->startSection('content'); ?>
    <form autocomplete="on" id="formRecuperarSenha" name="formRecuperarSenha" method="post" action="<?php echo e(route('admin.enviarEmailRecuperacao')); ?>">
        <section class="d-flex align-items-center min-vh-100">
            <div class="container">
                <div class="row justify-content-center">
                    <div class="col-12">
                        <div class="card-admin-login p-5">
                            <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                            <div class="text-center">
                                <img src="<?php echo e(asset("pmar/assets/img/logo-angra-branco.svg")); ?>" class="card-img-top" title="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" alt="<?php echo e(__("Prefeitura Municipal de Angra dos Reis")); ?>" class="img-fluid text-center" style="width: 100%; height: 5rem;" />
                            </div>
                            <style>
                                .form-label{ color: #FFF !important}
                            </style>
                            <div class="card-body">
                                <h5 class="text-white card-title text-center"><?php echo e(__('Recuperar senha')); ?></h5>
                                <br>
                                <?php echo csrf_field(); ?>
                                <div class="mb-3">
                                    <input type="hidden" class="form-control" name="recaptcha" id="recaptcha">

                                    <!-- CPF ou E-mail -->
                                    <?php echo $__env->make('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "CPF ou E‑mail",
                                        "name" => "login",
                                        "id" => "loginEsqueceu",
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('login'),
                                        "oninput" => null,
                                        "readonly" => false,
                                        "small" => null,
                                        "autocomplete" => "username",
                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                    <small class="small-login-esqueceu"></small>
                                </div>

                                <div class="my-3">
                                    <button class="fs-5 rounded-4 btn m-auto btn-primary w-100" type="submit" id="submitRecuperarSenha"><?php echo e(__('Enviar')); ?></button>
                                </div>
                                <hr/>
                                <div class="my-3 text-center">
                                    <a href="<?php echo e(route("admin.login")); ?>" class="text-white">Login</a> | <a href="<?php echo e(route("admin.contas.publicas.create")); ?>" class="text-white">Crie sua conta</a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div id='recaptchaRecuperarSenha' data-size="invisible"></div>
        </section>
    </form>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.login.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/esqueceuSenha.blade.php ENDPATH**/ ?>