@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Objetivos de Projetos e Programas'))
@section('content')

    <div class="card shadow-sm">
        @php
            $headLine = "<i class='fa-solid fa-bullseye'></i> " . __('Objetivos de Projetos e Programas');
        @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.projetosProgramas.index',
            'routeBackParams' => ['tab' => 'objetivos'],
            'nameBack' => __('Voltar para lista de projetos'),
            'routeAdd' => 'admin.projetosProgramas.objetivos.create',
            'routeAddParams' => [],
            'nameAdd' => __('Novo Objetivo'),
            'permission' => 'GERENCIADOR_DE_PROJETOS_E_PROGRAMAS',
        ])

        <div class="card-body pt-3">
            @include('errors.messageFlash')

            <form method="get" class="row g-2 mb-3">
                <div class="col-md-6">
                    <label class="form-label small">{{ __('Buscar') }}</label>
                    <div class="input-group input-group-sm">
                        <input type="text"
                               name="search"
                               class="form-control"
                               value="{{ request('search') }}"
                               placeholder="{{ __('Buscar por nome do objetivo') }}">
                        <button class="btn btn-outline-secondary" type="submit">
                            <i class="fa fa-search"></i>
                        </button>
                    </div>
                </div>
                <div class="col-md-2">
                    <label class="form-label small">{{ __('Por página') }}</label>
                    <select name="per_page" class="form-select form-select-sm" onchange="this.form.submit()">
                        @foreach($perPageOptions as $option)
                            <option value="{{ $option }}" {{ $currentPerPage == $option ? 'selected' : '' }}>{{ $option }}</option>
                        @endforeach
                    </select>
                </div>
            </form>

            <x-tables._table :thead="['#', __('Nome'), __('Criado em'), __('Atualizado em'), __('Ações')]" :pagination="$objetivos->links()">
                <x-slot name="body">
                    @php $index = $objetivos->firstItem(); @endphp
                    @forelse($objetivos as $objetivo)
                        <tr>
                            <td class="text-center">{{ $index }}</td>
                            <td class="text-start">{{ $objetivo->nome }}</td>
                            <td class="text-center">{{ optional($objetivo->created_at)->format('d/m/Y H:i') }}</td>
                            <td class="text-center">{{ optional($objetivo->updated_at)->format('d/m/Y H:i') }}</td>
                            <td class="text-center">
                                <div class="d-flex justify-content-center gap-2">
                                    @include('components.buttons._editButton', [
                                        'route' => 'admin.projetosProgramas.objetivos.edit',
                                        'id' => $objetivo->id,
                                        'title' => __('Editar'),
                                        'fontawesome' => null,
                                        'permission' => 'GERENCIADOR_DE_PROJETOS_E_PROGRAMAS',
                                    ])

                                    @include('components.buttons._deleteButton', [
                                        'message' => __('* Este objetivo será excluído e esta ação não poderá ser desfeita, deseja continuar?'),
                                        'route' => 'admin.projetosProgramas.objetivos.destroy',
                                        'id' => $objetivo->id,
                                        'title' => __('Excluir'),
                                        'fontawesome' => null,
                                        'permission' => 'GERENCIADOR_DE_PROJETOS_E_PROGRAMAS',
                                    ])
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @empty
                        <tr>
                            <td colspan="5" class="text-center text-muted py-3">
                                {{ __('Nenhum objetivo cadastrado.') }}
                            </td>
                        </tr>
                    @endforelse
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection

