@php
    use App\Http\Resources\Accounts\AccountResource;

    $listFilterParams = AccountResource::listFilterQueryParams(request());
@endphp

@foreach($listFilterParams as $key => $value)
    <input type="hidden" name="{{ $key }}" value="{{ $value }}">
@endforeach
