@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Novo Convênio'))
@section('content')
    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-plus'></i> " . __('Novo Convênio'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.ppps.index',
            'nameBack' => __('Voltar'),
            'routeAdd' => null,
            'nameAdd' => null,
            'permission' => 'GERENCIADOR_DE_PPPS',
        ])
        <div class="card-body">
            <form action="{{ route('admin.convenios.store') }}" method="POST">
                @csrf
                @include('admin.convenios._form')
            </form>
        </div>
    </div>
@endsection
