<section class="internas-secretarias-home-title">
    <div class="container">
        <div class="row">
            <div class="col">
                @if(isset($secretaria->pertence->name))
                    <h1>{{ $secretaria->name }}{{--  ({{ $secretaria->abbreviation }}) --}}</h1>
                    <p>{{ $secretaria->pertence->name }} ({{ $secretaria->pertence->abbreviation }})</p>
                @else
                    <h1>{{ $secretaria->name }}</h1>
                    {{-- ({{ $secretaria->abbreviation }}) --}}
                @endif
            </div>
        </div>
    </div>
</section>