@props(['label', 'value', 'icon', 'iconBg' => 'bg-primary'])

<div class="info-item">
    <div class="info-icon {{ $iconBg }}">
        <i class="{{ $icon }}"></i>
    </div>
    <div class="info-content">
        <label class="info-label">{{ __($label) }}</label>
        <p class="info-value">{{ $value }}</p>
    </div>
</div>

