<?php $__env->startSection("title", "SEI - Angra dos Reis"); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container-fluid">
            <?php echo $__env->make('sei.sectionsManual.botaoSumario', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('sei.sectionsManual.main', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </section>
    <section>
        <div class="container pt-5 mt-5">
            <?php echo $__env->make('sei.sectionsManual.slideCanva', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.sei.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/sei/manual.blade.php ENDPATH**/ ?>