<div class="col-12 col-md-6 col-xl-4">
    <div class="card h-100 border-0 shadow-sm">
        <div class="card-body">
            <h5 class="card-title mb-3">{{ __($mock['title']) }}</h5>
            <ul class="list-unstyled small mb-3">
                @foreach ($mock['items'] as $item)
                <li class="d-flex justify-content-between mb-2">
                    <span>{{ __($item['label']) }}</span>
                    <span class="fw-semibold text-muted">{{ __($item['value']) }}</span>
                </li>
                @endforeach
            </ul>
            <p class="text-muted small mb-0">{{ __($mock['notes']) }}</p>
            <span class="badge bg-warning text-dark mt-2">{{ __("Em construção") }}</span>
        </div>
    </div>
</div>
