<div class="row">
    <div class="col-12 col-xl-8 home-redes-sociais-texto">
        <h3 class="text-center py-4">{{ __("Siga-nos nas Redes Sociais") }}</h3>
    </div>
    <div class="col-xl-4 col-md-12 home-redes-sociais-logos">
        <div class="home-redes-sociais-logos-logo" onclick="window.open('https://www.instagram.com/prefeituraangra/', '_blank');">
            <i class="fa-brands fa-instagram"></i>
        </div>
        <div class="home-redes-sociais-logos-logo" onclick="window.open('https://www.tiktok.com/@prefeituraangra', '_blank');">
            <i class="fa-brands fa-tiktok"></i>
        </div>
        <div class="home-redes-sociais-logos-logo" onclick="window.open('https://www.facebook.com/PrefeituradeAngra', '_blank');">
            <i class="fa-brands fa-facebook"></i>
        </div>
    </div>
</div>