<!-- Meio Ambiente -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-success">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-leaf fa-2x me-3"></i>
                <h5 class="card-title mb-0">Meio Ambiente</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item">
                    <i class="fas fa-tree me-2 text-muted"></i> 
                    Áreas verdes 
                    <small class="badge bg-info">em breve</small>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-search-location me-2 text-muted"></i> 
                    Fiscalização ambiental 
                    <small class="badge bg-info">em breve</small>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-recycle me-2 text-muted"></i> 
                    Coleta seletiva 
                    <small class="badge bg-info">em breve</small>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-file-alt me-2 text-muted"></i> 
                    Licenciamento 
                    <small class="badge bg-info">em breve</small>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-paw me-2 text-muted"></i> 
                    Castração animal 
                    <small class="badge bg-info">em breve</small>
                </li>
            </ul>
        </div>
        <div class="card-footer bg-transparent">
            <small class="text-muted">Angra dos Reis - Preservada</small>
        </div>
    </div>
</div>
