<?php $__env->startSection('title', env('APP_NAME') . ' :: ' . __('Nova legislação')); ?>

<?php $__env->startSection('content'); ?>
    <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <div class="card shadow-sm">
        <?php $headLine = "<i class='fa-solid fa-plus'></i> " . __('Nova legislação'); ?>
        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.legislacao.index',
            'routeBackParams' => request()->only(['q', 'page', 'ano', 'tipo', 'status', 'sort_by', 'sort_dir']),
            'nameBack' => __('Legislações'),
            'permission' => 'GERENCIADOR_DE_LEGISLACAO',
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <div class="card-body">
            <form id="legislacao-main-form" method="post"
                action="<?php echo e(route('admin.legislacao.store', request()->only(['q', 'page', 'ano', 'tipo', 'status', 'sort_by', 'sort_dir']))); ?>"
                enctype="multipart/form-data">
                <?php echo csrf_field(); ?>
                <?php echo $__env->make('admin.legislacao._form', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </form>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php $__env->startPush('scripts'); ?>
    
    <link rel="stylesheet" href="<?php echo e(asset('pmar/lib/tom-select/tom-select.bootstrap5.min.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/admin/legislacao/categorias-tom-select.css')); ?>">
<?php $__env->stopPush(); ?>

<?php $__env->startPush('after-scripts'); ?>
    <script src="<?php echo e(asset('pmar/lib/tom-select/tom-select.complete.min.js')); ?>"></script>
    <script src="<?php echo e(asset('pmar/js/admin/legislacao-boletim-api-select.js')); ?>" defer></script>
    <script src="<?php echo e(asset('pmar/js/admin/legislacao-form.js')); ?>" defer></script>
<?php $__env->stopPush(); ?>

<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/legislacao/create.blade.php ENDPATH**/ ?>