<?php
    $extensoesImagem = ['jpg', 'jpeg', 'png', 'gif'];
    $extensao = pathinfo($asset, PATHINFO_EXTENSION);
?>
<?php if(in_array(strtolower($extensao), $extensoesImagem)): ?>
    <button type="button" style="border: 0; background" class="btn" data-bs-toggle="modal" data-bs-target="#open_<?php echo e($index); ?>">
        <img src="<?php echo e(asset($asset)); ?>" alt="<?php echo e($alt); ?>" title="<?php echo e($title); ?>" class="img-fluid img-thumbnail src-file-image" <?php if(!empty($style)): ?> style="<?php echo e($style); ?>" <?php endif; ?>>
    </button>
    <div class="modal fade" id="open_<?php echo e($index); ?>" tabindex="-1"
     aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-xl">
            <div class="modal-content">
                <div class="modal-header">
                    <h1 class="modal-title fs-5" id="exampleModalLabel"><?php echo e($text); ?></h1>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <img src="<?php echo e(asset($asset)); ?>" title="<?php echo e($title); ?>" alt="<?php echo e($title); ?>" class="img-fluid rounded-2">
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary"
                    data-bs-dismiss="modal">Fechar</button>
                </div>
            </div>
        </div>
    </div>
<?php else: ?>
    <span class="text-muted">Arquivo não suportado</span>
<?php endif; ?><?php /**PATH /var/www/html/portal/resources/views/components/tables/_openPhoto.blade.php ENDPATH**/ ?>