<?php $__env->startSection('title', env('APP_NAME') . ' :: ' . __('Editar Contrato')); ?>

<?php $__env->startSection('content'); ?>
    <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <div class="card shadow-sm">
        <?php $headLine = "<i class='fa-solid fa-file-contract'></i> " . __('Contratos'); ?>
        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.contratos.index',
            'routeBackParams' => request()->only(['q', 'ano', 'con_modalidade', 'con_status', 'page']),
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.contratos.create',
            'routeAddParams' => request()->only(['q', 'ano', 'con_modalidade', 'con_status', 'page'])
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <div class="card-body">
            <form method="post" action="<?php echo e(route('admin.contratos.update', $registro->id_contrato)); ?>">
                <?php echo $__env->make('admin.contratos._form', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </form>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/contratos/edit.blade.php ENDPATH**/ ?>