<div class="topo">
	<div class="container">
		<div class="row">
			<div class="topo-logo">
				<a href="{{ route("sei.index") }}">
					<img src="{{ asset("sei-angra/assets/img/sei-angra.svg") }}" class="topo-logo-img"
						alt="Prefeitura de Angra, Construindo oportunidades">
				</a>
			</div>
		</div>
	</div>
</div>

<div class="topo-nav">
	<nav class="navbar bg-light navbar-expand-xl shadow-lg py-2 rounded-4" id="mainNav">
		<div class="container">
			<a class="navbar-brand fw-bold" href="{{ route("paginas.home") }}"><img id="logo-nav"
					src="{{ asset('pmar/assets/img/logo-pmar.svg') }}" alt="Sei Angra dos Reis"></a>

			<button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarResponsive"
				aria-controls="navbarResponsive" aria-expanded="false" aria-label="Toggle navigation">
				<span class="navbar-toggler-icon"></span>
			</button>

			<div class="collapse navbar-collapse text-center" id="navbarResponsive">
				<ul class="navbar-nav ms-auto my-3 my-lg-0 text-center d-flex align-items-center">
					<li class="nav-item text-nowrap fw-bold"><a class="nav-link mx-1 text-dark" href="{{ route('sei.index') . '#capacitacao' }}">Capacitação</a></li>
					<li class="nav-item text-nowrap fw-bold"><a class="nav-link mx-1 text-dark" href="{{ route('sei.index') . '#pontosFocais' }}">Pontos Focais</a></li>
					<li class="nav-item text-nowrap fw-bold"><a class="nav-link mx-1 text-dark" href="{{ route('sei.index') . '#cadastrarse' }}">Cadastro</a></li>
					<li class="nav-item text-nowrap fw-bold"><a class="nav-link mx-1 text-dark" href="{{ route('sei.index') . '#perguntas' }}">Perguntas frequentes</a></li>
					</li>
				</ul>
				<div class="dropdown text-center">
					<a class="my-2 text-nowrap btn bg-primary fw-bold text-white dropdown-toggle mx-2 me-lg-3" href="#" role="button"
						id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
						<i class="fa-solid fa-door-open me-2"></i> Acessar Sei
					</a>
					<ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
						<li><a class="dropdown-item" target="_blank" href="http://angra.sei.rj.gov.br">Usuário
								Interno</a></li>
						<li><a class="dropdown-item" type="button" class="btn btn-success" data-bs-toggle="modal"
								data-bs-target="#staticBackdrop">Usuário
								Externo</a></li>
						<li>
							<a href="#cadastrarse" class="dropdown-item" type="button" class="btn btn-success">Fazer Cadastro</a>
						</li>
					</ul>
				</div>
				<a href="https://angra.sei.rj.gov.br/consultaprocessual" target="_blank"
					class="text-nowrap my-2 btn bg-secondary fw-bold text-white me-lg-3">
					<i class="fa-solid fa-search me-2"></i>
					Consultar processos</a>
				<br>
				<a href="{{ route('sei.index') . '#suporte' }}" class="text-nowrap my-2 bg-success btn text-white fw-bold me-lg-3">
					<i class="fa fa-question-circle me-2"></i>
					Suporte</a>
			</div>
		</div>
	</nav>
</div>
