<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <title>{{ __('Documento reprovado') }}</title>
</head>
<body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">
<table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
    <tr><td align="center">
        <table width="600" cellpadding="0" cellspacing="0" style="background:#fff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">
            <tr><td style="background:#007bc3; padding:20px; color:#fff; text-align:center;">{{ env('APP_NAME') }} – {{ __('Credenciamento de Músicos') }}</td></tr>
            <tr><td style="padding:30px; color:#333; font-size:15px; line-height:1.6;">
                <p>{{ __('Olá, :name!', ['name' => $musico->user->firstName ?? $musico->user->name ?? __('Artista')]) }}</p>
                <div style="background:#f8d7da; border:1px solid #f5c6cb; color:#721c24; padding:15px; border-radius:6px; margin:15px 0;">
                    <strong>{{ __('Documento reprovado') }}</strong><br>
                    {{ __('O documento ":tipo" do seu credenciamento foi reprovado.', ['tipo' => \App\Enums\Cultura\Credenciamento\TipoDocumentoCredenciamento::label($musico->tipo_pessoa ?? 'PF', $documento->tipo_documento)]) }}
                    @if($observacao)
                        <p style="margin:10px 0 0;"><strong>{{ __('Observação') }}:</strong> {{ $observacao }}</p>
                    @endif
                </div>
                <p>{{ __('Acesse o sistema, envie um novo documento ou entre em contato em caso de dúvidas.') }}</p>
                <p style="margin-top:25px;"><strong>{{ __('Equipe de Cultura') }}</strong></p>
            </td></tr>
            <tr><td style="background:#f7f7f7; text-align:center; padding:15px; font-size:12px; color:#999;">{{ __('E-mail automático. Não responda.') }}</td></tr>
        </table>
    </td></tr>
</table>
</body>
</html>
