<div class="my-3">
    <form method="GET" action="{{ route($url) }}">
        <div class="input-group">
            <input type="text" name="busca" value="{{ request($search) }}" class="form-control"
                placeholder="{{ $placeholder }}">
            <button class="btn btn-primary" type="submit">{{$label1}}</button>
            <a href="{{ route($url) }}"
                class="btn btn-outline-secondary">{{ $label2 }}</a>
        </div>
    </form>
</div>