@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção")
@section('content')

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.index") }}">{{ __("Concursos Públicos e Processos de Seleção") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Andamento") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: {{ $concurso->ds_ano }}</h1>

                    <hr>
                    
                    @if($concurso->hasNivel(0))
                        <h3 class="top30">NÍVEL FUNDAMENTAL INCOMPLETO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 1)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach
                            </tbody>
                        </table>
                    @endif
                    
                    @if($concurso->hasNivel(1))
                        <h3 class="top30">NÍVEL FUNDAMENTAL</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 1)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach
                            </tbody>
                        </table>
                    @endif

                    @if($concurso->hasNivel(2))    
                        <h3 class="top30">NÍVEL MÉDIO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 2)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach

                            </tbody>
                        </table>
                    @endif

                    @if($concurso->hasNivel(3))
                        <h3 class="top30">NÍVEL SUPERIOR</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 3)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach

                            </tbody>
                        </table>
                    @endif

                    @if($concurso->hasNivel(4))
                        <h3 class="top30">NÍVEL MÉDIO TÉCNICO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 3)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach

                            </tbody>
                        </table>
                    @endif
                      
                        
                     @if($concurso->hasNivel(5))
                        <h3 class="top30">INDEFINIDO</h3>
                        <table class="table">
                            <thead>
                                <tr>
                                    <th width="51%">Cargo</th>
                                    <th width="10%" class="centro">Vagas (Edital)</th>
                                    <th width="14%" class="centro">Classificados</th>
                                    <th width="13%" class="centro">Convocados</th>
                                    <th width="12%" class="centro">Cadastros Disponíveis</th>
                                    <th width="12%" class="centro">Vagas Disponíveis</th>
                                </tr>
                            </thead>

                            <tbody>
                                @foreach($concurso->cargos as $cargo)
                                    @if($cargo->cd_nivel == 3)
                                        <tr>
                                            <td class="centro"><a href="{{ route("paginas.concursos.convocacoes", [$cargo->id_concurso, $cargo->id_cargo])}}">{{ $cargo->nm_cargo }}</a></td>
                                            <td class="centro">{{ $cargo->nr_vagas_edital }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() }}</td>
                                            <td class="centro">{{ $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->totalCandidatos() - $cargo->totalConvocados() }}</td>
                                            <td class="centro">{{ $cargo->cadastroDisponivel() }}</td>
                                        </tr>
                                    @endif
                                @endforeach

                            </tbody>
                        </table>
                    @endif
                        
                </div>
            </div>
        </div>
    </section>


@endsection