<h3>Gestor(a)</h3>
<div class="mb-3">
    <label for="pronunciation" class="form-label text-bold">Pronome de Tratamento: <span class="span-admin-create">*</span></label>
    <select class="form-control @error('pronunciation') is-invalid @enderror" name="pronunciation" id="pronunciation">
        @foreach(App\Enums\StructuresPronunciationStatusEnum::cases() as $pronunciations)
            <option value="{{ $pronunciations->name }}">{{ $pronunciations->value }}</option>
        @endforeach
    </select>
                            @error('type')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="manager" class="form-label text-bold">Nome: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('manager') is-invalid @enderror" name="manager" id="manager" autocomplete="off" value="{{ old('manager') }}">
                            @error('manager')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3 text-wrap">
    <label for="academicBackground" class="form-label text-bold">Formação Acadêmica: <span class="span-admin-create">*</span></label>
    <textarea class="form-control textarea-comments @error('academicBackground') is-invalid @enderror" name="academicBackground" id="academicBackground">{{ old('academicBackground') }}</textarea>
                            @error('academicBackground')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3 text-wrap">
    <label for="skills" class="form-label text-bold">Competências: <span class="span-admin-create">*</span></label>
    <textarea class="form-control textarea-comments @error('skills') is-invalid @enderror" name="skills" id="skills">{{ old('skills') }}</textarea>
                            @error('skills')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3 text-wrap">
    <label for="duties" class="form-label text-bold">Atribuições: <span class="span-admin-create">*</span></label>
    <textarea class="form-control textarea-comments @error('duties') is-invalid @enderror" name="duties" id="duties">{{ old('duties') }}</textarea>
                            @error('duties')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="managerPhoto" class="form-label text-bold">Foto: <span class="span-admin-create">*</span></label>
    <input type="file" class="form-control" name="managerPhoto" id="managerPhoto" accept="image/jpeg,image/jpg,image/png,image/gif" />
</div>