<section class="bg-light" id="atas-comite">
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 p-3 text-center">
                <h1>{{ __('Comitê Gestor') }}</h1>
            </div>
        </div>
        <div class="row justify-content-center align-items-center g-2">
            <div
                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Presidente') }}</strong>:
                                {{ __('Rodolfo Orion Lebres Bontempo') }} <br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('SMGP') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('33882') }} <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i
                                        class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Vice-Presidente') }}</strong>:
                                {{ __('João Vitor Costa da Silva Carvalho') }}<br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('CGM') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('28249') }} <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Secretária') }}</strong>:
                                {{ __('Bárbara Di Sarli de Carvalho') }} <br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('PGM') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('32684') }} <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Membro') }}</strong>:
                                {{ __('Lucas Soares dos Santos') }}<br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('SMGP') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('33870') }} <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Membro') }}</strong>:
                                {{ __('Daniel Silva de Azevedo') }} <br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('SMGP') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('19183') }} <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Membro') }}</strong>:
                                {{ __('Matheus Silva Lopes') }} <br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('PGM') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('32376') }} <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;{{ __('Membro') }}</strong>:
                                {{ __('Bruno Santana de Lima') }} <br>
                                <strong>{{ __('Órgão') }}</strong>: {{ __('CGM') }} <br>
                                <strong>{{ __('Matrícula') }}</strong>: {{ __('26744') }} <br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="row">
            <div class="col-md-6">
                @php
                    $colorStyleAtasReuniao = 'color: #696969; cursor: pointer;';
                @endphp
                <div class="p-3">
                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                        style="{{ $colorStyleAtasReuniao }}">
                        {{ __('Atas de Reunião') }} <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                    </h3>
                    <div class="content d-none">
                        <div class="mt-5 mb-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3431"
                                    target="_blank"><strong>{{ __('Nº 001/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 7 de Março de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a
                                    href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3437"target="_blank"><strong>{{ __('Nº 002/2024') }},
                                        <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 7 de Março de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3800"
                                    target="_blank"><strong>{{ __('Nº 003/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 11 de Março de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=6526"
                                    target="_blank"><strong>{{ __('Nº 004/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 15 de Março de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=7531"
                                    target="_blank"><strong>{{ __('Nº 005/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 19 de Março de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=34324"
                                    target="_blank"><strong>{{ __('Nº 006/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 20 de Maio de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=77901"
                                    target="_blank"><strong>{{ __('Nº 007/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 05 de Agosto de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=116957"
                                    target="_blank"><strong>{{ __('Nº 008/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 20 de Setembro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=118357"
                                    target="_blank"><strong>{{ __('Nº 009/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 23 de Setembro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=190267"
                                    target="_blank"><strong>{{ __('Nº 010/2024') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 11 de Dezembro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=317111"
                                    target="_blank"><strong>{{ __('Nº 001/2025') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 20 de Fevereiro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="p-3">
                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                        style="{{ $colorStyleAtasReuniao }}">
                        {{ __('Pareceres') }} <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                    </h3>
                    <div class="content d-none">
                        <div class="mt-5 mb-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162463"
                                    target="_blank"><strong>{{ __('Parecer 1') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 30 de Outubro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162579"
                                    target="_blank"><strong>{{ __('Parecer 2') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 30 de Outubro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=219494"
                                    target="_blank"><strong>{{ __('Parecer 3') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 11 de Dezembro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=229393"
                                    target="_blank"><strong>{{ __('Parecer 4') }}, <span
                                            style="{{ $colorStyleAtasReuniao }}">{{ __('de 17 de Dezembro de 2024') }}</span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>