@if(count($bannersSection1) > 0)
    <div class="row">
        <div class="col-12">
            <div id="carouselSection1" class="carousel slide" data-bs-ride="carousel" data-bs-interval="4000">
                <div class="carousel-indicators">
                    @foreach($bannersSection1 as $index => $banner)
                        <button type="button" data-bs-target="#carouselSection1" data-bs-slide-to="{{ $index }}" 
                        class="{{ $index == 0 ? 'active' : '' }}" 
                        aria-label="Slide {{ $index + 1 }}"></button>
                    @endforeach
                </div>
                <div class="carousel-inner">
                    @foreach($bannersSection1 as $index => $banner)
                        <div class="carousel-item {{ $index == 0 ? 'active' : '' }}">
                            <a href="{{ $banner->url }}" target="{{ $banner->target }}" title="{{ $banner->title }}">
                                <img src="{{ asset($banner->photo) }}" alt="{{ $banner->title }}" title="{{ $banner->title }}" class="d-block w-100">
                            </a>
                        </div>
                    @endforeach
                </div>
                <button class="carousel-control-prev" type="button" data-bs-target="#carouselSection1" data-bs-slide="prev">
                    <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Previous</span>
                </button>
                <button class="carousel-control-next" type="button" data-bs-target="#carouselSection1" data-bs-slide="next">
                    <span class="carousel-control-next-icon" aria-hidden="true"></span>
                    <span class="visually-hidden">Next</span>
                </button>
            </div>
        </div>
    </div>
@endif
