@php
    use App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource;

    $filterParams = $filterParams ?? EmpresaTurismoResource::listFilterParamsFromRequest(request());
    $usePrefixedNames = $usePrefixedNames ?? false;
@endphp

@foreach($filterParams as $key => $value)
    @if($value !== null && $value !== '')
        @if($usePrefixedNames)
            <input type="hidden" name="list_filter[{{ $key }}]" value="{{ $value }}">
        @else
            <input type="hidden" name="{{ $key }}" value="{{ $value }}">
        @endif
    @endif
@endforeach

@if($usePrefixedNames)
    <input type="hidden" name="list_filter_sent" value="1">
@endif
