<?php $__env->startSection('title', env('APP_NAME') . ' :: Cadastro de Pacientes com Fibromialgia'); ?>
<?php $__env->startSection('content'); ?>
<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a href="<?php echo e(route('paginas.home')); ?>"><?php echo e(__('Portal')); ?></a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            <?php echo e(__('Cadastro de Pacientes com Fibromialgia')); ?>

                        </li>
                    </ol>
                </nav>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <h1 class="mb-3"><?php echo e(__('Cadastro de Pacientes com Fibromialgia')); ?></h1>

                <p class="mb-3"><?php echo e(__("A Prefeitura de Angra dos Reis, por meio da Secretaria de Saúde, está realizando o Cadastro de Pacientes com Fibromialgia. A iniciativa tem como objetivo identificar, registrar e acompanhar de forma contínua os pacientes diagnosticados com essa condição no município.")); ?></p>
                <p class="mb-3"><?php echo e(__("Para solicitar o cartão, acesse o link disponível e preencha o formulário, anexando digitalmente os seguintes documentos:  laudo médico com a descrição da condição de fibromialgia (CID 10 M79.7); foto 3x4; comprovante de residência; documento de identidade (RG); CPF; Cartão SUS.")); ?></p>
                <p class="mb-3"><?php echo e(__("O acompanhamento do processo é de responsabilidade do paciente, e a retirada do cartão deverá ser feita presencialmente na sede da Secretaria de Saúde.")); ?></p>
                <p class="mb-3"><?php echo e(__("De acordo com a ")); ?><strong><?php echo e(__("Lei Municipal nº 3.909, de 29 de novembro de 2019")); ?></strong><?php echo e(__(", o cartão garante atendimento preferencial nas mesmas filas destinadas a idosos, gestantes e pessoas com deficiência, assegurando mais dignidade e respeito no acesso aos serviços de saúde.")); ?></p>

                <p class="mb-3"><?php echo e(__("Antes de iniciar o preenchimento, certifique-se de ter em mãos toda a documentação digitalizada necessária para emissão do cartão de identificação.")); ?></p>

                <ol class="list-group list-group-numbered mb-3">
                    <li class="list-group-item"><?php echo e(__("Laudo Médico com a descrição da condição de fibromialgia (CID10 M79.7);")); ?></li>
                    <li class="list-group-item"><?php echo e(__("01 foto tamanho 3x4;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("Comprovante de residência;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("RG;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("CPF e;")); ?></li>
                    <li class="list-group-item"><?php echo e(__("Cartão SUS.")); ?></li>
                </ol>

                <p class="alert alert-info mb-3"><?php echo e(__("Lembramos que é de responsabilidade do usuário acompanhar pelo sistema o andamento do processo e a retirada do cartão deverá ser feita na Secretaria de Saúde.")); ?></p>

                <hr>

                <div class="mb-3">
                    <a class="btn btn-lg btn-primary" href="<?php echo e(route("admin.adesao.fibromialgia")); ?>">
                        <?php echo e(__("Sim, desejo fazer a adesão ao cadastro de Paciente com Fibromialgia.")); ?>

                    </a>
                </div>

            </div>
        </div>
    </div>
</section>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/saude/fibromialgia.blade.php ENDPATH**/ ?>