@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Cadastro de Ambulantes - Novo Ambulante")
@section('content')


    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
                        <h5 class="my-2">Cadastro de Ambulantes - Novo Ambulante</h5>
                    </div>
                    <div class="card-body">
                        
                        @include("errors.messageFlash")

                        <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm"
                        role="tablist">
                            
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioStore', 
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioEdit', 
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif
                                                        
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.representanteLegalIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.representanteLegalStore', 
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif
                            
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioStore',  
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif
                            
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesStore',  
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.documentosIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.documentosStore',  
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.fotosIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.fotosStore', 
                                ])) 

                                @include('components.lists._liLinkBtnNavInterna', [
                                    'items' => [
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'primeiraSection', 'label' => 'Proprietário'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'segundaSection', 'label' => 'Representante Legal'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'terceiraSection', 'label' => 'Dados do Comércio'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'quartaSection', 'label' => 'Demais Informações'],
                                        ['class' => 'disabled bg-success text-white', 'hash' => 'quintaSection', 'label' => 'Documentos'],
                                        ['class' => 'disabled bg-success text-white active', 'hash' => 'sextaSection', 'label' => 'Fotos'],
                                    ]
                                ])
                            
                            @endif

                        </ul>

                        <div class="tab-content">
                            
                            @if (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioStore', 
                                    'admin.cadastroDeAmbulantes.ambulantes.proprietarioEdit', 
                                ])) 
                                <div class="tab-pane fade show active py-3" id="primeiraSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.dadosProprietario")
                                </div>
                            @elseif (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.representanteLegalIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.representanteLegalStore', 
                                ])) 
                                <div class="tab-pane fade show active py-3" id="segundaSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.dadosRepresentanteLegal")
                                </div>
                            @elseif (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioStore', 
                                ])) 
                                <div class="tab-pane fade show active py-3" id="terceiraSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.dadosComercio")
                                </div>
                            @elseif (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesStore',
                                ])) 
                                <div class="tab-pane fade show active py-3" id="quartaSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.demaisInformacoes")
                                </div>
                            @elseif (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.documentosIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.documentosStore',  
                                ])) 
                                <div class="tab-pane fade show active py-3" id="quintaSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.documento")
                                </div>
                            @elseif (in_array(Route::currentRouteName(), [
                                    'admin.cadastroDeAmbulantes.ambulantes.fotosIndex', 
                                    'admin.cadastroDeAmbulantes.ambulantes.fotosStore',  
                                ])) 
                                <div class="tab-pane fade show active py-3" id="sextaSection">
                                    @include("admin.cadastroDeAmbulantes.ambulantes.section.fotos")
                                </div>
                            @endif
                            
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
