<div class="form-check">
    <input class="form-check-input" type="checkbox" name="isWhatsapp" id="isWhatsapp"
           value="1"
           <?php echo e(old('isWhatsapp', $isWhatsapp ?? false) ? 'checked' : ''); ?>>
    <label class="form-check-label" for="isWhatsapp">
        <?php echo e(__("Este número também é Whatsapp?")); ?>

    </label>
</div><?php /**PATH /var/www/html/portal/resources/views/components/inputs/_checkBoxIsWhatsapp.blade.php ENDPATH**/ ?>