<?php $__env->startSection('title', 'Bem-vindo ao Parque da Cidade da Prefeitura Municipal de Angra dos Reis'); ?>
<?php $__env->startSection('content'); ?>

    <div class="banner">
        <div class="overlay">
            <div class="container">
                <div class="intro-text">
                    <!--<h1>Parque da Cidade</span></h1>
                                <p>Parque Natural Municipal da Mata Atlântica</p>-->
                </div>
            </div>
        </div>
    </div>

    <section id="about-section" class="about-section">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <div class="section-title text-center wow fadeInDown" data-wow-duration="2s" data-wow-delay="50ms">
                        <h2>O Parque da Cidade</h2>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-md-5">
                    <div class="about-img">
                        <img src="asset/images/vista-parque-cidade.jpg" class="img-responsive mb-5" alt="">

                    </div>
                </div>
                <div class="col-md-7">
                    <div class="about-text">
                        <p>O belíssimo cenário formado pelo mar de águas cristalinas cercado pelo paredão de montanhas e
                            ilhas dominadas pelo verde da Mata Atlântica atraem turistas do mundo inteiro para a Baía da
                            Ilha Grande.</p>
                        <p>Entre as diversas tipologias de unidades de conservação da natureza, os Parques, têm o
                            objetivo de estimular o contato das pessoas com as áreas naturais. Daí vem o lema dos
                            Parques: conhecer para preservar.</p>
                        <p>É esse espírito que norteou a criação do Parque Natural Municipal da Mata Atlântica, ou
                            simplesmente Parque da Cidade, unidade de conservação sob gestão administrativa do Instituto
                            Municipal do Ambiente - IMAAR, e que possui três claros objetivos: ordenamento do solo,
                            preservação ambiental e desenvolvimento do ecoturismo.</p>
                    </div>

                    <div class="about-list">
                        <h4><strong>Atrativos do Parque</strong></h4>
                        <ul>
                            <li><i class="fa fa-check-square"></i>Caminhada/trekking</li>
                            <li><i class="fa fa-check-square"></i>Escalada</li>
                            <li><i class="fa fa-check-square"></i>Atrativos naturais</li>
                            <li><i class="fa fa-check-square"></i>Vôo livre</li>
                            <li><i class="fa fa-check-square"></i>Rapel</li>
                            <li><i class="fa fa-check-square"></i>Contemplação de paisagens através de mirantes</li>
                        </ul>
                    </div>

                </div>
            </div>
        </div>
    </section>

    <section style="margin-bottom: 100px;">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <object width="100%" height="620">
                        <param name="movie" value="http://www.youtube.com/v/anY4KqvxU9I">
                        </param>
                        <param name="allowFullScreen" value="true">
                        </param>
                        <param name="allowscriptaccess" value="always">
                        </param>
                        <embed src="http://www.youtube.com/v/anY4KqvxU9I" type="application/x-shockwave-flash"
                            allowscriptaccess="always" allowfullscreen="true">
                        </embed>
                    </object>
                </div>
            </div>
        </div>
    </section>



    <section class="call-to-action">
        <div class="container">
            <div class="row">
                <div class="col-md-12 wow zoomIn" data-wow-duration="2s" data-wow-delay="300ms">
                    <p>O Parque da Cidade é um lugar especial</p>
                </div>
            </div>
        </div>
    </section>

    <section id="portfolio" class="portfolio-section-1">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <div class="section-title text-center wow fadeInDown" data-wow-duration="2s" data-wow-delay="50ms">
                        <h2>Fotos do Local</h2>
                        <p>belas imagens do local</p>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-md-12">

                    <ul id="portfolio-list">
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img1.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Mirante do Retiro</h4>
                                    <p>Campo escola de escalada em rocha</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img2.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Mirante do Retiro</h4>
                                    <p>Campo escola de escalada em rocha</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img3.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Mirante do Retiro</h4>
                                    <p>Pico do Frade visto do mirante</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img15.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img4.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Pedra do Retiro</h4>
                                    <p>Parede de Escalada</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img21.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img5.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Parede de Escalada</h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img6.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Placa no caminho do Santo</h4>
                                    <p>Caminhada/trekking</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img7.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Caminho do Santo</h4>
                                    <p>Chegado ao Morro do Bulé</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img19.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img8.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Marco histórico</h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img9.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Mirante do Retiro</h4>
                                    <p>Vista interna</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img10.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Vegetação local</h4>
                                    <p>Bromélia</p>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img20.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img14.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Vista aérea do Parque</h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img18.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>0</h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img12.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4>Vegetação local</h4>
                                    <p>Desnte de Leão</p>

                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img17.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>
                        <li class="wow fadeInLeft" data-wow-duration="2s" data-wow-delay="300ms">
                            <div class="portfolio-item">
                                <img src="asset/images/galery/img16.jpg" class="img-responsive" alt="" />
                                <div class="portfolio-caption">
                                    <h4> </h4>
                                </div>
                            </div>
                        </li>


                    </ul>
                </div>
            </div>
        </div>
    </section>

<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.parquedacidade.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/parque-da-cidade/index.blade.php ENDPATH**/ ?>