<div class="mb-3">
    <?php if($label): ?>
        <label for="<?php echo e($id ?? $name); ?>" class="form-label text-bold">
            <?php echo e($label); ?> <?php if(isset($required) && $required): ?><span class="span-admin-create">*</span><?php endif; ?>
        </label>
    <?php endif; ?>

    <textarea
        class="form-control <?php echo e($class ?? ''); ?> <?php if(isset($name)): ?> <?php $__errorArgs = [$name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?> <?php endif; ?>"
        name="<?php echo e($name ?? ''); ?>"
        id="<?php echo e($id ?? $name); ?>"
        rows="<?php echo e($rows ?? 1); ?>"
        <?php if(isset($height) && $height): ?> style="height: <?php echo e($height); ?>" <?php endif; ?> ><?php echo e($value); ?></textarea>

    <?php $__errorArgs = [isset($name) && $name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
        <small class="text-danger text-bold"><?php echo e($message); ?></small>
    <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/inputs/_textarea.blade.php ENDPATH**/ ?>