<!-- Bootstrap JS (CDN) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous"></script>

<!-- HandTalk - Acessibilidade -->
<script src="https://plugin.handtalk.me/web/latest/handtalk.min.js"></script>
<script>
    var ht = new HT({
        token: "7a92081e27daf17bd3b2efe277d0648c",
        avatar: "MAYA",
        pageSpeech: true,
        maxTextSize: 1000
    });
</script>

<!-- Scripts customizados -->
<script src="{{ asset('calendario-de-eventos/assets/js/script.js') }}"></script>

@yield('scripts')
