<div class="home-mais-buscados-col col-12 col-sm-12 col-md-6 col-lg-4 col-xl-3 col-xxl-3">
    <div onclick="javascript:window.open('<?php echo e($url); ?>', '_blank')" class="card">
        <div class="imgTopicos" style="background-color: <?php echo e($color); ?>">
            <h4><?php echo __($header); ?></h4>
            <img src="<?php echo e(asset($image)); ?>" class="card-img-top img-fluid">
        </div>
        <div class="card-body">
            <h5 class="card-title"><?php echo e(__($title)); ?></h5>
            <p class="card-text"><?php echo e(__($subtitle)); ?></p>
        </div>
    </div>
</div><?php /**PATH /var/www/html/portal/resources/views/components/cards/_cardTopicosMaisBuscados.blade.php ENDPATH**/ ?>