@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Área Restrita'))
@push('scripts')
    <link rel="stylesheet" href="{{ asset('pmar/css/dashboard-admin.css') }}">
    <script src="{{ asset('pmar/js/dashboard-admin.js') }}"></script>
@endpush
@section('content')

    @php
        // Todos os módulos disponíveis
        $todosModulos = [
            [
                'route' => 'admin.noticias.index',
                'icon' => 'fa-solid fa-bullhorn',
                'name' => 'Notícias',
                'permission' => 'GERENCIADOR_DE_NOTICIAS',
            ],
            [
                'route' => 'admin.boletins.index',
                'icon' => 'fa-solid fa-newspaper',
                'name' => 'Boletins Oficiais',
                'permission' => 'GERENCIADOR_DE_BOLETINS',
            ],
            [
                'route' => 'admin.banners.index',
                'icon' => 'fa-regular fa-image',
                'name' => 'Banners',
                'permission' => 'GERENCIADOR_DE_BANNERS',
            ],
            [
                'route' => 'admin.boletim.meteorologico.index',
                'icon' => 'fa-solid fa-cloud-sun',
                'name' => 'Boletins Meteorológicos',
                'permission' => 'GERENCIADOR_DE_BOLETINS_METEOROLOGICOS',
            ],
            [
                'route' => 'admin.secretarias.index',
                'icon' => 'fa-solid fa-building-columns',
                'name' => 'Secretarias',
                'permission' => 'SYSADMIN',
            ],
            [
                'route' => 'admin.contas.index',
                'icon' => 'fa-solid fa-users-gear',
                'name' => 'Usuários',
                'permission' => 'SYSADMIN',
            ],
            [
                'route' => 'admin.diagnostico.email.index',
                'icon' => 'fa-solid fa-envelope-circle-check',
                'name' => 'Diagnóstico de E-mail',
                'permission' => 'SYSADMIN',
            ],
            [
                'route' => 'admin.htmls.index',
                'icon' => 'fa-solid fa-file-code',
                'name' => 'Páginas HTML',
                'permission' => 'GERENCIADOR_DE_PAGINAS_HTML',
            ],
            [
                'route' => 'admin.menusReutilizaveis.index',
                'icon' => 'fa-solid fa-layer-group',
                'name' => 'Menus Reutilizáveis',
                'permission' => 'GERENCIADOR_DE_MENUS_REUTILIZAVEIS',
            ],
            [
                'route' => 'admin.urls.index',
                'icon' => 'fa-solid fa-link',
                'name' => 'Redirecionamentos',
                'permission' => 'GERENCIADOR_DE_URLS',
            ],
            [
                'route' => 'admin.repositorio.index',
                'icon' => 'fa-solid fa-box-archive',
                'name' => 'Repositório',
                'permission' => 'GERENCIADOR_DO_REPOSITORIO_DO_PORTAL',
            ],
            [
                'route' => 'admin.temas.index',
                'icon' => 'fa-solid fa-palette',
                'name' => 'Temas',
                'permission' => 'GERENCIADOR_DE_TEMAS',
            ],
            [
                'route' => 'admin.pontosFocais.index',
                'icon' => 'fa-solid fa-network-wired',
                'name' => 'Pontos Focais',
                'permission' => 'GERENCIADOR_DE_PONTOS_FOCAIS',
            ],
            [
                'route' => 'admin.seiAlertas.index',
                'icon' => 'fa-solid fa-triangle-exclamation',
                'name' => 'Alerta SEI',
                'permission' => 'GERENCIADOR_DE_ALERTA_SEI',
            ],
            [
                'route' => 'admin.curriculos.index',
                'icon' => 'fa-solid fa-file-lines',
                'name' => 'Buscar Currículo',
                'permission' => 'GERENCIADOR_DE_CURRICULOS',
            ],
            [
                'route' => 'admin.informativos_recursos_humanos.index',
                'icon' => 'fa-solid fa-circle-info',
                'name' => 'Informativos RH',
                'permission' => 'GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS',
            ],
            [
                'route' => 'admin.validacaoDocumentos.index',
                'icon' => 'fa-solid fa-file-shield',
                'name' => 'Validação de Documentos',
                'permission' => 'GERENCIADOR_VALIDACAO_DE_DOCUMENTOS',
            ],
            [
                'route' => 'admin.gerador-id.index',
                'icon' => 'fa-solid fa-id-card',
                'name' => 'Gerador de ID',
                'permission' => 'GESTOR_DE_ID',
            ],
            [
                'route' => 'admin.unidadesSaude.index',
                'icon' => 'fa-solid fa-hospital',
                'name' => 'Unidades de Saúde',
                'permission' => 'GERENCIADOR_DE_UNIDADES_SAUDE',
            ],
            [
                'route' => 'admin.saude.fibromialgia.index',
                'icon' => 'fa-solid fa-hand-holding-medical',
                'name' => 'Fibromialgia',
                'permission' => 'GERENCIADOR_DO_CADASTRO_DE_PACIENTES_COM_FIBROMIALGIA',
            ],
            // Cadastro de pessoas trans desativado (rotas admin comentadas em routes/admin.php).
            // [
            //     'route' => 'admin.saude.pessoas-trans.index',
            //     'icon' => 'fa-solid fa-venus-mars',
            //     'name' => 'Pessoas Trans',
            //     'permission' => 'GERENCIADOR_DO_CADASTRO_DE_PESSOAS_TRANS',
            // ],
            [
                'route' => 'admin.escolas.index',
                'icon' => 'fa-solid fa-school',
                'name' => 'Escolas',
                'permission' => 'GERENCIADOR_DE_ESCOLAS',
            ],
            [
                'route' => 'admin.acaoSocial.centrosDeReferencia.index',
                'icon' => 'fa-solid fa-house-chimney-user',
                'name' => 'Centros de Referência',
                'permission' => 'GERENCIADOR_DE_CENTROS_REFERENCIA',
            ],
            [
                'route' => 'admin.conselhosMunicipais.conselhos.index',
                'icon' => 'fa-solid fa-people-group',
                'name' => 'Conselhos',
                'permission' => 'GERENCIADOR_DE_CONSELHOS',
            ],
            [
                'route' => 'admin.visiteAngra.index',
                'icon' => 'fa-solid fa-compass',
                'name' => 'Visite Angra',
                'permission' => 'GERENCIADOR_VISITE_ANGRA',
            ],
            [
                'route' => 'admin.guias.index',
                'icon' => 'fa-solid fa-map-location-dot',
                'name' => 'Guias Turísticos',
                'permission' => 'GERENCIADOR_DE_GUIAS_TURISTICOS',
            ],
            [
                'route' => 'admin.empresasDeTurismo.index',
                'icon' => 'fa-solid fa-sailboat',
                'name' => 'Empresas de Turismo',
                'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
            ],
            [
                'route' => 'admin.cultura.arteSacra.index',
                'icon' => 'fa-solid fa-church',
                'name' => 'Arte Sacra',
                'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA',
            ],
            [
                'route' => 'admin.cultura.credenciamentoMusicos.index',
                'icon' => 'fa-solid fa-guitar',
                'name' => 'Credenciamento de Músicos',
                'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
            ],
            [
                'route' => 'admin.parquesJardins.index',
                'icon' => 'fa-solid fa-tree',
                'name' => 'Parques e Jardins',
                'permission' => 'GERENCIADOR_DE_PARQUES_E_JARDINS',
            ],
            [
                'route' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
                'icon' => 'fa-solid fa-paw',
                'name' => 'Castração Animal',
                'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL',
            ],
            [
                'route' => 'admin.parqueTecnologico.index',
                'icon' => 'fa-solid fa-flask',
                'name' => 'Parque Tecnológico',
                'permission' => 'GERENCIADOR_DE_PARQUE_TECNOLOGICO',
            ],
            [
                'route' => 'admin.licitacoesProcedimentos.index',
                'icon' => 'fa-solid fa-scale-balanced',
                'name' => 'Licitações e Procedimentos',
                'permission' => 'GERENCIADOR_DE_LICITACOES_E_PROCEDIMENTOS',
            ],
            [
                'route' => 'admin.contratos.index',
                'icon' => 'fa-solid fa-file-contract',
                'name' => __('Contratos'),
                'permission' => 'GERENCIADOR_DE_CONTRATOS',
            ],
            [
                'route' => 'admin.atas.index',
                'icon' => 'fa-solid fa-file-signature',
                'name' => 'Atas',
                'permission' => 'GERENCIADOR_DE_ATAS',
            ],
            [
                'route' => 'admin.legislacao.index', 
                'icon' => 'fa-solid fa-scale-balanced',
                'name' => 'Legislação',
                'permission' => 'GERENCIADOR_DE_LEGISLACAO',
            ],
            [
                'route' => 'admin.cartaServicos.index',
                'icon' => 'fa-solid fa-file-lines',
                'name' => 'Carta de Serviços',
                'permission' => 'GERENCIADOR_DA_CARTA_DE_SERVICOS',
            ],
            [
                'route' => 'admin.ppps.index',
                'icon' => 'fa-solid fa-handshake',
                'name' => 'PPPs e Convênios',
                'permission' => 'GERENCIADOR_DE_PPPS',
            ],
            [
                'route' => 'admin.turisAngra.fluxoDeOnibus.onibusTurismo.index',
                'icon' => 'fa-solid fa-bus-simple',
                'name' => 'Fluxo de Ônibus',
                'permission' => 'GERENCIADOR_DE_FLUXO_DE_ONIBUS',
            ],
            [
                'route' => 'admin.mobiangra.index',
                'icon' => 'fa-solid fa-bus',
                'name' => 'MobiAngra',
                'permission' => 'GERENCIADOR_DE_MOBIANGRA',
            ],
            [
                'route' => 'admin.empresas.index',
                'icon' => 'fa-solid fa-building',
                'name' => __('Empresas'),
                'permission' => 'GERENCIADOR_DE_EMPRESAS',
            ],
            [
                'route' => 'admin.cadastroDeAmbulantes.ambulantes.index',
                'icon' => 'fa-solid fa-store',
                'name' => 'Cadastro de Ambulantes',
                'permission' => 'GERENCIADOR_CADASTRO_DE_AMBULANTES',
            ],
            [
                'route' => 'admin.dividaAtiva.index',
                'icon' => 'fa-solid fa-file-invoice-dollar',
                'name' => 'Dívidas Ativas',
                'permission' => 'GERENCIADOR_REGISTROS_DE_DIVIDA_ATIVA',
            ],
            [
                'route' => 'admin.processos.index',
                'icon' => 'fa-solid fa-folder-open',
                'name' => 'Meus Processos SEI',
                'permission' => 'GERENCIADOR_DE_PROCESSOS',
            ],
            [
                'route' => 'admin.projetosProgramas.index',
                'icon' => 'fa-solid fa-diagram-project',
                'name' => 'Projetos e Programas',
                'permission' => 'GERENCIADOR_DE_PROJETOS_E_PROGRAMAS',
            ],
            [
                'route' => 'admin.ocorrencias-pca.index',
                'icon' => 'fa-solid fa-clipboard-list',
                'name' => 'Ocorrências PCA',
                'permission' => 'GERENCIADOR_DE_OCORRENCIAS_PCA',
            ],
            [
                'route' => 'admin.dashboardEstrategico.index',
                'icon' => 'fa-solid fa-chart-line',
                'name' => 'Dashboard Estratégico',
                'permission' => 'GERENCIADOR_DO_DASHBOARD_ESTRATEGICO',
            ],
            [
                'route' => 'admin.indicadoresTi.index',
                'icon' => 'fa-solid fa-computer',
                'name' => 'Indicadores Ti',
                'permission' => 'INDICADORES_TI',
            ],
            [
                'route' => 'admin.contaAngra.index',
                'icon' => 'fa-solid fa-circle-user',
                'name' => 'Conta Angra',
                'permission' => 'GERENCIADOR_DE_CONTA_ANGRA',
            ],
            [
                'route' => 'admin.contaAngra.linhasDoTempo.index',
                'icon' => 'fa-solid fa-timeline',
                'name' => 'Linhas do Tempo',
                'permission' => 'GERENCIADOR_DE_LINHAS_DO_TEMPO',
            ],
            [
                'route' => 'admin.cronogramas.dashboard',
                'icon' => 'fa-solid fa-chart-gantt',
                'name' => 'Cronogramas',
                'permission' => 'GERENCIADOR_DE_CRONOGRAMAS',
            ],
            [
                'route' => 'admin.unidadesOrganizacionais.index',
                'icon' => 'fa-solid fa-sitemap',
                'name' => 'Unidades Organizacionais',
                'permission' => 'GERENCIADOR_DE_UNIDADES_ORGANIZACIONAIS',
            ],
            [
                'route' => 'admin.observatorio.indicadores.index',
                'icon' => 'fa-solid fa-chart-line',
                'name' => 'Observatório / Indicadores',
                'permission' => 'GERENCIADOR_DO_OBSERVATORIO',
            ],
        ];

        // Filtra módulos pelo permissão do usuário e ordena alfabeticamente
        $userPermissions = auth()->user()->listaPermissoes();
        $modulosDisponiveis = collect($todosModulos)
            ->filter(fn($m) => in_array($m['permission'], $userPermissions))
            ->sortBy('name')
            ->values();
    @endphp

    <main class="dashboard-admin">
        {{-- Header com Busca --}}
        <div class="dashboard-header">
            <div class="dashboard-header-left">
                <h1 class="dashboard-title">
                    <i class="fa-solid fa-gauge-high"></i>
                    {{ __('Painel Administrativo') }}
                </h1>
                <p class="dashboard-subtitle">{{ __('Bem-vindo(a)') }}, {{ auth()->user()->name }}</p>
            </div>
            <div class="dashboard-search">
                <i class="fa-solid fa-search search-icon"></i>
                <input type="text" id="searchModules" class="search-input" placeholder="{{ __('Buscar módulo...') }}"
                    autocomplete="off">
                <span class="search-shortcut">Ctrl+K</span>
            </div>
        </div>

        {{-- Contador de módulos --}}
        <div class="modules-info">
            <span class="modules-count">
                <i class="fa-solid fa-th-large"></i>
                <span id="modulesVisible">{{ $modulosDisponiveis->count() }}</span> {{ __('de') }}
                {{ $modulosDisponiveis->count() }} {{ __('módulos') }}
            </span>
            <span class="modules-hint d-none" id="searchHint">
                <i class="fa-solid fa-lightbulb"></i>
                {{ __('Pressione Enter para acessar o primeiro resultado') }}
            </span>
        </div>

        {{-- Grid de Módulos --}}
        <div class="modules-container" id="modulesContainer">
            @forelse($modulosDisponiveis as $modulo)
                <a href="{{ route($modulo['route']) }}" class="module-card" data-name="{{ strtolower($modulo['name']) }}">
                    <div class="module-icon">
                        <i class="{{ $modulo['icon'] }}"></i>
                    </div>
                    <span class="module-name">{{ __($modulo['name']) }}</span>
                </a>
            @empty
                <div class="empty-modules">
                    <i class="fa-solid fa-lock"></i>
                    <p>{{ __('Nenhum módulo disponível para seu perfil de acesso.') }}</p>
                    <small>{{ __('Entre em contato com o administrador para solicitar permissões.') }}</small>
                </div>
            @endforelse
        </div>

        {{-- Mensagem de nenhum resultado --}}
        <div class="no-results d-none" id="noResults">
            <i class="fa-solid fa-search"></i>
            <p>{{ __('Nenhum módulo encontrado') }}</p>
            <small>{{ __('Tente buscar com outros termos') }}</small>
        </div>

        {{-- Seção de Outros Sistemas --}}
        <div class="external-systems-section">
            <h2 class="dashboard-section-title">
                <i class="fa-solid fa-external-link"></i>
                {{ __('Outros Sistemas') }}
            </h2>
            <div class="modules-container">
                <a href="https://angra.sei.rj.gov.br" class="module-card" target="_blank" rel="noopener" data-name="sei">
                    <div class="module-icon">
                        <i class="fa-solid fa-file-signature"></i>
                    </div>
                    <span class="module-name">{{ __('SEI!') }}</span>
                </a>

                <a href="https://angra.rj.gov.br/prodata" class="module-card" target="_blank" rel="noopener"
                    data-name="prodata">
                    <div class="module-icon">
                        <i class="fa-solid fa-folder-open"></i>
                    </div>
                    <span class="module-name">{{ __('PRODATA') }}</span>
                </a>

                <a href="https://ged.angra.rj.gov.br" class="module-card" target="_blank" rel="noopener" data-name="ged">
                    <div class="module-icon">
                        <i class="fa-solid fa-archive"></i>
                    </div>
                    <span class="module-name">{{ __('GED') }}</span>
                </a>

                <a href="https://siati.angra.rj.gov.br/" class="module-card" target="_blank" rel="noopener"
                    data-name="siati">
                    <div class="module-icon">
                        <i class="fa-solid fa-chart-bar"></i>
                    </div>
                    <span class="module-name">{{ __('SIATI') }}</span>
                </a>

                <a href="https://www.angra.rj.gov.br/sopa/" class="module-card" target="_blank" rel="noopener"
                    data-name="sopa">
                    <div class="module-icon">
                        <i class="fa-solid fa-chart-pie"></i>
                    </div>
                    <span class="module-name">{{ __('SOPA') }}</span>
                </a>

                <a href="https://angra.rj.gov.br/ganet" class="module-card" target="_blank" rel="noopener"
                    data-name="ganet">
                    <div class="module-icon">
                        <i class="fa-solid fa-network-wired"></i>
                    </div>
                    <span class="module-name">{{ __('GANET') }}</span>
                </a>

                <a href="https://educacao.angra.rj.gov.br/sectonline" class="module-card" target="_blank" rel="noopener"
                    data-name="sect online">
                    <div class="module-icon">
                        <i class="fa-solid fa-graduation-cap"></i>
                    </div>
                    <span class="module-name">{{ __('SECT ONLINE') }}</span>
                </a>

                <a href="https://angra.pontoid.com.br/Acesso/Entrar?ReturnUrl=%2f" class="module-card" target="_blank"
                    rel="noopener" data-name="ponto id">
                    <div class="module-icon">
                        <i class="fa-solid fa-fingerprint"></i>
                    </div>
                    <span class="module-name">{{ __('PONTO ID') }}</span>
                </a>

                <a href="https://angra.licenciamento.net.br/" class="module-card" target="_blank" rel="noopener"
                    data-name="silo">
                    <div class="module-icon">
                        <i class="fa-solid fa-building"></i>
                    </div>
                    <span class="module-name">{{ __('SILO') }}</span>
                </a>

                <a href="https://www.viconsaga.com.br/site/home" class="module-card" target="_blank" rel="noopener"
                    data-name="vicon saga">
                    <div class="module-icon">
                        <i class="fa-solid fa-clipboard-list"></i>
                    </div>
                    <span class="module-name">{{ __('VICON SAGA') }}</span>
                </a>
            </div>
        </div>
    </main>
@endsection