@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar Documentos do Músico - Credenciamento")
@section('content')
    <div class="card shadow">
        @php $headLine = "<i class='fa-solid fa-guitar'></i> Editar Documentos do Músico - Credenciamento"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        "permission" => "GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS",
                    ])

        <div class="card-body">
            @php $routeUpdate = str_contains(request()->route()->getName() ?? '', 'perfil.') ? route('admin.cultura.credenciamentoMusicos.perfil.documentos.update', $musico->id) : route('admin.cultura.credenciamentoMusicos.documentos.update', $musico->id); @endphp
            <form action="{{ $routeUpdate }}" method="post" enctype="multipart/form-data">

                @include("errors.messageFlash")
                @csrf
                @method('post')
                
                @include('components.modal._modelProfile')

                <hr>

                <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">

                @include('components.lists._liLinkBtnNavInterna', [ 
                    'items' => [
                        ['class' => 'active bg-success disabled', 'hash' => 'primeiraSection', 'label' => 'Dados de Usuário'],
                        ['class' => 'active bg-success disabled', 'hash' => 'segundaSection', 'label' => 'Dados Pessoais'],
                        ['class' => 'active bg-success disabled', 'hash' => 'terceiraSection', 'label' => 'Documentos'],
                        ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Endereço'],
                        ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Credenciamento'],
                        ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Integrantes'],
                        ['class' => 'disabled', 'hash' => 'setimaSection', 'label' => 'Arquivos'],
                    ]
                ])

                </ul>

                <div class="tab-content">
                    
                    
                    <div class="row">
                        <div class="col-sm-12 col-md-4">
                            
                            <!-- Campo Número da carteira de identidade" -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Número da carteira de identidade",
                                "name" => "numeroCI",
                                "id" => null,
                                "required" => true,
                                "type" => null,
                                "old" => old('numeroCI', $pessoa?->numeroCI),
                                "oninput" => "this.value = this.value.toUpperCase().replace(/[^A-Z0-9.-]/g, '');",
                                "readonly" => false,
                                "small" => null,
                            ])
                            
                        </div>
                        <div class="col-sm-12 col-md-4">
                            
                            <!-- Campo Órgão expedidor -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Órgão expedidor",
                                "name" => "orgaoExp",
                                "id" => null,
                                "required" => false,
                                "type" => null,
                                "old" => old('orgaoExp', $pessoa?->orgaoExp),
                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                "readonly" => false,
                                "small" => null,
                                "listName" => "orgaoExpList",
                                "arrayList" => [
                                    'SSP/AC – Secretaria de Segurança Pública do Acre',
                                    'SSP/AL – Secretaria de Segurança Pública de Alagoas',
                                    'SSP/AM – Secretaria de Segurança Pública do Amazonas',
                                    'SSP/AP – Secretaria de Segurança Pública do Amapá',
                                    'SSP/BA – Secretaria de Segurança Pública da Bahia',
                                    'SSP/CE – Secretaria de Segurança Pública do Ceará',
                                    'SSP/DF – Secretaria de Segurança Pública do Distrito Federal',
                                    'SSP/ES – Secretaria de Segurança Pública do Espírito Santo',
                                    'SSP/GO – Secretaria de Segurança Pública de Goiás',
                                    'SSP/MA – Secretaria de Segurança Pública do Maranhão',
                                    'SSP/MG – Secretaria de Segurança Pública de Minas Gerais',
                                    'SSP/MS – Secretaria de Segurança Pública do Mato Grosso do Sul',
                                    'SSP/MT – Secretaria de Segurança Pública do Mato Grosso',
                                    'SSP/PA – Secretaria de Segurança Pública do Pará',
                                    'SSP/PB – Secretaria de Segurança Pública da Paraíba',
                                    'SSP/PE – Secretaria de Segurança Pública de Pernambuco',
                                    'SSP/PI – Secretaria de Segurança Pública do Piauí',
                                    'SSP/PR – Secretaria de Segurança Pública do Paraná',
                                    'SSP/RJ – Secretaria de Segurança Pública do Rio de Janeiro',
                                    'SSP/RN – Secretaria de Segurança Pública do Rio Grande do Norte',
                                    'SSP/RO – Secretaria de Segurança Pública de Rondônia',
                                    'SSP/RR – Secretaria de Segurança Pública de Roraima',
                                    'SSP/RS – Secretaria de Segurança Pública do Rio Grande do Sul',
                                    'SSP/SC – Secretaria de Segurança Pública de Santa Catarina',
                                    'SSP/SE – Secretaria de Segurança Pública de Sergipe',
                                    'SSP/SP – Secretaria de Segurança Pública de São Paulo',
                                    'SSP/TO – Secretaria de Segurança Pública do Tocantins',
                                    'PM – Polícia Militar',
                                    'CBM – Corpo de Bombeiros Militar',
                                    'EXERC – Exército Brasileiro',
                                    'FAB – Força Aérea Brasileira',
                                    'MB – Marinha do Brasil',
                                    'DGPM – Diretoria-Geral do Pessoal da Marinha',
                                    'DPF – Departamento de Polícia Federal',
                                    'DPRF / PRF – Polícia Rodoviária Federal',
                                    'PC – Polícia Civil',
                                    'OAB – Ordem dos Advogados do Brasil',
                                    'CRM – Conselho Regional de Medicina',
                                    'CRF – Conselho Regional de Farmácia',
                                    'CRO – Conselho Regional de Odontologia',
                                    'COREN – Conselho Regional de Enfermagem',
                                    'CRP – Conselho Regional de Psicologia',
                                    'CRQ – Conselho Regional de Química',
                                    'CREA – Conselho Regional de Engenharia e Agronomia',
                                    'CRBio – Conselho Regional de Biologia',
                                    'CRB – Conselho Regional de Biblioteconomia',
                                    'CRMV – Conselho Regional de Medicina Veterinária',
                                    'CRA – Conselho Regional de Administração',
                                    'CRC – Conselho Regional de Contabilidade',
                                    'CRFa – Conselho Regional de Fonoaudiologia',
                                    'CREF – Conselho Regional de Educação Física',
                                    'CRESS – Conselho Regional de Serviço Social',
                                    'TJ – Tribunal de Justiça',
                                    'TRT – Tribunal Regional do Trabalho',
                                    'TRE – Tribunal Regional Eleitoral',
                                    'TRF – Tribunal Regional Federal',
                                    'STM – Superior Tribunal Militar',
                                    'STJ – Superior Tribunal de Justiça',
                                    'STF – Supremo Tribunal Federal',
                                    'DETRAN – Departamento Estadual de Trânsito',
                                    'DETRAN-UF (ex.: DETRAN-SP, DETRAN-RJ etc.)',
                                    'IBAMA – Instituto Brasileiro do Meio Ambiente',
                                    'ICMBio – Instituto Chico Mendes',
                                    'MTE / TEM – Ministério do Trabalho e Emprego (carteiras antigas)',
                                    'FUNAI – Fundação Nacional dos Povos Indígenas',
                                    'PF – Polícia Federal',
                                    'SUSEP – Superintendência de Seguros Privados',
                                    'INSS – Instituto Nacional do Seguro Social',
                                    'IF / CEFET – Institutos Federais em emissões específicas',
                                    'Prefeituras (PM) – raros casos de carteiras funcionais',
                                    'Universidades Públicas (UF / UFF / UFRJ etc.) – carteiras funcionais',
                                ],
                            ])
                            
                        </div>
                        <div class="col-sm-12 col-md-4">
                            
                            <!-- Campo Data de expedição -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Data de expedição",
                                "name" => "dtaExpedicao",
                                "id" => null,
                                "required" => false,
                                "type" => "date",
                                "old" => old('dtaExpedicao', $pessoa->dtaExpedicao),
                                "oninput" => "",
                                "readonly" => false,
                                "small" => null,
                            ])
                            
                        </div>
                        
                    </div>
                    <div class="row">
                        
                        <div class="col-sm-12 col-md-6">
                            
                            <!-- Campo Registro profissional (DRT / OMB) -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Registro profissional (DRT / OMB)",
                                "name" => "registroMusico",
                                "id" => null,
                                "required" => true,
                                "type" => null,
                                "old" => old('registroMusico', $musico->registroMusico),
                                "oninput" => "this.value = this.value.toUpperCase().replace(/[^A-Z0-9.-]/g, '');",
                                "readonly" => false,
                                "small" => null,
                            ])
                            
                        </div>
                        <div class="col-sm-12 col-md-6">
                            
                            <!-- Campo Data de expedição -->
                            @include('components.inputs._inputType',[
                                "for" => null,
                                "label" => "Data de expedição do registro de músico",
                                "name" => "dtaExpedicaoRegistroMusico",
                                "id" => null,
                                "required" => false,
                                "type" => "date",
                                "old" => old('dtaExpedicaoRegistroMusico', $musico->dtaExpedicaoRegistroMusico),
                                "oninput" => "",
                                "readonly" => false,
                                "small" => null,
                            ])
                            
                        </div>
                    </div>
                    
                    <hr class="my-4">
                    <h5 class="mb-3">{{ __('Documentos da Habilitação Documental (Licitação)') }}</h5>
                    <p class="text-muted small">{{ __('Cada documento deve ser enviado e pode ser aprovado ou reprovado pela equipe de Licitação.') }}</p>
                    <div class="table-responsive mb-4">
                        <table class="table table-bordered table-sm">
                            <thead>
                                <tr>
                                    <th>{{ __('Documento') }}</th>
                                    <th>{{ __('Status') }}</th>
                                    <th>{{ __('Arquivo') }}</th>
                                    <th>{{ __('Observação') }}</th>
                                    @php $podeEditar = (auth()->id() === $musico->user_id) || (auth()->user()->getPermissaoDetalhes('GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS')['editar'] ?? false); @endphp
                                    @if($podeEditar)
                                    <th>{{ __('Ações') }}</th>
                                    @endif
                                </tr>
                            </thead>
                            <tbody>
                                @foreach($musico->documentosCredenciamento as $doc)
                                <tr>
                                    <td>{{ $tiposLabels[$doc->tipo_documento] ?? $doc->tipo_documento }}</td>
                                    <td>
                                        @if($doc->status === 'APROVADO')
                                            <span class="badge bg-success">{{ __('Aprovado') }}</span>
                                        @elseif($doc->status === 'REPROVADO')
                                            <span class="badge bg-danger">{{ __('Reprovado') }}</span>
                                        @else
                                            <span class="badge bg-warning text-dark">{{ __('Pendente') }}</span>
                                        @endif
                                    </td>
                                    <td>
                                        @if($doc->arquivo_url)
                                            <a href="{{ asset($doc->arquivo_url) }}" target="_blank" rel="noopener">{{ __('Ver arquivo') }}</a>
                                        @else
                                            —
                                        @endif
                                    </td>
                                    <td class="small">{{ $doc->observacao ?: '—' }}</td>
                                    @if($podeEditar)
                                    <td>
                                        @php $routeUpload = str_contains(request()->route()->getName() ?? '', 'perfil.') ? route('admin.cultura.credenciamentoMusicos.perfil.documentos.upload', [$musico->id, $doc->id]) : route('admin.cultura.credenciamentoMusicos.documentos.upload', [$musico->id, $doc->id]); @endphp
                                        <form action="{{ $routeUpload }}" method="post" enctype="multipart/form-data" class="d-inline">
                                            @csrf
                                            <input type="file" name="arquivo" accept=".pdf,.jpg,.jpeg,.png" class="form-control form-control-sm d-inline-block w-auto" required>
                                            <button type="submit" class="btn btn-sm btn-outline-primary">{{ __('Enviar') }}</button>
                                        </form>
                                        @if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS')['editar'] ?? false)
                                        <form action="{{ route('admin.cultura.credenciamentoMusicos.documentos.avaliar', [$musico->id, $doc->id]) }}" method="post" class="d-inline mt-1">
                                            @csrf
                                            <input type="text" name="observacao" placeholder="{{ __('Observação') }}" class="form-control form-control-sm d-inline-block w-auto" value="{{ old('observacao') }}">
                                            <button type="submit" name="status" value="APROVADO" class="btn btn-sm btn-success">{{ __('Aprovar') }}</button>
                                            <button type="submit" name="status" value="REPROVADO" class="btn btn-sm btn-danger">{{ __('Reprovar') }}</button>
                                        </form>
                                        @endif
                                    </td>
                                    @endif
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>

                    <div class="row">
                        <div class="d-flex justify-content-between mt-4">
                            <a class="btn btn-outline-secondary" href="{{ route("admin.cultura.credenciamentoMusicos.dadosPessoais", $musico->id) }}">
                                <i class="fa-solid fa-arrow-left-long"></i> {{ __("Anterior") }}
                            </a>
                            <button class="btn btn-primary d-inline" type="submit">
                                <i class="fa-solid fa-user-plus"></i> {{ __("Salvar e Prosseguir") }}
                            </button>
                        </div>
                    </div>
                </div>
            </form>

        </div>
    </div>

