@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Página de Acompanhamento - Cadastro de Pacientes com Fibromialgia")
@section('content')

<div class="card shadow">

    @php $headLine = "<i class='fa-solid fa-user-injured'></i> Página de Acompanhamento - Cadastro de Pacientes com Fibromialgia"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
    'headLine' => __($headLine),
    'routeBack' => 'admin.contaAngra.index',
    'routeBackParams' => [], 
    'nameBack' => __("Voltar"),
    "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
    ])

    <div class="card-body">

        @include("errors.messageFlash")
        @include('components.modal._modelProfile')

        <hr>

        <div class="tab-content">
            <div class="mb-3">

                <div class="row">
                    <div class="col-12">
                        <h1 class="mb-3">{{ __('Página de Acompanhamento - Cadastro de Pacientes com Fibromialgia') }}</h1>

                        <style>
                            .btn-card {
                                border: none;
                                background: #fff;
                                border-radius: 10px;
                                box-shadow: 0 2px 6px rgba(0,0,0,0.15);
                                padding: 30px 20px;
                                transition: all 0.2s ease-in-out;
                                cursor: pointer;
                                width: 100%;
                            }

                            .btn-card:hover {
                                transform: translateY(-4px);
                                box-shadow: 0 4px 12px rgba(0,0,0,0.2);
                            }

                            .btn-card h2 {
                                font-size: 1.4rem;
                                margin: 0;
                                text-align: center;
                                color: #333;
                                font-weight: 600;
                            }
                        </style>

                        <div class="row g-3">

                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.dadosUsuario') }}'">
                                    <h2>{{ __("Dados de Usuário") }}</h2>
                                </div>
                            </div>
                            
                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.dadosPessoais') }}'">
                                    <h2>{{ __("Dados Pessoais") }}</h2>
                                </div>
                            </div>

                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.documentos') }}'">
                                    <h2>{{ __("Documentos") }}</h2>
                                </div>
                            </div>

                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.endereco') }}'">
                                    <h2>{{ __("Endereço") }}</h2>
                                </div>
                            </div>

                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.arquivos') }}'">
                                    <h2>{{ __("Arquivos") }}</h2>
                                </div>
                            </div>

                            <div class="col-12 col-sm-6 col-lg-4">
                                <div role="button" class="btn-card"
                                     onclick="window.location.href='{{ route('admin.saude.fibromialgia.perfil.carteirinha') }}'">
                                    <h2>{{ __("Carteirinha") }}</h2>
                                </div>
                            </div>

                        </div>

                    </div>
                </div>

            </div>
        </div>

    </div>
</div>

@endsection