<div class="card-body">

    <div class="row">
        <div class="col-12">
            @include("errors.messageFlash")
        </div>
    </div>
    <div class="row">

        @php
        $colors = [
        'text-primary',
        'text-success',
        'text-warning',
        'text-danger',
        'text-info',
        'text-secondary',
        'text-dark',
        ];
        @endphp

        @foreach($itens as $index => $item)
        @if (in_array($item["permission"], auth()->user()->listaPermissoes()))
        <div class="col-md-6 col-lg-3 mb-3">
            <a href="{{ route($item["route"]) }}" class="text-decoration-none">
                <div class="card h-100 shadow-sm hover-card text-center border-0">
                    <div class="card-body">
                        <div class="mb-3 {{ $colors[$index % count($colors)] }} fs-1">
                            {!! $item["fontawesome"] !!}
                        </div>
                        <h6 class="fw-bold text-dark">{{ __($item["nameButton"]) }}</h6>
                    </div>
                </div>
            </a>
        </div>
        @endif
        @endforeach

    </div>
</div>
