<section class="ma-quick-actions" aria-label="{{ __('Ações rápidas') }}">
    <div class="container">
        <div class="ma-quick-actions__grid">
            <a href="{{ route('mobiangra.horarios') }}" class="ma-quick-actions__card">
                <span class="ma-quick-actions__icon ma-quick-actions__icon--blue" aria-hidden="true">
                    <i class="fa-solid fa-clock"></i>
                </span>
                <span class="ma-quick-actions__label">{{ __('Linhas e horários') }}</span>
            </a>
            <a href="{{ route('mobiangra.mapa') }}" class="ma-quick-actions__card">
                <span class="ma-quick-actions__icon ma-quick-actions__icon--blue" aria-hidden="true">
                    <i class="fa-solid fa-map-location-dot"></i>
                </span>
                <span class="ma-quick-actions__label">{{ __('Ver mapa em tempo real') }}</span>
            </a>
            <a href="{{ route('mobiangra.passageiro_cidadao') }}" class="ma-quick-actions__card">
                <span class="ma-quick-actions__icon ma-quick-actions__icon--blue" aria-hidden="true">
                    <i class="fa-solid fa-id-card"></i>
                </span>
                <span class="ma-quick-actions__label">{{ __('Passageiro Cidadão') }}</span>
            </a>
            <a href="{{ route('mobiangra.informacoes') }}" class="ma-quick-actions__card">
                <span class="ma-quick-actions__icon ma-quick-actions__icon--blue" aria-hidden="true">
                    <i class="fa-solid fa-circle-info"></i>
                </span>
                <span class="ma-quick-actions__label">{{ __('Informações ao usuário') }}</span>
            </a>
        </div>
    </div>
</section>
