<?php $__env->startSection('title', __('Passageiro Cidadão - MobiAngra') . ' - ' . config('app.name')); ?>

<?php $__env->startSection('content'); ?>
    <section class="mobiangra-subpage">
        <div class="container">
            <?php if (isset($component)) { $__componentOriginal64b445abe4d6b6e54d21775dae604123 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal64b445abe4d6b6e54d21775dae604123 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.breadcrumb','data' => ['items' => [
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Passageiro Cidadão')],
            ]]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute([
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Passageiro Cidadão')],
            ])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $attributes = $__attributesOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__attributesOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $component = $__componentOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__componentOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>

            <div class="mobiangra-subpage-card">
                <?php if (isset($component)) { $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.subpage-header','data' => ['title' => __('Passageiro Cidadão')]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.subpage-header'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['title' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(__('Passageiro Cidadão'))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $attributes = $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $component = $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>

                <div class="p-4 mobiangra-conteudo">
                    <h2 class="h4"><?php echo e(__('O que é?')); ?></h2>
                    <p>
                        <?php echo e(__('O Programa Passageiro Cidadão é um benefício concedido pela Prefeitura Municipal de Angra dos Reis para proporcionar passagens de ônibus mais baratas para os seus moradores. O programa visa facilitar o acesso à cidade, promover a inclusão social e reduzir desigualdades.')); ?>

                    </p>
                    <p>
                        <?php echo e(__('Atualmente, o beneficiário do programa paga R$ 2,00 para as tarifas “A” e “B” e R$ 3,00 para a tarifa C, tendo direito a duas passagens diárias durante todos os dias da semana. Cabe ressaltar que há no Município o sistema de integração que possibilita mais de uma viagem de ônibus com uma única passagem sob certas condições.')); ?>

                    </p>

                    <h2 class="h4 mt-4"><?php echo e(__('Como obter o seu cartão?')); ?></h2>
                    <ol class="mb-0">
                        <li class="mb-3">
                            <strong><?php echo e(__('1º Passo - Pré-cadastro on-line:')); ?></strong>
                            <?php echo e(__('Clique em CADASTRAR e preencha o formulário.')); ?>

                            <a href="https://angra.rj.gov.br/passageirocidadao" target="_blank" rel="noopener noreferrer">
                                <?php echo e(__('Clique aqui para se cadastrar')); ?>

                            </a>
                        </li>
                        <li class="mb-3">
                            <strong><?php echo e(__('2º Passo - Agendamento:')); ?></strong>
                            <?php echo e(__('Após o pré-cadastro, ligue para o número 0800 286 1500 e agende o atendimento presencial. Este serviço funciona exclusivamente de segunda a sexta-feira, das 10h às 16h.')); ?>

                            <?php echo e(__('Atenção: serão disponibilizadas diariamente 60 vagas de agendamento.')); ?>

                        </li>
                        <li class="mb-3">
                            <strong><?php echo e(__('3º Passo - Cadastro presencial:')); ?></strong>
                            <?php echo e(__('No dia e hora marcados, compareça à sede da Secretaria de Segurança Pública (Rua Marquês de Tamandaré, nº 156, Centro - Antigo Fórum) e apresente a documentação necessária (RG, CPF e comprovante de residência).')); ?>

                        </li>
                        <li class="mb-3">
                            <strong><?php echo e(__('4º Passo - Biometria e retirada do cartão:')); ?></strong>
                            <?php echo e(__('Com o documento emitido pela Secretaria de Segurança Pública em mãos, vá até a garagem da Viação Senhor do Bonfim (Rua Prefeito João Gregório Galindo, nº 110, Japuíba) para a realização da biometria facial (foto) e emissão do cartão.')); ?>

                        </li>
                    </ol>

                    <div class="alert alert-warning mt-4 mb-0" role="alert">
                        <h3 class="h5 alert-heading"><?php echo e(__('Cuidado com golpes!')); ?></h3>
                        <p class="mb-2">
                            <?php echo e(__('O cadastro para o Programa Passageiro Cidadão é inteiramente GRATUITO e só é feito pela Prefeitura de Angra dos Reis. Em caso de mensagens suspeitas, entre em contato com o Disque Denúncia 0300 253 1177 e, em caso de golpe, acione a polícia.')); ?>

                        </p>
                        <p class="mb-0">
                            <a href="https://delegaciaonline.pcivil.rj.gov.br/" target="_blank" rel="noopener noreferrer">
                                <?php echo e(__('Delegacia Online - Polícia Civil do RJ')); ?>

                            </a>
                        </p>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.mobiangra.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/mobiangra/passageiro_cidadao.blade.php ENDPATH**/ ?>