@extends('layouts.admin.theme')

@section('content')
    <div class="container text-start pb-5 mb-5">
        @if($errors->any())
            <div class="alert alert-danger mb-4" role="alert">
                @foreach($errors->all() as $e)
                    <div>{{ $e }}</div>
                @endforeach
            </div>
        @endif
        <div class="row mb-4">
            <div class="col text-start">
                <h3>{{ __('Orçamento') }}</h3>
            </div>
            <div class="col text-end d-flex justify-content-end">
                <button type="button" class="btn btn-light bg-mediumGray me-2"
                    onclick="window.location='{{ route('admin.projetosProgramas.index', $projetosListagemReturnQuery ?? []) }}'">
                    <i class="fa fa-list me-1"></i> {{ __('Início') }}
                </button>
            </div>
        </div>
        @include('admin.projetosProgramas.partials.steps', [
            'current' => 'investimento',
            'project' => $project,
            'projetosListagemReturnQuery' => $projetosListagemReturnQuery ?? [],
        ])
        @include('components.projetosProgramas._stickyProjectHeader', ['project' => $project])
        @php
            $fonteSelecionada = old('fonte_id', $project->fonte_id);
            $fonteAtual = $fontes->firstWhere('id', $fonteSelecionada);
            $showConvenio = optional($fonteAtual)->nome === 'Convênio';
            $selectedConvenioOrg = old('conve_orgao', $project->conve_orgao);
        @endphp
        <form method="post" action="{{ route('admin.projetosProgramas.investimento.store', $project->id) }}" class="mt-3 text-start"
            data-investimento-form
            data-lbl-convenio="{{ __('Convênio') }}">
            @csrf
            @include('components.projetosProgramas._pp_listagem_context_hiddens', ['query' => $projetosListagemReturnQuery ?? []])
            <div class="row g-3">
                <div class="col-md-6">
                    <label class="form-label" for="fonte_id">{{ __('Fonte') }}</label>
                    <select name="fonte_id" id="fonte_id" class="form-select" data-fonte-select>
                        <option value="">{{ __('--- Selecione ---') }}</option>
                        @foreach($fontes as $f)
                            <option value="{{ $f->id }}" data-nome="{{ $f->nome }}" {{ (string) $fonteSelecionada === (string) $f->id ? 'selected' : '' }}>{{ $f->nome }}</option>
                        @endforeach
                    </select>
                    <label class="form-label visually-hidden" for="fonte_outro">{{ __('Outra fonte') }}</label>
                    <input type="text" name="fonte_outro" id="fonte_outro" class="form-control mt-2"
                        placeholder="{{ __('Outro') }}"
                        value="{{ old('fonte_outro', $project->fonte_outro) }}">
                </div>
                <div id="divConvenio" class="col-12 mt-1" @if(!$showConvenio) hidden @endif>
                    <div class="row g-2">
                        <div class="col-md-4">
                            <label class="form-label" for="conve_orgao">{{ __('Órgão') }}</label>
                            <select name="conve_orgao" id="conve_orgao" class="form-select" data-convenio-orgao>
                                <option value="">{{ __('--- Selecione ---') }}</option>
                                @foreach(['Governo Federal', 'Governo do Estado do RJ', 'Eletronuclear', 'Petrobras', 'Transpetro', 'Outro'] as $org)
                                    <option value="{{ $org }}" {{ $selectedConvenioOrg == $org ? 'selected' : '' }}>{{ $org }}
                                    </option>
                                @endforeach
                            </select>
                            <input type="text" name="conve_orgao_outro" class="form-control mt-2" placeholder="{{ __('Qual órgão?') }}"
                                value="{{ old('conve_orgao_outro', $project->conve_orgao_outro) }}"
                                @if($selectedConvenioOrg !== 'Outro') hidden @endif
                                data-convenio-orgao-outro>
                        </div>
                        <div class="col-md-4">
                            <label class="form-label" for="conve_proposta">{{ __('Nº da proposta') }}</label>
                            <input type="text" name="conve_proposta" id="conve_proposta" class="form-control"
                                value="{{ old('conve_proposta', $project->conve_proposta) }}">
                        </div>
                        <div class="col-md-4">
                            <label class="form-label" for="conve_convenio">{{ __('Nº do convênio') }}</label>
                            <input type="text" name="conve_convenio" id="conve_convenio" class="form-control"
                                value="{{ old('conve_convenio', $project->conve_convenio) }}">
                        </div>
                    </div>
                </div>
            </div>
            <div class="row g-3 mt-1">
                <div class="col-md-6">
                    <label class="form-label" for="orcamento_previsto">{{ __('Orçamento previsto (R$)') }}</label>
                    <input type="text" name="orcamento_previsto" id="orcamento_previsto" class="form-control"
                        value="{{ old('orcamento_previsto', $project->orcamento_previsto) }}" data-currency-input>
                </div>
                <div class="col-md-6">
                    <label class="form-label" for="orcamento_disponivel">{{ __('Orçamento disponível (R$)') }}</label>
                    <input type="text" name="orcamento_disponivel" id="orcamento_disponivel" class="form-control"
                        value="{{ old('orcamento_disponivel', $project->orcamento_disponivel) }}" data-currency-input>
                </div>
            </div>
            <div class="text-end mt-4 d-flex gap-3">
                <button type="submit" class="btn btn-green">
                    <i class="fa fa-check me-1"></i> {{ __('Salvar e finalizar') }}
                </button>
            </div>
        </form>
        <script src="{{ asset('pmar/js/projetos-programas-investimento.js') }}"></script>
    </div>
@endsection
