<?php if(isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['excluir']): ?>
    <form class="d-inline" action="<?php echo e(route($route, $id)); ?>" method="post" onsubmit="return confirmDelete(this)">
        <?php echo csrf_field(); ?>
        <?php if(isset($method)): ?>
            <?php echo method_field($method); ?>
        <?php else: ?>
            <?php echo method_field('delete'); ?>
        <?php endif; ?>
        <?php if(!empty($queryParams)): ?>
            <?php $__currentLoopData = $queryParams; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $value): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <?php if($value !== null && $value !== ''): ?>
                    <input type="hidden" name="<?php echo e($key); ?>" value="<?php echo e($value); ?>">
                <?php endif; ?>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        <?php else: ?>
            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
            <?php if(request()->filled('q')): ?>
                <input type="hidden" name="q" value="<?php echo e(request()->input('q')); ?>">
            <?php endif; ?>
        <?php endif; ?>
        <input type="hidden" name="confirm" value="<?php echo e(__($message)); ?>">
        <button type="submit" class="btn btn-sm btn-danger" title="<?php echo e($title); ?>">
        <?php if($fontawesome == null): ?>
            <i class="fa-solid fa-trash"></i>
        <?php else: ?>
            <?php echo $fontawesome; ?>

        <?php endif; ?>
        </button>
    </form>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/buttons/_deleteButton.blade.php ENDPATH**/ ?>