@php $evento = $evento ?? null; @endphp
<div class="row g-3 mb-3">
    <div class="col-12">
        <label for="nome" class="form-label">{{ __('Nome') }} *</label>
        <input type="text" class="form-control" id="nome" name="nome" value="{{ old('nome', $evento->nome ?? '') }}" required>
    </div>
    <div class="col-md-6">
        <label for="categoria" class="form-label">{{ __('Categoria') }}</label>
        <input type="text" class="form-control" id="categoria" name="categoria" value="{{ old('categoria', $evento->categoria ?? '') }}">
    </div>
    <div class="col-md-6">
        <label for="data" class="form-label">{{ __('Data') }}</label>
        <input type="date" class="form-control" id="data" name="data" value="{{ old('data', $evento->data ? $evento->data->format('Y-m-d') : '') }}">
    </div>
    <div class="col-12">
        <label for="observacoes" class="form-label">{{ __('Observações') }}</label>
        <textarea class="form-control" id="observacoes" name="observacoes" rows="3">{{ old('observacoes', $evento->observacoes ?? '') }}</textarea>
    </div>
    <div class="col-12">
        <div class="form-check">
            <input type="hidden" name="ativo" value="0">
            <input type="checkbox" class="form-check-input" id="ativo" name="ativo" value="1" {{ old('ativo', $evento->ativo ?? true) ? 'checked' : '' }}>
            <label class="form-check-label" for="ativo">{{ __('Ativo') }}</label>
        </div>
    </div>
</div>
