<section class="ma-status-bar" aria-label="{{ __('Status do sistema') }}">
    <div class="container">
        <div class="ma-status-bar__inner">
            <span class="ma-status-bar__dot" aria-hidden="true"></span>
            <span class="ma-status-bar__text">{{ __('Sistema em operação') }}</span>
            <span class="ma-status-bar__updated d-none d-sm-inline">
                {{ __('Atualizado agora há pouco') }}
            </span>
            <a href="{{ route('mobiangra.mapa') }}" class="ma-status-bar__link ms-auto">
                {{ __('Ver detalhes') }}
                <i class="fa-solid fa-chevron-right" aria-hidden="true"></i>
            </a>
        </div>
    </div>
</section>
