@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Fibromialgia - Chamados Fechados")
@section('content')

<div class="card shadow-sm border-0">

    @php $headLine = "<i class='fa-solid fa-user-injured'></i> Fibromialgia <i class='fa-solid fa-headset'></i> Chamados Fechados"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
        'headLine' => __($headLine),
        'routeBack' => 'admin.saude.fibromialgia.index',
        'routeBackParams' => [], 
        'nameBack' => __("Sair"),
        'routeAdd' => 'admin.saude.fibromialgia.chamados.abertos',
        'routeAddParams' => [], 
        'nameAdd' => __('Chamados abertos'),
        'fontawesomeAdd' => "<i class='fa-solid fa-headset'></i>",
        "permission" => "GERENCIADOR_DO_CADASTRO_DE_PACIENTES_COM_FIBROMIALGIA",
    ])

    <div class="card-body">

            @include("errors.messageFlash")

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "chamadosFechados", 
                "placeholder" => "Pesquisar atendimento..."
            ])

            <x-tables._table :thead="['Protocolo','Criado em','Usuário','Assunto', 'Andamento', 'Ações']" :pagination="$chamados->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($chamados as $chamado)
                        <tr>
                            <td>{{ $chamado->numeroChamado }}</td>
                            <td>{{ date("d/m/Y H:i", strtotime($chamado->created_at)) }}</td>
                            <td>{{ $chamado->convenioAtual }}</td>
                            <td>{{ $chamado->assunto }}</td>
                            <td>{{ $chamado->statusChamado }}</td>
                            <td>
                                <div class="d-flex gap-2 justify-content-center">
                                    
                                    @include('components.buttons._editButton', [
                                        "route" => "admin.saude.fibromialgia.chamados.show",
                                        "id" => $chamado->id,
                                        "title" => "Página de Acompanhamento",
                                        "fontawesome" => "<i class='fa-solid fa-eye'></i>",
                                        "permission" => "GERENCIADOR_DO_CADASTRO_DE_PACIENTES_COM_FIBROMIALGIA",
                                    ])
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>

        </div>

</div>

@endsection