<form action="{{ route('admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioStore', $ambulante->id) }}" method="post" enctype="multipart/form-data">

    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        
                        <div class="mb-3 p-5 bg-secondary text-white rounded">
                            <h1>{{ $ambulante->proprietario->firstName }} {{ $ambulante->proprietario->lastName }}</h1>
                            <p class="text-white">CPF: {{ $ambulante->proprietario->cpf }}</p>
                            <p class="text-white">Telefone: {{ $ambulante->proprietario->phoneNumber }}</p>
                            <p class="text-white">Email: {{ $ambulante->proprietario->email }}</p>
                        </div>
                        
                        <div class="form-check mb-3">
                            @php $checkComercioAmbulante = ($ambulante->empresa_id == "" || $ambulante->empresa_id == null) ? NULL : $ambulante->empresa_id @endphp
                            <input class="form-check-input" type="checkbox" name="checkComercioAmbulante" id="checkComercioAmbulante" {{ old('checkComercioAmbulante', $checkComercioAmbulante) ? 'checked' : '' }}>
                            <label class="form-check-label" for="checkComercioAmbulanteWithCNPJ">
                                Marque esta opção se o ambulante possuir CNPJ.
                            </label>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="container my-3">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Dados do comércio</h5>
                        <div class="container">
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        @csrf
                                        @method('POST')
                                        <input type="hidden" name="owner_id" id="owner_id" value="{{ auth()->user()->id }}"/>
                                        <label for="razaoSocial" class="form-label text-bold">Razão social: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('razaoSocial') is-invalid @enderror" name="razaoSocial" id="razaoSocial" value="{{ old('razaoSocial', $comercio?->razaoSocial ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('razaoSocial')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="numeroInscricaoMunicipal" class="form-label text-bold">Inscrição municipal: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('numeroInscricaoMunicipal') is-invalid @enderror" name="numeroInscricaoMunicipal" id="numeroInscricaoMunicipal" value="{{ old('numeroInscricaoMunicipal', $comercio?->numeroInscricaoMunicipal ?? NULL) }}" oninput="this.value = this.value.replace(/\D/g, '')" autocomplete="off">
                                        @error('numeroInscricaoMunicipal')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="nomeFantasia" class="form-label text-bold">Nome fantasia: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('nomeFantasia') is-invalid @enderror" name="nomeFantasia" id="nomeFantasia" value="{{ old('nomeFantasia', $comercio?->nomeFantasia ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('nomeFantasia')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="cnpj" class="form-label text-bold">CNPJ: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('cnpj') is-invalid @enderror" name="cnpj" id="cnpj" value="{{ formatCnpjCpf(old('cnpj', $comercio?->cnpj ?? NULL)) }}" oninput="javascript:aplicarMascaraCNPJ(this)" autocomplete="off">
                                    @error('cnpj')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="anoAbertura" class="form-label text-bold">Ano de abertura: <span class="span-admin-create">*</span></label>
                                        <input type="text" class="form-control @error('anoAbertura') is-invalid @enderror" name="anoAbertura" id="datepickerYear" value="{{ old('anoAbertura', $comercio?->anoAbertura ?? NULL) }}" autocomplete="off">
                                    @error('anoAbertura')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="tipoComercio" class="form-label text-bold">Tipo de comércio: <span class="span-admin-create">*</span></label>
                                        <input class="form-control  @error('tipoComercio') is-invalid @enderror" list="optionsTipoComercio" name="tipoComercio" id="tipoComercio" oninput="this.value = this.value.toUpperCase()" value="{{ old('tipoComercio', $ambulante?->tipoComercio ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        <datalist id="optionsTipoComercio">
                                        <option value="1. Alimentação - Lanches e salgados (cachorro-quente, coxinha, pastel, sanduíches)"></option>
                                        <option value="1. Alimentação - Sorvetes e picolés"></option>
                                        <option value="1. Alimentação - Doces e confeitaria (brigadeiro, bolo, doces tradicionais)"></option>
                                        <option value="1. Alimentação - Frutas e sucos naturais"></option>
                                        <option value="1. Alimentação - Bebidas (refrigerantes, água, sucos industrializados, cafés)"></option>
                                        <option value="1. Alimentação - Churrasquinho / espetinhos / carnes grelhadas"></option>
                                        <option value="1. Alimentação - Comida típica regional"></option>
                                        <option value="1. Alimentação - Marmitas e refeições rápidas"></option>
                                        <option value="2. Bebidas - Refrigerantes e águas"></option>
                                        <option value="2. Bebidas - Sucos e vitaminas"></option>
                                        <option value="2. Bebidas - Cervejas e bebidas alcoólicas (onde permitido)"></option>
                                        <option value="2. Bebidas - Drinks prontos (coquetéis)"></option>
                                        <option value="3. Artesanato e Produtos Manuais - Bijuterias e acessórios"></option>
                                        <option value="3. Artesanato e Produtos Manuais - Artesanato local / souvenirs"></option>
                                        <option value="3. Artesanato e Produtos Manuais - Roupas e acessórios feitos à mão"></option>
                                        <option value="3. Artesanato e Produtos Manuais - Objetos de decoração"></option>
                                        <option value="3. Artesanato e Produtos Manuais - Trabalhos em madeira, cerâmica, tecido, crochê"></option>
                                        <option value="4. Vestuário e Moda - Roupas em geral (camisetas, shorts, calças, vestidos)"></option>
                                        <option value="4. Vestuário e Moda - Acessórios (chapéus, bonés, cintos, bolsas)"></option>
                                        <option value="4. Vestuário e Moda - Calçados e sandálias"></option>
                                        <option value="4. Vestuário e Moda - Óculos de sol, bijuterias e bijuterias artesanais"></option>
                                        <option value="5. Serviços - Serviços de beleza (cortes de cabelo, manicure, maquiagem)"></option>
                                        <option value="5. Serviços - Serviços de fotografia e lembranças"></option>
                                        <option value="5. Serviços - Aluguel de equipamentos ou brinquedos (balões, brinquedos infláveis)"></option>
                                        <option value="5. Serviços - Recarga de celulares / cartões pré-pagos"></option>
                                        <option value="6. Outros Produtos - Brinquedos e artigos infantis"></option>
                                        <option value="6. Outros Produtos - Materiais escolares e papelaria"></option>
                                        <option value="6. Outros Produtos - Produtos eletrônicos pequenos (fones, carregadores, cabos)"></option>
                                        <option value="6. Outros Produtos - Plantas e flores"></option>
                                        <option value="6. Outros Produtos - Itens sazonais (Natal, Páscoa, festas regionais)"></option>
                                        <option value="7. Mistos e Diversos - Combinações de alimentos e bebidas"></option>
                                        <option value="7. Mistos e Diversos - Mesas de produtos variados"></option>
                                        <option value="7. Mistos e Diversos - Cozinhas móveis (food trucks, trailers, carrinhos)"></option>
                                    </datalist>
                                    @error('tipoComercio')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="telefone" class="form-label text-bold">Telefone do comércio:</label>
                                    <input type="text" class="form-control @error('telefone') is-invalid @enderror" name="telefone" id="telefone" value="{{ old('telefone', $comercio?->telefone ?? NULL) }}" oninput="aplicarMascaraTelefone(this)" autocomplete="off">
                                                                @error('telefone')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="celular" class="form-label text-bold">Celular do comércio:</label>
                                    <input type="text" class="form-control @error('celular') is-invalid @enderror" name="celular" id="celular" value="{{ old('celular', $comercio?->celular ?? NULL) }}" oninput="aplicarMascaraTelefone(this)" autocomplete="off">
                                                                @error('celular')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="email" class="form-label text-bold">Email do comércio: <span class="span-admin-create">*</span></label>
                                    <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" id="email" value="{{ old('email', $comercio?->email ?? NULL) }}" oninput="this.value = this.value.toLowerCase()" autocomplete="off">
                                                                @error('email')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="site" class="form-label text-bold">Site do comércio:</label>
                                    <input type="text" class="form-control @error('site') is-invalid @enderror" name="site" id="site" value="{{ old('site', $comercio?->site ?? NULL) }}" oninput="this.value = this.value.toLowerCase()" autocomplete="off">
                                                                @error('site')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-12">
                                <div class="mb-3 text-wrap">
                                    <label for="principalAtividade" class="form-label text-bold">Principal atividade: </label>
                                    <textarea class="form-control @error('principalAtividade') is-invalid @enderror textarea-comments" style="height: 100px" name="principalAtividade" id="principalAtividade">{{ old('principalAtividade', $comercio?->principalAtividade ?? NULL) }}</textarea>
                                    @error('principalAtividade')
                                        <small class="text-danger text-bold">{{ $message }}</small><br>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="situacaoLicenca" class="form-label text-bold">Situação da Licença: <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control @error('numeroAutorizacao') is-invalid @enderror" list="optionsSituacaoLicenca" name="situacaoLicenca" id="situacaoLicenca" value="{{ old('situacaoLicenca', $ambulante?->situacaoLicenca ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        <datalist id="optionsSituacaoLicenca">
                                    <option value="Aguardando autorização"></option>
                                    <option value="Ativa"></option>
                                    <option value="Suspensa"></option>
                                    <option value="Cassada"></option>
                                </datalist>
                                    @error('situacaoLicenca')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                        </div>
                        <div class="col-sm-12 col-md-5">
                            <div class="mb-3">
                                <label for="localizacaoPonto" class="form-label text-bold">Localização do ponto:</label>
                                <input type="text" class="form-control @error('validadeAutorizacao') is-invalid @enderror" list="optionsLocalizacaoPonto" name="localizacaoPonto" id="localizacaoPonto" value="{{ old('localizacaoPonto', $ambulante?->localizacaoPonto ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                        <datalist id="optionsLocalizacaoPonto"> 
                                <option value="Área verde / Jardim"></option>
                                <option value="Avenida"></option>
                                <option value="Bairro (especificar nome)"></option>
                                <option value="Calçadão"></option>
                                <option value="Centro comercial / shopping popular"></option>
                                <option value="Comunidade / vila"></option>
                                <option value="Condomínio / conjunto habitacional"></option>
                                <option value="Escola / universidade (próximo a)"></option>
                                <option value="Esquina (especificar ruas)"></option>
                                <option value="Evento cultural (shows, festas populares)"></option>
                                <option value="Evento esportivo (estádios, arenas)"></option>
                                <option value="Feira livre"></option>
                                <option value="Festa religiosa (procissões, festas de padroeiro)"></option>
                                <option value="Hospital / posto de saúde (próximo a)"></option>
                                <option value="Largo"></option>
                                <option value="Mercado municipal"></option>
                                <option value="Obras / áreas de grande circulação temporária (próximo a)"></option>
                                <option value="Orla / calçadão da praia"></option>
                                <option value="Parque público"></option>
                                <option value="Porto / cais"></option>
                                <option value="Ponto turístico (monumentos, igrejas, museus)"></option>
                                <option value="Praia"></option>
                                <option value="Praça"></option>
                                <option value="Repartições públicas (próximo a)"></option>
                                <option value="Rodoviária"></option>
                                <option value="Rua"></option>
                                <option value="Terminal urbano (ônibus, barcas)"></option>
                                <option value="Travessa"></option>
                            </datalist>
                                    @error('localizacaoPonto')
                                <small class="text-danger text-bold">{{ $message }}</small>
                            @enderror
                        </div>
                    </div>
                    <div class="col-sm-12 col-md-7">
                        <div class="mb-3">
                            <label for="numeroAutorizacao" class="form-label text-bold">Número da autorização/licença: <span class="span-admin-create">*</span></label>
                            <input type="text" class="form-control @error('numeroAutorizacao') is-invalid @enderror" name="numeroAutorizacao" id="numeroAutorizacao" value="{{ old('numeroAutorizacao', $ambulante?->numeroAutorizacao ?? NULL) }}" oninput="this.value = this.value.replace(/\D/g, '')" autocomplete="off">
                                    @error('numeroAutorizacao')
                                <small class="text-danger text-bold">{{ $message }}</small>
                            @enderror
                        </div>
                    </div>
                    <div class="col-sm-12 col-md-5">
                        <div class="mb-3">
                            <label for="validadeAutorizacao" class="form-label text-bold">Validade:</label>
                            <input type="date" class="form-control @error('validadeAutorizacao') is-invalid @enderror" name="validadeAutorizacao" id="validadeAutorizacao" value="{{ old('validadeAutorizacao', $ambulante?->validadeAutorizacao ?? NULL) }}" autocomplete="off">
                                    @error('validadeAutorizacao')
                                <small class="text-danger text-bold">{{ $message }}</small>
                            @enderror
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
</div>
</div>

<div class="container my-3">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">Endereço do comércio ambulante</h5>
                    <div class="container address">
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <input type="hidden" name="domicilioDadosComercio" id="domicilioDadosComercio" value="OUTROS"/>
                                    <label for="cepDadosComercio" class="form-label">CEP <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control cep @error('cepDadosComercio') is-invalid @enderror" name="cepDadosComercio" id="cepDadosComercio" oninput="aplicarMascaraCEP(this)" value="{{ old('cepDadosComercio', $endereco?->cep ?? NULL) }}" autocomplete="off">
                                    @error('cepDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="logradouroDadosComercio" class="form-label">Logradouro <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control logradouro @error('logradouroDadosComercio') is-invalid @enderror" name="logradouroDadosComercio" id="logradouroDadosComercio" value="{{ old('logradouroDadosComercio', $endereco?->logradouro ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('logradouroDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="numeroDadosComercio" class="form-label">Número</label>
                                    <input type="text" class="form-control numero @error('numeroDadosComercio') is-invalid @enderror" name="numeroDadosComercio" id="numeroDadosComercio" value="{{ old('numeroDadosComercio', $endereco?->numero ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('numeroDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="complementoDadosComercio" class="form-label">Complemento</label>
                                    <input type="text" class="form-control complemento @error('complementoDadosComercio') is-invalid @enderror" name="complementoDadosComercio" id="complementoDadosComercio" value="{{ old('complementoDadosComercio', $endereco?->complemento ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('complementoDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="cidadeDadosComercio" class="form-label">Cidade <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control cidade @error('cidadeDadosComercio') is-invalid @enderror" name="cidadeDadosComercio" id="cidadeDadosComercio" value="{{ old('cidadeDadosComercio', $endereco?->cidade ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('cidadeDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="bairroDadosComercio" class="form-label">Bairro <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control bairro @error('bairroDadosComercio') is-invalid @enderror" name="bairroDadosComercio" id="bairroDadosComercio" value="{{ old('bairroDadosComercio', $endereco?->bairro ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    @error('bairroDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="ufDadosComercio" class="form-label">UF <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control uf @error('ufDadosComercio') is-invalid @enderror" list="optionsSiglasDadosComercio" name="ufDadosComercio" id="ufDadosComercio" maxlength="2" value="{{ old('ufDadosComercio', $endereco?->uf ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" autocomplete="off">
                                    <datalist id="optionsSiglasDadosComercio">
                                        <option value="AC"></option>
                                        <option value="AL"></option>
                                        <option value="AP"></option>
                                        <option value="AM"></option>
                                        <option value="BA"></option>
                                        <option value="CE"></option>
                                        <option value="DF"></option>
                                        <option value="ES"></option>
                                        <option value="GO"></option>
                                        <option value="MA"></option>
                                        <option value="MT"></option>
                                        <option value="MS"></option>
                                        <option value="MG"></option>
                                        <option value="PA"></option>
                                        <option value="PB"></option>
                                        <option value="PR"></option>
                                        <option value="PE"></option>
                                        <option value="PI"></option>
                                        <option value="RJ"></option>
                                        <option value="RN"></option>
                                        <option value="RS"></option>
                                        <option value="RO"></option>
                                        <option value="RR"></option>
                                        <option value="SC"></option>
                                        <option value="SP"></option>
                                        <option value="SE"></option>
                                        <option value="TO"></option>
                                      </datalist>
                                    @error('ufDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="latitudeDadosComercio" class="form-label">Latitude <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control latitude @error('latitudeDadosComercio', $endereco?->latitude ?? NULL) is-invalid @enderror bg-light" name="latitudeDadosComercio" id="latitudeDadosComercio" autocomplete="off" value="{{ old('latitudeDadosComercio') }}">
                                    @error('latitudeDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="longitudeDadosComercio" class="form-label">Longitude <span class="span-admin-create">*</span></label>
                                    <input type="text" class="form-control longitude @error('longitudeDadosComercio', $endereco?->longitude ?? NULL) is-invalid @enderror bg-light" name="longitudeDadosComercio" id="longitudeDadosComercio" autocomplete="off" value="{{ old('longitudeDadosComercio') }}">
                                    @error('longitudeDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="comprovanteDadosComercio" class="form-label text-bold">Comprovante de endereço:</label>
                                    <input type="file" class="form-control comprovante @error('comprovanteDadosComercio') is-invalid @enderror" name="comprovanteDadosComercio" id="comprovanteDadosComercio" accept="image/jpeg,image/jpg,image/png,image/gif,.pdf" />
                                    @error('comprovanteDadosComercio')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                @if(isset($endereco->id))
                                    <div style="width: 90px;">
                                    @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $endereco->comprovante,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<div class="d-flex justify-content-between mt-4">
    <a class="btn btn-outline-secondary" href="{{ route("admin.cadastroDeAmbulantes.ambulantes.representanteLegalIndex", $ambulante->id ) }}">
        <i class="fa-solid fa-arrow-left-long"></i> Anterior
    </a>
    <button class="btn btn-primary d-inline" type="submit">
        <i class="fa-solid fa-user-plus"></i> Salvar e Prosseguir
    </button>
</div>
</form>