@if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar'])
    <form id="{{ "checkStatus_" . $index }}" class="fix" action="{{ route($route, $id)}}" method="post">
        @csrf
        <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
        @if($status == "ATIVADO" || $status == 1 )
            <div class="form-check form-switch d-flex justify-content-center">
                <input type="hidden" name="checkStatus" value="DESATIVADO">
                <input class="form-check-input" type="checkbox" checked
                   onclick="javascript:$('#{{ "checkStatus_" . $index }}').submit()">
            </div>
        @else
            <div class="form-check form-switch d-flex justify-content-center">
                <input type="hidden" name="checkStatus" value="ATIVADO">
                <input class="form-check-input" type="checkbox"
                   onclick="javascript:$('#{{ "checkStatus_" . $index }}').submit()">
            </div>
        @endif
    </form>
 @endif