<?php if(!empty($seiAlertaConteudo)): ?>
<aside class="text-center bg-dark mt-5" role="alert" aria-live="polite">
    <div class="container px-5">
        <div class="row gx-5 justify-content-center">
            <div class="col-xl-12">
                <div class="h2 fs-1 text-white mb-4">
                    <span class="shadow-text"><?php echo $seiAlertaConteudo; ?></span>
                </div>
            </div>
        </div>
    </div>
</aside>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/sei/sections/bannerEmergencial.blade.php ENDPATH**/ ?>