<!-- Educação -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-info">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-graduation-cap fa-2x me-3"></i>
                <h5 class="card-title mb-0">Educação</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item">
                    <i class="fas fa-user-edit me-2 text-muted"></i>
                    <a href="https://matriculadigital.angra.rj.gov.br/#/" target="_blank" class="text-dark">Matrícula Digital</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-laptop-code me-2 text-muted"></i>
                    <a href="https://escoladigital.angra.rj.gov.br" target="_blank" class="text-dark">Escola Digital</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-school me-2 text-muted"></i>
                    <a href="{{ route('servicos.escolasMunicipais') }}" class="text-dark">Escolas Municipais</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-baby me-2 text-muted"></i>
                    <a href="{{ route('servicos.crechesMunicipais') }}" class="text-dark">Creches</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-apple-alt me-2 text-muted"></i>
                    <a href="{{ route('servicos.cardapioDeAlimentacaoEscolar') }}" class="text-dark">Merenda Escolar</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-bus-alt me-2 text-muted"></i>
                    Transporte Escolar <small class="badge bg-info">em breve</small>
                </li>
            </ul>
        </div>
    </div>
</div>