@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Animais do Tutor')

@section('content')


    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-paw'></i> Castração Animal - Lista de Animais de " . $tutor->user->name; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
            'routeBackParams' => [],
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.meioAmbiente.castracaoAnimal.animais.create',
            'routeAddParams' => [$tutor->id],
            'nameAdd' => __('Novo animal'),
            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
            "tabs" => [
//                ['route' => 'admin.meioAmbiente.castracaoAnimal.tutores.index', 'class' => 'fa-solid fa-list', 'label' => 'Lista de tutores', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.caes', 'class' => 'fa-solid fa-dog', 'label' => 'Lista de cães', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.gatos', 'class' => 'fa-solid fa-cat', 'label' => 'Lista de gatos', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
            ],
        ])

        <div class="card-body">

            @include("errors.messageFlash")
            @include('components.modal._modelProfile')
            

            <x-tables._table :thead="['#', 'Criado em', 'Nome', 'Espécie', 'Raça', 'Sexo', 'Idade', 'Peso', 'Tipo', 'Status', 'Ações']" :pagination="$animais->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                            @foreach($animais as $animal)
                        <tr>
                            <td style="width:150px">
                                @include('components.tables._openPhoto', [
                                    'asset' => $animal->photo,
                                    'alt' => $animal->nome,
                                    'title' => $animal->nome,
                                    'text' => 'Visualizar foto',
                                ])
                            </td>
                            <td>{{ date("d/m/Y H:i", strtotime($animal->created_at)) }}</td>
                            <td>{{ $animal->nome }}</td>
                            <td>{{ $animal->especie }}</td>
                            <td>{{ $animal->raca->nome_raca }}</td>
                            <td>{{ \App\Enums\SexoAnimal::from($animal->sexo)->value }}</td>
                            <td>{{ $animal->idade }} {{ \App\Enums\IdadeEm::from($animal->idade_em)->value }}</td>
                            <td>{{ $animal->peso }} kg</td>
                            <td>{{ \App\Enums\TipoAnimal::from($animal->tipo)->value }}</td>
                            <td class="text-center align-middle">
                                @include('components.buttons._status', [
                                    "index" => $index,
                                    "route" => "admin.meioAmbiente.castracaoAnimal.animais.status",
                                    "id" => [$tutor->id, $animal->id],
                                    "status" => $animal->status,
                                    "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                ])
                            </td>
                            <td>
                                <div class="d-flex gap-2 justify-content-center">

                                    @include('components.buttons._editButton', [
                                            "route" => "admin.meioAmbiente.castracaoAnimal.animais.edit",
                                            "id" => [$tutor->id, $animal->id],
                                            "title" => "Editar",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                    @include('components.buttons._deleteButton', [
                                            "message" => __("* Esta raça será excluída e esta ação não poderá ser desfeita, deseja continuar?"),
                                            "route" => "admin.meioAmbiente.castracaoAnimal.animais.destroy",
                                            "id" => [$tutor->id, $animal->id],
                                            "title" => "Excluir",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                                        ])

                                </div>

                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>
            
        </div>
    </div>
@endsection