@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Castração Animal - Nova Raça')

@section('content')


    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                        @php $headLine = "<i class='fa-solid fa-paw'></i> Castração Animal - Nova Raça"; @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'tabs' => [
                                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.caes', 'class' => 'fa-solid fa-dog', 'label' => 'Lista de cães', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.gatos', 'class' => 'fa-solid fa-cat', 'label' => 'Lista de gatos', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                            ],
                        ])

                        <div class="card-body">
                            @csrf
                            @method('POST')
                            @include("errors.messageFlash")


                            <form action="{{ route('admin.meioAmbiente.castracaoAnimal.racas.store') }}" method="POST">


                                <div class="row">
                                    <div class="col-sm-12 col-md-10">
                                    <!-- Campo Nome completo -->
                                        @include('components.inputs._inputType',[
                                        "for" => "nome_raca",
                                        "label" => "Nova raça",
                                        "name" => "nome_raca",
                                        "id" => null,
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('nome_raca'),
                                        "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                        "readonly" => false,
                                        "small" => null,
                                    ])
                                    </div>
                                    <div class="col-sm-12 col-md-2 d-flex align-items-center">
                                        <div class="form-check pt-3">
                                            <input class="form-check-input" type="checkbox" name="is_braquicefalico" id="is_braquicefalico" value="1">
                                            <label class="form-check-label" for="is_braquicefalico">{{ __("É braquicefálico?") }} </label>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-sm-12 col-md-6">
                                    <!-- Campo Secretaria -->
                                        @include('components.inputs._selectType', [
                                            "for" => "especie",
                                            "label" => "Espécie",
                                            "name" => "especie",
                                            "id" => "especie",
                                            "required" => true,
                                            "readonly" => false,
                                            "placeholder" => "Selecione uma espécie...",
                                            "options" => ['Cão' => 'Cão', 'Gato' => 'Gato'],
                                            "selected" => old('especie'),
                                            "small" => "Selecione a espécie desta raça.",
                                        ])
                                    </div>
                                    <div class="col-sm-12 col-md-6">
                                    <!-- Campo Status -->
                                        @include('components.inputs._selectType', [
                                            "for" => "status",
                                            "label" => "Status",
                                            "name" => "status",
                                            "required" => true,
                                            "readonly" => false,
                                            "options" => collect(App\Enums\StatusEnum::cases())
                                                ->mapWithKeys(fn($status) => [$status->name => $status->value])
                                                ->toArray(),
                                            "selected" => old('status'),
                                            "placeholder" => "Selecione o status...",
                                            "small" => "Informe o status atual da raça.",
                                            "onchange" => null
                                        ])
                                    </div>
                                </div>

                                @include('components.buttons._backAndSend', [
                                        'textBack' => 'Voltar', 
                                        'textSend' => 'Salvar', 
                                        'routeBack' => 'admin.meioAmbiente.castracaoAnimal.racas.index'
                                    ]
                                )

                            </form>

                        </div>
                    </div>
                </div>
            </div>
        </div>
    @endsection
