<?php $__env->startSection("title", env("APP_NAME") . " :: Alterar Foto"); ?>
<?php $__env->startSection('content'); ?>
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="card shadow mx-0">  
                    <?php $headLine = "<i class='fa-solid fa-images'></i> Alterar Foto"; ?>

                    <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
                                'headLine' => __($headLine),
                                "permission" => "GUEST",
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                    <div class="card-body">
                        <form action="<?php echo e(route('admin.photo')); ?>" method="post" enctype="multipart/form-data">
                            
                            <?php echo csrf_field(); ?>
                            <?php echo method_field('post'); ?>

                            <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                            <?php echo $__env->make('components.modal._modelProfile', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                            <hr/>


                            <div class="row">
                                <div class="col-sm-12 d-flex align-items-end">
                                    <div style="width: 100%">
                                    <!-- Campo Foto -->
                                        <?php echo $__env->make('components.inputs._inputType',[
                                            "for" => null,
                                            "label" => "Foto",
                                            "name" => "photo",
                                            "id" => null,
                                            "required" => false,
                                            "type" => 'file',
                                            "old" => null,
                                            "oninput" => null,
                                            "readonly" => true,
                                            "small" => null,
                                            "accept" => 'image/jpeg,image/jpg,image/png,image/gif',
                                        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-12">
                                    <?php echo $__env->make('components.buttons._backAndSend', [
                                    'textSend' => 'Atualizar', 
                                ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                </div>
                            </div>

                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/photo.blade.php ENDPATH**/ ?>