<section class="ma-help-bar" aria-label="<?php echo e(__('Canais de atendimento')); ?>">
    <div class="container">
        <a href="<?php echo e(route('mobiangra.fale_conosco')); ?>" class="ma-help-bar__card">
            <span class="ma-help-bar__card-text"><?php echo e(__('Precisa de ajuda?')); ?></span>
            <span class="ma-help-bar__card-icon" aria-hidden="true">
                <i class="fa-solid fa-comment-dots"></i>
            </span>
        </a>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/help-bar.blade.php ENDPATH**/ ?>