<!-- Parques e Jardins -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-success">
        <div class="card-header {{ $cor }} text-dark">
            <div class="d-flex align-items-center">
                <i class="fas fa-tree fa-2x me-3"></i>
                <h5 class="card-title mb-0">Parques e Jardins</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item">
                    <i class="fas fa-park me-2 text-muted"></i> 
                    <a href="{{ route("servicos.parquesJardins.supj") }}" class="text-dark">Parques e Jardins</a>
                </li>
                <li class="list-group-item"><i class="fas fa-park me-2 text-muted"></i> Manutenção de parques <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-leaf me-2 text-muted"></i> Arborização urbana <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-seedling me-2 text-muted"></i> Jardins públicos <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-hiking me-2 text-muted"></i> Trilhas e áreas de lazer <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-dog me-2 text-muted"></i> Parques para pets <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
    </div>
</div>