<script src="<?php echo e(asset('pmar/js/jquery-3.7.1.min.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/tinymce/tinymce.min.js')); ?>"/></script>
<script src="<?php echo e(asset('pmar/js/functions.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/app.js')); ?>"></script>
<script src="<?php echo e(asset('pmar/js/functionsArteSacra.js')); ?>"></script>
<script src="https://cdn.sheetjs.com/xlsx-0.19.3/package/dist/xlsx.full.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<?php /**PATH /var/www/html/portal/resources/views/layouts/window/elements/footer.blade.php ENDPATH**/ ?>