@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Visite Angra - Lista de Corredores Turísticos')
@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-route fa-2x'></i> Visite Angra - Lista de Corredores Turísticos"; @endphp
        
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.visiteAngra.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.visiteAngra.corredores.create',
            'routeAddParams' => [], 
            'nameAdd' => __("Novo corredor"),
            "permission" => "GERENCIADOR_VISITE_ANGRA",
        ])
        
        @include("components.cards._cardNavVisiteAngra")

        <div class="card-body">

            @include("errors.messageFlash") 

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "visiteAngraListaCorredorTuristico", 
                "placeholder" => "Pesquisar por corredor..."
            ])

            <x-tables._table :thead="['Foto','Corredor Turístico','Subtitulo','Status','Ações']" :pagination="$corredores->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($corredores as $corredor)

                        <tr>
                            <td style="width: 200px;">
                                @include('components.tables._openPhoto',[
                                        'asset' => $corredor->foto,
                                        'alt' => $corredor->corredor,
                                        'title' => $corredor->corredor,
                                        'text' => 'Visualizar corredor',
                                    ])
                            </td>
                            <td>{{ $corredor->corredor }}</td>
                            <td>{{ $corredor->subtitulo }}</td>
                            <td>
                                @include('components/buttons/_status', [
                                    "index" => $index,
                                    "route" => "admin.visiteAngra.corredores.status",
                                    "id" => $corredor->id,
                                    "status" => $corredor->status,
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])

                            </td>
                            <td>
                                <div class="btn-group" role="group">
                                    @include('components/buttons/_editButton', [
                                    "route" => "admin.visiteAngra.corredores.edit",
                                    "id" => $corredor->id,
                                    "fontawesome" => null,
                                    "title" => "Editar",
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])

                                    @include("components.buttons._upload",[
                                    "route" => "admin.visiteAngra.corredores.arquivos.index",
                                    "id" => $corredor->id,
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])

                                    @include('components/buttons/_deleteButton', [
                                    "message" => "* Este corredor será excluído e esta ação não poderá ser desfeita?",
                                    "route" => "admin.visiteAngra.corredores.destroy",
                                    "id" => $corredor->id,
                                    "fontawesome" => null,
                                    "title" => "Excluir",
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])
                                </div>
                            </td>
                        </tr>

                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>

        </div>
    </div>
@endsection