@extends('layouts.sei.theme')
@section("title", "SEI - Angra dos Reis")
@section('content')
    <section>
        <div class="container-fluid">
            @include('sei.sectionsManual.botaoSumario')
            @include('sei.sectionsManual.main')
        </div>
    </section>
    <section>
        <div class="container pt-5 mt-5">
            @include('sei.sectionsManual.slideCanva')
        </div>
    </section>
@endsection