@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Parcelamento')
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ url('/secretarias/secretaria-de-financas') }}">{{ __('Secretaria de Finanças') }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Parcelamento de Débitos Tributários e não
                                Tributários</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <div id="conteudo" class="content mediapress">
                        <!-- Content -->

                        <section class="col-md-9 nopadding single-article espaco_conteudo">
                            <header class="article-header">
                                <!-- Title -->
                                <h1 class="title">Parcelamento de Débitos Tributários e não Tributários</h1>
                                <!-- Excerpt -->
                            </header>
                            <article class="article-main">
                                <p>A <a href="downloads/SFI/Parcelamento2024/Lei-3062-2013-Parcelamento.pdf"
                                        target="_blank"><strong>Lei Nº 3.062/2013</strong></a>, alterada pelas Leis N&ordm;
                                    <a href="downloads/SFI/Parcelamento2024/Lei-4086-2022-Altera-lei-3062-2013-Parcelamento-comum.pdf"
                                        target="_blank"><strong>4.086/2022</strong></a> e <a
                                        href="downloads/SFI/Parcelamento2024/Lei-4214-2023-Altera-lei-do-parcelamento.pdf"
                                        target="_blank"><strong>4.214/2023</strong></a>, regulamentadas pelos Decretos Nº <a
                                        href="downloads/SFI/Parcelamento2024/Decreto-8949-2013-Parcelamento-comum.pdf"
                                        target="_blank"><strong>8949/2013</strong></a>, <a
                                        href="downloads/SFI/Parcelamento2024/Decreto-10899-2018-parcelamento-especial.pdf"
                                        target="_blank"><strong>10.899/2018</strong></a> e <a
                                        href="downloads/SFI/Parcelamento2024/Decreto-13228-2023-NOVO-DECRETO-PARCELAMENTO-COMUM.pdf"
                                        target="_blank"><strong>13.228/2023</strong></a>, instituiu o parcelamento
                                    administrativo no âmbito do Município de Angra dos Reis.</p>
                                <p>O parcelamento &eacute; destinado a promover a regulariza&ccedil;&atilde;o de
                                    d&eacute;bitos,
                                    tribut&aacute;rios ou n&atilde;o tribut&aacute;rios, inscritos ou n&atilde;o em
                                    d&iacute;vida ativa, ajuizados ou n&atilde;o, perante o Munic&iacute;pio.</p>
                                <p>Caber&aacute; ao contribuinte preencher corretamente os dados para
                                    solicita&ccedil;&atilde;o,
                                    que ser&atilde;o automaticamente encaminhados ao e-mail do Departamento de
                                    Cr&eacute;ditos
                                    Tribut&aacute;rios - parcelamento@angra.rj.gov.br .</p>
                                <p><strong>O parcelamento n&atilde;o &eacute; online</strong>. O departamento entrar&aacute;
                                    em
                                    contato com o contribuinte atrav&eacute;s do e-mail cadastrado, por meio do qual as
                                    demais
                                    tratativas, encaminhamento de documenta&ccedil;&atilde;o e posterior envio das guias
                                    ser&atilde;o realizadas.</p>
                                <p>Aos contribuintes que formalizarem parcelamentos que ultrapassem o exerc&iacute;cio
                                    atual,
                                    caber&aacute; a solicita&ccedil;&atilde;o das demais parcelas atrav&eacute;s dos canais
                                    de
                                    atendimento, antes do vencimento das mesmas.</p>
                                <p><strong>Todas as informações a partir do envio da solicitação serão prestadas via
                                        e-mail.</strong></p>
                                <div class="clear bottom20"> </div>
                                <h3 class="bottom30">Principais informa&ccedil;&otilde;es</h3>

                                <details>
                                    <summary style="font-size:18px;">Documentos necess&aacute;rios</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ol class="olist_normal" type="a">
                                                <strong>Pessoa F&iacute;sica</strong>
                                                <li>C&oacute;pia simples da Carteira de Identidade e CPF do contribuinte;
                                                </li>
                                                <li>Comprovante de resid&ecirc;ncia do contribuinte;</li>
                                                <li>Procura&ccedil;&atilde;o - prova de que o signat&aacute;rio &eacute;
                                                    representante legal do contribuinte;</li>
                                                <li>C&oacute;pia simples da Carteira de Identidade e CPF do outorgado.</li>
                                            </ol>
                                            <ol class="olist_normal" type="a">
                                                <strong>Pessoa Jur&iacute;dica</strong>
                                                <li>C&oacute;pia simples do Cadastro Nacional de Pessoa Jur&iacute;dica
                                                    (CNPJ);
                                                </li>
                                                <li>C&oacute;pia simples do contrato social da empresa e suas
                                                    altera&ccedil;&otilde;es, ou &uacute;ltima altera&ccedil;&atilde;o com
                                                    consolida&ccedil;&atilde;o;</li>
                                                <li>Procura&ccedil;&atilde;o - prova de que o signat&aacute;rio &eacute;
                                                    representante legal do contribuinte;</li>
                                                <li>C&oacute;pia simples da Carteira de Identidade e CPF do outorgado.</li>
                                            </ol>
                                            <ol class="olist_normal" type="a">
                                                <strong>Terceiro interessado</strong>
                                                <li>C&oacute;pia simples da Carteira de Identidade e CPF do requerente;</li>
                                                <li>Comprovante de resid&ecirc;ncia do requerente;</li>
                                                <li>Documento comprobat&oacute;rio de que o requerente possui
                                                    rela&ccedil;&atilde;o com o cr&eacute;dito a ser negociado. (ex.
                                                    Documento
                                                    de Compra e Venda, Escritura ou RGI para Adquirente de im&oacute;vel,
                                                    Termo
                                                    de Inventariante ou certid&atilde;o de &Oacute;bito para Titular
                                                    falecido,
                                                    entre outros);</li>
                                                <li><a href="downloads/SFI/Parcelamento2024/TERMO-DE-CIENCIA-E-DECLARACAO-DE-MOTIVACAO.pdf"
                                                        target="_blank"><strong>Termo de ci&ecirc;ncia e
                                                            declara&ccedil;&atilde;o de motiva&ccedil;&atilde;o</strong></a>
                                                    (devidamente preenchido e assinado).</li>
                                            </ol>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>

                                <details>
                                    <summary style="font-size:18px;">Formas de parcelamento</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ol class="olist_normal">
                                                <li><strong>MELHOR OPORTUNIDADE!</strong> até 06 (seis) parcelas,
                                                    <strong>sem
                                                        acréscimos de juros (O valor do d&eacute;bito &eacute; atualizado
                                                        para a
                                                        data de vencimento da 1&ordf; parcela);</strong></li>
                                                <li>de 07 (sete) até 24 (vinte e quatro) parcelas mensais, com acréscimo de
                                                    0,25% (vinte e cinco centésimos por cento) por parcela, calculado sobre
                                                    o
                                                    valor total do débito;</li>
                                                <li>de 25 (vinte e cinco) até 36 (trinta e seis) parcelas mensais iguais,
                                                    com
                                                    acréscimo de 0,5% (cinco décimos por cento) por parcela, calculado sobre
                                                    o
                                                    valor total do débito;</li>
                                                <li>de 37 (trinta e sete) até 48 (quarenta e oito) parcelas mensais iguais,
                                                    com
                                                    acréscimo de 0,75% (setenta e cinco centésimos por cento) por parcela,
                                                    calculado sobre o valor total do débito;</li>
                                                <li>de 49 (quarenta e nove) até 60 (sessenta) parcelas mensais iguais, com
                                                    acréscimo de 1,00% (um por cento) por parcela, calculado sobre o valor
                                                    total
                                                    do débito.</li>
                                            </ol>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <details>
                                    <summary style="font-size:18px;">Parcelamento especial</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ul class="olist_normal">
                                                <li>Débitos de valor igual ou superior à R$150.000,00 (cento e cinquenta mil
                                                    reais) – Até 90 vezes</li>
                                                <li>Débitos de valor igual ou superior à R$360.000,00 (trezentos e sessenta
                                                    mil
                                                    reais) – Até 120 vezes</li>
                                                <li>Débitos de valor igual ou superior à R$180.000,00 (cento e oitenta mil
                                                    reais), de entidades sem fins econômicos tais como entidades
                                                    hospitalares,
                                                    educacionais, de reabilitação fisica para deficientes, asilos,
                                                    orfanatos.
                                                </li>
                                                <p><span class="red">* Vide legislação: <strong><a
                                                                href="downloads/SFI/Parcelamento2024/Lei-4214-2023-Altera-lei-do-parcelamento.pdf"
                                                                target="_blank">Lei 4.214/2023</a></strong> e <strong><a
                                                                href="downloads/SFI/Parcelamento2024/Decreto-13228-2023-NOVO-DECRETO-PARCELAMENTO-COMUM.pdf"
                                                                target="_blank">Decreto 13.228/2023</a></strong>.</span></p>
                                            </ul>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <details>
                                    <summary style="font-size:18px;">Valor mínimo das parcelas</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ul class="olist_normal">
                                                <li><strong>R$30,00 (trinta reais)</strong> para pessoas físicas e
                                                    <strong>R$100,00 (cem reais)</strong> para pessoas jurídicas.
                                                </li>
                                            </ul>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <details>
                                    <summary style="font-size:18px;">Cancelamento</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ul class="olist_normal">
                                                <li>O parcelamento será cancelado na falta de pagamento da primeira parcela,
                                                    de
                                                    05 (cinco) parcelas consecutivas ou 150 (cento e cinquenta) dias do
                                                    vencimento de qualquer parcela que implicará na antecipação do
                                                    vencimento
                                                    das parcelas vincendas.</li>
                                            </ul>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <details>
                                    <summary style="font-size:18px;">Reparcelamento</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ul class="olist_normal">
                                                <li>Ao contribuinte &eacute; facultado requerer o reparcelamento do
                                                    d&eacute;bito, na forma prevista na legisla&ccedil;&atilde;o.</li>
                                                <li>O reparcelamento, a cada vez que solicitado, fica condicionado ao
                                                    pagamento
                                                    de <strong>entrada</strong> &agrave; vista de 10% (dez por cento) do
                                                    <strong>valor da d&iacute;vida negociada</strong>, que ser&aacute;
                                                    <strong>adicionada</strong> &agrave; primeira parcela.
                                                </li>
                                            </ul>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <details>
                                    <summary style="font-size:18px;">D&uacute;vidas</summary>
                                    <ul class="project-info">
                                        <li>
                                            <ul class="olist_normal">
                                                <li>Em caso de d&uacute;vidas, entre em contato conosco para que possamos
                                                    melhor
                                                    orient&aacute;-lo(a).<br>
                                                    Tel: (24) 3377-8837 ou (24) 3365-6536<br>
                                                    WhatsApp: (24) 3365-6536 (somente mensagens de texto)<br>
                                                    E-mail: parcelamento@angra.rj.gov.br
                                                </li>
                                            </ul>
                                        </li>
                                    </ul>
                                    <hr>
                                </details>
                                <div class="clear"> </div>
                                <div class="clear bottom50"> </div>
                                <!--
                                    <h2>Simula&ccedil;&atilde;o de Parcelamento</h2>
                                    <div class="olist_normal">
                                        <ul>
                                          <li><strong><a href="https://www.spe.angra.rj.gov.br/da/debitos.aspx?tributo=11&menu=2" target="_blank">D&eacute;bitos Imobili&aacute;rios</a></strong></li>
                                          <li><strong><a href="https://www.spe.angra.rj.gov.br/senhaweb/login.aspx" target="_blank">D&eacute;bitos Mobili&aacute;rios</a></strong></li>
                                      </ul>
                                    </div>
                                    <div class="clear bottom20"> </div>
                      -->
                                <h2>Formul&aacute;rio de solicita&ccedil;&atilde;o de parcelamento</h2>
                                <p>Sr. Contribuinte, preencha corretamente os campos abaixo, incluindo os dados conforme
                                    consta
                                    do cadastro municipal.</p>
                                <p>Utilize o campo &quot;observa&ccedil;&otilde;es&quot; para informa&ccedil;&otilde;es
                                    relevantes a respeito do d&eacute;bito para o qual solicita parcelamento (se n&atilde;o
                                    for
                                    sua totalidade, se houve mudan&ccedil;a de propriet&aacute;rio, procuradores,
                                    d&uacute;vidas, e etc.).</p>
                                <p>O termo de confiss&atilde;o de d&iacute;vida e parcelamento (link abaixo) dever&aacute;
                                    ser
                                    baixado, preenchido e encaminhado juntamente a documenta&ccedil;&atilde;o
                                    necess&aacute;ria,
                                    quando solicitado.</p>

                                <div class="list_down">
                                    <ul>
                                        <li><a href="downloads/SFI/Parcelamento2024/TERMO-DE-COMPROMISSO-E-CONFISSAO-DE-DIVIDA-DECRETO-2023.pdf"
                                                target="_blank"><strong><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">Termo de Confiss&atilde;o de d&iacute;vida e
                                                    parcelamento</strong></a></li>
                                    </ul>
                                </div>
                                <form id="form1" name="form1" method="post"
                                    action="sfi-parcelamento.asp?indexsigla=sfi" onsubmit="return ValidarCampos(this)"
                                    class="contactForm top30">
                                    <span style="font-size:11px; display:inline-block;" class="bottom25"> <span
                                            class="red">*</span> Campos obrigat&oacute;rios</span>
                                    <div class="clear"> </div>
                                    <div class="col-md-6">
                                        <label for="ds_nome"><span class="red">*</span> <strong>Nome:</strong></label>
                                        <br>
                                        <input name="ds_nome" type="text" id="ds_nome" />
                                    </div>
                                    <div class="col-md-3">
                                        <label for="ds_cpf"><span class="red">*</span> <strong>CPF /
                                                CNPJ:</strong></label>
                                        <br>
                                        <input name="ds_cpf" type="text" id="ds_cpf" onFocus="VerificaConteudo(this)"
                                            size="15" onKeyUp="this.value=ChkField_O(this.value,'0123456789')"
                                            onClick="this.value=ChkField_O(this.value,'0123456789')"
                                            placeholder="Digite apenas numeros" />
                                    </div>
                                    <div class="col-md-5">
                                        <label for="ds_endereco"><span class="red">*</span>
                                            <strong>Endere&ccedil;o:</strong></label>
                                        <br>
                                        <input name="ds_endereco" type="text" id="ds_endereco" />
                                    </div>
                                    <div class="col-md-3">
                                        <label for="ds_cidade"><span class="red">*</span>
                                            <strong>Cidade:</strong></label>
                                        <input name="ds_cidade" type="text" id="ds_cidade" />
                                    </div>
                                    <div class="col-md-2">
                                        <label for="ds_cep"><strong>CEP:</strong></label>
                                        <input name="ds_cep" type="text" id="ds_cep" />
                                    </div>
                                    <div class="col-md-4">
                                        <label for="ds_email"><span class="red">*</span>
                                            <strong>E-mail:</strong></label>
                                        <input name="ds_email" type="text" id="ds_email" />
                                    </div>
                                    <div class="col-md-3">
                                        <label for="ds_tel"><span class="red">*</span>
                                            <strong>Telefone:</strong></label>
                                        <input name="ds_tel" type="text" id="ds_tel" />
                                    </div>
                                    <div class="clear"></div>
                                    <div class="col-md-3">
                                        <label for="ds_iptu"><span class="red">*</span>
                                            <strong>Inscri&ccedil;&atilde;o no
                                                IPTU:</strong></label>
                                        <input name="ds_iptu" type="text" id="ds_iptu" maxlength="14" />
                                    </div>
                                    <div class="col-md-1"><br><label>ou</label></div>
                                    <div class="col-md-3">
                                        <label for="ds_iss"><span class="red">*</span>
                                            <strong>Inscri&ccedil;&atilde;o no
                                                ISS:</strong></label>
                                        <input name="ds_iss" type="text" id="ds_iss" maxlength="10" />
                                    </div>
                                    <div class="col-md-2">
                                        <label for="ds_parcelas"><span class="red">*</span> <strong>N&ordm; de
                                                parcelas</strong></label>
                                        <input name="ds_parcelas" type="text" id="ds_parcelas" placeholder="Até 60x"
                                            maxlength="2" />
                                    </div>
                                    <div class="clear"></div>
                                    <div class="col-md-6">
                                        <label for="ds_pedido">Observa&ccedil;&otilde;es:</label>
                                        <textarea name="ds_pedido" id="ds_pedido" cols="20" rows="2"></textarea>
                                    </div>
                                    <div class="clear"></div>
                                    <div class="col-md-3 top25">
                                        @if (config('recaptcha.enabled'))
                                        <div class="g-recaptcha" data-callback="recaptchaCallback"
                                            data-sitekey="6Lf75TkUAAAAAEHgXPyCVl20Eh1qfSabxJh8exoX"></div>
                                        <script src="https://www.google.com/recaptcha/api.js?hl=pt-BR" async defer></script>
                                        @endif
                                        <br>
                                        <input type="submit" class="btn btn-large" name="Submit" id="btnEnviar"
                                            value="Enviar Solicita&ccedil;&atilde;o" @if (config('recaptcha.enabled')) disabled @endif />
                                    </div>
                                </form>

                                <div class="clear"></div>
                                <div class="bottom50"></div>


                            </article>
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection
