<!-- Modal -->
<div class="modal fade" id="staticBackdrop" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
    aria-labelledby="staticBackdropLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header text-center">
                <h1 class="modal-title fs-3 fw-bolder" id="staticBackdropLabel">Quer aprender a utilizar o sistema? Consulte nossos materiais de apoio:</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">    
                <div class="row d-flex justify-content-center text-center">
                    <div class="col p-3 d-flex justify-content-center">
                        <div class="card" style="width: 18rem;">
                            <div class="card-body">
                                <h5 class="card-title">1 - Iniciando Processo como usuário Externo</h5>
                                <a href="<?php echo e(asset('sei-angra/assets/1-COMO-ABRIR-PROCESSO-COMO-USUARIO-EXTERNO.pdf')); ?>" target="_blank"
                                    class="fw-bolder btn btn-success col-12">Aprender</a>
                            </div>
                        </div>
                    </div>
                    <div class="col p-3 d-flex justify-content-center">
                        <div class="card" style="width: 18rem;">
                            <div class="card-body">
                                <h5 class="card-title">2 - Como anexar documentação em um processo já existente <br>
                                    <p class="fs-6 fw-bold pt-2">(Peticionamento Intercorrente)</p>
                                </h5>
                                <a href="<?php echo e(asset('sei-angra/assets/2-COMO-ANEXAR-DOCUMENTACAO-EM-PROCESSO-EXISTENTE.pdf')); ?>"
                                    target="_blank" class="fw-bolder btn btn-success col-12">Aprender</a>
                            </div>
                        </div>
                    </div>
                    <div class="col p-3 d-flex justify-content-center">
                        <div class="card" style="width: 18rem;">
                            <div class="card-body">
                                <h5 class="card-title">3 - Manual Completo para USUÁRIO EXTERNO <br>
                                </h5>
                                <a href="https://angra.rj.gov.br/sei/manual" target="_blank"
                                    class="fw-bolder btn btn-success col-12">Aprender</a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-footer text-center d-flex justify-content-center">
                <button onclick="window.open('https://angra.sei.rj.gov.br/externo', '_blank');" type="button"
                    class="btn btn-primary fs-4 m-3 text-center shadow border-0 fw-bolder">ACESSAR - Já SEI! <br>
                    Certifico que já possuo o conhecimento necessário.</button>
            </div>
        </div>
    </div>
</div>
<?php /**PATH /var/www/html/portal/resources/views/layouts/cmgd/elements/modal.blade.php ENDPATH**/ ?>