<!doctype html>
<html lang="pt-BR">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{{ __('MAPÃO - PROJETOS E PROGRAMAS') }}</title>
    <link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-print.css') }}">
</head>

<body onload="window.print();">
    <table class="mapao-cabecalho-inst" border="0">
        <tr>
            <td width="85"><img src="{{ asset('pmar/assets/img/brasao-angra-dos-reis.png') }}" alt="" width="74" height="90"></td>
            <td>
                <strong>
                    {{ __('Estado do Rio de Janeiro') }}<br>
                    {{ __('PREFEITURA MUNICIPAL DE ANGRA DOS REIS') }}<br>
                    {{ __('Secretaria de Articulação Governamental') }}<br>
                    {{ __('Superintendência de Políticas Públicas') }}
                </strong>
            </td>
        </tr>
    </table>

    <h1 class="mapao-titulo">{{ __('MAPÃO - PROJETOS E PROGRAMAS') }}</h1>

    @if(!empty($mapaoFiltrosResumo))
        <div class="mapao-filtros-resumo" role="region" aria-label="{{ __('Filtros da impressão') }}">
            <ul class="mapao-filtros-resumo__lista">
                @foreach($mapaoFiltrosResumo as $linha)
                    <li><span class="mapao-filtros-resumo__k">{{ $linha['label'] }}:</span> {{ $linha['value'] }}</li>
                @endforeach
            </ul>
        </div>
    @endif

    <table class="relatorio-mapao" border="0" cellspacing="0" cellpadding="0">
        <thead>
            <tr>
                <th class="mapao-th-col-num">{{ __('Nº') }}</th>
                <th class="mapao-th-col-nome">{{ __('NOME DO PROJETO') }}</th>
                <th class="mapao-th-col-bairro">{{ __('BAIRRO') }}</th>
                <th class="mapao-th-col-orc">{{ __('ORÇAMENTO PREVISTO') }}</th>
                <th class="mapao-th-col-orc">{{ __('ORÇAMENTO DISPONÍVEL') }}</th>
                <th class="mapao-th-col-and">{{ __('ANDAMENTO') }}</th>
                <th class="mapao-th-col-prazo">{{ __('PRAZO DE IMPLANTAÇÃO') }}</th>
            </tr>
        </thead>
        <tbody>
            @forelse($mapaoGrupos as $grupo)
                @php $numPai = $loop->iteration; @endphp
                <tr class="mapao-linha-programa">
                    <td class="mapao-td-num mapao-td-center">{{ $numPai }}</td>
                    <td colspan="6" class="mapao-td-banner">
                        <strong>{{ mb_strtoupper($grupo['titulo_banner'], 'UTF-8') }}</strong>
                    </td>
                </tr>
                @foreach($grupo['projetos'] as $proj)
                    @php
                        $corAndamento = match ($proj->andamento_cor ?? '') {
                            'verde' => 'mapao-andamento-verde',
                            'amarelo' => 'mapao-andamento-amarelo',
                            'vermelho' => 'mapao-andamento-vermelho',
                            default => '',
                        };
                    @endphp
                    <tr>
                        <td class="mapao-td-num mapao-td-center">{{ $numPai }}.{{ $loop->iteration }}</td>
                        <td class="mapao-td-nome">{{ mb_strtoupper((string) ($proj->denominacao ?? ''), 'UTF-8') }}</td>
                        <td class="mapao-td-bairro">{{ mb_strtoupper((string) ($proj->bairro ?? ''), 'UTF-8') }}</td>
                        <td class="mapao-td-moeda">R$ {{ number_format((float) ($proj->orcamento_previsto ?? 0), 2, ',', '.') }}</td>
                        <td class="mapao-td-moeda">R$ {{ number_format((float) ($proj->orcamento_disponivel ?? 0), 2, ',', '.') }}</td>
                        <td class="mapao-td-andamento {{ $corAndamento }} mapao-td-center">
                            @include('components.projetosProgramas._andamento_mapao_celula', [
                                'legendaPorCor' => $mapaoCoresLegenda ?? [],
                                'cor' => $proj->andamento_cor,
                                'textoLivre' => $proj->andamento,
                            ])
                        </td>
                        <td class="mapao-td-center">
                            @include('components.projetosProgramas._prazo_implantacao_celula', [
                                'mesAno' => $proj->prazoEntregaCompetenciaMesAnoFormatado(),
                                'dias' => $proj->prazo_entrega_dias,
                            ])
                        </td>
                    </tr>
                @endforeach
            @empty
                <tr>
                    <td colspan="7" class="mapao-td-center"></td>
                </tr>
            @endforelse
        </tbody>
    </table>

    <footer class="mapao-legenda" role="region" aria-label="{{ __('Legenda do andamento') }}">
        <p class="mapao-legenda-titulo">{{ __('LEGENDA:') }}</p>
        <ul class="mapao-legenda-lista">
            <li class="mapao-legenda-item">
                <span class="mapao-legenda-cor mapao-legenda-cor--verde" aria-hidden="true"></span>
                <span class="mapao-legenda-texto">{{ __('PROJETO EM ANDAMENTO.') }}</span>
            </li>
            <li class="mapao-legenda-item">
                <span class="mapao-legenda-cor mapao-legenda-cor--vermelho" aria-hidden="true"></span>
                <span class="mapao-legenda-texto">{{ __('PROJETO NÃO TEM VALOR DEFINIDO.') }}</span>
            </li>
            <li class="mapao-legenda-item">
                <span class="mapao-legenda-cor mapao-legenda-cor--amarelo" aria-hidden="true"></span>
                <span class="mapao-legenda-texto">{{ __('PROJETO TEM VALOR DEFINIDO, MAS AINDA DEPENDE DE LICITAÇÃO E/OU AINDA NÃO HÁ RECURSO PARA EXECUÇÃO.') }}</span>
            </li>
        </ul>
    </footer>
</body>

</html>
