{{-- Módulo Projetos e Programas embutido no Dashboard Estratégico (abas resumidas + prioridades) --}}
<link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-table.css') }}">
<link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-prioridades.css') }}">
<link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-dashboard.css') }}">
<link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-visualizar.css') }}">
<link rel="stylesheet" href="{{ asset('pmar/css/projetos-programas-mapa.css') }}">
<link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css">
<link rel="stylesheet" href="https://unpkg.com/leaflet.markercluster@1.5.3/dist/MarkerCluster.css">
<link rel="stylesheet" href="https://unpkg.com/leaflet.markercluster@1.5.3/dist/MarkerCluster.Default.css">
<div class="projetos-programas-embed-dash">
    @include('admin.projetosProgramas.partials._index_conteudo')
</div>
<script src="{{ asset('pmar/js/projetos-programas.js') }}"></script>
<script src="{{ asset('pmar/js/projetos-programas-table.js') }}"></script>
<script src="{{ asset('pmar/js/projetos-programas-prioridades.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-visualizar.js') }}"></script>
    <script src="{{ asset('pmar/js/projetos-programas-andamento-rapido.js') }}"></script>
<script src="https://unpkg.com/leaflet@1.9.4/dist/leaflet.js"></script>
<script src="https://unpkg.com/leaflet.markercluster@1.5.3/dist/leaflet.markercluster.js"></script>
<script src="{{ asset('pmar/js/projetos-programas-mapa.js') }}?v={{ filemtime(public_path('pmar/js/projetos-programas-mapa.js')) }}"></script>
<script src="{{ asset('pmar/js/projetos-programas-dashboard.js') }}"></script>
