@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Cadastro de Ambulantes - Verificar Ajudante")
@section('content')

<form action="{{ route('admin.cadastroDeAmbulantes.ajudantes.verify', $ambulante->id) }}" method="post" enctype="multipart/form-data">
    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
                        <h5 class="my-2">Cadastro de Ambulantes - Verificar Ajudante</h5>
                    </div>
                    <div class="card-body">
                        @include("errors.messageFlash")
                        @csrf
                        @method('post')
                        
                        <div class="mb-3">
                            <label for="cpf" class="form-label text-bold">CPF: <span class="span-admin-create">*</span></label>
                            <input type="text" class="form-control @error('cpf') is-invalid @enderror" name="cpf" id="cpf" autocomplete="off" value="{{ old('cpf') }}" oninput="javascript:aplicarMascaraCPF(this)" autocomplete="off" required>
                            @error('cpf')
                                <small class="text-danger text-bold">{{ $message }}</small>
                            @enderror
                        </div>
                        
                        @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar', 
                                'textSend' => 'Verificar', 
                                'routeBack' => 'admin.cadastroDeAmbulantes.ajudantes.index',
                                'backId' => $ambulante->id
                            ]
                        )
                        
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>

@endsection