@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Endereço da Empresa de Turismo")
@section('content')

    @php
        $filterParams = \App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource::listFilterParamsFromRequest(request());
    @endphp

    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                    @php $headLine = "<i class='fa-solid fa-water'></i> Endereço da Empresa de Turismo"; @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'routeBack' => 'admin.empresasDeTurismo.index',
                            'routeBackParams' => $filterParams,
                            'nameBack' => __("Voltar"),
                            "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                        ])

                    <div class="card-body">
                        <form action="{{ route('admin.empresasDeTurismo.enderecoUpdate', [$empresaTurismo->id, $endereco->id]) }}" method="post" enctype="multipart/form-data">
                            @include('admin.turisAngra.empresasDeTurismo.sections._filterHidden', ['filterParams' => $filterParams])
                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                            <div class="row">
                                <div class="col-12">
                                    <hr/>
                                    <h3 class="text-primary">
                                        {{ $empresa->razaoSocial ?? '-' }} <br>
                                        {{ __("CNPJ: ") . ($empresa->cnpj ?? '-') }}
                                    </h3>
                                    <hr/>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-4">
                                <!-- Campo CEP -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "CEP",
                                                "name" => "cep",
                                                "id" => "zipCode",
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('cep', $endereco->cep),
                                                "oninput" => "javascript:aplicarMascaraCEP(this)",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-6">
                                <!-- Campo Logradouro -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Logradouro",
                                                "name" => "logradouro",
                                                "id" => "street",
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('logradouro', $endereco->logradouro),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-2">
                                <!-- Campo Número -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Número",
                                                "name" => "numero",
                                                "id" => "numero",
                                                "required" => false,
                                                "type" => null,
                                                "old" => old('numero', $endereco->numero),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Complemento -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Complemento",
                                                "name" => "complemento",
                                                "id" => "complemento",
                                                "required" => false,
                                                "type" => null,
                                                "old" => old('complemento', $endereco->complemento),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Cidade -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Cidade",
                                                "name" => "cidade",
                                                "id" => "city",
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('cidade', $endereco->cidade),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Bairro -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Bairro",
                                                "name" => "bairro",
                                                "id" => "neighborhood",
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('bairro', $endereco->bairro),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo UF -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "UF",
                                                "name" => "uf",
                                                "id" => "state",
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('uf', $endereco->uf),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                                "listName" => "estadosBrasileiros",
                                                "arrayList" => [
                                                    'AC', 'AL', 'AM', 'AP', 'BA', 'CE', 'DF', 'ES', 'GO',
                                                    'MA', 'MG', 'MS', 'MT', 'PA', 'PB', 'PE', 'PI', 'PR',
                                                    'RJ', 'RN', 'RO', 'RR', 'RS', 'SC', 'SE', 'SP', 'TO'
                                                ],
                                            ])
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-sm-12 col-md-3 d-flex justify-content-center align-self-center">
                                <!-- Map Modal -->
                                    @include('components.modal._mapModal',[
                                                "label" => "Clique no mapa e escolha um determinado ponto",
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Latitude -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Latitude",
                                                "name" => "latitude",
                                                "id" => null,
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('latitude', $endereco->latitude),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Longitude -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Longitude",
                                                "name" => "longitude",
                                                "id" => null,
                                                "required" => true,
                                                "type" => null,
                                                "old" => old('longitude', $endereco->longitude),
                                                "oninput" => "javascript:this.value = this.value.toUpperCase()",
                                                "readonly" => false,
                                                "small" => null,
                                            ])
                                </div>
                                <div class="col-sm-12 col-md-3">
                                <!-- Campo Comprovante -->
                                    @include('components.inputs._inputType',[
                                                "for" => null,
                                                "label" => "Comprovante de endereço",
                                                "name" => "comprovante",
                                                "id" => null,
                                                "required" => false,
                                                "type" => 'file',
                                                "old" => null,
                                                "oninput" => null,
                                                "readonly" => true,
                                                "small" => null,
                                                "accept" => 'image/jpeg,image/jpg,image/png,image/gif,.pdf',
                                            ])
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 text-center">
                                    <hr/>
                                    <a href="{{ asset($endereco->comprovante) }}" class="text-primary" download>
                                        {{ __("Comprovante de endereço") }} - <small>{{ __("baixar") }}</small> <i class="fa-solid fa-download"></i>
                                </a>
                            </div>
                        </div>

                        @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar',
                                'textSend' => 'Atualizar',
                                'routeBack' => 'admin.empresasDeTurismo.index'
                            ]
                        )
                    </form>
                </div>
            </div>
        </div>
    </div>
    </div>

@endsection
