<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <meta name="site" content="https://angra.rj.gov.br">

    <title>@yield('title')</title>

    <meta name="description"
        content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade." />
    <meta name="robots" content="noodp" />

    <link rel="canonical" href="https://angra.rj.gov.br" />

    @if (Route::currentRouteName() == 'paginas.slug')
        <meta property="og:locale" content="pt_BR" />
        <meta property="og:type" content="government" />
        <meta property="og:title" content="{{ $noticia->title }}" />
        <meta property="og:description" content="{{ $noticia->summary }}" />
        <meta property="og:url"
            content="{{ url(route('paginas.slug', [date('d-m-Y', strtotime($noticia->created_at)), $noticia->slug])) }}" />
        <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
        <meta property="og:image" content="{{ url(asset($noticia->featuredPhoto)) }}" />
    @elseif (Route::currentRouteName() == 'paginas.boletim-meteorologico.show' && isset($boletim))
        {{-- Meta Tags Open Graph para Boletim Meteorológico --}}
        <meta property="og:locale" content="pt_BR" />
        <meta property="og:type" content="article" />
        <meta property="og:title"
            content="Boletim Meteorológico Nº {{ $boletim->numero_boletim }} - Defesa Civil de Angra dos Reis" />
        <meta property="og:description"
            content="Confira o Boletim Meteorológico da Defesa Civil de Angra dos Reis. Previsão do tempo atualizada para a região." />
        <meta property="og:url" content="{{ url()->current() }}" />
        <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
        <meta property="og:image" content="{{ url('/pmar/assets/img/og-boletim-meteorologico.png') }}" />
        <meta property="og:image:secure_url" content="{{ url('/pmar/assets/img/og-boletim-meteorologico.png') }}" />
        <meta property="og:image:width" content="1200" />
        <meta property="og:image:height" content="630" />
        <meta property="og:image:type" content="image/png" />
        <meta property="og:image:alt" content="Boletim Meteorológico - Defesa Civil Angra dos Reis" />

        {{-- Twitter Card --}}
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:title"
            content="Boletim Meteorológico Nº {{ $boletim->numero_boletim }} - Defesa Civil de Angra dos Reis" />
        <meta name="twitter:description"
            content="Confira o Boletim Meteorológico da Defesa Civil de Angra dos Reis. Previsão do tempo atualizada para a região." />
        <meta name="twitter:image" content="{{ url('/pmar/assets/img/og-boletim-meteorologico.png') }}" />
    @elseif (!str_contains(Route::currentRouteName(), 'boletim-meteorologico'))
        {{-- Meta tags genéricas (não aplicar em boletim meteorológico) --}}
        <meta property="og:locale" content="pt_BR" />
        <meta property="og:type" content="government" />
        <meta property="og:title" content="Prefeitura de Angra dos Reis" />
        <meta property="og:description"
            content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade." />
        <meta property="og:url" content="https://www.angra.rj.gov.br" />
        <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
        <meta property="og:image" content="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png" />
    @endif

    <meta http-equiv="cache-control" content="max-age=0" />
    <meta http-equiv="cache-control" content="no-cache" />
    <meta http-equiv="expires" content="0" />
    <meta http-equiv="expires" content="Tue, 01 Jan 2977 1:00:00 GMT" />
    <meta http-equiv="pragma" content="no-cache" />


    <link rel="apple-touch-icon" sizes="57x57" href="{{ asset("pmar/assets/fav/apple-icon-57x57-2026.png") }}">
    <link rel="apple-touch-icon" sizes="60x60" href="{{ asset("pmar/assets/fav/apple-icon-60x60-2026.png") }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ asset("pmar/assets/fav/apple-icon-72x72-2026.png") }}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{ asset("pmar/assets/fav/apple-icon-76x76-2026.png") }}">
    <link rel="apple-touch-icon" sizes="114x114" href="{{ asset("pmar/assets/fav/apple-icon-114x114-2026.png") }}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{ asset("pmar/assets/fav/apple-icon-120x120-2026.png") }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ asset("pmar/assets/fav/apple-icon-144x144-2026.png") }}">
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset("pmar/assets/fav/apple-icon-180x180-2026.png") }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset("pmar/assets/fav/favicon-32x32-2026.png") }}">
    <link rel="icon" type="image/png" sizes="96x96" href="{{ asset("pmar/assets/fav/favicon-96x96-2026.png") }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset("pmar/assets/fav/favicon-16x16-2026.png") }}">
    <link rel="manifest" href="{{ asset("pmar/assets/fiveicon/manifest.json") }}">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="{{ asset("pmar/assets/fav/ms-icon-144x144-2026.png") }}">
    <meta name="theme-color" content="#ffffff">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    {{-- Bootstrap CSS (via npm - copiado pelo Vite durante o build) --}}
    <link rel="stylesheet" href="{{ asset('pmar/build/bootstrap/css/bootstrap.min.css') }}">
    {{-- FontAwesome CSS (via npm - copiado pelo Vite durante o build) --}}
    <link rel="stylesheet" href="{{ asset('pmar/build/fontawesome/css/all.min.css') }}">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css" rel="stylesheet">
    <link rel="stylesheet" href="{{ asset('pmar/css/style.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/defaultBar.css') }}">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    @if (Route::currentRouteName() == 'pages.fibromialgia.cadastroPaciente')
        <link rel="stylesheet" href="{{ asset('pmar/css/FormCadastroPaciente.css') }}">
    @endif
    @stack('head')
</head>