@php
    $content = $content ?? '';
@endphp

<div class="dashboard-card">
    <div class="dashboard-card-header">
        <h3 class="dashboard-card-title">
            @if(isset($icon) && $icon)
                <i class="{{ $icon }} me-2"></i>
            @endif
            {{ __($title) }}
        </h3>
    </div>
    <div class="dashboard-card-body">
        {!! $content !!}
    </div>
</div>
