<!-- Assistência Social -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-warning">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-hands-helping fa-2x me-3"></i>
                <h5 class="card-title mb-0">Assistência Social</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-hand-holding-usd me-2 text-muted"></i> Programas sociais <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-id-card me-2 text-muted"></i> Emissão de documentos <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-home me-2 text-muted"></i> 
                    <a href="{{ route("servicos.centrosDeReferencia") }}" class="text-dark">Centros de referência e assistência</a>
                </li>
                <li class="list-group-item">
                    <i class="fa-solid fa-handshake text-muted"></i>   
                    <a href="{{ route("servicos.conselhos.sdsp") }}" class="text-dark">Conselhos</a>
                </li>
                <li class="list-group-item"><i class="fas fa-homeless me-2 text-muted"></i> Abrigos <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-briefcase me-2 text-muted"></i> Capacitação profissional <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-cross me-2 text-muted"></i> Assistencia Funerária <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
    </div>
</div>