<h3 class="subtitle-home"><?php echo e(__("Tópicos mais buscados")); ?></h3>

<div class="row gx-5 gy-5">

    <?php
        $cards = [
            [
                'url' => 'https://saaeangra.com.br',
                'color' => '#213f99',
                'header' => 'Água e <span>Esgoto</span>',
                'image' => 'pmar/assets/img/agua.jpg',
                'title' => 'SAAE',
                'subtitle' => '2ª via de conta, atualização cadastral e outras solicitações',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/transito-estacionamento-idoso.asp?IndexSigla=SEOPM',
                'color' => '#1F58A7',
                'header' => '<span>Estacionamento</span>',
                'image' => 'pmar/assets/img/estacionamento.jpg',
                'title' => 'Estacionamento',
                'subtitle' => 'Emissão da Credencial de Estacionamento para idosos',
            ],
            [
                'url' => 'https://visite.angra.rj.gov.br/fluxo-de-onibus',
                'color' => '#1D72B8',
                'header' => '<span>Turismo</span>',
                'image' => 'pmar/assets/img/onibus.jpg',
                'title' => 'Fluxo de ônibus',
                'subtitle' => 'Entrada de ônibus de turismo no município',
            ],
            [
                'url' => 'https://angra.licenciamento.net.br',
                'color' => '#007bc4',
                'header' => 'Licenciamento de <span>Obras</span>',
                'image' => 'pmar/assets/img/licenciamento.jpg',
                'title' => 'Portal de Licenciamento',
                'subtitle' => 'Abra e acompanhe processos de licenciamentos',
            ],
            [
                'url' => 'https://angra.rj.gov.br/servicos/cras-maritimo-e-cras-movel',
                'color' => '#4683a4',
                'header' => 'Desenvolvimento <span>Social</span>',
                'image' => 'pmar/assets/img/crasmovel.jpg',
                'title' => 'Cras Itinerante',
                'subtitle' => 'Confira a agenda do CRAS Móvel e CRAS Marítimo pelo município',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/noticia.asp?vid_noticia=65474&IndexSigla=imp',
                'color' => '#5b9aa8',
                'header' => '<span>Ramais</span>',
                'image' => 'pmar/assets/img/ramais.jpg',
                'title' => 'Novos Ramais',
                'subtitle' => 'Nova lista de telefones e ramais dos órgãos e setores da prefeitura de Angra',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/fusar-ouvidoria.asp?IndexSigla=SSA',
                'color' => '#57a88f',
                'header' => 'Fale com a <span>Saúde</span>',
                'image' => 'pmar/assets/img/sus.jpg',
                'title' => 'Ouvidoria SUS',
                'subtitle' => 'Canal de comunicação entre você e a Secretaria de Saúde',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/passageirocidadao',
                'color' => '#63c083',
                'header' => 'Transporte </br> <span>Público</span>',
                'image' => 'pmar/assets/img/passageirocidadao.jpg',
                'title' => 'Passageiro Cidadão',
                'subtitle' => 'Inscreva-se e seja mais um beneficiado do Programa Passageiro Cidadão',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/procureolugarcerto/',
                'color' => '#85c775',
                'header' => 'Aonde <span>ir</span>',
                'image' => 'pmar/assets/img/saude.jpg',
                'title' => 'Saúde',
                'subtitle' => 'Fique atento aos sintomas e vá ao lugar certo',
            ],
            [
                'url' => 'https://www.cipteadigital.com/angradosreis',
                'color' => '#b6d558',
                'header' => '<span>Inclusão</span>',
                'image' => 'pmar/assets/img/autismo.jpg',
                'title' => 'Carteira do Autista',
                'subtitle' => 'Cadastro para emissão da Carteira de Identificação de Pessoa com Transtorno do Espectro Autista',
            ],
            [
                'url' => 'https://www.inea.rj.gov.br/angra-dos-reis/',
                'color' => '#cdcb44',
                'header' => 'Banho de <span>Mar</span>',
                'image' => 'pmar/assets/img/balneabilidade.jpg',
                'title' => 'Balneabilidade',
                'subtitle' => 'Relatório de balneabilidade das praias do litoral e Ilha Grande',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/noticia.asp?vid_noticia=66280&indexsigla=imp',
                'color' => '#febd10',
                'header' => '<span>Ambiente</span>',
                'image' => 'pmar/assets/img/coletadelixo.jpg',
                'title' => 'Coleta no Município',
                'subtitle' => 'Confira o calendário das coletas em Angra dos Reis.',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/saladoempreendedor/',
                'color' => '#fcaf16',
                'header' => '<span>MEI</span>',
                'image' => 'pmar/assets/img/mei.jpg',
                'title' => 'Sala do Empreendedor',
                'subtitle' => 'Nosso espaço digital dedicado a ajudar ao Micro empreendedor individual do município',
            ],
            [
                'url' => 'https://ppp.angra.rj.gov.br/',
                'color' => '#F89C1C',
                'header' => 'Programa de Parceria <span>Público Privada</span>',
                'image' => 'pmar/assets/img/ppp.jpg',
                'title' => 'Angra PPP',
                'subtitle' => 'Conheça o portal do Programa de Parceria Público-Privada do município de Angra dos Reis',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/proteja/',
                'color' => '#F68E1E',
                'header' => 'Proteção </br> <span>Infantil</span>',
                'image' => 'pmar/assets/img/protecaoinfantil.jpg',
                'title' => 'Proteja',
                'subtitle' => 'Campanha de combate ao abuso e exploração sexual infantil',
            ],
            [
                'url' => 'https://portal.angra.rj.gov.br/sdc-trans-horarios-onibus.asp?IndexSigla=seopm',
                'color' => '#F48120',
                'header' => 'Vá de </br> <span>ônibus</span>',
                'image' => 'pmar/assets/img/transportecoletivo.jpg',
                'title' => 'Transporte Coletivo',
                'subtitle' => 'Tarifa integrada, horários e itinerários. Fique por dentro',
            ],
            [
                'url' => 'https://pncp.gov.br/app/editais/29172467000109/2027/78',
                'color' => '#F4622B',
                'header' => 'Músicos de </br> <span>Angra</span>',
                'image' => 'pmar/assets/img/credenciamento-musicos.jpg',
                'title' => 'Credenciamento de Músicos',
                'subtitle' => 'Credenciamento para a contratação de artistas locais para apresentações no município.',
            ],
            [
                'url' => 'https://angra.rj.gov.br/secretarias/secretaria-de-educacao-juventude-e-inovacao',
                'color' => '#F44336',
                'header' => 'inovar para </br> <span>Educar,</span> </br>Inspirar para </br> <span>Transformar</span>',
                'image' => 'pmar/assets/img/educacao-juventude-inovacao.jpg',
                'title' => 'Secretaria de Educação, Juventude e Inovação',
                'subtitle' => 'Promovendo a inovação e a educação para transformar o futuro da nossa juventude',
            ],
            [
                'url' => 'https://angra.rj.gov.br/familiaacolhedora',
                'color' => '#f94d88',
                'header' => 'Serviço de <span>Acolhimento</span>',
                'image' => 'pmar/assets/img/familia-acolhedora.jpg',
                'title' => 'Família Acolhedora',
                'subtitle' => 'Ser Família Acolhedora é como oferecer um guarda-chuva no momento da tempestade',
            ],
            [
                'url' => route("saude.fibromialgia"),
                'color' => '#9C27B0',
                'header' => '<span>Fibromialgia</span>',
                'image' => 'pmar/assets/img/cadastro-ficromialgia.jpg',
                'title' => 'Identificação para Pessoas',
                'subtitle' => 'Peça sua carteirinha pelo site e tenha direito a atendimento preferencial',
            ],
            /* [
                'url' => route("cultura.credenciamentoMusicos"),
                'color' => '#9C27B0',
                'header' => 'Credenciamento de <span>Músicos</span>',
                'image' => 'pmar/assets/img/cadastro-ficromialgia.jpg',
                'title' => 'Peça sua carteirinha pelo site',
                'subtitle' => 'O credenciamento é fundamental para que o músico oseja chamado para eventos',
            ], */
            [
                'url' => 'https://angra.rj.gov.br/noticias/08-07-2025/prefeitura-lanca-pca-digital-e-reforca-compromisso-com-a-participacao-popular',
                'color' => '#673AB7',
                'header' => 'Comunidades de <span>Angra</span>',
                'image' => 'pmar/assets/img/pca-digital.jpg',
                'title' => 'Aplicativo PCA Digital',
                'subtitle' => 'Baixe o app e participe sugerindo melhorias para sua comunidade',
            ],

        ];
    ?>

    <?php $__currentLoopData = $cards; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $card): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
        <?php echo $__env->make('components.cards._cardTopicosMaisBuscados', $card, array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

</div>
<?php /**PATH /var/www/html/portal/resources/views/paginas/partsHome/topicoMaisBuscados.blade.php ENDPATH**/ ?>