    <form method="POST" action="{{ route('admin.cultura.arteSacra.options.update', [$id, $type]) }}"> 
        <div class="input-group mb-3">
            @csrf
            @method('post')
            <input type="text" name="name" value="{{ $value }}" class="form-control" required id="input-{{ str_replace('-', '_', $id) }}" style="background-color: #e9ecef">
            @if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar'])
                <button type="submit" class="btn btn-outline-secondary">{{ __("Atualizar") }}</button>
            @endif
            @if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['excluir'])
                <button class="btn btn-outline-danger" type="button" onclick="javascript:if(confirm('Esse registro será excluído definitivamente e você não poderá recuperá-lo, deseja continuar?')){window.location.href='{{ route('admin.cultura.arteSacra.options.destroy', [$id, $type])}}'}">
            @endif
                <i class="fa-solid fa-xmark"></i>
            </button>
        </div>                     
    </form>