<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.arte-sacra.elements.head')

<body class="fade-in">
    <header>
        @include('layouts.arte-sacra.elements.nav')
        <!-- @if (Route::currentRouteName() == 'museu-de-arte-sacra.index')
        @include('layouts.arte-sacra.elements.nav')
        @else
        @endif -->
    </header>
    <main>
        @yield('content')
    </main>
    <footer class="footer-pmar">
        @include('layouts.arte-sacra.elements.footer')
    </footer>
</body>

</html>