@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __("Lista de Pontos Focais"))
@section('content')

    @include("errors.messageFlash")

    <div class="card shadow-sm">
        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center mb-3">
            <h5 class="mb-0">{{ __("Lista de Pontos Focais") }}</h5>
        </div>
        <div class="card-body">
            <div class="d-flex">
                @include('components.buttons._newButton', ['url' => 'admin.pontosFocais.create', 'text' => __('Novo Ponto Focal')])
            </div>
            <form id="searchPontosFocais" class="d-flex mb-4 pt-4" method="get">
                <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
                <input type="text" class="form-control me-2" name="q" placeholder="{{ __('Pesquisar ponto focal...') }}"
                    value="{{ request()->input('q') }}">
                <button class="btn btn-outline-success" type="submit"><i class="fa-solid fa-magnifying-glass"></i></button>
            </form>

            <div class="table-responsive">
                <table class="table table-bordered table-hover table-striped align-middle text-center">
                    <thead class="table-light">
                        <tr>
                            <th>{{ __("Nome") }}</th>
                            <th>{{ __("Instituição") }}</th>
                            <th>{{ __("Matrícula") }}</th>
                            <th>{{ __("Telefone/Ramal") }}</th>
                            <th>{{ __("E-mail") }}</th>
                            <th>{{ __("Ações") }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php $index = 0 @endphp
                        @forelse($pontosFocais as $pontoFocal)
                            <tr>
                                <td>{{ $pontoFocal->nome }}</td>
                                <td>{{ $pontoFocal->instituicao->name ?? '-' }}@if($pontoFocal->instituicao && $pontoFocal->instituicao->abbreviation) ({{ $pontoFocal->instituicao->abbreviation }})@endif</td>
                                <td>{{ $pontoFocal->matricula }}</td>
                                <td>{{ $pontoFocal->telefone_ramal ?? '-' }}</td>
                                <td>{{ $pontoFocal->email ?? '-' }}</td>
                                <td>
                                    <div class="btn-group" role="group">
                                        <a href="{{ route('admin.pontosFocais.edit', $pontoFocal->id) }}" class="btn btn-sm btn-warning"
                                            title="{{ __('Editar') }}"><i class="fa-solid fa-pen-to-square"></i></a>

                                        <form class="d-inline" action="{{ route('admin.pontosFocais.destroy', $pontoFocal->id) }}"
                                            method="post" onsubmit="return confirmDelete(this)">
                                            @csrf
                                            @method('delete')
                                            <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
                                            <input type="hidden" name="confirm"
                                                value="{{ __('* Este ponto focal será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                            <button type="submit" class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                                                <i class="fa-solid fa-trash"></i>
                                            </button>
                                        </form>
                                    </div>
                                </td>
                            </tr>
                            @php $index++ @endphp
                        @empty
                            <tr>
                                <td colspan="6" class="text-muted fst-italic">{{ __("* Nenhum registro encontrado!") }}</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>

            <div class="d-flex justify-content-center mt-4">
                {!! $pontosFocais->links() !!}
            </div>
        </div>
    </div>
@endsection
