<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'items' => [],
    'ariaLabel' => null,
    'responsiveAbbreviation' => false,
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'items' => [],
    'ariaLabel' => null,
    'responsiveAbbreviation' => false,
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    $ariaLabel = $ariaLabel ?? __('Navegação em trilha');
?>

<nav aria-label="<?php echo e($ariaLabel); ?>">
    <ol <?php echo e($attributes->merge(['class' => 'breadcrumb'])); ?>>
        <?php $__currentLoopData = $items; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <?php
                $isLast = $index === count($items) - 1;
                $url = $item['url'] ?? null;
                $label = $item['label'] ?? '';
                $labelShort = $item['labelShort'] ?? null;
            ?>
            <li class="<?php echo \Illuminate\Support\Arr::toCssClasses(['breadcrumb-item', 'active' => $isLast]); ?>" <?php if($isLast): ?> aria-current="page" <?php endif; ?>>
                <?php if(! $isLast && filled($url)): ?>
                    <a href="<?php echo e($url); ?>">
                        <?php if($responsiveAbbreviation && filled($labelShort)): ?>
                            <span class="d-none d-md-inline"><?php echo e($label); ?></span>
                            <span class="d-md-none"><?php echo e($labelShort); ?></span>
                        <?php else: ?>
                            <?php echo e($label); ?>

                        <?php endif; ?>
                    </a>
                <?php else: ?>
                    <?php if($responsiveAbbreviation && filled($labelShort)): ?>
                        <span class="d-none d-md-inline"><?php echo e($label); ?></span>
                        <span class="d-md-none"><?php echo e($labelShort); ?></span>
                    <?php else: ?>
                        <?php echo e($label); ?>

                    <?php endif; ?>
                <?php endif; ?>
            </li>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </ol>
</nav>
<?php /**PATH /var/www/html/portal/resources/views/components/portal/breadcrumb.blade.php ENDPATH**/ ?>