@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: " . __('Detalhes do Contrato'))

@section('content')
<link rel="stylesheet" href="{{ asset('pmar/css/paginas/contratos.css') }}">
<section class="py-5 contratos-detalhe-section">
    <div class="container">
        <nav aria-label="breadcrumb" class="mb-4">
            <ol class="breadcrumb small">
                <li class="breadcrumb-item"><a href="{{ route('paginas.home') }}">{{ __('Portal') }}</a></li>
                <li class="breadcrumb-item"><a href="{{ route('paginas.contratos') }}">{{ __('Contratos') }}</a></li>
                <li class="breadcrumb-item active">{{ __('Detalhes') }}</li>
            </ol>
        </nav>

        <div class="card border-0 shadow-lg contratos-detalhe-card">
            <div class="card-body p-4 p-md-5">
                <div class="d-flex flex-column flex-md-row justify-content-between align-items-start mb-4">
                    <div>
                        <h1 class="h3 fw-bold text-dark mb-1">{{ __('Contrato Nº') }} {{ $contrato->con_numero ?: '-' }}</h1>
                        <span class="badge bg-primary-subtle text-primary px-3 py-2 rounded-pill">{{ $contrato->modalidade_label ?: '-' }}</span>
                    </div>
                    <div class="mt-3 mt-md-0">
                        <span class="badge bg-success px-3 py-2 rounded-pill">{{ $contrato->status_label ?: '-' }}</span>
                    </div>
                </div>

                @php $prorrogacao = $contrato->prorrogacao; @endphp

                <div class="row g-4 mb-4">
                    <div class="col-md-4"><strong>{{ __('Publicado em') }}:</strong> {{ $contrato->con_datapub ?: '-' }}</div>
                    <div class="col-md-4"><strong>{{ __('Data de início') }}:</strong> {{ $contrato->con_dataini ?: '-' }}</div>
                    <div class="col-md-4">
                        <strong>{{ __('Data de término') }}:</strong>
                        {{ $contrato->con_datafim ?: '-' }}
                        @if($prorrogacao)
                            <span class="text-muted d-block small mt-1">
                                {{ __('Prorrogado até') }} <strong>{{ $prorrogacao->arq_datafim }}</strong>
                                {{ __('pelo anexo') }} {{ $prorrogacao->arq_titulo ?: $prorrogacao->arq_numero }}
                            </span>
                        @endif
                    </div>
                    <div class="col-md-4"><strong>{{ __('Ano') }}:</strong> {{ $contrato->con_ano ?: '-' }}</div>
                    <div class="col-md-4"><strong>{{ __('Processo') }}:</strong> {{ $contrato->con_processo ?: '-' }}</div>
                    <div class="col-md-4"><strong>{{ __('Valor') }}:</strong> {{ $contrato->con_valor ?: '-' }}</div>
                    <div class="col-md-6"><strong>{{ __('Favorecido') }}:</strong> {{ $contrato->favorecido?->fav_nome ?: '-' }}</div>
                    <div class="col-md-6"><strong>{{ __('CPF/CNPJ') }}:</strong> {{ $contrato->con_favorecido ?: '-' }}</div>
                    <div class="col-md-6"><strong>{{ __('Secretaria') }}:</strong> {{ $contrato->secretaria?->name ?: '-' }}</div>
                    <div class="col-md-6"><strong>{{ __('Secretaria Gestora') }}:</strong> {{ $contrato->secretariaGestora?->name ?: '-' }}</div>
                    <div class="col-md-6">
                        <strong>{{ __('Licitação vinculada') }}:</strong>
                        @if($contrato->licitacao_procedimento_id)
                            <a href="{{ route('paginas.licitacoes-e-procedimentos.detalhe', $contrato->licitacao_procedimento_id) }}">
                                {{ $contrato->licitacao?->nr_licitacao ?? ('#' . $contrato->licitacao_procedimento_id) }}
                            </a>
                        @else
                            -
                        @endif
                    </div>
                    <div class="col-md-12"><strong>{{ __('Título') }}:</strong> {{ $contrato->con_titulo ?: '-' }}</div>
                    <div class="col-md-12"><strong>{{ __('Fiscais') }}:</strong> {{ $contrato->con_fiscais ?: '-' }}</div>
                </div>

                <div>
                    <h6 class="fw-bold mb-3">{{ __('Arquivos') }}</h6>
                    @if($contrato->arquivos->isNotEmpty())
                        <div class="d-flex flex-wrap gap-3">
                            @foreach($contrato->arquivos as $arquivo)
                                <a class="btn btn-outline-primary d-flex align-items-center gap-2 px-3 py-2 rounded-pill shadow-sm"
                                   href="{{ $arquivo->arquivo_url }}"
                                   target="_blank"
                                   rel="noopener noreferrer">
                                    <i class="fa-solid fa-file-arrow-down"></i>
                                    <span>{{ $arquivo->arq_titulo ?: basename((string) $arquivo->arq_arquivo) }}</span>
                                </a>
                            @endforeach
                        </div>
                    @else
                        <div class="text-muted">{{ __('Sem arquivos vinculados.') }}</div>
                    @endif
                </div>
            </div>
        </div>
    </div>
</section>
@endsection
