@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Avaliação - Arte Sacra')

@section('body_class', 'page-avaliacao')

@section('content')
    <div class="card shadow-sm">
        
        @php $headLine = "<i class='fa-solid fa-church'></i> Arte Sacra - Avaliação Técnica - {$acervo->codigo_acervo} - {$acervo->nome_peca}"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            "headLine" => __($headLine),
            "routeBack" => "admin.cultura.arteSacra.index",
            "routeBackParams" => [],
            "fontawesomeBack" => '<i class="fa-solid fa-rectangle-list"></i>',
            "nameBack" => __("Lista de Peças"),
            "routeAdd" => "admin.cultura.arteSacra.create",
            "routeAddParams" => [],
            "nameAdd" => __("Nova peça"),
            "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
        ])

        @include('errors.messageFlash')
        
        <div class="row my-4 ps-4">
            <div class="col-auto" id="container-botao-incluir">
                <button id="btn-incluir" class="btn btn-primary ms-2">
                    <i class="fa-solid fa-plus"></i> Adicionar Avaliação
                </button>
            </div>
        </div>

        <div class="card-body">
            <div id="form-add" class="d-none">
                <form action="{{ route('admin.cultura.arteSacra.avaliacao-tecnica.store') }}" method="POST"
                    enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf

                    <div class="card border-0 shadow-sm mb-4">
                        <div class="card-header bg-primary text-white">
                            <h5 class="mb-0"><i class="fas fa-clipboard-check me-2"></i> Nova Avaliação Técnica</h5>
                        </div>
                        <div class="card-body">
                            <input type="hidden" name="codigo_acervo" value="{{ $acervo->codigo_acervo }}">
                            <div class="mb-4">
                                <h6 class="text-primary fw-bold border-bottom pb-2 mb-3">
                                    <i class="fas fa-clipboard-list me-2"></i>Estado de Conservação
                                </h6>

                                <div class="row">
                                    <div class="col-md-6">
                                        <label for="suporte" class="form-label fw-semibold">
                                            <i class="fas fa-palette me-1 text-muted"></i> Suporte
                                        </label>
                                        <select name="suporte" class="form-select border-primary" required>
                                            <option value="" disabled selected>Selecione o estado...</option>
                                            <option value="Ótimo" {{ old('suporte') == 'Ótimo' ? 'selected' : '' }}>Ótimo
                                            </option>
                                            <option value="Bom" {{ old('suporte') == 'Bom' ? 'selected' : '' }}>Bom
                                            </option>
                                            <option value="Regular" {{ old('suporte') == 'Regular' ? 'selected' : '' }}>
                                                Regular</option>
                                            <option value="Ruim" {{ old('suporte') == 'Ruim' ? 'selected' : '' }}>Ruim
                                            </option>
                                            <option value="Péssimo" {{ old('suporte') == 'Péssimo' ? 'selected' : '' }}>
                                                Péssimo</option>
                                        </select>
                                        <div class="invalid-feedback">Por favor, selecione o estado do suporte.</div>
                                    </div>

                                    <div class="col-md-6">
                                        <label for="policromia" class="form-label fw-semibold">
                                            <i class="fas fa-brush me-1 text-muted"></i> Policromia
                                        </label>
                                        <select name="policromia" class="form-select border-primary" required>
                                            <option value="" disabled selected>Selecione o estado...</option>
                                            <option value="Ótimo" {{ old('policromia') == 'Ótimo' ? 'selected' : '' }}>
                                                Ótimo</option>
                                            <option value="Bom" {{ old('policromia') == 'Bom' ? 'selected' : '' }}>Bom
                                            </option>
                                            <option value="Regular" {{ old('policromia') == 'Regular' ? 'selected' : '' }}>
                                                Regular</option>
                                            <option value="Ruim" {{ old('policromia') == 'Ruim' ? 'selected' : '' }}>Ruim
                                            </option>
                                            <option value="Péssimo" {{ old('policromia') == 'Péssimo' ? 'selected' : '' }}>
                                                Péssimo</option>
                                            <option value="Não possui"
                                                {{ old('policromia') == 'Não possui' ? 'selected' : '' }}>Não possui
                                            </option>
                                        </select>
                                        <div class="invalid-feedback">Por favor, selecione o estado da policromia.</div>
                                    </div>
                                </div>
                            </div>

                            <div class="mb-4 text-wrap">
                                <label for="diagnostico" class="form-label fw-semibold">
                                    <i class="fas fa-stethoscope me-1 text-muted"></i> Diagnóstico
                                </label>
                                <textarea name="diagnostico" class="form-control border-primary textarea-comments" rows="4"
                                    style="min-height: 100px;">{{ old('diagnostico') }}</textarea>
                            </div>

                            <div class="mb-4">
                                <label for="procedimentos" class="form-label fw-semibold">
                                    <i class="fas fa-tasks me-1 text-muted"></i> Tratamento realizado
                                </label>
                                <textarea name="procedimentos" class="form-control border-primary" rows="4" style="min-height: 100px;">{{ old('procedimentos') }}</textarea>
                            </div>
                        </div>
                    </div>

                    <div class="row g-4">
                        <div class="col-lg-6 col-md-12">
                            <div class="card border-info h-100">
                                <div class="card-header bg-info bg-opacity-10">
                                    <h6 class="mb-0 fw-bold text-white">
                                        <i class="fas fa-camera me-2"></i>Imagem Antes da Análise
                                    </h6>
                                </div>
                                <div class="card-body">
                                    <div class="row g-3">
                                        <div class="col-md-6">
                                            <label for="imagem_antes_frente" class="form-label fw-semibold">
                                                <i class="fas fa-image me-1 text-muted"></i> Frente
                                            </label>
                                            <input type="file" name="imagem_antes_frente" class="form-control"
                                                accept="image/*">
                                            <div class="form-text">Formatos: JPG, PNG (Máx. 5MB)</div>
                                        </div>
                                        <div class="col-md-6">
                                            <label for="imagem_antes_verso" class="form-label fw-semibold">
                                                <i class="fas fa-image me-1 text-muted"></i> Verso
                                            </label>
                                            <input type="file" name="imagem_antes_verso" class="form-control"
                                                accept="image/*">
                                            <div class="form-text">Formatos: JPG, PNG (Máx. 5MB)</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-6 col-md-12">
                            <div class="card border-success h-100">
                                <div class="card-header bg-success bg-opacity-10">
                                    <h6 class="mb-0 fw-bold text-white">
                                        <i class="fas fa-camera-retro me-2"></i>Imagem Depois da Análise
                                    </h6>
                                </div>
                                <div class="card-body">
                                    <div class="row g-3">
                                        <div class="col-md-6">
                                            <label for="imagem_depois_frente" class="form-label fw-semibold">
                                                <i class="fas fa-image me-1 text-muted"></i> Frente
                                            </label>
                                            <input type="file" name="imagem_depois_frente" class="form-control"
                                                accept="image/*">
                                            <div class="form-text">Formatos: JPG, PNG (Máx. 5MB)</div>
                                        </div>
                                        <div class="col-md-6">
                                            <label for="imagem_depois_verso" class="form-label fw-semibold">
                                                <i class="fas fa-image me-1 text-muted"></i> Verso
                                            </label>
                                            <input type="file" name="imagem_depois_verso" class="form-control"
                                                accept="image/*">
                                            <div class="form-text">Formatos: JPG, PNG (Máx. 5MB)</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card border-0 shadow-sm mb-4 mt-4">
                        <div class="card-header bg-primary">
                            <h6 class="mb-0 fw-bold text-white">
                                <i class="fas fa-user-tie me-2"></i>Responsável pela Avaliação
                            </h6>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <label for="data_avaliacao" class="form-label fw-semibold">
                                        <i class="far fa-calendar-alt me-1 text-muted"></i> Data da Avaliação
                                    </label>
                                    <input type="date" class="form-control border-primary" name="data_avaliacao"
                                        value="{{ old('data_avaliacao') }}" required>
                                    <div class="invalid-feedback">Por favor, informe a data da avaliação.</div>
                                </div>
                                <div class="col-md-6">
                                    <label for="responsavel" class="form-label fw-semibold">
                                        <i class="fas fa-signature me-1 text-muted"></i> Responsável
                                    </label>
                                    <input type="hidden" name="user_id" value="{{ Auth::user()->id }}">
                                    <input type="text" class="form-control border-primary" name="responsavel"
                                        value="{{ old('responsavel', Auth::user()->firstName . ' ' . Auth::user()->lastName) }}"
                                        readonly="true">
                                    <div class="invalid-feedback">Por favor, informe o nome do responsável.</div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="d-flex justify-content-end gap-2">
                        <button type="button" id="btn-cancelar" class="btn btn-outline-secondary">
                            <i class="fas fa-times me-1"></i> Cancelar
                        </button>
                        <button type="submit" id="btn-incluir" class="btn btn-primary">
                            <i class="fas fa-plus-circle me-1"></i> Adicionar Avaliação
                        </button>
                    </div>
                </form>
            </div>

            <div class="table-responsive mt-4">
                <table class="table table-striped">
                    @include('components.tables._thead', [
                        'thead' => [
                            'Suporte',
                            'Policromia',
                            'Diagnóstico',
                            'Procedimentos',
                            'Imagens Antes',
                            'Imagens Depois',
                            'Data da Avaliação',
                            'Responsável',
                            'Ações'
                        ]
                    ])
                    <tbody>
                        @foreach ($avaliacoes as $avaliacao)
                            <tr>
                                <td>{{ $avaliacao->suporte }}</td>
                                <td>{{ $avaliacao->policromia }}</td>
                                <td>
                                    @php
                                        $text = strip_tags($avaliacao->diagnostico);
                                        $limit = 100;
                                    @endphp

                                    @if (strlen($text) > $limit)
                                        <span class="short-text">{{ Str::limit($text, $limit) }}</span>
                                        <span class="full-text" style="display:none;">{{ $text }}</span>
                                        <a href="#" class="toggle-text"
                                            onclick="event.preventDefault(); toggleText(this);">ver mais</a>
                                    @else
                                        {{ $text }}
                                    @endif
                                </td>

                                <td>
                                    @php
                                        $text = strip_tags($avaliacao->procedimentos);
                                        $limit = 100;
                                    @endphp

                                    @if (strlen($text) > $limit)
                                        <span class="short-text">{{ Str::limit($text, $limit) }}</span>
                                        <span class="full-text" style="display:none;">{{ $text }}</span>
                                        <a href="#" class="toggle-text"
                                            onclick="event.preventDefault(); toggleText(this);">ver mais</a>
                                    @else
                                        {{ $text }}
                                    @endif
                                </td>

                                <td>
                                    @foreach (['imagem_antes_frente' => 'Antes Frente', 'imagem_antes_verso' => 'Antes Verso'] as $campo => $alt)
                                        @if ($avaliacao->$campo)
                                            <img src="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                width="90" height="90" alt="{{ $alt }}"
                                                class="rounded-circle me-1" style="object-fit: cover; cursor: pointer;"
                                                data-bs-toggle="modal"
                                                data-bs-target="#modal-{{ $campo }}-{{ $avaliacao->id }}">

                                            <div class="modal fade" id="modal-{{ $campo }}-{{ $avaliacao->id }}"
                                                tabindex="-1" aria-hidden="true" data-bs-backdrop="false">
                                                <div class="modal-dialog modal-dialog-centered" style="max-width: 600px;">
                                                    <div class="modal-content border-0">
                                                        <div class="modal-header p-2 justify-content-end">
                                                            <button type="button" class="btn-close"
                                                                data-bs-dismiss="modal" aria-label="Fechar"></button>
                                                        </div>
                                                        <div class="modal-body p-0 text-center">
                                                            <img src="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                                class="img-fluid" alt="Ampliação - {{ $alt }}"
                                                                style="max-height: 70vh; max-width: 100%; object-fit: contain;">
                                                        </div>
                                                        <div class="modal-footer p-2 justify-content-center">
                                                            @php
                                                                $ext = pathinfo($avaliacao->$campo, PATHINFO_EXTENSION);
                                                                $nome =
                                                                    Str::slug($alt) .
                                                                    '-avaliacao-' .
                                                                    $avaliacao->id .
                                                                    '.' .
                                                                    $ext;
                                                            @endphp
                                                            <a href="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                                download="{{ $nome }}"
                                                                class="btn btn-sm btn-dark">
                                                                <i class="fas fa-download me-1"></i> Baixar
                                                            </a>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        @endif
                                    @endforeach
                                </td>
                                <td>
                                    @foreach (['imagem_depois_frente' => 'Depois Frente', 'imagem_depois_verso' => 'Depois Verso'] as $campo => $alt)
                                        @if ($avaliacao->$campo)
                                            <img src="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                width="90" height="90" alt="{{ $alt }}"
                                                class="rounded-circle me-1" style="object-fit: cover; cursor: pointer;"
                                                data-bs-toggle="modal"
                                                data-bs-target="#modal-{{ $campo }}-{{ $avaliacao->id }}">

                                            <div class="modal fade" id="modal-{{ $campo }}-{{ $avaliacao->id }}"
                                                tabindex="-1" aria-hidden="true" data-bs-backdrop="false">
                                                <div class="modal-dialog modal-dialog-centered" style="max-width: 600px;">
                                                    <div class="modal-content border-0">
                                                        <div class="modal-header p-2 justify-content-end">
                                                            <button type="button" class="btn-close"
                                                                data-bs-dismiss="modal" aria-label="Fechar"></button>
                                                        </div>
                                                        <div class="modal-body p-0 text-center">
                                                            <img src="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                                class="img-fluid" alt="Ampliação - {{ $alt }}"
                                                                style="max-height: 70vh; max-width: 100%; object-fit: contain;">
                                                        </div>
                                                        <div class="modal-footer p-2 justify-content-center">
                                                            @php
                                                                $ext = pathinfo($avaliacao->$campo, PATHINFO_EXTENSION);
                                                                $nome =
                                                                    Str::slug($alt) .
                                                                    '-avaliacao-' .
                                                                    $avaliacao->id .
                                                                    '.' .
                                                                    $ext;
                                                            @endphp
                                                            <a href="{{ asset("pmar/assets/img/arte_sacra/avaliacaoTecnica/{$avaliacao->$campo}") }}"
                                                                download="{{ $nome }}"
                                                                class="btn btn-sm btn-dark">
                                                                <i class="fas fa-download me-1"></i> Baixar
                                                            </a>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        @endif
                                    @endforeach
                                </td>

                                <td>{{ \Carbon\Carbon::parse($avaliacao->data_avaliacao)->format('d/m/Y') }}</td>
                                <td>{{ $avaliacao->responsavel }}</td>
                                <td>
                                    <button type="button" class="btn btn-info text-white me-2" data-bs-toggle="modal"
                                        data-bs-target="#editarModal-{{ $avaliacao->id }}" title="Editar">
                                        <i class="fa-solid fa-pen-to-square"></i>
                                    </button>

                                    <div class="modal fade" id="editarModal-{{ $avaliacao->id }}" tabindex="-1"
                                        aria-labelledby="editarModalLabel-{{ $avaliacao->id }}" aria-hidden="true">
                                        <div class="modal-dialog modal-xl">
                                            <form
                                                action="{{ route('admin.cultura.arteSacra.avaliacao-tecnica.update', $avaliacao->id) }}"
                                                method="POST" enctype="multipart/form-data">
                                                @csrf
                                                @method('PUT')

                                                <div class="modal-content border-0 shadow-lg">
                                                    <div class="modal-header bg-primary text-white">
                                                        <h5 class="modal-title"
                                                            id="editarModalLabel-{{ $avaliacao->id }}">
                                                            <i class="fas fa-clipboard-check me-2"></i>Editar Avaliação
                                                            Técnica
                                                        </h5>
                                                        <button type="button" class="btn-close btn-close-white"
                                                            data-bs-dismiss="modal" aria-label="Fechar"></button>
                                                    </div>

                                                    <div class="modal-body p-4">
                                                        <div class="row g-4">
                                                            <div class="col-md-6">
                                                                <div class="card h-100 border-0 shadow-sm">
                                                                    <div class="card-header bg-light">
                                                                        <h6 class="mb-0 fw-bold text-primary">
                                                                            <i
                                                                                class="fas fa-info-circle me-2"></i>Informações
                                                                            Básicas
                                                                        </h6>
                                                                    </div>
                                                                    <div class="card-body">
                                                                        <input type="hidden" name="acervo_id"
                                                                            value="{{ $avaliacao->acervo_id }}">

                                                                        <div class="mb-3">
                                                                            <label for="suporte-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="fas fa-palette me-1 text-muted"></i>
                                                                                Suporte
                                                                            </label>
                                                                            <select name="suporte" class="form-select border-primary" required>
                                                                                <option value="" disabled selected>Selecione o estado...</option>
                                                                                <option value="Ótimo" {{ old('suporte', $avaliacao->suporte) == 'Ótimo' ? 'selected' : '' }}>Ótimo
                                                                                </option>
                                                                                <option value="Bom" {{ old('suporte', $avaliacao->suporte) == 'Bom' ? 'selected' : '' }}>Bom
                                                                                </option>
                                                                                <option value="Regular" {{ old('suporte', $avaliacao->suporte) == 'Regular' ? 'selected' : '' }}>Regular</option>
                                                                                <option value="Ruim" {{ old('suporte', $avaliacao->suporte) == 'Ruim' ? 'selected' : '' }}>Ruim
                                                                                </option>
                                                                                <option value="Péssimo" {{ old('suporte', $avaliacao->suporte) == 'Péssimo' ? 'selected' : '' }}>Péssimo</option>
                                                                            </select>
                                                                            <div class="invalid-feedback">Por favor, selecione o estado do suporte.</div>
                                                                        </div>

                                                                        <div class="mb-3">
                                                                            <label for="policromia-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="fas fa-brush me-1 text-muted"></i>
                                                                                Policromia
                                                                            </label>
                                                                            <select name="policromia" class="form-select border-primary" required>
                                                                                <option value="<" disabled selected>Selecione o estado...</option>
                                                                                <option value="Ótimo" {{ old('policromia', $avaliacao->policromia) == 'Ótimo' ? 'selected' : '' }}>
                                                                                    Ótimo</option>
                                                                                <option value="Bom" {{ old('policromia', $avaliacao->policromia) == 'Bom' ? 'selected' : '' }}>Bom
                                                                                </option>
                                                                                <option value="Regular" {{ old('policromia', $avaliacao->policromia) == 'Regular' ? 'selected' : '' }}>
                                                                                    Regular</option>
                                                                                <option value="Ruim" {{ old('policromia', $avaliacao->policromia) == 'Ruim' ? 'selected' : '' }}>Ruim
                                                                                </option>
                                                                                <option value="Péssimo" {{ old('policromia', $avaliacao->policromia) == 'Péssimo' ? 'selected' : '' }}>
                                                                                    Péssimo</option>
                                                                                <option value="Não possui"
                                                                                    {{ old('policromia', $avaliacao->policromia) == 'Não possui' ? 'selected' : '' }}>Não possui
                                                                                </option>
                                                                            </select>
                                                                            <div class="invalid-feedback">Por favor, selecione o estado da policromia.</div>
                                                                        </div>

                                                                        <div class="mb-3">
                                                                            <label
                                                                                for="data_avaliacao-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="far fa-calendar-alt me-1 text-muted"></i>
                                                                                Data da Avaliação
                                                                            </label>
                                                                            <input type="date"
                                                                                class="form-control border-primary border-1"
                                                                                id="data_avaliacao-{{ $avaliacao->id }}"
                                                                                name="data_avaliacao"
                                                                                value="{{ \Carbon\Carbon::parse($avaliacao->data_avaliacao)->format('Y-m-d') }}"
                                                                                required>
                                                                        </div>

                                                                        <div class="mb-3">
                                                                            <label for="responsavel-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="fas fa-user-tie me-1 text-muted"></i>
                                                                                Responsável
                                                                            </label>
                                                                            <input type="text"
                                                                                class="form-control border-primary border-1"
                                                                                id="responsavel-{{ $avaliacao->id }}"
                                                                                name="responsavel"
                                                                                value="{{ $avaliacao->responsavel }}"
                                                                                required>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>

                                                            <div class="col-md-6">
                                                                <div class="card h-100 border-0 shadow-sm">
                                                                    <div class="card-header bg-light">
                                                                        <h6 class="mb-0 fw-bold text-primary">
                                                                            <i class="fas fa-search me-2"></i>Análise
                                                                            Técnica
                                                                        </h6>
                                                                    </div>
                                                                    <div class="card-body">
                                                                        <div class="mb-3 text-wrap">
                                                                            <label for="diagnostico-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="fas fa-stethoscope me-1 text-muted"></i>
                                                                                Diagnóstico
                                                                            </label>
                                                                            <textarea class="form-control textarea-comments border-primary border-1" id="diagnostico-{{ $avaliacao->id }}"
                                                                                name="diagnostico" rows="3" style="min-height: 100px;">{!! $avaliacao->diagnostico !!}</textarea>
                                                                        </div>

                                                                        <div class="mb-3">
                                                                            <label
                                                                                for="procedimentos-{{ $avaliacao->id }}"
                                                                                class="form-label fw-semibold">
                                                                                <i
                                                                                    class="fas fa-tasks me-1 text-muted"></i>
                                                                                Procedimentos
                                                                            </label>
                                                                            <textarea class="form-control border-primary border-1" id="procedimentos-{{ $avaliacao->id }}" name="procedimentos"
                                                                                rows="3" style="min-height: 100px;">{{ $avaliacao->procedimentos }}</textarea>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>

                                                            <div class="col-12">
                                                                <div class="card border-0 shadow-sm">
                                                                    <div class="card-header bg-primary">
                                                                        <h6 class="mb-0 fw-bold text-white">
                                                                            <i class="fas fa-images me-2"></i>Documentação
                                                                            Fotográfica
                                                                        </h6>
                                                                    </div>
                                                                    <div class="card-body">
                                                                        <div class="row">
                                                                            <div class="col-md-6">
                                                                                <div class="card mb-3 border-primary">
                                                                                    <div
                                                                                        class="card-header bg-info bg-opacity-10">
                                                                                        <h6
                                                                                            class="mb-0 fw-bold text-white">
                                                                                            <i
                                                                                                class="fas fa-camera me-2"></i>Antes
                                                                                            da Intervenção
                                                                                        </h6>
                                                                                    </div>
                                                                                    <div class="card-body">
                                                                                        <div class="row">
                                                                                            <div class="col-md-6 mb-3">
                                                                                                <label
                                                                                                    for="imagem_antes_frente-{{ $avaliacao->id }}"
                                                                                                    class="form-label fw-semibold">Frente</label>
                                                                                                <input type="file"
                                                                                                    class="form-control"
                                                                                                    id="imagem_antes_frente-{{ $avaliacao->id }}"
                                                                                                    name="imagem_antes_frente"
                                                                                                    accept="image/*">
                                                                                                @if ($avaliacao->imagem_antes_frente)
                                                                                                    <div
                                                                                                        class="mt-2 text-center">
                                                                                                        <img src="{{ asset('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_antes_frente) }}"
                                                                                                            alt="Antes Frente"
                                                                                                            class="img-thumbnail"
                                                                                                            style="max-height: 150px;">
                                                                                                        <p
                                                                                                            class="small text-muted mt-1">
                                                                                                            Imagem atual</p>
                                                                                                    </div>
                                                                                                @endif
                                                                                            </div>
                                                                                            <div class="col-md-6 mb-3">
                                                                                                <label
                                                                                                    for="imagem_antes_verso-{{ $avaliacao->id }}"
                                                                                                    class="form-label fw-semibold">Verso</label>
                                                                                                <input type="file"
                                                                                                    class="form-control"
                                                                                                    id="imagem_antes_verso-{{ $avaliacao->id }}"
                                                                                                    name="imagem_antes_verso"
                                                                                                    accept="image/*">
                                                                                                @if ($avaliacao->imagem_antes_verso)
                                                                                                    <div
                                                                                                        class="mt-2 text-center">
                                                                                                        <img src="{{ asset('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_antes_verso) }}"
                                                                                                            alt="Antes Verso"
                                                                                                            class="img-thumbnail"
                                                                                                            style="max-height: 150px;">
                                                                                                        <p
                                                                                                            class="small text-muted mt-1">
                                                                                                            Imagem atual</p>
                                                                                                    </div>
                                                                                                @endif
                                                                                            </div>
                                                                                        </div>
                                                                                    </div>
                                                                                </div>
                                                                            </div>

                                                                            <div class="col-md-6">
                                                                                <div class="card mb-3 border-success">
                                                                                    <div
                                                                                        class="card-header bg-success bg-opacity-10">
                                                                                        <h6
                                                                                            class="mb-0 fw-bold text-white">
                                                                                            <i
                                                                                                class="fas fa-camera-retro me-2"></i>Depois
                                                                                            da Intervenção
                                                                                        </h6>
                                                                                    </div>
                                                                                    <div class="card-body">
                                                                                        <div class="row">
                                                                                            <div class="col-md-6 mb-3">
                                                                                                <label
                                                                                                    for="imagem_depois_frente-{{ $avaliacao->id }}"
                                                                                                    class="form-label fw-semibold">Frente</label>
                                                                                                <input type="file"
                                                                                                    class="form-control"
                                                                                                    id="imagem_depois_frente-{{ $avaliacao->id }}"
                                                                                                    name="imagem_depois_frente"
                                                                                                    accept="image/*">
                                                                                                @if ($avaliacao->imagem_depois_frente)
                                                                                                    <div
                                                                                                        class="mt-2 text-center">
                                                                                                        <img src="{{ asset('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_depois_frente) }}"
                                                                                                            alt="Depois Frente"
                                                                                                            class="img-thumbnail"
                                                                                                            style="max-height: 150px;">
                                                                                                        <p
                                                                                                            class="small text-muted mt-1">
                                                                                                            Imagem atual</p>
                                                                                                    </div>
                                                                                                @endif
                                                                                            </div>
                                                                                            <div class="col-md-6 mb-3">
                                                                                                <label
                                                                                                    for="imagem_depois_verso-{{ $avaliacao->id }}"
                                                                                                    class="form-label fw-semibold">Verso</label>
                                                                                                <input type="file"
                                                                                                    class="form-control"
                                                                                                    id="imagem_depois_verso-{{ $avaliacao->id }}"
                                                                                                    name="imagem_depois_verso"
                                                                                                    accept="image/*">
                                                                                                @if ($avaliacao->imagem_depois_verso)
                                                                                                    <div
                                                                                                        class="mt-2 text-center">
                                                                                                        <img src="{{ asset('pmar/assets/img/arte_sacra/avaliacaoTecnica/' . $avaliacao->imagem_depois_verso) }}"
                                                                                                            alt="Depois Verso"
                                                                                                            class="img-thumbnail"
                                                                                                            style="max-height: 150px;">
                                                                                                        <p
                                                                                                            class="small text-muted mt-1">
                                                                                                            Imagem atual</p>
                                                                                                    </div>
                                                                                                @endif
                                                                                            </div>
                                                                                        </div>
                                                                                    </div>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <div class="modal-footer">
                                                        <button type="button" class="btn btn-outline-secondary m-2"
                                                            data-bs-dismiss="modal">
                                                            <i class="fas fa-times me-1"></i> Cancelar
                                                        </button>
                                                        <button type="submit" class="btn btn-success m-2">
                                                            <i class="fas fa-save me-1"></i> Salvar Alterações
                                                        </button>
                                                    </div>
                                                </div>
                                            </form>
                                        </div>
                                    </div>

                                    <form
                                        action="{{ route('admin.cultura.arteSacra.avaliacao-tecnica.destroy', $avaliacao->id) }}"
                                        method="POST" class="d-inline"
                                        onsubmit="return confirm('Tem certeza que deseja excluir esta avaliação?');">
                                        @csrf
                                        @method('DELETE')
                                        <button type="submit" class="btn btn-danger" title="Excluir">
                                            <i class="fa-solid fa-trash"></i>
                                        </button>
                                    </form>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection
