<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <meta name="site" content="https://angra.rj.gov.br">

    <title><?php echo $__env->yieldContent('title'); ?></title>

    <meta name="description" content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade."/>
    <meta name="robots" content="noodp"/>

    <link rel="canonical" href="https://www.angra.rj.gov.br" />

    <meta property="og:locale" content="pt_BR" />
    <meta property="og:type" content="government" />
    <meta property="og:title" content="Prefeitura de Angra dos Reis" />
    <meta property="og:description" content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informa&ccedil;&otilde;es sobre as a&ccedil;&otilde;es, pol&iacute;ticas p&uacute;blicas, turismo e servi&ccedil;os em prol da cidade." />
    <meta property="og:url" content="https://www.angra.rj.gov.br" />
    <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
    <meta property="og:image"content="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png"/>

    <meta http-equiv="cache-control" content="max-age=0" />
    <meta http-equiv="cache-control" content="no-cache" />
    <meta http-equiv="expires" content="0" />
    <meta http-equiv="expires" content="Tue, 01 Jan 2977 1:00:00 GMT" />
    <meta http-equiv="pragma" content="no-cache" />

    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-57x57-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-60x60-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-72x72-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-76x76-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-114x114-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-120x120-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-144x144-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-152x152-2026.png")); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset("pmar/assets/fiveicon/apple-icon-180x180-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="192x192"  href="<?php echo e(asset("pmar/assets/fiveicon/android-icon-192x192-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-32x32-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-96x96-2026.png")); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset("pmar/assets/fiveicon/favicon-16x16-2026.png")); ?>">
    <link rel="manifest" href="<?php echo e(asset("pmar/assets/fiveicon/manifest.json")); ?>">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="<?php echo e(asset("pmar/assets/fiveicon/ms-icon-144x144-2026.png")); ?>">
    <meta name="theme-color" content="#ffffff">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    
    <link rel="stylesheet" href="<?php echo e(asset('pmar/build/bootstrap/css/bootstrap.min.css')); ?>">
    <link href='https://unpkg.com/boxicons@2.0.7/css/boxicons.min.css' rel='stylesheet'>
    
    <script src="<?php echo e(asset('pmar/build/bootstrap/js/bootstrap.bundle.min.js')); ?>"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
    
    <link rel="stylesheet" href="<?php echo e(asset('pmar/build/fontawesome/css/all.min.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/style.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(route('temas.css', ['scope' => 'admin'])); ?>?v=<?php echo e(time()); ?>">
    <link rel="stylesheet" href="<?php echo e(route('temas.dark-mode.css', ['scope' => 'admin'])); ?>?v=<?php echo e(time()); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/menu.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/admin.css')); ?>?v=<?php echo e(@filemtime(public_path('pmar/css/admin.css')) ?: time()); ?>">
    <style>
        .modal-backdrop {
            z-index: 9998 !important;
            pointer-events: auto !important;
            position: fixed !important;
        }
        .modal-backdrop.show {
            opacity: var(--bs-backdrop-opacity);
            z-index: 9998 !important;
            pointer-events: auto !important;
            position: fixed !important;
        }
        .modal {
            z-index: 9999 !important;
            position: fixed !important;
        }
        .modal.show {
            z-index: 9999 !important;
            position: fixed !important;
        }
        .modal-dialog {
            z-index: 9999 !important;
            pointer-events: auto !important;
            position: relative !important;
        }
        .modal-content {
            z-index: 9999 !important;
            pointer-events: auto !important;
            position: relative !important;
        }
    </style>
    <?php if(in_array(Route::currentRouteName(), [
        'admin.visiteAngra.pontos.create',
        'admin.visiteAngra.pontos.edit',
        'admin.visiteAngra.atrativos.create',
        'admin.visiteAngra.atrativos.edit',
        'admin.guias.create',
        'admin.guias.edit',
        'admin.empresas.create',
        'admin.empresas.edit',
        'admin.empresasDeTurismo.endereco',
        'admin.empresasDeTurismo.create',
        'admin.contas.enderecos.create',
        'admin.contas.enderecos.edit',
        'admin.perfilEnderecos.create',
        'admin.perfilEnderecos.edit',
        'admin.saude.fibromialgia.endereco',
        'admin.cultura.credenciamentoMusicos.endereco',
        'admin.meioAmbiente.castracaoAnimal.tutores.create',
        'admin.meioAmbiente.castracaoAnimal.tutores.edit',
        'admin.acaoSocial.centrosDeReferencia.create',
        'admin.acaoSocial.centrosDeReferencia.edit',
        'admin.turisAngra.fluxoDeOnibus.onibusTurismo.endereco',
        'admin.escolas.create',
        'admin.escolas.edit',
        'admin.projetosProgramas.create',
        'admin.projetosProgramas.identificacao',
    ])): ?>
    <link rel="stylesheet" href="https://unpkg.com/leaflet/dist/leaflet.css"/>
    <style>
        #map {
            width: 100%;
            height: 400px;
        }
    </style>
    <?php endif; ?>
    <?php if(in_array(Route::currentRouteName(), [
        'admin.escolas.create',
        'admin.escolas.edit',
        'admin.projetosProgramas.create',
        'admin.projetosProgramas.identificacao',
    ])): ?>
    <link rel="stylesheet" href="<?php echo e(asset('pmar/css/admin/escolas/escolas-admin.css')); ?>">
    <?php endif; ?>
    <?php if(in_array(Route::currentRouteName(), [
        'admin.empresas.create',
        'admin.empresas.edit',
        'admin.turismoNautico.embarcacoes.create',
        'admin.turismoNautico.embarcacoes.edit',
        'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioIndex',
        'admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioStore',
        'admin.dividaAtiva.create',
        'admin.dividaAtiva.edit',
        'admin.empresasDeTurismo.endereco',
        'admin.empresasDeTurismo.create',
        'admin.turisAngra.fluxoDeOnibus.onibusTurismo.create',
    ])): ?>
    <link rel="stylesheet" href="https://code.jquery.com/ui/1.13.2/themes/base/jquery-ui.css">
    <style>
        .ui-datepicker-current { display: none;  }
        .ui-datepicker-calendar, .ui-datepicker-month { display: none; }
    </style>
    <?php endif; ?>
    <?php echo $__env->yieldPushContent('styles'); ?>
    <?php echo $__env->yieldPushContent('scripts'); ?>


</head>
<?php /**PATH /var/www/html/portal/resources/views/layouts/admin/elements/head.blade.php ENDPATH**/ ?>