@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção")
@section('content')

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.index") }}">{{ __("Concursos Públicos e Processos de Seleção") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">{{ __("Andamento") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Editais de Convocações") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: {{ $concurso->ds_ano }}</h1>

                    <hr>

                    <h3 class="top30">EDITAIS DE CONVOCAÇÕES</h3>

                    <table class="table">
                        <thead>
                            <tr>
                                <th width="20%">Publicação</th>
                                <th width="60%" class="centro">Cargo</th>
                                <th width="20%" class="centro">Data de apresentação</th>
                            </tr>
                        </thead>

                        <tbody>
                            @foreach($editais as $edital)
                                <tr>
                                    <td class="centro">{{ date("d/m/Y", strtotime($edital->dt_publicacao)) }}</td>
                                    <td class="centro">
                                        <a href="{{ url("/concursos/" . $edital->nm_arquivo) }}">
                                            {{ $edital->ds_link_arquivo }}
                                        </a>
                                    </td>
                                    <td class="centro">{!! $edital->ds_apresentacao !!}</td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>


                </div>
            </div>
        </div>
    </section>


@endsection