@extends('layouts.sei.theme')
@section("title", "SEI - Angra dos Reis")
@section('content')
    @include('sei.sections.bannerEmergencial')
    @include('sei.sections.sectionApresentacao')
    @include('sei.sections.consulta')
    @include('sei.sections.features')
    @include('sei.sections.testimonial')
    @include('sei.sections.capacitacao')
    @include('sei.sections.asideCadastrarse')
    @include('sei.sections.pontosFocais')
    @include('sei.sections.perguntas')
    @include('sei.sections.legislacao')
    @include('sei.sections.atasComite')
    @include('sei.sections.cta')
    @include('sei.sections.suporte')
@endsection
