@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Eventos - Credenciamento'))
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-calendar'></i> " . __('Eventos - Credenciamento'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.cultura.credenciamentoMusicos.index',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.cultura.credenciamentoMusicos.eventos.create',
            'routeAddParams' => [],
            'nameAdd' => __('Novo evento'),
            'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            <div class="mb-2">
                <a class="btn btn-outline-secondary btn-sm" href="{{ route('admin.cultura.credenciamentoMusicos.convocacoes.index') }}">{{ __('Convocações') }}</a>
            </div>
            <x-tables._table :thead="[__('Nome'), __('Categoria'), __('Data'), __('Ativo'), __('Ações')]" :pagination="$eventos->links()">
                <x-slot name="body">
                    @foreach($eventos as $evento)
                        <tr>
                            <td>{{ $evento->nome }}</td>
                            <td>{{ $evento->categoria ?? '–' }}</td>
                            <td>{{ $evento->data ? $evento->data->format('d/m/Y') : '–' }}</td>
                            <td>
                                @if($evento->ativo)
                                    <span class="badge bg-success">{{ __('Sim') }}</span>
                                @else
                                    <span class="badge bg-secondary">{{ __('Não') }}</span>
                                @endif
                            </td>
                            <td>
                                <div class="btn-group">
                                    @include('components.buttons._navButton', [
                                        'route' => 'admin.cultura.credenciamentoMusicos.convocacoes.show',
                                        'id' => $evento->id,
                                        'fontawesome' => '<i class="fa-solid fa-list"></i>',
                                        'title' => __('Convocações'),
                                        'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
                                    ])
                                    @include('components.buttons._editButton', [
                                        'route' => 'admin.cultura.credenciamentoMusicos.eventos.edit',
                                        'id' => $evento->id,
                                        'title' => __('Editar'),
                                        'fontawesome' => null,
                                        'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
                                    ])
                                    @include('components.buttons._deleteButton', [
                                        'message' => __('Excluir este evento e suas convocações?'),
                                        'route' => 'admin.cultura.credenciamentoMusicos.eventos.destroy',
                                        'id' => $evento->id,
                                        'title' => __('Excluir'),
                                        'fontawesome' => null,
                                        'permission' => 'GERENCIADOR_CREDENCIAMENTO_DE_MUSICOS',
                                    ])
                                </div>
                            </td>
                        </tr>
                    @endforeach
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection
