@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Política de Privacidade')
@section('content')
<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a href="{{ route('paginas.home') }}">Portal</a>
                        </li>
                        <li class="breadcrumb-item">
                            <a href="{{ route('paginas.protecao-de-dados-lgpd') }}">Proteção de Dados - LGPD</a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">Política de Privacidade</li>
                    </ol>
                </nav>
            </div>
            <div id="conteudo" class="content mediapress">
                <div class="col-12">
                    <header class="article-header">
                        <h1 class="title">Política de Privacidade</h1>
                    </header>
                    <article class="article-main">
                        <p style="color: #8F8F8F;">
                            <small><strong>Versão 3.0</strong>, 09/05/2025</small>
                        </p>
                        <p>
                            A Prefeitura Municipal de Angra dos Reis torna pública, por meio de seu sítio eletrônico, 
                            a sua <strong>Política de Privacidade e Segurança</strong> em sua versão 3.0, elaborada em 
                            conformidade com as Leis Federais nº 
                            <a href="http://www.planalto.gov.br/ccivil_03/_ato2011-2014/2014/lei/l12965.htm" target="_blank">
                                <strong>12.965/2014</strong>
                            </a> e nº 
                            <a href="http://www.planalto.gov.br/ccivil_03/_Ato2019-2022/2019/Lei/L13853.htm#art1" target="_blank">
                                <strong>13.853/2019</strong>
                            </a>.
                        </p>
                        <h3 class="my-4">1. Política de Privacidade</h3>
                        <p>
                            Nesta Política de Privacidade, o usuário dos serviços (sítio eletrônico, softwares e, ainda, 
                            outros formatos de suporte de coleta de dados, sendo eles físicos ou não, utilizados por esta 
                            Prefeitura) encontrará esclarecimentos sobre o funcionamento do serviço e as regras aplicáveis 
                            a ele, a forma como são coletadas e tratadas as informações.
                        </p>
                        <p>
                            Ao utilizar os serviços, o usuário confirma que leu e compreendeu os Termos e Políticas aplicáveis 
                            ao serviço e concorda com eles.
                        </p>
                        <p class="my-3">
                            <strong>1.1.</strong> Esta Política de Privacidade também se aplica aos aplicativos CIOSP ANGRA, 
                            GOP ANGRA, Defesa Civil e Comunidades de Angra, desenvolvidos e mantidos pela Prefeitura Municipal 
                            de Angra dos Reis (PMAR), inscrita no CNPJ sob o nº 29.172.467/0001-09, como parte dos serviços 
                            digitais oferecidos ao servidor público e ao cidadão.
                        </p>
                        <h3 class="my-4">2. Quem é o titular dos dados pessoais?</h3>
                        <p>
                            O titular dos dados pessoais é a pessoa natural (pessoa física) a quem pertencem os dados pessoais 
                            que são objeto de tratamento, ou seja, que são utilizados.
                        </p>
                        <h3 class="my-4">3. Quem é o Controlador?</h3>
                        <p>
                            O Controlador é a Prefeitura Municipal de Angra dos Reis, pessoa jurídica de direito público, tendo 
                            suas atividades legalmente formalizadas sob forma de lei e inscrição do CNPJ sob número 
                            29.172.467/0001-09, doravante denominada <strong>PMAR</strong>. A <strong>PMAR</strong> compromete-se 
                            com a transparência do tratamento de dados pessoais da pessoa natural.
                        </p>
                        <h3 class="my-4">4. Quais dados coletamos sobre você e para qual finalidade?</h3>
                        <p>
                            <strong>4.1</strong> A <strong>PMAR</strong>, totalmente qualificada no <strong>item 3</strong> desta 
                            Política de Privacidade e Segurança, disponibiliza a sua Lei de Acesso à Informação (LAI) para todos 
                            os interessados em saber quais dados são coletados, a forma de coleta e como são tratados e utilizados 
                            por meio do sítio eletrônico no seguinte link: 
                            <a href="https://www.angra.rj.gov.br/downloads/Transparencia/SIC/Decreto9.151-2014-LAI.pdf" target="_blank">
                                <strong>https://www.angra.rj.gov.br/downloads/Transparencia/SIC/Decreto9.151-2014-LAI.pdf</strong>
                            </a>
                        </p>
                        <p class="mt-3"><strong>4.2 Uso de Localização:</strong></p>
                        <ul>
                            <li>
                                Aplicativos municipais como <strong>'CIOSP ANGRA'</strong> acessam a localização do dispositivo 
                                ('Location'), inclusive em segundo plano, com a finalidade de validar a presença dos agentes nos 
                                postos de trabalho;
                            </li>
                            <li>
                                Esse uso garante o controle e o registro preciso das operações durante os plantões, mesmo quando 
                                o app não está visível ao usuário.
                            </li>
                            <li>
                                A coleta da localização é feita somente com o consentimento do usuário, é usada exclusivamente 
                                para fins operacionais da administração pública municipal e não é compartilhada com terceiros.
                            </li>
                            <li>
                                O usuário pode, a qualquer momento, revogar a permissão de localização nas configurações do 
                                dispositivo. No entanto, ao fazer isso, certas funcionalidades essenciais do aplicativo podem 
                                deixar de funcionar corretamente.
                            </li>
                        </ul>
                        <h3 class="my-4">5. Consentimento</h3>
                        <p>
                            O consentimento é a manifestação livre, informada e inequívoca pela qual você autoriza a 
                            <strong>PMAR</strong> a tratar seus dados. Assim, em consonância com a Lei Geral de Proteção de Dados, 
                            seus dados só serão coletados, tratados e armazenados mediante prévio e expresso consentimento.
                        </p>
                        <p>
                            O consentimento será obtido de forma específica a fim de atender a finalidade para qual o dado tratado 
                            é destinado, evidenciando o compromisso de transparência e boa-fé da <strong>PMAR</strong>.
                        </p>
                        <p>
                            Ao utilizar os serviços da <strong>PMAR</strong> e fornecer seus dados pessoais, você está ciente e 
                            consentindo com as disposições desta Política de Privacidade e Segurança, de seus direitos e de como 
                            exercê-los.
                        </p>
                        <p>
                            A qualquer tempo e sem nenhum custo, você poderá revogar seu consentimento, porém isto poderá 
                            impossibilitar a entrega de alguns serviços online que requeiram tratamentos de dados. Neste caso, 
                            os serviços deverão ser solicitados diretamente no órgão competente, via formulário ou outro meio 
                            de suporte existente.
                        </p>
                        <h3 class="my-4">6. Quais são os seus direitos?</h3>
                        <p>
                            A Lei Geral de Proteção de Dados em seu artigo 18º trata sobre os direitos que a pessoa natural tem 
                            quanto aos seus dados junto ao Controlador, no caso, a PMAR, são eles:
                        </p>
                        <ul class="olist_normal">
                            <li><strong>6.1.</strong> Saber se há, por parte do Controlador, a existência de tratamento dos dados.</li>
                            <li><strong>6.2.</strong> Solicitar junto ao Controlador o acesso aos seus dados pessoais sem custos.</li>
                            <li><strong>6.3.</strong> A correção desses dados, caso estejam incompletos, inexatos ou desatualizados.</li>
                            <li><strong>6.4.</strong> No caso da existência de dados, conhecer se seus dados foram:</li>
                        </ul>
                        <ul class="olist_normal">
                            <li><strong>Anonimizados:</strong> é o tipo de tratamento que é possível conhecer pessoa natural por meio de informações generalizadas ou incompletas.</li>
                            <li><strong>Bloqueio ou Eliminação:</strong> conhecer se o controlador identificou dados desnecessários em seu tratamento a qual ocorreu bloqueio ou eliminação.</li>
                            <li><strong>Portabilidade de Dados:</strong> sempre que o controlador disponibilizar algum serviço para mais de um fornecedor, o titular dos dados poderá solicitar a portabilidade dos dados mediante solicitação expressa ou de acordo com regulamentação da Autoridade Nacional de Proteção de Dados.</li>
                        </ul>
                        <p>
                            <strong>6.5.</strong> O titular dos dados poderá solicitar sua eliminação, mediante requerimento expresso, exceto nas hipóteses previstas no artigo 16º da Lei Geral de Proteção de Dados, que diz:
                        </p>
                        <ol class="olist_normal" type="I">
                            <li>cumprimento de obrigação legal ou regulatória pelo controlador;</li>
                            <li>estudo por órgão de pesquisa, garantida, sempre que possível, a anonimização dos dados pessoais;</li>
                            <li>transferência a terceiro, desde que respeitados os requisitos de tratamento de dados dispostos nesta Lei; ou</li>
                            <li>uso exclusivo do controlador, vedado seu acesso por terceiro, e desde que anonimizados os dados.</li>
                        </ol>
                        <p>
                            <strong>6.6.</strong> Solicitar junto ao Controlador informações públicas e privadas inerentes a sua pessoa, caso tenha sido realizado compartilhamento de seus dados.
                        </p>
                        <p>
                            <strong>6.7.</strong> No caso da pessoa natural não fornecer consentimento sobre o tratamento de seus dados, o direito de obter junto ao Controlador as informações sobre as consequências dessa negativa.
                        </p>
                        <h3 class="my-4">7. Como e por quanto tempo seus dados serão armazenados?</h3>
                        <p>
                            Os dados pessoais coletados de pessoas naturais pela <strong>PMAR</strong> são coletados mediante Lei e finalidade pública, a fim de oferecer o melhor serviço ao cidadão de Angra dos Reis.
                        </p>
                        <p>
                            O tempo necessário para a prestação dos serviços e para atender as finalidades públicas e sociais será previsto em duas situações:
                        </p>
                        <ul class="olist_normal">
                            <li>O tempo determinado em lei;</li>
                            <li>Caso exista a necessidade de manter esses dados para atender políticas públicas, será informado no momento da coleta e tratamento de dados.</li>
                        </ul>
                        <h3 class="my-4">8. O que fazemos para manter seus dados seguros?</h3>
                        <p>
                            Para manter suas informações pessoais seguras, usa-se ferramentas físicas, eletrônicas e gerenciais orientadas para a proteção da privacidade.
                        </p>
                        <p>
                            Aplica-se estas ferramentas levando em consideração a natureza dos dados pessoais coletados, o contexto e a finalidade do tratamento e os riscos que eventuais violações gerariam para os direitos e liberdades do titular dos dados coletados e tratados.
                        </p>
                        <p>
                            Entre as medidas adotadas, destacamos as seguintes:
                        </p>
                        <ul class="olist_normal">
                            <li>Apenas pessoas autorizadas têm acesso a seus dados pessoais;</li>
                            <li>O acesso aos dados pessoais é feito somente após o compromisso de confidencialidade;</li>
                            <li>Seus dados pessoais são armazenados em ambiente seguro e idôneo.</li>
                        </ul>
                        <p>
                            A <strong>PMAR</strong> se compromete a adotar as melhores posturas para evitar incidentes de segurança, contudo é necessário destacar que, nenhuma página virtual é inteiramente segura e livre de riscos.
                        </p>
                        <p>
                            Em caso de incidentes de segurança que possam gerar risco ou dano relevante ao titular dos dados, os afetados e a Autoridade Nacional de Proteção de Dados serão notificados, em consonância com as disposições da Lei Geral de Proteção de Dados.
                        </p>
                        <h3 class="my-4">9. Cookies ou dados de navegação</h3>
                        <p>
                            A <strong>PMAR</strong> faz uso de Cookies, que são arquivos de texto enviados pela plataforma ao seu computador e que nele se armazenam, e que contém informações relacionadas à navegação do site. Em suma, os Cookies são utilizados para aprimorar a experiência de uso.
                        </p>
                        <p>
                            Ao acessar nosso site e consentir com o uso de Cookies, você manifesta conhecer e aceitar a utilização de um sistema de coleta de dados de navegação com o uso de Cookies em seu dispositivo.
                        </p>
                        <p>
                            A <strong>PMAR</strong> utiliza os seguintes Cookies: Cookie para salvar Tema Noturno ou Tema Padrão do Portal da Prefeitura de Angra dos Reis, que é um dos recursos de Acessibilidade do sítio eletrônico.
                        </p>
                        <p>
                            Você pode, a qualquer tempo e sem nenhum custo, alterar as permissões, bloquear ou recusar os Cookies em seu próprio navegador.
                        </p>
                        <p>
                            Para gerenciar os cookies do seu navegador, basta fazê-lo diretamente nas configurações do navegador, na área de gestão de Cookies. Você pode acessar tutoriais sobre o tema diretamente nos links abaixo:
                        </p>
                        <ul class="olist_normal">
                            <li>Se você usa o Internet Explorer: <a href="https://support.microsoft.com/pt-br/help/17442/windows-internet-explorer-delete-manage-cookies" target="_blank"><strong>https://support.microsoft.com/pt-br/help/17442/windows-internet-explorer-delete-manage-cookies</strong></a></li>
                            <li>Se você usa o Firefox: <a href="https://support.mozilla.org/pt-BR/kb/gerencie-configuracoes-de-armazenamento-local-de-s" target="_blank"><strong>https://support.mozilla.org/pt-BR/kb/gerencie-configuracoes-de-armazenamento-local-de-s</strong></a></li>
                            <li>Se você usa o Safari: <a href="https://support.apple.com/pt-br/guide/safari/sfri11471/mac" target="_blank"><strong>https://support.apple.com/pt-br/guide/safari/sfri11471/mac</strong></a></li>
                            <li>Se você usa o Google Chrome: <a href="https://support.google.com/chrome/answer/95647?co=GENIE.Platform%3DDesktop&oco=1&hl=pt-BR" target="_blank"><strong>https://support.google.com/chrome/answer/95647?co=GENIE.Platform%3DDesktop&amp;oco=1&amp;hl=pt-BR</strong></a></li>
                            <li>Se você usa o Microsoft Edge: <a href="https://support.microsoft.com/pt-br/help/4027947/microsoft-edge-delete-cookies" target="_blank"><strong>https://support.microsoft.com/pt-br/help/4027947/microsoft-edge-delete-cookies</strong></a></li>
                            <li>Se você usa o Opera: <a href="https://help.opera.com/en/latest/web-preferences/#cookies" target="_blank"><strong>https://help.opera.com/en/latest/web-preferences/#cookies</strong></a></li>
                        </ul>
                        <h3 class="my-4">10. Transferência internacional de dados</h3>
                        <p>
                            A <strong>PMAR</strong> se reserva no direito de transferência de dados internacionais com base na Lei Geral de Proteção de Dados, em seu artigo 33º. Sendo assim, não existe outra forma de fazê-lo, salvo previsão legal expressa na LAI Municipal, nº 9.151, de 03 de janeiro de 2014, para suprimir lacunas da LAI Federal, Lei nº 12.527, de 18 de novembro de 2011.
                        </p>
                        <p>
                            Nesse sentido, a <strong>PMAR</strong> se compromete a sempre adotar eficientes padrões de segurança cibernética e de proteção de dados, nos melhores esforços de garantir e cumprir as exigências legislativas.
                        </p>
                        <h3 class="my-4">11. Alteração da Política de Privacidade</h3>
                        <p>
                            A atual versão da Política de Privacidade foi formulada em: 11 de agosto de 2022.
                        </p>
                        <p>
                            A <strong>PMAR</strong> poderá modificar essa Política de Privacidade a qualquer tempo, principalmente em função da adequação a eventuais alterações feitas no site ou em âmbito legislativo.
                        </p>
                        <p>
                            Recomenda-se que você a revise com frequência.
                        </p>
                        <p>
                            Eventuais alterações entrarão em vigor a partir de sua publicação no site e sempre serão notificadas.
                        </p>
                        <p>
                            Ao utilizar os serviços e fornecer seus dados pessoais após tais modificações, você as consente.
                        </p>
                        <h3 class="my-4">12. Responsabilidade</h3>
                        <p>
                            A <strong>PMAR</strong> prevê a responsabilidade dos agentes que atuam nos processos de tratamento de dados, em conformidade com os artigos 42 ao 45 da Lei Geral de Proteção de Dados.
                        </p>
                        <p>
                            A <strong>PMAR</strong> se compromete em manter esta Política de Privacidade atualizada, observando suas disposições e zelando por seu cumprimento. Assume, ainda, o compromisso de buscar condições técnicas e organizativas seguramente aptas a proteger todo o processo de tratamento de dados, e, se compromete a tomar as providências exigidas pela Autoridade Nacional de Proteção de Dados, em relação ao tratamento de dados.
                        </p>
                        <h3 class="my-4">13. Encarregado de Proteção de Dados</h3>
                        <p>
                            A PMAR disponibiliza o <strong>Canal de Ouvidoria Externa – Fala.Br</strong>, cuja sua principal finalidade é esclarecer quaisquer dúvidas inerentes às informações que coletamos e a forma que tratamos essas informações.
                        </p>
                        <p>
                            Para acessar o <strong>Canal de Ouvidoria Externa – Fala.Br</strong>, visite o sítio eletrônico da PMAR em seu link: 
                            <a href="https://www.angra.rj.gov.br/ouvidoria.asp?IndexSigla=sgri" target="_blank">
                                <strong>https://www.angra.rj.gov.br/ouvidoria.asp?IndexSigla=sgri</strong>
                            </a>
                        </p>
                        <div class="bottom20"></div>
                    </article>
                </div>
            </div>
        </div>
    </div>
</section>
@endsection
