<div>
    <h3 class="text-center">
        <button type="button" data-bs-toggle="collapse" data-bs-target="#collapseDois" aria-expanded="false" aria-controls="collapseDois" class="border-0 bg-white">
            <strong>{{ __("Pareceres") }}</strong>
            <i class="bi bi-chevron-down"></i>
        </button>
    </h3>    
    
    <div>
        @php

            $array_pareceres = [
                
                [
                    'url' => __('http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162463'),
                    'target' => __('_blank'),
                    'nome' => __('Parecer 1'),
                    'data' => __('de 30 de Outubro de 2024'),
                    'fontawesome' => __('<i class="bi-save2-fill me-2"></i></strong></a>'),

                    ],

            ];

        @endphp

        @forelse($array_pareceres as $pareceres)
            @include('components/lists/_divLinkPareceres', $pareceres)
        @empty
            <div class="mt-5 mb-3">
            <p class="fw-normal text-muted mb-lg-0">
                {{ __("Nenhum parecer encontrado") }}<br>
            </p>
        </div>
        @endforelse
    </div>
</div>