@foreach($paineis as $pane)
<li class="nav-item-fibromialgia me-2" role="presentation">
    <button class="nav-link {{$pane['class']}}" id="{{$pane['id']}}" href="#{{$pane['hash']}}"
        data-bs-toggle="tab" data-bs-target="#{{$pane['target']}}" type="button" role="tab"
        aria-controls="{{$pane['aria1']}}" aria-selected="{{$pane['aria2']}}"><label for="{{$pane['for']}}"
        class="form-label text-bold">{{$pane['label']}}:</label></button>
</li>
@endforeach
