@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Chamados - Página de Acompanhamento")
@section('content')

<div class="card shadow">

    @php $headLine = "<i class='fa-solid fa-headset'></i> Chamados - Página de Acompanhamento"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
        'headLine' => __($headLine),
        'routeBack' => 'admin.contaAngra.chamados.index',
        'routeBackParams' => [], 
        'nameBack' => __("Voltar"),
        "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
    ])

    <div class="card-body">


        @include("errors.messageFlash")
        @include('components.modal._modelProfile')

        <div class="tab-content">

            @foreach($mensagens as $mensagem)
                @if($mensagem->solicitacao)

                    <div class="row">
                        <div class="col-12">
                            <ul class="list-group">
                                <li class="list-group-item bg-dark text-white"><h3>{{ __("Data") }}: {{ date("d/m/Y H:i", strtotime($chamado->created_at)) }}</h3></li>
                                <li class="list-group-item"><strong>{{ __("Solicitação") }}</strong>: {{ $chamado->numeroChamado }}</li>
                                <li class="list-group-item"><strong>{{ __("Criado por") }}</strong>: {{ $chamado->user->name }}</li>
                                <li class="list-group-item"><strong>{{ __("Demanda iniciada em") }}</strong>: {{ $chamado->convenio }}</li>
                                <li class="list-group-item"><strong>{{ __("Estado atual da demanda") }}</strong>: {{ $chamado->convenioAtual }}</li>
                                <li class="list-group-item"><strong>{{ __("Assunto") }}</strong>: {{ $chamado->assunto }}</li>
                                <li class="list-group-item"><strong>{{ __("Solicitação") }}</strong>: {!! $mensagem->mensagem !!}</li>
                                <li class="list-group-item"><strong>{{ __("Status") }}</strong>: {{ $chamado->statusChamado }}</li>
                                @php $index = 0; @endphp
                                @foreach($mensagem->arquivos as $arquivo)
                                    <li class="list-group-item">
                                        
                                        @include('components.tables._openPhotoAndPdf', [
                                            'asset' => $arquivo->link,
                                            'alt' => $arquivo->nome,
                                            'title' => $arquivo->nome,
                                            'text' => $arquivo->nome,
                                            'index' => $index,
                                        ])
                                    
                                    </li>
                                    @php $index++; @endphp
                                @endforeach
                            </ul>
                            <hr/>
                        </div>
                    </div>

                @endif
            @endforeach

            @foreach($mensagens as $mensagem)
                @if(!$mensagem->solicitacao)

                    <div class="row">
                        <div class="col-12">
                            <ul class="list-group">
                                <li class="list-group-item bg-dark text-white"><h3>{{ __("Data") }}: {{ date("d/m/Y H:i", strtotime($mensagem->created_at)) }}</h3></li>
                                <li class="list-group-item"><strong>{{ __("Criado por") }}</strong>: {{ $mensagem->user->name }}</li>
                                <li class="list-group-item"><strong>{{ __("Mensagem") }}</strong>: {!! $mensagem->mensagem !!}</li>
                                @php $index = 100; @endphp
                                @foreach($mensagem->arquivos as $arquivo)
                                    <li class="list-group-item">
                                        
                                        @include('components.tables._openPhotoAndPdf',[
                                            'asset' => $arquivo->link,
                                            'alt' => $arquivo->nome,
                                            'title' => $arquivo->nome,
                                            'text' => $arquivo->nome,
                                            'index' => $index,
                                        ])
                                    
                                    </li>
                                    @php $index++; @endphp
                                @endforeach
                            </ul>
                            <hr/>
                        </div>
                    </div>

                @endif
            @endforeach

            @if($chamado->statusChamado != "Finalizado")
                <form action="{{ route("admin.contaAngra.chamados.novaMensagem", $chamado->id) }}" method="post" enctype="multipart/form-data">
                    <div class="row">
                        <div class="col-12  text-wrap">

                            @csrf
                            @method('post')

                            <!-- Nova mensagem -->
                            @include('components.inputs._textarea', [
                                'label' => 'Nova mensagem',
                                'name' => 'mensagem',
                                'id' => 'limiteCaracter',
                                'rows' => 5,
                                'required' => true,
                                'height' => '200px',
                                'class' => "textarea-body",
                                'style' => null,
                                "oninput" => null,
                                'value' => old('mensagem'),
                                'small' => null,
                            ])
                        </div>
                        <div class="col-12">
                            <!-- Campo Arquivos -->
                            @include('components.inputs._inputType',[
                                "for" => "link",
                                "label" => "Arquivos",
                                "name" => "link[]",
                                "id" => 'link',
                                "required" => false,
                                "type" => 'file',
                                "old" => null,
                                "oninput" => null,
                                "readonly" => true,
                                "multiple" => true,
                                "small" => "* Apenas documentos de imagem: PDF, JPG, JPEG, PNG, GIF, BMP, WEBP.",
                                "accept" => 'application/pdf,image/*',
                            ])
                        </div>
                        <div class="col-12 mb-3">
                           <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="finalizado" id="finalizado"
                                       value="1"
                                       {{ old('finalizado', $finalizado ?? false) ? 'checked' : '' }}>
                                <label class="form-check-label" for="finalizado">
                                    {{ __("Sim, desejo finalizar minha solicitação") }}
                                </label>
                            </div>
                        </div>
                        <div class="col-12 mb-3">
                            @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar', 
                                'textSend' => 'Nova mensagem', 
                                'routeBack' => 'admin.contaAngra.chamados.index'
                            ])
                        </div>
                    </div>
                </form>
            @endif
            
        </div>
    </div>
</div>

@endsection