@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Licenciamento')
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Licenciamento</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <div id="conteudo" class="content mediapress">
                        <section class="col-md-9 nopadding single-article espaco_conteudo">
                            <header class="article-header mb-4">
                                <!-- Title -->
                                <h1 class="title">Licenciamento</h1>
                                <!-- Excerpt -->
                            </header>
                            <article class="article-main">
                                <table width="100%" class="table mb-4">
                                    <thead>
                                        <tr>
                                            <th width="11%">TIPO</th>
                                            <th width="9%">N&ordm;</th>
                                            <th width="14%">DATA</th>
                                            <th width="48%">RESUMO</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>3469</strong></td>
                                        <td>20/01/2016</td>
                                        <td>Institui o programa municipal Nossa Cidade Legal e d&aacute; outras
                                            provid&ecirc;ncias.</td>
                                        <td><a href="downloads/SMA/leis/3.469-2016.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 135kb.</a></td>
                                    </tr>
                                    <tr class="color-table">
                                        <td>Lei</td>
                                        <td><strong>3419</strong></td>
                                        <td>11/11/2015</td>
                                        <td>Institui a Outorga Onerosa do direito de construir, a Outorga Onerosa de
                                            altera&ccedil;&atilde;o de uso, altera dispositivos da Lei de Zoneamento
                                            Municipal
                                            N&ordm; 2.091/2009, da Lei de Uso e Ocupa&ccedil;&atilde;o do Solo N&ordm;
                                            2.092/2009 e d&aacute; outras provid&ecirc;ncias.</td>
                                        <td><a href="downloads/SMA/leis/3.419-2015.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 181kb.</a></td>
                                    </tr>

                                    <!--            <tr>
                                          <td rowspan="5">Decreto</td>
                                          <td rowspan="5"><strong>9767</strong></td>
                                          <td rowspan="5">24/07/2015</td>
                                          <td>Estabelece  no &acirc;mbito do licenciamento urban&iacute;stico e ambiental, modelos de requerimento,  documenta&ccedil;&atilde;o e procedimentos administrativos adotados no munic&iacute;pio de Angra dos  Reis.</td>
                                          <td><a href="downloads/SMA/leis/9.767-2015.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 144kb.</a></td>
                                        </tr>
                                       <tr>
                                          <td rowspan="4"> </td>
                                          <td rowspan="4"> </td>
                                          <td rowspan="4"> </td>
                              
                                                          
                                                          <td>Anexo II - Requerimento  de licenciamento de constru&ccedil;&atilde;o/regulariza&ccedil;&atilde;o de edifica&ccedil;&atilde;o e declara&ccedil;&atilde;o de  responsabilidade.</td>
                                          <td><a href="downloads/SMA/leis/ANEXO_II_r3.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 132kb.</a></td>
                                        </tr>
                                        <tr>
                                          <td>Anexo III - Requerimento de licenciamento de atividade e declara&ccedil;&atilde;o de responsabilidade.</td>
                                          <td><a href="downloads/SMA/leis/9.767-2015-Anexo III.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 177kb.</a></td>
                                        </tr>
                                        <tr>
                                          <td>Anexo IV - Documentos necess&aacute;rios para abertura de processo.</td>
                                          <td><a href="downloads/SMA/leis/9.767-2015-Anexo IV.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 95kb.</a></td>
                                        </tr>
                                        <tr>
                                          <td>Anexo VI - Modelo de publica&ccedil;&atilde;o no Boletim Oficial do Munic&iacute;pio.</td>
                                          <td><a href="downloads/SMA/leis/9.767-2015-Anexo VI.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 65kb.</a></td>
                                        </tr>-->
                                </table>
                                <h3 class="top25">Legisla&ccedil;&atilde;o</h3>
                                <div class="list_down">
                                    <ul>
                                        <li>
                                            <a href="downloads/SMA/Lei Org&acirc;nica do Municipio.htm"
                                                target="_blank"><img
                                                src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                alt="Baixar arquivo" width="18" height="18" border="0"><strong>Lei Org&acirc;nica - Publicada no D.O.R.J. em
                                                    05/04/90</strong> <br>
                                            </a>
                                            <span class="preto">O Munic&iacute;pio de Angra dos Reis &eacute; uma unidade
                                                do territ&oacute;rio do Estado do Rio de Janeiro, com autonomia
                                                pol&iacute;tica, legislativa, administrativa e financeira,
                                                regendo-se por
                                                esta Lei Org&acirc;nica, respeitados os princ&iacute;pios
                                                estabelecidos nas
                                                Constitui&ccedil;&otilde;es Federal e Estadual.
                                            </span>                 
                                        </li>
                                    </ul>
                                </div>
                                <div class="bottom30"></div>
                                <h3 class="top25">Zoneamento - Mapas do Google Earth</h3>
                                <p>Para visualizar os arquivos é necessário ter o programa <B>Google Earth</B> instalado
                                    na
                                    máquina. Para obter a informação de qual zona se trata, o usuário poderá clicar
                                    sobre o
                                    polígono que abrange o local de interesse.</p>
                                <br>

                                <p>Os arquivos "ZONEAMENTO MUNICIPAL DO CONTINENTE" e "ZONEAMENTO MUNICIPAL DAS ILHAS"
                                    seguem
                                    ambos o disposto nas Leis Municipais 2.091/2009 - Lei de Zoneamento e 2.092/2009 -
                                    Lei de
                                    Uso e Ocupação do Solo; o arquivo "ZONEAMENTO DA ILHA GRANDE" segue o disposto na
                                    Lei
                                    Municipal 162/1991 - Plano Diretor; e o arquivo ZONEAMENTO APA TAMOIOS segue o
                                    disposto no
                                    Decreto Estadual 44.175/2013 - Plano de Manejo da APA de Tamoios. Todavia, deve
                                    ficar
                                    registrado que estes mapas não substituem a publicação oficial da respectiva norma
                                    legal.
                                </p>
                                <br>
                                <P>Estes mapas servem para orientar os profissionais ligados à construção civil e demais
                                    interessados em construir, licenciar e analisar a viabilidade legal de instalação de
                                    atividades no Município.</P>
                                <table width="100%" class="table mb-5">
                                    <thead>
                                        <tr>
                                            <th width="11%">ARQUIVO</th>


                                            <th width="48%">DESCRI&Ccedil;&Atilde;O</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <tr>
                                        <td>Mapa </td>

                                        <td>Zoneamento APA Tamaios</td>

                                        <td><a href="downloads/SMA/mapas_google/ZONEAMENTO-APA-TAMOIOS.zip"
                                                target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                kmz, 2448KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Mapa </td>


                                        <td>Zoneamento Ilha Grande</td>
                                        <td><a href="downloads/SMA/mapas_google/Zon-PD-Municipal_Ilha_Grande_lei_162_1991.zip"
                                                target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                zip, 273KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Mapa</td>


                                        <td>Zoneamento Municipal das Ilhas e Continente</td>
                                        <td><a href="downloads/SMA/mapas_google/Zon-PD-Municipal_Continente_Ilhas_Lei_2092_2009.zip"
                                                target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                zip, 1.3MB.</a></td>
                                    </tr>
                                </table>
                                <div class="bottom20"></div>

                                <h3 class="mb-3">Legisla&ccedil;&atilde;o Urban&iacute;stica</h3>
                                <p>&Eacute; um conjunto de diretrizes que regulamentam o uso e ocupa&ccedil;&atilde;o do
                                    solo
                                    dentro do territ&oacute;rio municipal. Este conjunto de diretrizes &eacute; composto
                                    pela
                                    Lei do Plano Diretor, Lei do Zoneamento, Lei de Uso e Ocupa&ccedil;&atilde;o do
                                    Solo, Lei do
                                    Parcelamento, Lei do C&oacute;digo de Obras e outras afins que s&atilde;o os
                                    instrumentos de
                                    planejamento urbano cuja fun&ccedil;&atilde;o &eacute; regular o uso e
                                    ocupa&ccedil;&atilde;o do solo urbano por parte dos agentes de
                                    produ&ccedil;&atilde;o do
                                    espa&ccedil;o urbano, tais como as construtoras, incorporadoras,
                                    propriet&aacute;rios de
                                    im&oacute;veis e o pr&oacute;prio Munic&iacute;pio.</p>
                                <div class="bottom20"></div>
                                <table width="100%" class="table mb-5">
                                    <thead>
                                        <tr>
                                            <th width="11%">TIPO</th>
                                            <th width="9%">N&ordm;</th>
                                            <th width="14%">DATA</th>
                                            <th width="48%">RESUMO</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <tr>
                                        <td>Decreto</td>
                                        <td><strong>9260</strong></td>
                                        <td>04/04/2014</td>
                                        <td>Disp&otilde;e sobre os crit&eacute;rios urban&iacute;sticos e
                                            edil&iacute;cios da
                                            Zona Especial de Interesse Social da &Aacute;rea 22 da AMIZ do Parque
                                            Mambucaba, e
                                            regulamenta a Lei municipal 3.067 de&nbsp;11 de julho&nbsp;de 2013.</td>
                                        <td><a href="downloads/SMA/leis/DECRETO 9260-14.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 45KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2955</strong></td>
                                        <td>20/09/2012</td>
                                        <td>Altera dispositivo da Lei n&ordm; 2.091, de 23 de janeiro de 2009, que
                                            disp&otilde;e
                                            sobre zoneamento municipal. (altera o Art. 19 - conceito de ZUEP)</td>
                                        <td><a href="downloads/SMA/leis/lei_2955.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 85KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2937</strong></td>
                                        <td>19/07/2012</td>
                                        <td>Disp&otilde;e sobre a altera&ccedil;&atilde;o dos limites das &Aacute;reas
                                            01 e 02 e
                                            os usos permitidos para a &Aacute;rea 01 da &Aacute;rea do Microzoneamento
                                            da Vila
                                            Hist&oacute;rica de Mambucaba - &Aacute;rea 03 da Unidade Territorial
                                            (UT-01)
                                            denominadas de Zona de Interesse Tur&iacute;stico 01 (ZIT-1) e Zona de
                                            Interesse
                                            Ambiental de Prote&ccedil;&atilde;o (ZIAP)</td>
                                        <td><a href="downloads/SMA/leis/lei_2937.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 441KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2873</strong></td>
                                        <td>10/05/2012</td>
                                        <td>Altera o inciso VI, do Art.239 da Lei 2.087/2009 - C&oacute;digo de Obras
                                        </td>
                                        <td><a href="downloads/SMA/leis/lei_2873.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 127KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2866</strong></td>
                                        <td>19/03/2012</td>
                                        <td>Disp&otilde;e sobre a altera&ccedil;&atilde;o dos limites das &Aacute;reas
                                            08 e 09 e
                                            sobre as corre&ccedil;&otilde;es nos mapas, no memorial&nbsp; descritivo e
                                            na tabela
                                            de uso do solo da Unidade Territorial - 05 (UT-05)</td>
                                        <td><a href="downloads/SMA/leis/lei_2866.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 845KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2865</strong></td>
                                        <td>19/03/2012</td>
                                        <td>Disp&otilde;e sobre a &Aacute;rea de Microzoneamento da Banqueta - AMIZ da
                                            Banqueta,
                                            nos termos do art. 22 da lei 2091 de 23 de janeiro de 2009</td>
                                        <td><a href="downloads/SMA/leis/lei_2865.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 327KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2860</strong></td>
                                        <td>06/03/2012</td>
                                        <td>Disp&otilde;e sobre a cria&ccedil;&atilde;o da &Aacute;rea 30, a partir da
                                            redu&ccedil;&atilde;o de por&ccedil;&atilde;o de terra da &Aacute;rea 12 da
                                            Unidade
                                            Territorial 04 (UT-04)</td>
                                        <td><a href="downloads/SMA/leis/lei_2860.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 313KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2859</strong></td>
                                        <td>06/03/2012</td>
                                        <td>Altera as leis n&deg; 2091 e 2092, de 23 de janeiro de 2009, cria a Zona
                                            Industrial
                                            no munic&iacute;pio de Angra dos Reis </td>
                                        <td><a href="downloads/SMA/leis/lei_2859.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 129KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2709</strong></td>
                                        <td>28/12/2010</td>
                                        <td>Disp&otilde;e sobre a altera&ccedil;&atilde;o da denomina&ccedil;&atilde;o
                                            do
                                            zoneamento da&nbsp; &Aacute;rea 25 do Microzoneamento da Japu&iacute;ba -
                                            &Aacute;rea 5 da Unidade Territorial 05 (UT 05),&nbsp; constante do Anexo
                                            III da Lei
                                            n&ordm; 2.091, de 23 de janeiro de 2009 </td>
                                        <td><a href="downloads/SMA/leis/lei_2709.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 137KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2640</strong></td>
                                        <td>31/08/2010</td>
                                        <td>Altera o inciso VI do Art. 239 da lei n&ordm; 2.087, de 23 de janeiro de
                                            2009 -
                                            c&oacute;digo de obras do munic&iacute;pio de Angra dos Reis.</td>
                                        <td><a href="downloads/SMA/leis/lei_2640.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 93KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Decreto</td>
                                        <td><strong>7400</strong></td>
                                        <td>06/01/2010</td>
                                        <td>Disp&otilde;e sobre a suspens&atilde;o das obras de constru&ccedil;&atilde;o
                                            nas
                                            &aacute;reas de risco geol&oacute;gico e geot&eacute;cnico</td>
                                        <td><a href="downloads/SMA/leis/decreto_7400.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 104KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2093</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Disp&otilde;e sobre o Parcelamento do Solo no munic&iacute;pio de Angra dos
                                            Reis
                                        </td>
                                        <td><a href="downloads/SMA/leis/lei_2093.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 293KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2092</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Disp&otilde;e sobre o Uso e Ocupa&ccedil;&atilde;o do Solo no
                                            munic&iacute;pio de
                                            Angra dos Reis&nbsp; </td>
                                        <td><a href="downloads/SMA/leis/lei_2092.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 387KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2091</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Disp&otilde;e sobre o Zoneamento Municipal de Angra dos Reis </td>
                                        <td><a href="downloads/SMA/leis/lei_2091.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 160KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>2088</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Disp&otilde;e sobre a Lei de Diretrizes Territoriais para a Ilha Grande, de
                                            acordo
                                            com o artigo 15 da lei 1.754 de 21 de dezembro de 2006</td>
                                        <td><a href="downloads/SMA/leis/lei_2088.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 247KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2087</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Disp&otilde;e sobre o C&oacute;digo de Obras do munic&iacute;pio de Angra
                                            dos Reis.
                                        </td>
                                        <td><a href="downloads/SMA/leis/lei_2087.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 696KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>1780</strong></td>
                                        <td>08/02/2007</td>
                                        <td>D&aacute; nova reda&ccedil;&atilde;o a dispositivos da Lei Municipal n&ordm;
                                            1754,
                                            de 21 de dezembro de 2006 </td>
                                        <td><a href="downloads/SMA/leis/lei_1780.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 154KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>1754</strong></td>
                                        <td>21/12/2006</td>
                                        <td>Disp&otilde;e sobre o Plano Diretor municipal de Angra dos Reis.</td>
                                        <td><a href="downloads/SMA/leis/lei_1754.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 257KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Decreto</td>
                                        <td><strong>2003</strong></td>
                                        <td>10/05/2000</td>
                                        <td>Institui servid&atilde;o p&uacute;blica nas trilhas da Ilha Grande.</td>
                                        <td><a href="downloads/SMA/leis/decreto_2003.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 2353KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>817</strong></td>
                                        <td>18/01/1999</td>
                                        <td>Disp&otilde;e sobre a cria&ccedil;&atilde;o de Programa de Engenharia/
                                            Arquitetura
                                            P&uacute;blica no Munic&iacute;pio</td>
                                        <td><a href="downloads/SMA/leis/lei_817.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 10KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Modelo </td>
                                        <td><strong></strong></td>
                                        <td></td>
                                        <td>Modelo de Carimbo para Plantas</td>
                                        <td><a href="downloads/SMA/modelo_carimbo_plantas.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 312KB.</a></td>
                                    </tr>
                                </table>
                                <div class="bottom30"></div>

                                <h3>Legisla&ccedil;&atilde;o Urban&iacute;stica Parcialmente em Vigor </h3>
                                <table width="100%" class="table mb-5">
                                    <thead>
                                        <tr>
                                            <th width="11%">TIPO</th>
                                            <th width="9%">N&ordm;</th>
                                            <th width="14%">DATA</th>
                                            <th width="48%">RESUMO</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>821</strong></td>
                                        <td>09/03/1999</td>
                                        <td>Cria e regulamenta a &aacute;rea especial de interesse cultural, ambiental,
                                            tur&iacute;stico, e de utiliza&ccedil;&atilde;o p&uacute;blica das ilhas do
                                            munic&iacute;pio de angra dos reis - AECATUP das ilhas, altera o
                                            par&aacute;grafo
                                            1&ordm; do artigo 91 e o artigo 92 da lei n&ordm; 162/L.O. de 12 de dezembro
                                            de 1991
                                        </td>
                                        <td><a href="downloads/SMA/leis/lei_821.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 114KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>648</strong></td>
                                        <td>29/12/1997</td>
                                        <td>Disp&otilde;e sobre a &Aacute;rea Especial de Interesse Cultural, Ambiental,
                                            Tur&iacute;stico e de Utiliza&ccedil;&atilde;o P&uacute;blica da Vila do
                                            Abra&atilde;o, nos termos dos artigos 113, 114 e 115 da Lei Municipal N&deg;
                                            162/L.O., de 12 de dezembro de 1991 (AECATUP do Abra&atilde;o)</td>
                                        <td><a href="downloads/SMA/leis/lei_648.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 1294KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>575</strong></td>
                                        <td>25/07/1997</td>
                                        <td>Disp&otilde;e sobre a substitui&ccedil;&atilde;o dos mapas anexos da Lei
                                            n&ordm;
                                            162/L.O., de 12 de dezembro de 1991</td>
                                        <td><a href="downloads/SMA/leis/lei_575.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 2342KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>361</strong></td>
                                        <td>19/05/1994</td>
                                        <td>D&aacute; nova reda&ccedil;&atilde;o ao artigo 225 da lei n&ordm; 162/L.O. -
                                            Plano&nbsp; Diretor Municipal (refere-se a CMUMA)</td>
                                        <td><a href="downloads/SMA/leis/lei_361.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 72KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>162</strong></td>
                                        <td>12/12/1991</td>
                                        <td>Plano Diretor Municipal</td>
                                        <td><a href="downloads/SMA/leis/lei_162.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 803KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>158</strong></td>
                                        <td>22/04/1982</td>
                                        <td>Disp&otilde;e sobre o uso do solo na Vila Hist&oacute;rica de Mambucaba.
                                        </td>
                                        <td><a href="downloads/SMA/leis/lei_158.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 504KB.</a></td>
                                    </tr>
                                </table>
                                <div class="bottom30"></div>
                                <h3>Legisla&ccedil;&atilde;o Ambiental</h3>
                                <p>&Eacute; um conjunto de regulamentos jur&iacute;dicas especialmente dirigidos
                                    &agrave;s
                                    atividade que afetam a qualidade do meio ambiente.</p>
                                <div class="bottom20"></div>
                                <table width="100%" class="table mb-5">
                                    <thead>
                                        <tr>
                                            <th width="11%">TIPO</th>
                                            <th width="9%">N&ordm;</th>
                                            <th width="14%">DATA</th>
                                            <th width="48%">RESUMO</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <!--            <tr>
                                            <td>Decreto</td>
                                            <td><strong>9783</strong></td>
                                            <td>13/08/2015</td>
                                            <td>Disp&otilde;e  sobre a regulamenta&ccedil;&atilde;o da emiss&atilde;o de autoriza&ccedil;&atilde;o ambiental para corte de  &aacute;rvores isoladas em &aacute;rea particular.</td>
                                            <td><a href="downloads/SMA/leis/decreto9.783-2015.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 177KB.</a></td>
                                          </tr>
                                          <tr>
                                            <td>Decreto</td>
                                            <td><strong>9767</strong></td>
                                            <td>24/07/2015</td>
                                            <td>Estabelece  no &acirc;mbito do licenciamento urban&iacute;stico e ambiental, modelos de requerimento,  documenta&ccedil;&atilde;o e procedimentos administrativos adotados no munic&iacute;pio de Angra dos  Reis.</td>
                                            <td><a href="downloads/SMA/leis/Decreto_9767-2015.zip"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> zip, 840KB.</a></td>
                                          </tr>
                                        <tr>-->
                                    <td width="11%">Decreto</td>
                                    <td width="9%"><strong>8585</strong></td>
                                    <td width="14%">30/11/2012</td>
                                    <td width="48%">Disp&otilde;e sobre o uso ordenado das embarca&ccedil;&otilde;es
                                        de
                                        turismo n&aacute;utico, proibi&ccedil;&atilde;o de preparo de alimentos e
                                        disposi&ccedil;&atilde;o de res&iacute;duos nas praias.</td>
                                    <td><a href="downloads/SMA/leis/decreto_8585.pdf" target="_blank"><img
                                                src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                alt="Baixar arquivo" width="18" height="18" border="0">
                                            pdf, 287KB.</a></td>
                                    </tr>

                                    <tr>
                                        <td width="11%">Decreto</td>
                                        <td width="9%"><strong>7481</strong></td>
                                        <td width="14%">07/06/2010</td>
                                        <td width="48%">Regulamenta o procedimento de fiscaliza&ccedil;&atilde;o
                                            ambiental
                                            no munic&iacute;pio de Angra dos Reis previsto no cap&iacute;tulo XI da Lei
                                            n&ordm;
                                            1965, de 24 de junho de 2008, e d&aacute; outras provid&ecirc;ncias</td>
                                        <td><a href="downloads/SMA/leis/decreto_7481.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 180KB.</a></td>
                                    </tr>
                                    <!--          <tr>
                                          <td width="11%">Decreto</td>
                                          <td width="9%"><strong>8404</strong></td>
                                          <td width="14%">24/06/2008</td>
                                          <td width="48%">Disp&otilde;e sobre a regulamenta&ccedil;&atilde;o do servi&ccedil;o de corte de &aacute;rvores pela prefeitura    Municipal de Angra dos Reis</td>
                                          <td><a href="downloads/SMA/leis/Decreto_8404.pdf" target="_blank"><img src="{{ asset('pmar/assets/img/icons/download.gif') }}" alt="Baixar arquivo" width="18" height="18" border="0"> pdf, 234KB.</a></td>
                                        </tr>
                              -->
                                    <tr>
                                        <td width="11%">Lei</td>
                                        <td width="9%"><strong>1965</strong></td>
                                        <td width="14%">24/06/2008</td>
                                        <td width="48%">Disp&otilde;e sobre o novo C&oacute;digo Ambiental do
                                            munic&iacute;pio de Angra dos Reis</td>
                                        <td><a href="downloads/SMA/leis/Lei_1965.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 372KB.</a></td>
                                    </tr>
                                </table>
                                <div class="bottom30"></div>
                                <h3>Legisla&ccedil;&atilde;o da Divis&atilde;o Pol&iacute;tico-administrativa</h3>
                                <p>&Eacute; um conjunto de diretrizes que regulamentam a divis&atilde;o administrativa
                                    do
                                    territ&oacute;rio municipal. Este conjunto de diretrizes &eacute; composto pela Lei
                                    de
                                    Divis&atilde;o do Munic&iacute;pio em Distritos e Lei de Abairramento do
                                    Munic&iacute;pio.
                                </p>
                                <div class="bottom20"></div>
                                <table width="100%" class="table mb-5">
                                    <thead>
                                        <tr>
                                            <th width="11%">TIPO</th>
                                            <th width="9%">N&ordm;</th>
                                            <th width="14%">DATA</th>
                                            <th width="48%">RESUMO</th>
                                            <th width="18%">DOWNLOAD</th>
                                        </tr>
                                    </thead>
                                    <tr>
                                        <td>Lei </td>
                                        <td><strong>2089</strong></td>
                                        <td>23/01/2009</td>
                                        <td>Altera os anexos da Lei n&ordm; 900/2000 - Lei de Abairramento do
                                            munic&iacute;pio
                                            de Angra dos Reis</td>
                                        <td><a href="downloads/SMA/leis/lei_2089.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 1548KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>900</strong></td>
                                        <td>20/01/2000</td>
                                        <td>Lei de Abairramento do Munic&iacute;pio de Angra dos Reis</td>
                                        <td><a href="downloads/SMA/leis/lei_900.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 3.1MB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Decreto</td>
                                        <td><strong>1760</strong></td>
                                        <td>03/09/1999</td>
                                        <td>Descritivo da Revis&atilde;o Distrital do munic&iacute;pio.</td>
                                        <td><a href="downloads/SMA/leis/decreto_1760.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 76KB.</a></td>
                                    </tr>
                                    <tr>
                                        <td>Lei</td>
                                        <td><strong>270</strong></td>
                                        <td>15/04/1993</td>
                                        <td>Divis&atilde;o do Munic&iacute;pio 04 (quatro) Distritos.</td>
                                        <td><a href="downloads/SMA/leis/lei_270.pdf" target="_blank"><img
                                                    src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0">
                                                pdf, 1159KB.</a></td>
                                    </tr>
                                </table>
                                <a name="zoneamento"></a>
                                <div class="bottom30"></div>
                                <div class="inner-post-desc mb-5">
                                    <h3>Mapas do Zoneamento Municipal (Anexos I, II e III da Lei do Zoneamento - Lei
                                        N&ordm;
                                        2091/2009)</h3>
                                    <p>Todos os mapas abaixo foram confeccionados pela Secretaria Municipal de Meio
                                        Ambiente.
                                    </p>
                                    <div class="list_down">
                                        <ul>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Divisao_das_UTs.pdf"
                                                    target="_blank">Divis&atilde;o
                                                    das UTS </A>(pdf, 838KB)</li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Macrozoneamento_do_Municipio.pdf"
                                                    target="_blank">Macrozoneamento do Munic&iacute;pio</A> (pdf,
                                                1.48MB)</li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_do_Municipio_REV_AGOS_2012.pdf"
                                                    target="_blank">Zoneamento do Munic&iacute;pio </A>(pdf, 23.8MB)
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-01.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-01</A> (pdf, 2.38MB)
                                                <ul>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-01_Mambucaba.pdf"
                                                            target="_blank">Microzoneamento UT-01 Praia Brava</A> (pdf,
                                                        13.9MB)
                                                    </li>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-01_Parque_Mambucaba.pdf"
                                                            target="_blank">Microzoneamento UT-01 Parque Mambucaba</A>
                                                        (pdf,
                                                        57.6MB)</li>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-01_Vila Histórica_de_Mambucaba.pdf"
                                                            target="_blank">Microzoneamento UT-01 Vila Hist&oacute;rica
                                                            de
                                                            Mambucaba</A> (pdf, 18.2MB)</li>
                                                </ul>
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-02.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-02</A> (pdf, 1.1MB)</li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-03.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-03</A> (pdf, 7.67MB)
                                                <ul>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-03_Frade.pdf"
                                                            target="_blank">Microzoneamento UT-03 Frade</A> (pdf,
                                                        47.3MB)</li>
                                                </ul>
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-04.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-04</A> (pdf, 10.2MB)</li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-05.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-05</A> (pdf, 7.7MB)
                                                <ul>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-05_Japuíba.pdf"
                                                            target="_blank">Microzoneamento UT-05 Japu&iacute;ba</A>
                                                        (pdf,
                                                        75.4MB)</li>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-05_Banqueta.pdf"
                                                            target="_blank">Microzoneamento UT-05 Banqueta</A> (pdf,
                                                        97MB)</li>
                                                </ul>
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-06.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-06</A> (pdf, 1.1MB)
                                                <ul>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-06_Centro.pdf"
                                                            target="_blank">Microzoneamento UT-06 Centro</A> (pdf,
                                                        31.9MB)
                                                    </li>
                                                </ul>
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-07.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-07</A> (pdf, 2.8MB)
                                                <ul>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-07_Camorim.pdf"
                                                            target="_blank">Microzoneamento UT-07 Camorim</A> (pdf,
                                                        12.8MB)
                                                    </li>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-07_Monsuaba.pdf"
                                                            target="_blank">Microzoneamento UT-07 Monsuaba</A> (pdf,
                                                        7.43MB)
                                                    </li>
                                                    <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                            alt="Baixar arquivo" width="18" height="18"
                                                            border="0"><A
                                                            href="downloads/SMA/UTS/Microzoneamento_UT-07_Verolme.pdf"
                                                            target="_blank">Microzoneamento UT-07 Verolme</A> (pdf,
                                                        12.7MB)
                                                    </li>
                                                </ul>
                                            </li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento-UT-08.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-08</A> (pdf, 2.5MB)</li>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/UTS/Zoneamento_UT-10.pdf"
                                                    target="_blank">Zoneamento -
                                                    UT-10</A> (pdf, 3.8MB) </li>
                                        </ul>
                                    </div>
                                    <div class="mb-5"></div>
                                    <h3>MemoriaL Descritivo</h3>
                                    <div class="list_down">
                                        <ul>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/leis/lei_2091_anexo_IV.pdf" target="_blank">Anexo
                                                    IV da
                                                    Lei de Zoneamento - Lei 2091/2009 </A>(pdf, 969KB) </li>
                                        </ul>
                                    </div>
                                    <div class="mb-5"></div>
                                    <h3>Tabela</h3>
                                    <div class="list_down">
                                        <ul>
                                            <li><img src="{{ asset('pmar/assets/img/icons/download.gif') }}"
                                                    alt="Baixar arquivo" width="18" height="18" border="0"><A
                                                    href="downloads/SMA/leis/Lei_2092_anexo_II.pdf" target="_blank">Anexo
                                                    II da
                                                    Lei de Uso e Ocupa&ccedil;&atilde;o do Solo - Lei 2092/2009</A>
                                                (pdf, 258KB)
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </article>
                        </section>
                    </div>
                </div>

            </div>
        </div>
    </section>
@endsection
