<?php $__env->startSection('title', env('APP_NAME') . ' :: Ouvidoria SUS'); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container d-flex ">
            <div class="row">
                <div>
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route('paginas.home')); ?>">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(url('/secretarias/secretaria-de-saude')); ?>"><?php echo e(__('Secretaria de Saúde')); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Manual de Redação Oficial da Prefeitura de Angra</li>
                        </ol>
                    </nav>
                </div>
                <div class="row">
                <div class="col-md-9 nopadding single-article espaco_conteudo w-75 mx-auto text-center">
                    <header class="article-header">
                        <h1 class="title">Ouvidoria SUS</h1>
                    </header>

                    <div class="py-5 ">
                        <div class="accordion accordion rounded-3 shadow" id="accordionSUS">
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse1" aria-expanded="false" aria-controls="flush-collapse1">
                                    O que é a Ouvidoria SUS?
                                </button>
                            </h2>
                            <div id="flush-collapse1" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    É um canal de comunicação entre você, usuário do SUS e a administração pública responsável pelo serviço. Através da Ouvidoria, você exerce sua cidadania, dando sugestões, elogiando e reclamando seus direitos.
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse2" aria-expanded="false" aria-controls="flush-collapse2">
                                    Como funcionamos?
                                </button>
                            </h2>
                            <div id="flush-collapse2" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    Orientamos e informamos sobre o serviços de saúde; acolhemos as sugestões, solicitações, reclamações e elogios; encaminhamos aos órgãos competentes para análise e providências; recebemos e analisamos a resposta fornecida pelo órgão informando ao cidadão; e elaboramos relatórios para os gestores contribuindo para a melhoria da Saúde Pública e o fortalecimento do SUS.
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse3" aria-expanded="false" aria-controls="flush-collapse3">
                                    Missão
                                </button>
                            </h2>
                            <div id="flush-collapse3" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    Ser um canal de comunicação e articulação entre o gestor e o controle social, visando a melhoria da qualidade dos serviços prestados ao cidadão.
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse4" aria-expanded="false" aria-controls="flush-collapse4">
                                    Visão
                                </button>
                            </h2>
                            <div id="flush-collapse4" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    Garantir e ampliar o acesso do cidadão na real busca de seus direitos. Atuar como ferramenta para o fortalecimento do controle social e da gestão.
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse5" aria-expanded="false" aria-controls="flush-collapse5">
                                    Valores
                                </button>
                            </h2>
                            <div id="flush-collapse5" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    Comprometimento, Cooperação, Ética, Transparência, Excelência e Respeito.
                                </div>
                            </div>
                        </div>
                        <div class="accordion-item">
                            <h2 class="accordion-header">
                                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#flush-collapse6" aria-expanded="false" aria-controls="flush-collapse6">
                                    Como entrar em contato com a Ouvidoria?
                                </button>
                            </h2>
                            <div id="flush-collapse6" class="accordion-collapse collapse" data-bs-parent="#accordionSUS">
                                <div class="accordion-body">
                                    Preencha o formulário online abaixo ou utilize o e-mail fusar.ouvidoriasus@angra.rj.gov.br.<hr>
                                    Por telefone:(24) 3364-4844 / 3365-2803<hr>
                                    Por carta: Avenida Almirante Machado Portela, 85 - Balneário. <br> CEP: 23906-190. Angra dos Reis - RJ. <hr>
                                    Horário de atendimento:8:30 às 17:00hs
                                </div>
                            </div>
                        </div>
                        </div>
                    </div>  
                </div>  
                
                    <article class="article-main">
                        <img src="images/secretarias/FUSAR/logo_sus_ouvidoria.jpg" alt="Ouvidoria SUS Angra dos Reis">
                        <div class="clear"></div>
                        <div class="bottom30"></div>
                            
                        <form  class="row g-3 w-75 mx-auto mb-5">
                            <div class="justify-content-start col-md-12">
                                <label for="inputState" class="form-label">Tipo de assunto</label>
                                <select id="inputState" class="form-select">
                                <option selected>Informação</option>
                                <option>Elogio</option>
                                <option>Sugestão</option>
                                <option>Reclamação</option>
                                <option>Denúncia</option>
                                <option>Solicitação</option>
                                </select>
                            </div>
                            <div class="col-md-12">
                                <label for="inputEmail4" class="form-label">Assunto</label>
                                <input type="email" class="form-control" id="inputEmail4" placeholder="*">
                            </div>
                            <div class="col-md-12">
                                <label for="inputPassword4" class="form-label">Descrição do assunto</label>
                                <input type="password" class="form-control" id="inputPassword4" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">Nome do usuário</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">Nome da Mãe do Usuário</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col-12">
                                <label for="inputAddress" class="form-label">CPF</label>
                                <input type="text" class="form-control" id="inputAddress" placeholder="xxx.xxx.xxx-xx">
                            </div>
                            <div class="col-12">
                                <label for="inputAddress2" class="form-label">Data de nascimento</label>
                                <input type="text" class="form-control" id="inputAddress2" placeholder="*">
                            </div>
                            <div class="col-12">
                                <label for="inputAddress2" class="form-label">Cartão do SUS</label>
                                <input type="text" class="form-control" id="inputAddress2" placeholder="*">
                            </div>
                            <div class="col-12">
                                <label for="inputAddress2" class="form-label">Endereço</label>
                                <input type="text" class="form-control" id="inputAddress2" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">Nº</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">Bairro</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">Município</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col">
                                <label for="inputCity" class="form-label">CEP</label>
                                <input type="text" class="form-control" placeholder="*">
                            </div>
                            <div class="col-12">
                                <label for="inputAddress2" class="form-label">telefone</label>
                                <input type="text" class="form-control" id="inputAddress2" placeholder="*">
                            </div>
                            <div class="mb-3">
                                <label for="exampleFormControlInput1" class="form-label">E-mail</label>
                                <input type="email" class="form-control" id="exampleFormControlInput1" placeholder="nome@exemplo.com">
                            </div>
                            <div class="col-12">
                                <button type="submit" class="btn btn-primary">Sign in</button>
                            </div>
                        </form>

                        <!--<div class="bottom40"></div>
                        <h3 class="bottom25">Formul&aacute;rio Online</h3>
                        <form id="formOuvidoria" name="formOuvidoria" method="post"
                            action="fusar-ouvidoria.asp?indexsigla=SSA" onsubmit="return ValidarCampos(this)"
                            class="contactForm">
                            <div id="status"></div>
                            <div class="col-md-3">
                                <label for="selAssunto"><span class="red">*</span>Tipo de assunto: </label>
                                <select name="selAssunto" id="selAssunto" required>
                                    <option selected="selected" value="Informa&ccedil;&atilde;o">Informa&ccedil;&atilde;o
                                    </option>
                                    <option value="Elogio">Elogio</option>
                                    <option value="Sugest&atilde;o">Sugest&atilde;o</option>
                                    <option value="Reclama&ccedil;&atilde;o">Reclama&ccedil;&atilde;o</option>
                                    <option value="Den&uacute;ncia">Den&uacute;ncia</option>
                                    <option value="Solicita&ccedil;&atilde;o">Solicita&ccedil;&atilde;o</option>
                                </select>
                            </div>
                            <div class="col-md-6">
                                <label for="ds_assunto"><span class="red">*</span>Assunto: </label>
                                <input name="ds_assunto" type="text" id="ds_assunto" onfocus="VerificaConteudo(this)"
                                    value="*" required />
                            </div>
                            <div class="clear"> </div>
                            <div class="col-md-9">
                                <label for="ds_assunto_desc"><span class="red">*</span>Descri&ccedil;&atilde;o do
                                    assunto: </label>

                                <textarea name="ds_assunto_desc" rows="3" id="ds_assunto_desc" onFocus="VerificaConteudo(this)">*</textarea>
                            </div>
                            <div class="col-md-9">
                                <label for="ds_nome"><span class="red">*</span>Nome do usu&aacute;rio: </label>
                                <input name="ds_nome" type="text" id="ds_nome" onFocus="VerificaConteudo(this)"
                                    value="*" size="35" required />
                            </div>
                            <div class="col-md-9">
                                <label for="ds_nome_mae"><span class="red">*</span>Nome da Mãe do Usuário: </label>
                                <input name="ds_nome_mae" type="text" id="ds_nome_mae" onFocus="VerificaConteudo(this)"
                                    value="*" size="35" required />
                            </div>
                            <div class="clear"> </div>
                            <div class="col-md-3">
                                <label for="nr_cpf"><span class="red">*</span>CPF:</label>
                                <input name="nr_cpf" id="nr_cpf" type="text" onfocus="VerificaConteudo(this)"
                                    data-mask="000.000.000-00" minlength="14" placeholder="xxx.xxx.xxx-xx" class="cpf"
                                    pattern="\d{3}\.\d{3}\.\d{3}-\d{2}" required />
                            </div>
                            <div class="col-md-3">
                                <label for="dt_nasc"><span class="red">*</span>Data de nascimento:</label>
                                <input name="dt_nasc" type="text" id="dt_nasc" onfocus="VerificaConteudo(this)"
                                    onkeyup="if (this.value=ChkField_O(this.value,'0123456789/')){return maskDataTime(this,1)}else{return false;}"
                                    onclick="if (this.value=ChkField_O(this.value,'0123456789/')){return maskDataTime(this,1)}else{return false;}"
                                    onblur="return ValidD(this, this.value,'Data Inv&aacute;lida !')" value="*"
                                    maxlength="10" placeholder="dd/mm/aaaa" required />
                            </div>
                            <div class="col-md-3">
                                <label for="ds_endereco">Cartão do SUS: </label>

                                <input name="ds_cartao_sus" type="text" id="ds_cartao_sus"
                                    onFocus="VerificaConteudo(this)" value="*" data-mask="000/0000/0000/0000"
                                    placeholder="000/0000/0000/0000" />
                            </div>
                            <div class="clear"> </div>
                            <div class="col-md-7">
                                <label for="ds_endereco"><span class="red">*</span>Endere&ccedil;o:
                                </label>
                                <input name="ds_endereco" type="text" id="ds_endereco"
                                    onFocus="VerificaConteudo(this)" value="*" size="35" required />
                            </div>

                            <div class="col-md-2">
                                <label for="ds_numero"><span class="red">*</span>N&ordm;:

                                </label><br>
                                <input name="ds_numero" type="text" id="ds_numero" onFocus="VerificaConteudo(this)"
                                    value="*" size="10"
                                    onKeyUp="this.value=ChkField_O(this.value,'0123456789')"
                                    onClick="this.value=ChkField_O(this.value,'0123456789')" required />
                            </div>

                            <div class="col-md-4">
                                <label for="ds_bairro"><span class="red">*</span>Bairro:
                                </label> <br>
                                <input name="ds_bairro" type="text" id="ds_bairro" onfocus="VerificaConteudo(this)"
                                    value="*" size="35" required />
                            </div>

                            <div class="col-md-3">
                                <label for="ds_cidade"><span class="red">*</span>Munic&iacute;pio: </label>
                                <input name="ds_cidade" type="text" id="ds_cidade" onfocus="VerificaConteudo(this)"
                                    value="*" size="35" required />
                            </div>

                            <div class="col-md-2">
                                <label for="ds_cep"><span class="red">*</span>CEP: </label><br>
                                <input name="ds_cep" type="text" id="ds_cep" onfocus="VerificaConteudo(this)"
                                    value="*" size="35" onblur="ValidCep(this.value)"
                                    onkeypress="return verseenumero(event)" onkeyup="maskcep(this,1);"
                                    placeholder="11111-111" maxlength="9" required />
                            </div>

                            <div class="col-md-4">
                                <label for="ds_tel"><span class="red">*</span>Telefone:</label>
                                <input name="ds_tel" type="text" id="ds_tel" onFocus="VerificaConteudo(this)"
                                    value="*" size="15" onkeypress="return(CelularFormat(this,event))"
                                    placeholder="(22) 12345-6789" required />
                            </div>

                            <div class="col-md-5">
                                <label for="ds_email"><span class="red">*</span>E-mail: </label><br>
                                <input name="ds_email" type="email" id="ds_email" onblur="ValidaEmail(this)"
                                    onfocus="VerificaConteudo(this)" value="*"
                                    pattern="[a-z0-9._%+\-]+@[a-z0-9.\-]+\.[a-z]{2,}$" required />
                            </div>
                            <div class="clear"></div>
                            <p style="margin-left: 20px;"><strong class="red">*</strong> <small>Campos
                                    obrigat&oacute;rios</small> </p>
                            <div class="col-md-8 top30">
                                <?php if(config('recaptcha.enabled')): ?>
                                <div class="g-recaptcha" data-callback="recaptchaCallback"
                                    data-sitekey="6Lf75TkUAAAAAEHgXPyCVl20Eh1qfSabxJh8exoX"></div>
                                <script src="https://www.google.com/recaptcha/api.js?hl=pt-BR" async defer></script>
                                <?php endif; ?>

                                <input type="button" class="btn btn-large top30" name="Submit" id="btnEnviar"
                                    value="Enviar" onClick="enviaFormulario()" <?php if(config('recaptcha.enabled')): ?> disabled <?php endif; ?> />
                            </div>

                        </form>
                        <div class="clear"></div>

                        <div class="bottom30"></div>

                    </article>-->

                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/ouvidoria-sus.blade.php ENDPATH**/ ?>