{{-- 
    @include("admin.components.btnEdit", [
        'route' => "id do serviço",
        'id' => "id do serviço",
    ])
--}}

<a class="btn btn-warning btn-sm flex-fill"  href='{{ route($route, $id)}}'>
    <span class="material-symbols-outlined" data-bs-toggle="tooltip" data-bs-placement="top" title="Editar"> <i class="fa-solid fa-pen-to-square"></i> </span>
</a>
