@if(isset($custom_menu_links) && $custom_menu_links->isNotEmpty())
<div class="col-12 mb-3">
    <div class="row d-flex flex-column align-items-center">
        <div class="col">
            <div class="card-slug">
                <ul class="list-unstyled">
                    @foreach ($custom_menu_links as $link)
                        <li>
                            <a class="text-decoration-none text-dark link-secretarias" href="{{ url($link->link) }}" target="{{ $link->status ?? '_SELF' }}">
                                {{ $link->titulo }}
                                <i class="text-primary fa-solid fa-angle-right"></i>
                            </a>
                        </li>
                    @endforeach
                </ul>
            </div>
        </div>
    </div>
</div>
@endif
