@extends('layouts.pmar.app')

@section('title', 'Verificar Código - Credenciamento de Músicos')

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title text-center">Verificar Código</h3>
                </div>
                <div class="card-body">
                    <p class="text-center mb-4">Digite o código de 4 dígitos que foi enviado para seu e-mail.</p>
                    
                    <form method="POST" action="{{ route('paginas.credenciamento-musico.verificarCodigo') }}">
                        @csrf
                        
                        <div class="form-group">
                            <label for="code">Código *</label>
                            <input type="text" name="code" id="code" class="form-control @error('code') is-invalid @enderror" 
                                   placeholder="0000" maxlength="4" value="{{ old('code') }}" required>
                            @error('code')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary btn-block">
                                <i class="fas fa-check"></i> Verificar Código
                            </button>
                        </div>
                        
                        <div class="text-center">
                            <a href="{{ route('paginas.credenciamento-musico.esqueciSenha') }}" class="btn btn-link">
                                Solicitar novo código
                            </a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Máscara para código (apenas números)
    const codeInput = document.getElementById('code');
    codeInput.addEventListener('input', function(e) {
        let value = e.target.value.replace(/\D/g, '');
        e.target.value = value;
    });
});
</script>
@endsection
