<div class="mb-3">
    <?php if(isset($label) && $label): ?>
    <label for="<?php echo e($for ?? $name); ?>" class="form-label text-bold">
        <?php echo e(__($label)); ?>:
        <?php if(isset($required) && $required): ?>
        <span class="span-admin-create">*</span>
        <?php endif; ?>
    </label>
    <?php endif; ?>
    <div class="<?php echo e((isset($inputGroup) && $inputGroup) ? 'input-group' : ''); ?>">
        <?php
        $valor = old($name, $old ?? '');
        if (is_array($valor)) {
            $valor = implode(', ', $valor);
        }
    ?>

        <input type="<?php echo e($type ?? 'text'); ?>"
               class="form-control <?php if(isset($name)): ?> <?php $__errorArgs = [$name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?> <?php endif; ?>"
               name="<?php echo e($name ?? ''); ?>"
               id="<?php echo e($id ?? $name); ?>"
               value="<?php echo e($valor); ?>"
               <?php if(isset($oninput) && $oninput): ?> oninput="<?php echo e($oninput); ?>" <?php endif; ?>
               <?php if(isset($onchange) && $onchange): ?> onchange="<?php echo e($onchange); ?>" <?php endif; ?>
               autocomplete="off"
           <?php if(!empty($listName) && $listName != null): ?> list="<?php echo e($listName); ?>" <?php endif; ?>
           <?php if(!empty($placeholder) && $placeholder != null): ?> placeholder="<?php echo e($placeholder); ?>" <?php endif; ?>
           <?php if(!empty($autocomplete) && $autocomplete != null): ?> autocomplete="<?php echo e($autocomplete); ?>" <?php endif; ?>
        <?php echo e(($multiple ?? false) ? 'multiple' : ''); ?>

        <?php echo e(($required ?? false) ? 'required' : ''); ?>

        <?php echo e(($readonly ?? false) ? 'readonly' : ''); ?>

        <?php if(!empty($accept) && $accept != null): ?> accept="<?php echo e($accept); ?>" <?php endif; ?>>

        <?php if(!empty($arrayList) && $arrayList != null): ?>
        <datalist id="<?php echo e($listName); ?>">
            <?php $__currentLoopData = $arrayList; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <option value="<?php echo __($item); ?>"></option>                            
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        </datalist>
    <?php endif; ?>

    <?php if(!empty($toggleButton) && $toggleButton != null): ?>
        <button type="button" class="btn btn-outline-secondary" id="<?php echo e($toggleButtonId); ?>">
            <?php echo $toggleButtonFontawesome; ?>

        </button>
    <?php endif; ?>

    <?php if(isset($small) && $small): ?>
        <small class="text-secondary text-bold"><?php echo __($small); ?></small>
    <?php endif; ?>

    <?php $__errorArgs = [isset($name) && $name];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
        <small class="text-danger text-bold"><?php echo e(__($message)); ?></small>
    <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
</div>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/inputs/_inputType.blade.php ENDPATH**/ ?>