<div class="row">
    <div class="col-sm-12 col-md-8">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Nome completo do responsável legal') . ' *',
            'name' => 'fullNameResponsavelEmpresa',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('fullNameResponsavelEmpresa', $responsavel->name ?? null),
            'oninput' => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\\p{L}\\s]+/gu, '').replace(/\\s{2,}/g,' ').trimStart()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('CPF do responsável legal') . ' *',
            'name' => 'cpfResponsavelEmpresa',
            'id' => 'cpfResponsavelEmpresa',
            'required' => true,
            'type' => null,
            'old' => old('cpfResponsavelEmpresa', $responsavel->cpf ?? null),
            'oninput' => "javascript:aplicarMascaraCPF(this)",
            'readonly' => false,
            'small' => null,
        ])
    </div>
</div>
<div class="row">
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Email do responsável legal') . ' *',
            'name' => 'emailResponsavelEmpresa',
            'id' => null,
            'required' => false,
            'type' => 'email',
            'old' => old('emailResponsavelEmpresa', $responsavel->email ?? null),
            'oninput' => "javascript:this.value = this.value.toLowerCase()",
            'readonly' => false,
            'small' => null,
            'placeholder' => 'nome@email.com',
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Telefone do responsável legal') . ' *',
            'name' => 'phoneNumberResponsavelEmpresa',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('phoneNumberResponsavelEmpresa', $responsavel->phoneNumber ?? null),
            'oninput' => "javascript:aplicarMascaraTelefone(this)",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Foto responsável legal'),
            'name' => 'photoResponsavelEmpresa',
            'id' => null,
            'required' => false,
            'type' => 'file',
            'old' => null,
            'oninput' => null,
            'readonly' => true,
            'small' => null,
            'accept' => 'image/jpeg,image/jpg,image/png,image/gif',
        ])
    </div>
</div>
