@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Meu Chamados")
@section('content')

<div class="card shadow-sm border-0">

    @php $headLine = "<i class='fa-solid fa-headset'></i> Meu Chamados"; @endphp

    @include('components.buttons._headLineButtonsBackAdd', [
        'headLine' => __($headLine),
        'routeBack' => 'admin.contaAngra.index',
        'routeBackParams' => [], 
        'nameBack' => __("Voltar"),
        'routeAdd' => 'admin.contaAngra.chamados.create',
        'routeAddParams' => [], 
        'nameAdd' => __('Novo atendimento'),
        "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
    ])

    <div class="card-body">

            @include("errors.messageFlash")
            @include('components.modal._modelProfile')

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "cadastroDeUsuario", 
                "placeholder" => "Pesquisar atendimento..."
            ])

            <x-tables._table :thead="['Protocolo','Criado em','Enviado para','Assunto', 'Andamento', 'Ações']" :pagination="$chamados->links()">
                <x-slot name="body">
                    @php
                        $index = 0;
                        $mensagensNaoLidasPorChamado = $mensagensNaoLidasPorChamado ?? [];
                    @endphp
                     @foreach($chamados as $chamado)
                        <tr>
                            <td class="chamado-registro-numero-cell">
                                <x-chamados.registro-numero-badge
                                    :numero="$chamado->numeroChamado"
                                    :nao-lidas="$mensagensNaoLidasPorChamado[(string) $chamado->id] ?? 0"
                                    :monospace="false" />
                            </td>
                            <td>{{ date("d/m/Y H:i", strtotime($chamado->created_at)) }}</td>
                            <td>{{ $chamado->convenioAtual }}</td>
                            <td>{{ $chamado->assunto }}</td>
                            <td>{{ $chamado->statusChamado }}</td>
                            <td>
                                <div class="d-flex gap-2 justify-content-center">
                                    
                                    @if($chamado->statusChamado == "Em edição")
                                    
                                        @include('components.buttons._editButton', [
                                            "route" => "admin.contaAngra.chamados.edit",
                                            "id" => $chamado->id,
                                            "title" => "Editar",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
                                        ])
                                    
                                        @include('components.buttons._deleteButton', [
                                            "message" => __("* Este atendimento e seu histórico serão excluídos e esta ação não poderá ser desfeita, deseja continuar?"),
                                            "route" => "admin.contaAngra.chamados.destroy",
                                            "id" => $chamado->id,
                                            "title" => "Excluir",
                                            "fontawesome" => null,
                                            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
                                        ])
                                    @else
                                        @include('components.buttons._editButton', [
                                            "route" => "admin.contaAngra.chamados.show",
                                            "id" => $chamado->id,
                                            "title" => "Página de Acompanhamento",
                                            "fontawesome" => "<i class='fa-solid fa-eye'></i>",
                                            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
                                        ])
                                    @endif
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>

        </div>

</div>

@endsection