<!DOCTYPE html>
<html lang="pt-BR">
<head>
<meta charset="UTF-8">
<title>{{ __('Teste de E-mail - Portal Angra') }}</title>
</head>
<body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">

<table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
    <tr>
        <td align="center">

            <!-- Container -->
            <table width="600" cellpadding="0" cellspacing="0" style="background:#ffffff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">

                <!-- Header com logo -->
                <tr>
                    <td align="center" style="background-color:#007bc3; padding:30px;">
                        <img src="https://angra.rj.gov.br/pmar/assets/img/logo-angra-tematico-white.png"
                             alt="{{ __('Logo Prefeitura de Angra dos Reis') }}"
                             width="260"
                             style="max-width:260px; height:auto; display:block;">
                    </td>
                </tr>

                <!-- Corpo -->
                <tr>
                    <td style="padding:30px; color:#333333; font-size:15px; line-height:1.6;">

                        <p style="margin:0 0 15px;">
                            {{ __('Este é um e-mail de diagnóstico gerado pelo painel administrativo.') }}
                        </p>

                        <p style="margin:0 0 15px;">
                            {{ __('Se você recebeu esta mensagem, significa que o envio de e-mails via SMTP está funcionando corretamente.') }}
                        </p>

                        <table width="100%" cellpadding="0" cellspacing="0" style="margin:20px 0; border:1px solid #dddddd; border-radius:6px;">
                            <tr>
                                <td style="padding:12px 18px; background:#f7f7f7; font-size:13px; color:#555555;">
                                    <strong>{{ __('Referência') }}:</strong> {{ $referencia }}<br>
                                    <strong>{{ __('Gerado em') }}:</strong> {{ $geradoEm }}
                                </td>
                            </tr>
                        </table>

                        @if($observacao)
                        <p style="margin:0 0 15px;">
                            <strong>{{ __('Observação') }}:</strong><br>
                            {{ $observacao }}
                        </p>
                        @endif

                    </td>
                </tr>

                <!-- Rodapé -->
                <tr>
                    <td style="background:#f7f7f7; text-align:center; padding:18px; font-size:12px; color:#aaaaaa;">
                        {{ __('Prefeitura Municipal de Angra dos Reis') }}<br>
                        {{ __('Este é um e-mail automático, por favor não responda.') }}
                    </td>
                </tr>

            </table>
            <!-- Fim Container -->

        </td>
    </tr>
</table>

</body>
</html>
