<h3>Redes sociais</h3>
<div class="mb-3">
    <label for="facebook" class="form-label text-bold">Facebook:</label>
    <input type="text" class="form-control @error('facebook') is-invalid @enderror" name="facebook" id="facebook" autocomplete="off" value="{{ old('facebook') }}">
                            @error('facebook')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="instagram" class="form-label text-bold">Instagram:</label>
    <input type="text" class="form-control @error('instagram') is-invalid @enderror" name="instagram" id="instagram" autocomplete="off" value="{{ old('instagram') }}">
                            @error('instagram')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="twitter" class="form-label text-bold">Twitter:</label>
    <input type="text" class="form-control @error('twitter') is-invalid @enderror" name="twitter" id="twitter" autocomplete="off" value="{{ old('twitter') }}">
                            @error('twitter')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>