<?php if(isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar']): ?>
    <form class="del d-inline" action="<?php echo e(route($route, $id)); ?>" method="post">
        <?php echo csrf_field(); ?>
        <button class="text-danger text-decoration-none border-0 bg-transparent fs-5" type="submit">
            <span class="material-symbols-outlined"> 
                <?php if($fontawesome == null): ?>
                    <i class="text-danger fa-solid fa-rotate-left d-inline fs-5"></i> 
                <?php else: ?>
                    <?php echo $fontawesome; ?>

                <?php endif; ?>
            </span>
        </button>
    </form>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/buttons/_btnActionPost.blade.php ENDPATH**/ ?>