@extends('layouts.mobiangra.theme')

@section('title', __('Passageiro Cidadão - MobiAngra') . ' - ' . config('app.name'))

@section('content')
    <section class="mobiangra-subpage">
        <div class="container">
            <x-mobiangra.breadcrumb :items="[
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Passageiro Cidadão')],
            ]" />

            <div class="mobiangra-subpage-card">
                <x-mobiangra.subpage-header :title="__('Passageiro Cidadão')" />

                <div class="p-4 mobiangra-conteudo">
                    <h2 class="h4">{{ __('O que é?') }}</h2>
                    <p>
                        {{ __('O Programa Passageiro Cidadão é um benefício concedido pela Prefeitura Municipal de Angra dos Reis para proporcionar passagens de ônibus mais baratas para os seus moradores. O programa visa facilitar o acesso à cidade, promover a inclusão social e reduzir desigualdades.') }}
                    </p>
                    <p>
                        {{ __('Atualmente, o beneficiário do programa paga R$ 2,00 para as tarifas “A” e “B” e R$ 3,00 para a tarifa C, tendo direito a duas passagens diárias durante todos os dias da semana. Cabe ressaltar que há no Município o sistema de integração que possibilita mais de uma viagem de ônibus com uma única passagem sob certas condições.') }}
                    </p>

                    <h2 class="h4 mt-4">{{ __('Como obter o seu cartão?') }}</h2>
                    <ol class="mb-0">
                        <li class="mb-3">
                            <strong>{{ __('1º Passo - Pré-cadastro on-line:') }}</strong>
                            {{ __('Clique em CADASTRAR e preencha o formulário.') }}
                            <a href="https://angra.rj.gov.br/passageirocidadao" target="_blank" rel="noopener noreferrer">
                                {{ __('Clique aqui para se cadastrar') }}
                            </a>
                        </li>
                        <li class="mb-3">
                            <strong>{{ __('2º Passo - Agendamento:') }}</strong>
                            {{ __('Após o pré-cadastro, ligue para o número 0800 286 1500 e agende o atendimento presencial. Este serviço funciona exclusivamente de segunda a sexta-feira, das 10h às 16h.') }}
                            {{ __('Atenção: serão disponibilizadas diariamente 60 vagas de agendamento.') }}
                        </li>
                        <li class="mb-3">
                            <strong>{{ __('3º Passo - Cadastro presencial:') }}</strong>
                            {{ __('No dia e hora marcados, compareça à sede da Secretaria de Segurança Pública (Rua Marquês de Tamandaré, nº 156, Centro - Antigo Fórum) e apresente a documentação necessária (RG, CPF e comprovante de residência).') }}
                        </li>
                        <li class="mb-3">
                            <strong>{{ __('4º Passo - Biometria e retirada do cartão:') }}</strong>
                            {{ __('Com o documento emitido pela Secretaria de Segurança Pública em mãos, vá até a garagem da Viação Senhor do Bonfim (Rua Prefeito João Gregório Galindo, nº 110, Japuíba) para a realização da biometria facial (foto) e emissão do cartão.') }}
                        </li>
                    </ol>

                    <div class="alert alert-warning mt-4 mb-0" role="alert">
                        <h3 class="h5 alert-heading">{{ __('Cuidado com golpes!') }}</h3>
                        <p class="mb-2">
                            {{ __('O cadastro para o Programa Passageiro Cidadão é inteiramente GRATUITO e só é feito pela Prefeitura de Angra dos Reis. Em caso de mensagens suspeitas, entre em contato com o Disque Denúncia 0300 253 1177 e, em caso de golpe, acione a polícia.') }}
                        </p>
                        <p class="mb-0">
                            <a href="https://delegaciaonline.pcivil.rj.gov.br/" target="_blank" rel="noopener noreferrer">
                                {{ __('Delegacia Online - Polícia Civil do RJ') }}
                            </a>
                        </p>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection
