<!-- Segurança Pública -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-danger">
        <div class="card-header {{ $cor }} text-white">
            <div class="d-flex align-items-center">
                <i class="fas fa-shield-alt fa-2x me-3"></i>
                <h5 class="card-title mb-0">Segurança Pública</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-police-box me-2 text-muted"></i> Guarda Municipal <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-camera me-2 text-muted"></i> Monitoramento por câmeras <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-light-emergency me-2 text-muted"></i> Iluminação de segurança <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-people-robbery me-2 text-muted"></i> Prevenção à criminalidade <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-siren me-2 text-muted"></i> Patrulhamento preventivo <small class="badge bg-info">em breve</small></li>
            </ul>
        </div>
    </div>
</div>