@if (config('recaptcha.enabled'))
<script src="https://www.google.com/recaptcha/api.js?onload=onloadCallback&render=explicit" async defer type="text/x-javascript"></script>
@endif
<script src="{{ asset('pmar/js/jquery-3.7.1.min.js') }}"></script>
{{-- Bootstrap JS (via npm - copiado pelo Vite durante o build) --}}
<script src="{{ asset('pmar/build/bootstrap/js/bootstrap.bundle.min.js') }}"></script>
@if (Route::currentRouteName() == 'admin.login')
<script src="{{ asset('pmar/js/login.js') }}"></script>
@endif
@if (Route::currentRouteName() == 'admin.esqueceuSenha')
<script src="{{ asset('pmar/js/mascaras.js') }}"></script>
<script src="{{ asset('pmar/js/auth-masks.js') }}"></script>
<script src="{{ asset('pmar/js/auth-forgot-recaptcha.js') }}"></script>
@endif
@if (Route::currentRouteName() == 'admin.contas.publicas.create')
<script src="{{ asset('pmar/js/mascaras.js') }}"></script>
<script src="{{ asset('pmar/js/auth-create-recaptcha.js') }}"></script>
@endif
@if (Route::currentRouteName() == 'admin.novaConta')
<script src="{{ asset('pmar/js/mascaras.js') }}"></script>
<script src="{{ asset('pmar/js/auth-nova-conta-recaptcha.js') }}"></script>
@endif
