<div class="container mb-3">
    <div class="row">
        <div class="col-12">
            <address>
                Endereço: {{ $secretaria->address }}<br>
                Fone: {{ $secretaria->phoneNumber }}<br>
                E-mail: {{ $secretaria->email1 }}
                @if ($secretaria->email2 != null)
                    , {{ $secretaria->email2 }}
                @endif
                @if ($secretaria->email3 != null)
                    , {{ $secretaria->email3 }}
                @endif
            </address>
        </div>
    </div>
</div>
