@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Fluxo de Ônibus - Novo Agendamento - Dados da Empresa'))
@section('content')
    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-bus-simple'></i> " . __('Fluxo de Ônibus - Novo Agendamento  - Dados da Empresa'); @endphp

        @include('components.buttons._headLineButtonsBackAdd', 
            ['headLine' => $headLine, 
            'routeBack' => 'admin.turisAngra.fluxoDeOnibus.onibusTurismo.index', 
            'nameBack' => __('Lista de agendamentos'), 
            'fontawesomeBack' => '<i class="fa-solid fa-list"></i>', 
            'permission' => 'GERENCIADOR_DE_FLUXO_DE_ONIBUS'])

        <div class="card-body">
            @include('errors.messageFlash')
            
            <div class="alert alert-warning">
                
                <strong>ATENÇÃO</strong> <i class="fa-solid fa-triangle-exclamation"></i> : Caso sua empresa já esteja cadastrada na base de dados da Prefeitura de Angra dos Reis, não será possível realizar alterações diretamente por este sistema. Para atualização cadastral, é necessário abrir um chamado junto à Prefeitura.
                
            </div>

            <form action="{{ route('admin.turisAngra.fluxoDeOnibus.onibusTurismo.dadosDaEmpresaStore', $empresa?->id) }}" method="POST">
                @csrf
                @method("POST")
                
                <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">

                    @include('components.lists._liLinkBtnNavInterna', [
                        'items' => [
                            ['class' => 'active bg-success disabled', 'hash' => 'primeiraSection', 'label' => 'Dados de Empresa'],
                            ['class' => 'disabled', 'hash' => 'segundaSection', 'label' => 'Endereço'],
                            ['class' => 'disabled', 'hash' => 'terceiraSection', 'label' => 'Responsável Legal'],
                            ['class' => 'disabled', 'hash' => 'quartaSection', 'label' => 'Guia Turístico'],
                            ['class' => 'disabled', 'hash' => 'quintaSection', 'label' => 'Arquivos'],
                            ['class' => 'disabled', 'hash' => 'sextaSection', 'label' => 'Reserva'],
                        ]
                    ])

                </ul>
                

                <div class="row">
                    <div class="col-sm-12 col-md-6">
                    <!-- Campo Razão social -->
                        @include('components.inputs._inputType',[
                            "for" => "razaoSocial",
                            "label" => "Razão social",
                            "name" => "razaoSocial",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('razaoSocial', $empresa?->razaoSocial),
                            "oninput" => "javascript:this.value = this.value.toUpperCase()",
                            "readonly" => (isset($empresa?->razaoSocial) && $empresa?->razaoSocial != '' && $empresa?->razaoSocial != null) ? true : false,
                            "small" => null,
                        ])
                    </div>
                    <div class="col-sm-12 col-md-6">
                    <!-- Campo Razão social -->
                        @include('components.inputs._inputType',[
                            "for" => "nomeFantasia",
                            "label" => "Nome fantasia",
                            "name" => "nomeFantasia",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('nomeFantasia', $empresa?->nomeFantasia),
                            "oninput" => "javascript:this.value = this.value.toUpperCase()",
                            "readonly" => (isset($empresa?->nomeFantasia) && $empresa?->nomeFantasia != '' && $empresa?->nomeFantasia != null) ? true : false,
                            "small" => null,
                        ])
                    </div>
                </div>
                <div class="row">
                    <div class="col-sm-12 col-md-6">
                    <!-- Campo Inscrição municipal -->
                        @include('components.inputs._inputType',[
                            "for" => "numeroInscricaoMunicipal",
                            "label" => "Inscrição municipal",
                            "name" => "numeroInscricaoMunicipal",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('numeroInscricaoMunicipal', $empresa?->numeroInscricaoMunicipal),
                            "oninput" => "javascript:this.value = this.value.replace(/\D/g, '')",
                            "readonly" => (isset($empresa?->numeroInscricaoMunicipal) && $empresa?->numeroInscricaoMunicipal != '' && $empresa?->numeroInscricaoMunicipal != null) ? true : false,
                            "small" => null,
                        ])
                    </div>
                    <div class="col-sm-12 col-md-6">
                    <!-- Campo CNPJ -->
                        @include('components.inputs._inputType',[
                            "for" => "cnpj",
                            "label" => "CNPJ",
                            "name" => "cnpj",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('cnpj', session("cnpjTmp") ?? $empresa?->cnpj),
                            "oninput" => "javascript:aplicarMascaraCNPJ(this)",
                            "readonly" => (isset($empresa?->cnpj) && $empresa?->cnpj != '' && $empresa?->cnpj != null) ? true : false,
                            "small" => null,
                        ])
                    </div>
                </div>
                <div class="row">
                    <div class="col-sm-12 col-md-6">
                    <!-- Campo Ano de abertura -->
                        @include('components.inputs._inputType',[
                            "for" => "anoAbertura",
                            "label" => "Ano de abertura",
                            "name" => "anoAbertura",
                            "id" => "datepickerYear",
                            "required" => true,
                            "type" => 'year',
                            "old" => old('anoAbertura', $empresa?->anoAbertura),
                            "oninput" => "javascript:this.value = this.value.replace(/\D/g, '')",
                            "readonly" => (isset($empresa?->anoAbertura) && $empresa?->anoAbertura != '' && $empresa?->anoAbertura != null) ? true : false,
                            "small" => "Exemplo: 1942",
                        ])
                    </div>
                    <div class="col-sm-12 col-md-6">
                        <!-- Campo Cadastur -->
                        @include('components.inputs._inputType',[
                            'for' => null,
                            'label' => __('Cadastur'),
                            'name' => 'cadastur',
                            'id' => null,
                            'required' => true,
                            'type' => null,
                            'old' => old('cadastur', $empresa?->cadastur),
                            'oninput' => "javascript:this.value = this.value.replace(/\\D/g, '')",
                            'readonly' => (isset($empresa?->cadastur) && $empresa?->cadastur != '' && $empresa?->cadastur != null) ? true : false,
                            'small' => null,
                        ])
                    </div>
                </div>
                <div class="row">
                    <div class="col-sm-12 col-md-6">
                         <!-- Campo Celular -->
                        @include('components.inputs._inputType',[
                            "for" => "celular",
                            "label" => "Celular",
                            "name" => "celular",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('celular', $empresa?->celular),
                            "oninput" => "javascript:aplicarMascaraTelefone(this)",
                            "readonly" => (isset($empresa?->celular) && $empresa?->celular != '' && $empresa?->celular != null) ? true : false,
                            "small" => null,
                        ])
                    </div>
                    <div class="col-sm-12 col-md-6">
                       <!-- Campo Telefone -->
                        @include('components.inputs._inputType',[
                            "for" => "telefone",
                            "label" => "Telefone",
                            "name" => "telefone",
                            "id" => null,
                            "required" => true,
                            "type" => null,
                            "old" => old('telefone', $empresa?->telefone),
                            "oninput" => "javascript:aplicarMascaraTelefone(this)",
                            "readonly" => (isset($empresa?->telefone) && $empresa?->telefone != '' && $empresa?->telefone != null) ? true : false,
                            "small" => "Repetir o número do celular caso não possua telefone fixo",
                        ])
                    </div>
                </div>
                <div class="row">
                    <div class="col-sm-12 col-md-6">
                        <!-- Campo Email -->
                        @include('components.inputs._inputType',[
                            "for" => null,
                            "label" => "Email",
                            "name" => "email",
                            "id" => null,
                            "required" => true,
                            "type" => 'email',
                            "old" => old('email', $empresa?->email),
                            "oninput" => "javascript:this.value = this.value.toLowerCase()",
                            "readonly" => (isset($empresa?->email) && $empresa?->email != '' && $empresa?->email != null) ? true : false,
                            "small" => null,
                            "placeholder" => "nome@email.com",
                        ])
                    </div>
                    <div class="col-sm-12 col-md-6">
                        <!-- Campo Site -->
                        @include('components.inputs._inputType',[
                            "for" => "site",
                            "label" => "Site",
                            "name" => "site",
                            "id" => null,
                            "required" => false,
                            "type" => 'site',
                            "old" => old('site', $empresa?->site),
                            "readonly" => (isset($empresa?->site) && $empresa?->site != '' && $empresa?->site != null) ? true : false,
                            "small" => null,
                            "placeholder" => "https://meusite.com",
                        ])
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="row">
                            <div class="d-flex justify-content-between mt-4">
                                <a class="btn btn-dark" href="{{ route("admin.turisAngra.fluxoDeOnibus.onibusTurismo.index") }}">
                                    <i class="fa-solid fa-arrow-left-long"></i> {{ __("Sair") }}
                                </a>
                                <button class="btn btn-primary d-inline" type="submit">
                                    <i class="fa-solid fa-user-plus"></i> {{ __("Salvar e Prosseguir") }}
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
@endsection
