{{-- Conteúdo da célula ANDAMENTO: legenda institucional (cor) + texto livre --}}
@php
    $legendaPorCor = $legendaPorCor ?? [];
    $corKey = (string) ($cor ?? '');
    $legendaFixa = $corKey !== '' && isset($legendaPorCor[$corKey]) ? $legendaPorCor[$corKey] : null;
    $livre = trim((string) ($textoLivre ?? ''));
    $temConteudo = $legendaFixa || $livre !== '';
    $compacto = !empty($compacto);
@endphp
@if($temConteudo)
    <div class="pp-andamento-stack{{ $compacto ? ' pp-andamento-stack--compacto' : '' }}">
        @if($legendaFixa)
            <div class="pp-andamento-legenda" title="{{ $legendaFixa }}">{{ $compacto ? \Illuminate\Support\Str::limit($legendaFixa, 28) : $legendaFixa }}</div>
        @endif
        @if($livre !== '')
            <div class="pp-andamento-livre" title="{{ $livre }}">@if($legendaFixa)* @endif{{ $compacto ? \Illuminate\Support\Str::limit($livre, 24) : $livre }}</div>
        @endif
    </div>
@endif
