<section class="internas-secretarias-home-title">
    <div class="container">
        <div class="row">
            <div class="col">
                <?php if(isset($secretaria->pertence->name)): ?>
                    <h1><?php echo e($secretaria->name); ?></h1>
                    <p><?php echo e($secretaria->pertence->name); ?> (<?php echo e($secretaria->pertence->abbreviation); ?>)</p>
                <?php else: ?>
                    <h1><?php echo e($secretaria->name); ?></h1>
                    
                <?php endif; ?>
            </div>
        </div>
    </div>
</section><?php /**PATH /var/www/html/portal/resources/views/paginas/parts/headers.blade.php ENDPATH**/ ?>