<div class="form-check">
    <input class="form-check-input" type="checkbox" name="isWhatsapp" id="isWhatsapp"
           value="1"
           {{ old('isWhatsapp', $isWhatsapp ?? false) ? 'checked' : '' }}>
    <label class="form-check-label" for="isWhatsapp">
        {{ __("Este número também é Whatsapp?") }}
    </label>
</div>