<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'noticia',
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'noticia',
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<?php
    $slugDate = date('d-m-Y', strtotime($noticia->created_at));
    $noticiaUrl = route('paginas.slug', [$slugDate, $noticia->slug]);
    $titulo = html_entity_decode($noticia->title, ENT_QUOTES, 'UTF-8');
    $resumo = html_entity_decode($noticia->summary, ENT_QUOTES, 'UTF-8');
    $capaPadrao = asset('/pmar/assets/img/angra-default.png');
    $capaPath = ltrim((string) ($noticia->featuredPhoto ?? ''), '/');
    $capa = $capaPath !== '' && file_exists(public_path($capaPath))
        ? asset($noticia->featuredPhoto)
        : $capaPadrao;
?>

<article class="ma-news__card h-100">
    <a href="<?php echo e($noticiaUrl); ?>" class="ma-news__card-link text-reset text-decoration-none d-flex flex-column h-100">
        <div class="ratio ratio-16x9 ma-news__card-media">
            <img src="<?php echo e($capa); ?>"
                class="object-fit-cover"
                alt="<?php echo e(__('Capa da notícia')); ?>: <?php echo e(strip_tags($titulo)); ?>"
                loading="lazy">
        </div>
        <div class="ma-news__card-body flex-grow-1 d-flex flex-column">
            <h3 class="ma-news__card-title"><?php echo e($titulo); ?></h3>
            <p class="ma-news__card-text"><?php echo e(Str::limit(strip_tags($resumo), 120)); ?></p>
            <time class="ma-news__card-date mt-auto" datetime="<?php echo e($noticia->created_at); ?>">
                <?php echo e(app(App\Http\Controllers\Controller::class)->formatDateToPortuguese($noticia->created_at)); ?>

            </time>
        </div>
    </a>
</article>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/news-card.blade.php ENDPATH**/ ?>