@extends('layouts.pmar.theme')

@section('title', env('APP_NAME') . ' :: Cadastro de Pessoas Trans de Angra dos Reis')

@section('content')
<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a href="{{ route('paginas.home') }}">{{ __('Portal') }}</a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            {{ __('Cadastro de Pessoas Trans de Angra dos Reis') }}
                        </li>
                    </ol>
                </nav>
            </div>
        </div>

        <div class="row">
            <div class="col-lg-8">
                <h1 class="mb-3">{{ __('Cadastro de Pessoas Trans de Angra dos Reis') }}</h1>

                <p class="mb-3 fs-5">
                    Questionário de levantamento de dados das pessoas trans de Angra dos Reis.
                    As informações coletadas serão utilizadas exclusivamente para o planejamento,
                    qualificação e fortalecimento das ações e políticas públicas de saúde,
                    garantindo um cuidado mais humanizado, integral e respeitoso.
                </p>
                <p class="mb-4">
                    A sua participação é muito importante. As respostas serão tratadas com
                    <strong>sigilo, respeito e confidencialidade</strong>.
                </p>

                @if(session('success'))
                    <div class="alert alert-success alert-dismissible fade show" role="alert">
                        <i class="fa-solid fa-circle-check me-2"></i>
                        {{ session('success') }}
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                @endif

                @if(session('error'))
                    <div class="alert alert-danger alert-dismissible fade show" role="alert">
                        <i class="fa-solid fa-circle-exclamation me-2"></i>
                        {{ session('error') }}
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                @endif

                @if(session('info'))
                    <div class="alert alert-info alert-dismissible fade show" role="alert">
                        <i class="fa-solid fa-circle-info me-2"></i>
                        {{ session('info') }}
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                @endif

                <div class="alert alert-info mb-4">
                    <i class="fa-solid fa-circle-info me-2"></i>
                    Para preencher o formulário é necessário acessar com sua
                    <strong>Conta Angra</strong>. Caso ainda não tenha cadastro,
                    você poderá criá-lo na próxima etapa.
                </div>

                <div class="mb-4 pt-3 pb-5">
                    <a class="btn btn-lg btn-primary"
                       href="{{ auth()->check()
                                ? route('saude.pessoasTrans.formulario')
                                : route('admin.login', ['redirect' => route('saude.pessoasTrans.formulario')]) }}">
                        <i class="fa-solid fa-clipboard-check me-2"></i>
                        {{ __('Sim, desejo preencher o formulário de cadastro de pessoas trans.') }}
                    </a>
                </div>
            </div>

            <div class="col-lg-4">
                <div class="card shadow-sm border-0">
                    <div class="card-header bg-primary text-white">
                        <strong>{{ __('Antes de começar') }}</strong>
                    </div>
                    <div class="card-body">
                        <ol class="mb-0 ps-3">
                            <li class="mb-2">
                                {{ __('Tenha em mãos seus dados pessoais (nome social, CPF, endereço, contatos).') }}
                            </li>
                            <li class="mb-2">
                                {{ __('Reserve alguns minutos para responder com calma sobre saúde, renda e acesso aos serviços.') }}
                            </li>
                            <li class="mb-0">
                                Em caso de dúvidas, procure a Secretaria Municipal de Saúde ou fale conosco pelo e-mail: <a href="mailto:ssa.equidadeangra@gmail.com">ssa.equidadeangra@gmail.com</a>
                            </li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
@endsection

