<form id="formRecuperarSenha" name="formRecuperarSenha" autocomplete="off" method="post" action="{{ route('admin.enviarEmailRecuperacao') }}">
    @csrf
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('CPF ou E‑mail'),
        'name'=>'login',
        'id'=>'loginEsqueceu',
        'required'=>true,
        'type'=>null,
        'old'=>old('login'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
        <small class="small-login-esqueceu"></small>
    </div>
    <input type="hidden" name="recaptcha" id="recaptcha">
    <button class="btn btn-primary" type="submit" id="submitRecuperarSenha">{{ __('Enviar') }}</button>
    <div id='recaptchaRecuperarSenha' data-size="invisible"></div>
    <div class="my-3">
        <a href="{{ route("admin.login") }}" class="text-white">Login</a> | <a href="{{ route("admin.contas.publicas.create") }}" class="text-white">Crie sua conta</a>
    </div>
</form>
