@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: ' . $secretaria->name)
@section('content')
    <section>
        <div class="container mb-4">
            <div class="row">
                <hr />
                <div class="col-12">
                    <x-portal.breadcrumb :items="\App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, $secretaria->manager)" />
                </div>

                <div class="col-12 col-md-8 mt-4">
                    <div class="row mb-3">
                        <h1 class="name-secretario mb-3">{{ $secretaria->pronunciation }}</h1>
                        <div class="col-sm-12 col-md-4">
                            <img src="{{ asset($secretaria->managerPhoto) }}" class="img-fluid img-thumbnail"
                                alt="{{ $secretaria->manager }}" title="{{ $secretaria->manager }}"
                                style="border: none; border-radius: 0;" />
                        </div>
                        <div class="col-sm-12 col-md-8">
                            @foreach (App\Enums\StructuresPronunciationStatusEnum::cases() as $pronunciation)
                                @if ($pronunciation->name == $secretaria->pronunciation)
                                    <h3>{{ $secretaria->manager }}</h3>
                                @endif
                            @endforeach
                            <div>{!! $secretaria->academicBackground !!}</div>
                        </div>
                    </div>
                </div>
                
            </div>
        </div>
    </section>
@endsection
