<form action="{{ route('admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesStore', $ambulante->id) }}" method="post" enctype="multipart/form-data">

    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">

                        <div class="mb-3 p-5 bg-secondary text-white rounded">
                            <h1>{{ $ambulante->proprietario->firstName }} {{ $ambulante->proprietario->lastName }}</h1>
                            <p class="text-white">CPF: {{ $ambulante->proprietario->cpf }}</p>
                            <p class="text-white">Telefone: {{ $ambulante->proprietario->phoneNumber }}</p>
                            <p class="text-white">Email: {{ $ambulante->proprietario->email }}</p>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="container my-3">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Demais informações</h5>
                        <div class="container">
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        @csrf
                                        @method('POST')
                                        <label for="tempoResidenciaAngra" class="form-label text-bold">Tempo de residência em Angra dos Reis:</label>
                                        <input type="text" class="form-control @error('tempoResidenciaAngra') is-invalid @enderror" name="tempoResidenciaAngra" id="tempoResidenciaAngra" value="{{ old('tempoResidenciaAngra', $ambulante?->tempoResidenciaAngra ?? NULL) }}" oninput="this.value = this.value.replace(/[^0-9]/g, '')" autocomplete="off">
                                        @error('tempoResidenciaAngra')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="nacionalidade" class="form-label text-bold">Nacionalidade:</label>
                                        <input class="form-control  @error('nacionalidade') is-invalid @enderror" list="optionsPaises" name="nacionalidade" id="nacionalidade" oninput="this.value = this.value.toUpperCase()" value="{{ old('nacionalidade', $pessoa?->nacionalidade ?? NULL) }}" placeholder="" autocomplete="off">
                                        <datalist id="optionsPaises">
                                            @foreach($paises as $pais)
                                                <option value="{{ $pais["nome_pais"] }}, {{ $pais["nome_pais_int"] }}"></option>
                                            @endforeach
                                        </datalist>
                                        @error('nacionalidade')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="naturalidadeCidade" class="form-label text-bold">Naturalidade: <small class="text-primary">igual ao do documento</small></label> 
                                        <input type="text" class="form-control @error('naturalidadeCidade') is-invalid @enderror" name="naturalidadeCidade" id="naturalidadeCidade" oninput="this.value = this.value.toUpperCase()" value="{{ old('naturalidadeCidade', $pessoa?->naturalidadeCidade ?? NULL) }}" autocomplete="off">
                                        @error('naturalidadeCidade')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="naturalidadeEstado" class="form-label text-bold">Estado:</label>
                                        <input type="text" class="form-control @error('naturalidadeEstado') is-invalid @enderror" list="optionsEstados" name="naturalidadeEstado" id="naturalidadeEstado" oninput="this.value = this.value.toUpperCase()" value="{{ old('naturalidadeEstado', $pessoa?->naturalidadeEstado ?? NULL) }}" autocomplete="off">
                                        <datalist id="optionsEstados">
                                            <option value="Acre"></option>
                                            <option value="Alagoas"></option>
                                            <option value="Amapá"></option>
                                            <option value="Amazonas"></option>
                                            <option value="Bahia"></option>
                                            <option value="Ceará"></option>
                                            <option value="Distrito Federal"></option>
                                            <option value="Espírito Santo"></option>
                                            <option value="Goiás"></option>
                                            <option value="Maranhão"></option>
                                            <option value="Mato Grosso"></option>
                                            <option value="Mato Grosso do Sul"></option>
                                            <option value="Minas Gerais"></option>
                                            <option value="Pará"></option>
                                            <option value="Paraíba"></option>
                                            <option value="Paraná"></option>
                                            <option value="Pernambuco"></option>
                                            <option value="Piauí"></option>
                                            <option value="Rio de Janeiro"></option>
                                            <option value="Rio Grande do Norte"></option>
                                            <option value="Rio Grande do Sul"></option>
                                            <option value="Rondônia"></option>
                                            <option value="Roraima"></option>
                                            <option value="Santa Catarina"></option>
                                            <option value="São Paulo"></option>
                                            <option value="Sergipe"></option>
                                            <option value="Tocantins"></option>
                                        </datalist>
                                        @error('naturalidadeEstado')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="racaCor" class="form-label text-bold">Raça/Cor: <small class="text-primary">refere-se à tonalidade da pele e etnia.</small></label>
                                        <input class="form-control  @error('racaCor') is-invalid @enderror" list="optionsRaca" name="racaCor" id="racaCor" value="{{ old('racaCor', $pessoa?->racaCor ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" placeholder="" autocomplete="off">
                                        <datalist id="optionsRaca">
                                            <option value="Branca"></option>
                                            <option value="Preta"></option>
                                            <option value="Parda"></option>
                                            <option value="Amarela"></option>
                                            <option value="Indígena"></option>
                                        </datalist>
                                        @error('racaCor')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="nacimento_at" class="form-label text-bold">Data de Nascimento: <span class="span-admin-create">*</span></label>
                                        <input type="date" class="form-control @error('nacimento_at') is-invalid @enderror" name="nacimento_at" id="nacimento_at" value="{{ old('nacimento_at', $pessoa?->nacimento_at ?? NULL) }}" autocomplete="off">
                                        @error('nacimento_at')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="escolaridade" class="form-label text-bold">Escolaridade: </label>
                                        <input class="form-control  @error('escolaridade') is-invalid @enderror" list="optionsEscolaridade" name="escolaridade" id="escolaridade" value="{{ old('escolaridade', $pessoa?->escolaridade ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" placeholder="" autocomplete="off">
                                        <datalist id="optionsEscolaridade">
                                            <option value="Nível 1 – Educação Básica Inicial - Analfabeto – Pessoa que não sabe ler e escrever."></option>
                                            <option value="Nível 1 – Educação Básica Inicial - Até 5º Ano Incompleto – Escolaridade interrompida antes da conclusão da antiga 4ª série (atual 5º ano do Ensino Fundamental)."></option>
                                            <option value="Nível 1 – Educação Básica Inicial - 5º Ano Completo – Conclusão do 5º ano do Ensino Fundamental (antiga 4ª série)."></option>
                                            <option value="Nível 1 – Educação Básica Inicial - 6º ao 9º Ano do Fundamental – Ensino Fundamental II em andamento (antigas 5ª a 8ª séries)."></option>
                                            <option value="Nível 2 – Fundamental Completo - Fundamental Completo – Conclusão do 9º ano do Ensino Fundamental."></option>
                                            <option value="Nível 3 – Ensino Médio - Médio Incompleto – Ensino Médio iniciado, mas não concluído."></option>
                                            <option value="Nível 3 – Ensino Médio - Médio Completo – Conclusão do Ensino Médio (antigo 2º grau)."></option>
                                            <option value="Nível 4 – Ensino Superior - Superior Incompleto – Graduação em andamento."></option>
                                            <option value="Nível 4 – Ensino Superior - Superior Completo – Conclusão de curso superior de graduação."></option>
                                            <option value="Nível 5 – Pós-Graduação - Mestrado – Pós-graduação stricto sensu, nível de pesquisa e titulação acadêmica de Mestre."></option>
                                            <option value="Nível 5 – Pós-Graduação - Doutorado – Pós-graduação stricto sensu, titulação acadêmica de Doutor."></option>
                                            <option value="Sem Nível - Ignorado – Informação não declarada ou não classificada."></option>
                                        </datalist>
                                        @error('escolaridade')
                                            <small class="text-danger text-bold">{{ $message }}</small>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    <div class="mb-3">
                                        <label for="sexo" class="form-label text-bold">Sexo: </label>
                                        <input class="form-control  @error('sexo') is-invalid @enderror" list="optionsSexo" name="sexo" id="sexo" value="{{ old('sexo', $pessoa?->sexo ?? NULL) }}" oninput="this.value = this.value.toUpperCase()" placeholder="" autocomplete="off">
                                        <datalist id="optionsSexo">
                                            <option value="Masculino"></option>
                                            <option value="Feminino"></option>
                                            <option value="Prefiro não informar"></option>
                                        </datalist>
                                    @error('sexo')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-7">
                                <div class="mb-3">
                                    <label for="profissao" class="form-label text-bold">Profissão:</label>
                                    <input class="form-control  @error('profissao') is-invalid @enderror" list="optionsProfissoes" name="profissao" id="profissao" oninput="this.value = this.value.toUpperCase()" value="{{ old('profissao', $pessoa?->profissao ?? NULL) }}" placeholder="" autocomplete="off">
                                    <datalist id="optionsProfissoes">
                                        @foreach($ocupacoes as $ocupacao)
                                            <option value="{{ $ocupacao["name"] }}"></option>
                                        @endforeach
                                    </datalist>
                                    @error('profissao')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-sm-12 col-md-5">
                                <div class="mb-3">
                                    <label for="ocupacaoSecundaria" class="form-label text-bold">Ocupação Secundaria:</label>
                                    <input class="form-control  @error('ocupacaoSecundaria') is-invalid @enderror" list="optionsOcupacaoSecundaria" name="ocupacaoSecundaria" id="ocupacaoSecundaria" oninput="this.value = this.value.toUpperCase()" value="{{ old('ocupacaoSecundaria', $pessoa?->ocupacaoSecundaria ?? NULL) }}" placeholder="" autocomplete="off">
                                    <datalist id="optionsOcupacaoSecundaria">
                                        @foreach($ocupacoes as $ocupacao)
                                            <option value="{{ $ocupacao["name"] }}"></option>
                                        @endforeach
                                    </datalist>
                                    @error('ocupacaoSecundaria')
                                        <small class="text-danger text-bold">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>
                        </div>
                    </div> 
                </div>
            </div>
        </div>
    </div>
    </div>
    <div class="d-flex justify-content-between mt-4">
        <a class="btn btn-outline-secondary" href="{{ route("admin.cadastroDeAmbulantes.ambulantes.dadosDoComercioIndex", $ambulante->id ) }}">
            <i class="fa-solid fa-arrow-left-long"></i> Anterior
        </a>
        <button class="btn btn-primary d-inline" type="submit">
            <i class="fa-solid fa-user-plus"></i> Salvar e Prosseguir
        </button>
    </div>
</form>