@extends('layouts.parquedacidade.theme')
@section('title', 'Bem-vindo ao Parque da Cidade da Prefeitura Municipal de Angra dos Reis')
@section('content')

    <div class="page-title dark-background" data-aos="fade"
        style="background-image: url({{ asset('parquedacidade/imagens/img-fundo.jpg') }});">
        <div class="container position-relative">
            <h1 class="text-white">O Parque da Cidade</h1>
        </div>
    </div>

    <div class="container">
        <div class="row internas mt-5">

            <div class="col-12 blog-post">
                <div class="row justify-content-center mb-5">
                    <div class="col-12">
                        <h2 class="mb-4 text-center">Parque Natural Municipal da Mata Atlântica</h2>
                        <div class="card border-0 shadow-lg w-50 mx-auto">
                            <img src="{{ asset('parquedacidade/asset/images/parque-aerea.jpg') }}"
                                class="card-img-top rounded-top" alt="Vista aérea do parque da cidade. Baía da Ribeira">
                            <div class="card-body bg-light text-center">
                                <p class="card-text fst-italic mb-0">Vista aérea do Parque da Cidade - Baía da Ribeira</p>
                            </div>
                        </div>
                        <p class="lead mt-3 mb-4">O belíssimo cenário formado pelo mar de águas cristalinas cercado pelo
                            paredão
                            de montanhas e ilhas dominadas pelo verde da Mata Atlântica atrai turistas do mundo inteiro para
                            a Baía da Ilha Grande. No entanto, esse mesmo cenário sofre com a ocupação desordenada, a falta
                            de atrativos na região central e a baixa sinergia entre as unidades de conservação e seu uso
                            pela população.</p>

                        <p class="mb-4">Entre as diversas tipologias de unidades de conservação, os <strong>Parques</strong>
                            visam aproximar o público da natureza. Caminhadas, mirantes, escaladas, voo livre — seja qual
                            for a experiência, o contato com a natureza nos conecta aos ciclos e elementos naturais.</p>

                        <blockquote class="blockquote border-start border-3 border-success ps-3 mb-4">
                            <p class="mb-3">"Conhecer para preservar."</p>
                            <footer class="blockquote-footer">Lema dos Parques Naturais</footer>
                        </blockquote>

                        <p class="mb-4">É com esse espírito que foi criado, por meio do Decreto nº 10.760, de 26 de dezembro
                            de 2017, o <strong>Parque Natural Municipal da Mata Atlântica</strong> — ou simplesmente
                            <strong>Parque da Cidade</strong>. A unidade é administrada pelo Instituto Municipal do Ambiente
                            (IMAAR) e tem como pilares: <strong>ordenamento do solo, preservação ambiental e desenvolvimento
                                do ecoturismo</strong>.
                        </p>

                        <p class="mb-4">O Parque abrange as terras altas que cercam o centro de Angra dos Reis, passando por
                            morros como Carioca, Santo Antônio, Caixa D’água, Carmo, Peres, Glória, da Cruz, Encruzo,
                            Enseada, Retiro, Ribeira, Vila Velha, Praia Grande, Bonfim e Colégio Naval.</p>

                        <p class="mb-4">O <strong>Plano de Manejo</strong> está em elaboração. Ele definirá trilhas,
                            mirantes, estruturas administrativas, áreas de reflorestamento, atividades permitidas e a
                            viabilidade econômica do projeto.</p>

                        <p class="fs-5 fw-semibold text-success-emphasis mb-0">Nosso maior desafio é transformar o Parque da
                            Cidade em um atrativo turístico sustentável, que gere empregos e renda, preserve a
                            biodiversidade e desperte o sentimento de pertencimento em moradores e visitantes.</p>

                        <h2 class="mb-4 mt-5">A logomarca</h2>
                        <p class="lead">A escolha foi feita por votação popular no site da Prefeitura de Angra dos Reis.</p>
                        <p class="lead"><strong>Considerações da logomarca:</strong></p>
                        <p class="lead">As Identidades Visuais do PARQUE DA CIDADE/Parque Natural Municipal da Mata
                            Atlântica foram
                            criadas a
                            partir das seguintes premissas: Criatividade, adequação e rigor técnico.</p>
                        <p class="lead">A marca, aqui, se inspira na paisagem, buscou-se traduzir de maneira figurativa o
                            contexto do
                            Parque. De
                            uma sobreposição de formas surgem as montanhas... mar e mão se fundem... e a mensagem se
                            apresenta: é
                            imperativo preservar e cuidar do parque e das pessoas. A mão acolhe, dá suporte e, ao mesmo
                            tempo, dá
                            leveza.</p>
                        <p class="lead">O círculo representa o todo, é uma forma arquetípica que simboliza o sol, a terra, a
                            lua, o
                            universo.
                            Está diretamente ligado à natureza.</p>
                        <p class="lead">A tipologia, toda em caixa alta com bordas arredondadas, tem ótima legibilidade. As
                            serifas,
                            presentes
                            apenas na parte superior das letras, equilibra os conceitos de tradição e modernidade.</p>
                        <p class="fs-5 fw-semibold text-success-emphasis mb-0">As cores laranja/terra, azul/água e
                            verde/floresta são vivas, atraentes e conferem frescor e
                            dinamismo à
                            marca.</p>
                        <img src="{{ asset('parquedacidade/asset/images/logo.png') }}" class="d-block mx-auto" style="width: 50% !important;" alt="Logo do Parque da Cidade">
                        <h2 class="mb-4 mt-5">Cinturão Verde</h2>
                        <img src="{{ asset('parquedacidade/asset/images/cinturao-verde.jpg') }}" class="img-responsive"
                            alt="Imagem do Cinturão Verde do Parque da Cidade">
                    </div>
                </div>
            </div>

        </div>
    </div>

@endsection