<section class="ma-alerts-promo" id="ma-nearby-promo">
    <div class="container">
        <div class="row g-4">
            <div class="col-12 col-lg-7 order-2 order-lg-1">
                <div class="ma-alerts">
                    <x-mobiangra.nearby-lines-card />
                </div>
            </div>

            <div class="col-12 col-lg-5 order-1 order-lg-2">
                <article class="ma-promo">
                    <div class="ma-promo__header">
                        <i class="fa-solid fa-leaf ma-promo__icon" aria-hidden="true"></i>
                        <h2 class="ma-promo__title">{{ __('Transporte público é mais qualidade de vida') }}</h2>
                    </div>
                    <p class="ma-promo__text">
                        {{ __('Use, cuide e valorize o que é de todos. O transporte coletivo conecta pessoas, reduz o trânsito e melhora a qualidade de vida em Angra dos Reis.') }}
                    </p>
                    <a href="{{ route('mobiangra.informacoes') }}" class="btn btn-outline-success ma-promo__btn">
                        {{ __('Saiba mais') }}
                    </a>
                </article>
            </div>
        </div>
    </div>
</section>
