@php
    $trail = [
        \App\Support\PortalBreadcrumb::link(
            __('Portal de Dados Abertos'),
            route('servicos.dadosAbertos.index')
        ),
    ];
    $items = \App\Support\PortalBreadcrumb::forServicosPage($trail, $current);
@endphp

<x-portal.breadcrumb :items="$items" />
