@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Nova Unidade Escolar'))
@section('content')

    <form action="{{ route('admin.escolas.store') }}" method="post" enctype="multipart/form-data">
        <div class="container py-3">
            <div class="row">
                <div class="col-12">
                    <div class="card shadow">
                        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center mb-3">
                            <h5 class="mb-0">{{ __('Nova Unidade Escolar') }}</h5>
                        </div>
                        <div class="card-body">
                            @csrf
                            @include("errors.messageFlash")

                            {{-- Secretaria --}}
                            <div class="mb-3">
                                <label for="structureID" class="form-label text-bold">
                                    {{ __('Pertence a:') }} <span class="span-admin-create">*</span>
                                </label>
                                <select class="form-control @error('structure_id') is-invalid @enderror"
                                    name="structure_id" id="structureID">
                                    @foreach($secretarias as $secretaria)
                                        <option value="{{ $secretaria->id }}"
                                            {{ old('structure_id') == $secretaria->id ? 'selected' : '' }}>
                                            {{ $secretaria->name }} ({{ $secretaria->abbreviation }})
                                        </option>
                                    @endforeach
                                </select>
                                @error('structure_id')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Tipo de unidade --}}
                            <div class="mb-3">
                                <label for="tipoUnidadeEscolar" class="form-label text-bold">
                                    {{ __('Tipo de unidade:') }} <span class="span-admin-create">*</span>
                                </label>
                                <select class="form-control @error('tipoUnidadeEscolar') is-invalid @enderror"
                                    name="tipoUnidadeEscolar" id="tipoUnidadeEscolar">
                                    <option value="Escola" {{ old('tipoUnidadeEscolar') == 'Escola' ? 'selected' : '' }}>
                                        {{ __('Escola') }}
                                    </option>
                                    <option value="Creche" {{ old('tipoUnidadeEscolar') == 'Creche' ? 'selected' : '' }}>
                                        {{ __('Creche') }}
                                    </option>
                                    <option value="Escola e creche" {{ old('tipoUnidadeEscolar') == 'Escola e creche' ? 'selected' : '' }}>
                                        {{ __('Escola e creche') }}
                                    </option>
                                </select>
                                @error('tipoUnidadeEscolar')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Foto --}}
                            <div class="mb-3">
                                <label for="foto" class="form-label text-bold">{{ __('Foto da unidade:') }}</label>
                                <input type="file" class="form-control" name="foto" id="foto"
                                    accept="image/jpeg,image/jpg,image/png,image/gif">
                                @error('foto')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Nome --}}
                            <div class="mb-3">
                                <label for="nome" class="form-label text-bold">
                                    {{ __('Nome da unidade escolar:') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('nome') is-invalid @enderror"
                                    name="nome" id="nome" autocomplete="off"
                                    value="{{ old('nome') }}">
                                @error('nome')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Telefone --}}
                            <div class="mb-3">
                                <label for="telefone" class="form-label text-bold">{{ __('Telefone:') }}</label>
                                <input type="text"
                                    class="form-control @error('telefone') is-invalid @enderror"
                                    name="telefone" id="telefone" autocomplete="off"
                                    value="{{ old('telefone') }}">
                                @error('telefone')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- E-mail --}}
                            <div class="mb-3">
                                <label for="email" class="form-label text-bold">{{ __('Email:') }}</label>
                                <input type="email"
                                    class="form-control @error('email') is-invalid @enderror"
                                    name="email" id="email" autocomplete="off"
                                    value="{{ old('email') }}">
                                @error('email')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Recursos multifuncionais --}}
                            <div class="form-check mb-3">
                                <input class="form-check-input" type="checkbox"
                                    name="possuiRecursosMultifuncionais"
                                    id="possuiRecursosMultifuncionais">
                                <label class="form-check-label" for="possuiRecursosMultifuncionais">
                                    {{ __('Esta unidade oferece salas de recursos multifuncionais?') }}
                                </label>
                            </div>

                            <hr>

                            {{-- Tipo de imóvel --}}
                            <div class="mb-3">
                                <label for="domicilio" class="form-label text-bold">
                                    {{ __('Tipo de imóvel:') }} <span class="span-admin-create">*</span>
                                </label>
                                <select class="form-control @error('domicilio') is-invalid @enderror"
                                    name="domicilio" id="domicilio">
                                    @foreach(App\Enums\StatusDomicilio::cases() as $domicilio)
                                        <option value="{{ $domicilio->name }}"
                                            {{ old('domicilio') == $domicilio->name ? 'selected' : '' }}>
                                            {{ $domicilio->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('domicilio')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- CEP --}}
                            <div class="mb-3">
                                <label for="zipCode" class="form-label">
                                    {{ __('CEP') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('cep') is-invalid @enderror"
                                    name="cep" id="zipCode"
                                    oninput="aplicarMascaraCEP(this)"
                                    autocomplete="off" value="{{ old('cep') }}" required>
                                @error('cep')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Logradouro --}}
                            <div class="mb-3">
                                <label for="street" class="form-label">
                                    {{ __('Logradouro') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('logradouro') is-invalid @enderror"
                                    name="logradouro" id="street" autocomplete="off"
                                    value="{{ old('logradouro') }}">
                                @error('logradouro')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Número --}}
                            <div class="mb-3">
                                <label for="numero" class="form-label">{{ __('Número') }}</label>
                                <input type="text"
                                    class="form-control @error('numero') is-invalid @enderror"
                                    name="numero" id="numero" value="{{ old('numero') }}">
                                @error('numero')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Complemento --}}
                            <div class="mb-3">
                                <label for="complemento" class="form-label">{{ __('Complemento') }}</label>
                                <input type="text" class="form-control" name="complemento"
                                    id="complemento" value="{{ old('complemento') }}">
                            </div>

                            {{-- Cidade --}}
                            <div class="mb-3">
                                <label for="city" class="form-label">
                                    {{ __('Cidade') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('cidade') is-invalid @enderror"
                                    name="cidade" id="city" autocomplete="off"
                                    value="{{ old('cidade') }}">
                                @error('cidade')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Bairro --}}
                            <div class="mb-3">
                                <label for="neighborhood" class="form-label">
                                    {{ __('Bairro') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('bairro') is-invalid @enderror"
                                    name="bairro" id="neighborhood" autocomplete="off"
                                    value="{{ old('bairro') }}">
                                @error('bairro')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- UF --}}
                            <div class="mb-3">
                                <label for="state" class="form-label">
                                    {{ __('UF') }} <span class="span-admin-create">*</span>
                                </label>
                                <input type="text"
                                    class="form-control @error('uf') is-invalid @enderror"
                                    name="uf" id="state" maxlength="2" autocomplete="off"
                                    value="{{ old('uf') }}">
                                @error('uf')
                                    <small class="text-danger">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Geolocalização --}}
                            <div class="mb-2">
                                <label class="form-label text-bold">
                                    <i class="fas fa-map-marker-alt me-1 text-danger"></i>
                                    {{ __('Geolocalização') }}
                                </label>
                                <p class="text-muted small mb-2">
                                    {{ __('Clique no mapa para marcar a localização da unidade. Você também pode arrastar o marcador ou preencher manualmente os campos abaixo.') }}
                                </p>
                            </div>

                            <div class="row g-3 mb-3">
                                <div class="col-md-6">
                                    <label for="latitude" class="form-label">
                                        {{ __('Latitude') }}
                                    </label>
                                    <input type="text"
                                        class="form-control @error('latitude') is-invalid @enderror"
                                        name="latitude" id="latitude" value="{{ old('latitude') }}"
                                        autocomplete="off"
                                        placeholder="-23.0067">
                                    @error('latitude')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                                <div class="col-md-6">
                                    <label for="longitude" class="form-label">
                                        {{ __('Longitude') }}
                                    </label>
                                    <input type="text"
                                        class="form-control @error('longitude') is-invalid @enderror"
                                        name="longitude" id="longitude" value="{{ old('longitude') }}"
                                        autocomplete="off"
                                        placeholder="-44.3184">
                                    @error('longitude')
                                        <small class="text-danger">{{ $message }}</small>
                                    @enderror
                                </div>
                            </div>

                            {{-- Mapa interativo Leaflet --}}
                            <div id="map"
                                 data-lat="{{ old('latitude') }}"
                                 data-lng="{{ old('longitude') }}"
                                 data-nome="{{ old('nome') }}"
                                 class="mb-3"
                                 role="application"
                                 aria-label="{{ __('Mapa para seleção de localização') }}">
                            </div>

                            <hr>

                            {{-- Climatização --}}
                            <div class="mb-3">
                                <label for="climatizacao" class="form-label text-bold">
                                    <i class="fas fa-snowflake me-1 text-info"></i>
                                    {{ __('Climatização:') }} <span class="span-admin-create">*</span>
                                </label>
                                <select class="form-control @error('climatizacao') is-invalid @enderror"
                                    name="climatizacao" id="climatizacao">
                                    @foreach(App\Enums\ClimatizacaoEnum::cases() as $item)
                                        <option value="{{ $item->name }}"
                                            {{ old('climatizacao', 'PENDENTE') === $item->name ? 'selected' : '' }}>
                                            {{ $item->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('climatizacao')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Observações da Climatização --}}
                            <div class="mb-3">
                                <label for="observacoes_climatizacao" class="form-label text-bold">
                                    {{ __('Observações da Climatização:') }}
                                </label>
                                <textarea class="form-control textarea-observacoes @error('observacoes_climatizacao') is-invalid @enderror"
                                    name="observacoes_climatizacao"
                                    id="observacoes_climatizacao"
                                    placeholder="{{ __('Ex: 4 salas climatizadas, 2 aparelhos instalados em 2025, restante pendente de aquisição...') }}">{{ old('observacoes_climatizacao') }}</textarea>
                                @error('observacoes_climatizacao')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <hr>

                            {{-- Informações gerais --}}
                            <div class="mb-3">
                                <label for="informacoes" class="form-label text-bold">
                                    {{ __('Informações:') }}
                                </label>
                                <textarea class="form-control textarea-body @error('informacoes') is-invalid @enderror"
                                    name="informacoes"
                                    id="informacoes">{{ old('informacoes') }}</textarea>
                                @error('informacoes')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            {{-- Status --}}
                            <div class="mb-3">
                                <label for="status" class="form-label text-bold">
                                    {{ __('Status:') }} <span class="span-admin-create">*</span>
                                </label>
                                <select class="form-control @error('status') is-invalid @enderror"
                                    name="status" id="status">
                                    @foreach(App\Enums\StatusEnum::cases() as $statusEnum)
                                        <option value="{{ $statusEnum->name }}"
                                            {{ old('status') === $statusEnum->name ? 'selected' : '' }}>
                                            {{ $statusEnum->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('status')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack'  => __('Voltar'),
                                'textSend'  => __('Cadastrar'),
                                'routeBack' => 'admin.escolas.index',
                            ])
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </form>

@endsection
