<div class="row">
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('CEP') . ' *',
            'name' => 'cep',
            'id' => 'zipCode',
            'required' => true,
            'type' => null,
            'old' => old('cep', $endereco->cep ?? null),
            'oninput' => "javascript:aplicarMascaraCEP(this)",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-6">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Logradouro') . ' *',
            'name' => 'logradouro',
            'id' => 'street',
            'required' => true,
            'type' => null,
            'old' => old('logradouro', $endereco->logradouro ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-2">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Número'),
            'name' => 'numero',
            'id' => 'numero',
            'required' => false,
            'type' => null,
            'old' => old('numero', $endereco->numero ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
</div>
<div class="row">
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Complemento'),
            'name' => 'complemento',
            'id' => 'complemento',
            'required' => false,
            'type' => null,
            'old' => old('complemento', $endereco->complemento ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Cidade') . ' *',
            'name' => 'cidade',
            'id' => 'city',
            'required' => true,
            'type' => null,
            'old' => old('cidade', $endereco->cidade ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Bairro') . ' *',
            'name' => 'bairro',
            'id' => 'neighborhood',
            'required' => true,
            'type' => null,
            'old' => old('bairro', $endereco->bairro ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('UF') . ' *',
            'name' => 'uf',
            'id' => 'state',
            'required' => true,
            'type' => null,
            'old' => old('uf', $endereco->uf ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
            'listName' => 'estadosBrasileiros',
            'arrayList' => [
                'AC', 'AL', 'AM', 'AP', 'BA', 'CE', 'DF', 'ES', 'GO',
                'MA', 'MG', 'MS', 'MT', 'PA', 'PB', 'PE', 'PI', 'PR',
                'RJ', 'RN', 'RO', 'RR', 'RS', 'SC', 'SE', 'SP', 'TO'
            ],
        ])
    </div>
</div>

<div class="row">
    <div class="col-sm-12 col-md-3 d-flex justify-content-center align-self-center">
        @include('components.modal._mapModal',[
            'label' => __('Clique no mapa e escolha um determinado ponto'),
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Latitude') . ' *',
            'name' => 'latitude',
            'id' => 'latitude',
            'required' => true,
            'type' => null,
            'old' => old('latitude', $endereco->latitude ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Longitude') . ' *',
            'name' => 'longitude',
            'id' => 'longitude',
            'required' => true,
            'type' => null,
            'old' => old('longitude', $endereco->longitude ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Comprovante de endereço'),
            'name' => 'comprovante',
            'id' => null,
            'required' => false,
            'type' => 'file',
            'old' => null,
            'oninput' => null,
            'readonly' => true,
            'small' => null,
            'accept' => 'image/jpeg,image/jpg,image/png,image/gif,.pdf',
        ])
    </div>
</div>
