<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover">
    <meta name="robots" content="noindex, nofollow">
    <title>{{ __('Mapa MobiAngra') }}</title>
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css"
        integrity="sha256-p4NxAoJBhIIN+hmNHrzRCf9tD/miZyoHS5obTRR9BMY=" crossorigin="">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/maplibre-gl/4.7.1/maplibre-gl.min.css"
        integrity="sha512-qN/uDg9bS3IAldWq4lswyC+9ZSoShtfyNDp+FaJhdtXJqdgubHA+s4nB8BajW0m90Y0+RBGbqu2anzbxiQYdHA="
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css"
        crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="{{ asset('mobiangra-assets/css/mapa-embed.css') }}?v={{ @filemtime(public_path('mobiangra-assets/css/mapa-embed.css')) ?: time() }}">
</head>
<body class="ma-embed-body">
    <div id="ma-embed-map" role="application" aria-label="{{ __('Mapa resumido do transporte coletivo') }}"></div>

    <script>
        window.MOBIANGRA_EMBED = {
            liveDataUrl: @json(route('mobiangra.live_data')),
            shapesUrl: @json(route('mobiangra.shapes')),
            tripsUrl: @json(route('mobiangra.trips')),
            routeNames: @json($routeNames),
            lineColors: @json($lineColors),
            vehicleColors: @json($vehicleColors),
            microVehicles: @json($microVehicles),
            defaults: @json($mapDefaults),
            refreshInterval: {{ (int) $previewRefreshMs }},
            mapUrl: @json(route('mobiangra.mapa')),
            i18n: {
                ida: @json(__('Ida')),
                volta: @json(__('Volta')),
                linha: @json(__('Linha')),
                veiculo: @json(__('Veículo')),
            },
        };
    </script>
    <script src="https://unpkg.com/leaflet@1.9.4/dist/leaflet.js"
        integrity="sha256-20nQCchB9co0qIjJZRGuk2/Z9VM+kNiyxNV1lvTlZBo=" crossorigin=""></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/maplibre-gl/4.7.1/maplibre-gl.min.js"
        integrity="sha512-dXgoFR02YHJ9Fa29P3D/1umNaZ0EXS2N0w29Lm3b/1BK8UDLMdLWDFwuujIyJJdU27/PLuk3dmS1V9NO8ABX1A=="
        crossorigin="anonymous" referrerpolicy="no-referrer"></script>
    <script src="https://unpkg.com/@maplibre/maplibre-gl-leaflet@0.1.3/leaflet-maplibre-gl.js" crossorigin="anonymous"
        referrerpolicy="no-referrer"></script>
    <script src="{{ asset('mobiangra-assets/js/mapa-embed.js') }}?v={{ @filemtime(public_path('mobiangra-assets/js/mapa-embed.js')) ?: time() }}"></script>
</body>
</html>
