
<?php
    $hiddenParams = collect($filterParams ?? [])
        ->except(['tab', $pageParam ?? 'ap', 'per_page'])
        ->all();
?>

<form method="get"
      action="<?php echo e(route('admin.cronogramas.projetos.show', $project)); ?>"
      class="d-flex flex-wrap align-items-center gap-2 mb-0">
    <input type="hidden" name="tab" value="<?php echo e($viewTab); ?>">
    <?php echo $__env->make('components.cronogramas.persist-query', ['params' => $hiddenParams], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <label class="form-label small mb-0 text-muted" for="<?php echo e($selectId); ?>"><?php echo e(__('Por página')); ?>:</label>
    <select name="per_page"
            id="<?php echo e($selectId); ?>"
            class="form-select form-select-sm w-auto"
            onchange="this.form.submit()"
            aria-label="<?php echo e(__('Registros por página')); ?>">
        <?php $__currentLoopData = $perPageOptions; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $option): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <option value="<?php echo e($option); ?>" <?php if((int) ($currentPerPage ?? 20) === (int) $option): echo 'selected'; endif; ?>><?php echo e($option); ?></option>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </select>
</form>
<?php /**PATH /var/www/html/portal/resources/views/components/cronogramas/per-page-selector.blade.php ENDPATH**/ ?>