@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " - Portal de Dados Abertos")
@section('content')

    <section class="faq-9 faq section bg-light top70 bot70" id="faq">
        <div class="container">
            <div class="row">
                <div class="text-center bot70">
                    <h1 class="faq-title mb-0">Comitê Municipal de Governança Digital</h1>
                    <!-- <p class="lead">Do Município</p> -->
                </div>
                <div class="col-lg-5" data-aos="fade-up">
                    <p class="faq-description">O <strong>Comitê Municipal de Governança Digital de Angra dos Reis</strong> é um órgão de caráter consultivo e deliberativo, responsável por planejar, coordenar e acompanhar as ações de transformação digital no município. Seu objetivo é promover a modernização dos serviços públicos, garantindo mais eficiência, transparência, inovação e facilidade no acesso dos cidadãos aos serviços digitais. O comitê também atua na definição de estratégias, normas e diretrizes que fortalecem a gestão pública e impulsionam o desenvolvimento tecnológico da cidade.</p>
                    <h3 class="text-center">Membros do Comitê</h3>
                    <p class="faq-description">Confira a composição do Comitê Municipal de Governança Digital da
                        Prefeitura de Angra dos Reis, com os representantes distribuídos por secretaria.</p>
                    <div class="d-flex align-itens-center justify-content-center">
                        <div class="faq-arrow d-none d-lg-block" data-aos="fade-up" data-aos-delay="200">
                            <svg class="faq-arrow" width="200" height="211" viewBox="0 0 200 211" fill="none"
                                xmlns="http://www.w3.org/2000/svg">
                                <path
                                    d="M198.804 194.488C189.279 189.596 179.529 185.52 169.407 182.07L169.384 182.049C169.227 181.994 169.07 181.939 168.912 181.884C166.669 181.139 165.906 184.546 167.669 185.615C174.053 189.473 182.761 191.837 189.146 195.695C156.603 195.912 119.781 196.591 91.266 179.049C62.5221 161.368 48.1094 130.695 56.934 98.891C84.5539 98.7247 112.556 84.0176 129.508 62.667C136.396 53.9724 146.193 35.1448 129.773 30.2717C114.292 25.6624 93.7109 41.8875 83.1971 51.3147C70.1109 63.039 59.63 78.433 54.2039 95.0087C52.1221 94.9842 50.0776 94.8683 48.0703 94.6608C30.1803 92.8027 11.2197 83.6338 5.44902 65.1074C-1.88449 41.5699 14.4994 19.0183 27.9202 1.56641C28.6411 0.625793 27.2862 -0.561638 26.5419 0.358501C13.4588 16.4098 -0.221091 34.5242 0.896608 56.5659C1.8218 74.6941 14.221 87.9401 30.4121 94.2058C37.7076 97.0203 45.3454 98.5003 53.0334 98.8449C47.8679 117.532 49.2961 137.487 60.7729 155.283C87.7615 197.081 139.616 201.147 184.786 201.155L174.332 206.827C172.119 208.033 174.345 211.287 176.537 210.105C182.06 207.125 187.582 204.122 193.084 201.144C193.346 201.147 195.161 199.887 195.423 199.868C197.08 198.548 193.084 201.144 195.528 199.81C196.688 199.192 197.846 198.552 199.006 197.935C200.397 197.167 200.007 195.087 198.804 194.488ZM60.8213 88.0427C67.6894 72.648 78.8538 59.1566 92.1207 49.0388C98.8475 43.9065 106.334 39.2953 114.188 36.1439C117.295 34.8947 120.798 33.6609 124.168 33.635C134.365 33.5511 136.354 42.9911 132.638 51.031C120.47 77.4222 86.8639 93.9837 58.0983 94.9666C58.8971 92.6666 59.783 90.3603 60.8213 88.0427Z"
                                    fill="currentColor">
                                </path>
                            </svg>
                        </div>
                    </div>
                </div>

                <div class="col-lg-7" data-aos="fade-up" data-aos-delay="300">
                    <div class="faq-container">
                        <div class="faq-item">
                            <h3>Secretaria de Desenvolvimento Econômico</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Yasmin Muniz Suisso Santos (30272) - C.T. de
                                    Empregabilidade
                                    <br>
                                    <i class="fa fa-user me-1"></i> Giuliane Sousa de Meira (28072) - C.T. de Dados e
                                    Pesquisas
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Desenvolvimento Regional (SESEP)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Pryscila de Jesus de Sousa Tamburini (18218) - Técnica
                                    de Edificações
                                    <br>
                                    <i class="fa fa-user me-1"></i> Dulcinéia Gil da Silva (21819) - Diretora de Apoio a
                                    Departamento Administrativo
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Saúde</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Luciano Chaves Ferreira (32653) - Auxiliar Técnico da
                                    Atenção Primária
                                    <br>
                                    <i class="fa fa-user me-1"></i> Leandro Medeiros Silva (32747) - Coordenador Técnico de
                                    TI
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Articulação Governamental (SECO)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Ludmila da Silva Pereira (32361) - Superintendente de
                                    Comunicação
                                    <br>
                                    <i class="fa fa-user me-1"></i> Regina Coeli Lima Braz (32994) - Superintendente de
                                    Estratégia e Gestão da Comunicação
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Desenvolvimento Regional (SEIG)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Esabellen Barros (32761) - Coordenadora Técnica de
                                    Logistica
                                    <br>
                                    <i class="fa fa-user me-1"></i> Luana Cantanhede Serra Ventura (27900) - Coordenadora
                                    Técnica da Ilha Grande
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Esporte e Lazer</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Evelyn Conceição Botelho (32645) - Coordenador Técnica
                                    de Administração, Operacional e Planejamento
                                    <br>
                                    <i class="fa fa-user me-1"></i> Iderlan Cadilha Cunha (32634) - Coordenador Técnica de
                                    Administração Esportiva
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Urbanização, Parques e Jardins</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Adriana da Costa Rodrigues (21529) - Assessora de
                                    Contratos
                                    <br>
                                    <i class="fa fa-user me-1"></i> Leandro Corrêa da Silva (32578) - Acessor Administrativo
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Desenvolvimento Regional</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Hugo Marques Machado Ferreira (3095) - Coordenador
                                    Técnico Gestão de Contrato
                                    <br>
                                    <i class="fa fa-user me-1"></i> Tiziana Rodrigues (31641) - Diretora de Departamento
                                    Administrativo
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item">
                            <h3>Secretaria de Finanças</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Mariana de Abreu Ferreira (13774) - Diretora
                                    Departamento de Liquidação
                                    <br>
                                    <i class="fa fa-user me-1"></i> Claúdia Porto de Arroxellas Bragança (22299) - Diretora
                                    do Departamento de Tesouraria
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Modernização e Gestão de Pessoal (ATOP)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Tiago Soares da Rosa (19823) - Diretor do Departamento
                                    de Sistemas
                                    <br>
                                    <i class="fa fa-user me-1"></i> Isaque Soares do Brasil Luiz (32766) - Coordenador
                                    Técnico de Sistemas
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Modernização e Gestão de Pessoal (DMAP)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Gilberto Bicalho Cardoso (26292) - Diretor do
                                    Departamento de Modernização da Administração Pública
                                    <br>
                                    <i class="fa fa-user me-1"></i> Leidiane Anacleto Pinheiro Soares (32564) -
                                    Coordenadora-Técnica de Apoio Administrativo
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Agricultura, Aquicultura e Pesca</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Jordan Cidral Maia (32588) - Coordenador Técnico de
                                    Monitoramento Pesqueiro
                                    <br>
                                    <i class="fa fa-user me-1"></i> Willys Ferreira de Araújo Júnior (30153) - Coordenador
                                    Técnico de Operações Agrícolas
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Procuradoria Geral do Município</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Brunna Correa Pinheiro da SIlva (31587) - Diretora do
                                    Departamento de Normas e Procedimentos
                                    <br>
                                    <i class="fa fa-user me-1"></i> Eduarda Arruda (29509) - Assessora de Cooperação
                                    Institucional
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Educação, Juventude e Inovação</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Danielle Noronha de Melo (22449) - Diretora Departamento
                                    de Sistemas e Políticas de Tecnologia Educacional
                                    <br>
                                    <i class="fa fa-user me-1"></i> Raphael Carlos Pessanha do Rosário (17384) - Coordenador
                                    de Ciência e Tecnologia
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Serviço Autônomo de Água e Esgoto (SAAE)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Leonardo Lopes Barbosa (190379) - Diretor do
                                    Departamento de Informática
                                    <br>
                                    <i class="fa fa-user me-1"></i> Ethel Dora do Amaral Duveen (31787) - Diretora do
                                    Departamento de Protocolo, Atendimento e Ouvidoria
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Cultura e Patrimônio</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Jefferson Affonso Soares (17802) - Superintendente de
                                    Gestão
                                    <br>
                                    <i class="fa fa-user me-1"></i> Diana Soares dos Santos (17023) - Administrativo
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Educação, Juventude e Inovação (SEJUV)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Luís Gustavo Campos Muniz da Silva (30330) - Assessor
                                    Técnico de Novas Tecnologias
                                    <br>
                                    <i class="fa fa-user me-1"></i> Lucas Plácido Lima (27923) - Coordenador Técnico de
                                    Programas Continuados
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Desenvolvimento Social e Promoção da Cidadania</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Marcelle Jordão Fonseca Ramos (29604) - Coordenadora
                                    Técnica de Planejamento
                                    <br>
                                    <i class="fa fa-user me-1"></i> Arão de assis Carrilho (29548 ) - Coordenador Técnico de
                                    Vigilância Socioassistencial
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Desenvolvimento Regional (SEPM)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Helena Amaral de Souza (22215) - Agente de Ouvidoria
                                    <br>
                                    <i class="fa fa-user me-1"></i> Fernanda Mendes Dutra (29403) - Coordenadora Tecnica de
                                    Gestão
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Articulação Governamental</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Taisa Monteiro (-) - Superintendente de Articulação
                                    <br>
                                    <i class="fa fa-user me-1"></i> João Gabriel dos Santos Xavier (32635) - Coordenador
                                    Técnico de Apoio Institucional
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Controladoria Geral do Município</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Rodrigo Fonseca de Castro (12569) - Assessor Técnico de
                                    Normas e Controles
                                    <br>
                                    <i class="fa fa-user me-1"></i> Jobson Rodrigues da Silva (19706) - Ramal: 1174
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Controladoria Geral do Município (SUIC)</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Rodrigo Fonseca de Castro (12569) - Assessor Técnico de
                                    Normas e Controles
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Parcerias e Inovação Tecnológica</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Lorival Cutrim Gomes Neto (327939) - Assessor
                                    Administrativo
                                    <br>
                                    <i class="fa fa-user me-1"></i> Odilane Rodrigues Viveiros Gonçalves (32671) - C.T. de
                                    Parcerias
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Proteção e Defesa Civil</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Adriano Camargo de Oliveira (19125) - Coordenador de
                                    Depuração e Análise
                                    <br>
                                    <i class="fa fa-user me-1"></i> Gislaine de Oliveira Freitas da Silva (17946) - Controle
                                    Interno
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                        <div class="faq-item hidden-item">
                            <h3>Secretaria de Obras e Habitação</h3>
                            <div class="faq-content">
                                <p>
                                    <i class="fa fa-user me-1"></i> Maria Cecília Alves (32164) - Arquiteta
                                    <br>
                                    <i class="fa fa-user me-1"></i> Bruno Rodrigues Rosi (32087) - Engenheiro Civil
                                </p>
                            </div>
                            <i class="faq-toggle bi bi-chevron-right"></i>
                        </div>

                    </div>

                    <div class="d-flex justify-content-center align-itens-center">
                        <div class="text-center mt-4">
                            <button class="btn btn-outline-primary" id="verMaisBtn">Ver Mais Secretarias</button>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </section>

@endsection