<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.login.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<body class="login-body d-flex align-items-center justify-content-center">
    <video autoplay loop playsinline id="video-background" poster="<?php echo e(asset('pmar/assets/img/ilhacombarco.jpg')); ?>" muted>
        <source src="https://visite.angra.rj.gov.br/assets/imgs/angra_linda.mp4" type="video/mp4">
    </video>
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>
    <?php echo $__env->make('layouts.login.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
</body>
</html>
<?php /**PATH /var/www/html/portal/resources/views/layouts/login/theme.blade.php ENDPATH**/ ?>