<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.pmar.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body class="escolas-climatizadas-app">
    <header id="escolas-barra-topo" aria-label="<?php echo e(__('Barra de navegação')); ?>">
        <a href="https://angra.rj.gov.br" target="_blank" rel="noopener noreferrer"
           aria-label="<?php echo e(__('Prefeitura de Angra dos Reis — Site Oficial')); ?>">
            <img src="<?php echo e(asset('pmar/assets/img/logo-pmar.png')); ?>"
                 alt="<?php echo e(__('Prefeitura de Angra dos Reis')); ?>">
        </a>
        <div class="escolas-barra-separador" aria-hidden="true"></div>
        <span class="escolas-barra-titulo"><?php echo e(__('ESCOLAS CLIMATIZADAS')); ?></span>
    </header>

    <main class="escolas-climatizadas-main">
        <?php echo $__env->yieldContent('content'); ?>
    </main>
</body>

</html>
<?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/escolas-climatizadas/theme.blade.php ENDPATH**/ ?>