<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<?php echo $__env->make('layouts.pmar.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body class="fade-in">
    <header>
        <?php echo $__env->make('layouts.pmar.elements.nav', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </header>
    <main class="bg-white">
        <div class="container">
            <div class="row section-404">
                <div class="col-lg-6 text_404 text-center">
                    <h2>500</h2>
                    <p><strong>Ops! O endereço digitado está errado ou a página foi removida.</strong></p>
                    <p><a href="/">Ir para a página Inicial</a></p>

                    <!-- <p><strong>Nosso site está em manutenção para receber melhorias que tornarão sua navegação ainda melhor. Estaremos de volta em instantes.</strong></p> -->
                </div>
                <div class="col-lg-6 img_404">
                    <img src="<?php echo e(asset("pmar/assets/img/404.gif")); ?>" class="img-fluid" alt="">
                </div>
            </div>
        </div>
    </main>
    <footer class="footer-pmar">
        <?php echo $__env->make('layouts.pmar.elements.modal', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        <?php echo $__env->make('layouts.pmar.elements.defaultFooter', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </footer>
</body>

</html>
<?php /**PATH /var/www/html/portal/resources/views/errors/500.blade.php ENDPATH**/ ?>