<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">

<head>
    <meta charset="utf-8">
    
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0, user-scalable=no, viewport-fit=cover">
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">

    
    <meta name="mobile-web-app-capable" content="yes">
    <meta name="apple-mobile-web-app-capable" content="yes">
    <meta name="apple-mobile-web-app-status-bar-style" content="default">
    <meta name="apple-mobile-web-app-title" content="MobiAngra">
    <meta name="theme-color" content="#ffffff">

    <title><?php echo $__env->yieldContent('title', __('MobiAngra') . ' - ' . config('app.name')); ?></title>

    
    <meta name="description"
        content="Portal oficial da Prefeitura Municipal de Angra dos Reis. Informações sobre serviços, transporte público e monitoramento de ônibus em tempo real." />
    <meta name="robots" content="noodp" />

    <meta property="og:locale" content="pt_BR" />
    <meta property="og:type" content="website" />
    <meta property="og:title" content="<?php echo $__env->yieldContent('title', __('MobiAngra') . ' - ' . config('app.name')); ?>" />
    <meta property="og:description"
        content="Acompanhe em tempo real a frota de ônibus de Angra dos Reis com o MobiAngra." />
    <meta property="og:url" content="<?php echo e(url()->current()); ?>" />
    <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
    <meta property="og:image" content="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png" />

    <link rel="icon" type="image/png" href="<?php echo e(asset('mobiangra-assets/images/logo_mobiangra_2.png')); ?>">
    <link rel="apple-touch-icon" href="<?php echo e(asset('mobiangra-assets/images/logo_mobiangra_2.png')); ?>">

    <?php echo $__env->yieldPushContent('styles'); ?>
</head>

<body>

    <header id="barra-topo">
        <a href="https://angra.rj.gov.br" target="_blank" rel="noopener noreferrer" class="barra-topo-logo barra-topo-logo--angra">
            <img src="<?php echo e(asset('pmar/assets/img/logo-pmar.png')); ?>"
                 alt="<?php echo e(__('Prefeitura de Angra dos Reis - Site Oficial')); ?>">
        </a>
        <a href="<?php echo e(route('mobiangra.index')); ?>" class="barra-topo-logo barra-topo-logo--mobiangra" aria-label="<?php echo e(__('MobiAngra')); ?>">
            <img src="<?php echo e(asset('mobiangra-assets/images/logo_mobiangra_1.png')); ?>"
                 alt="<?php echo e(__('MobiAngra')); ?>"
                 width="3504"
                 height="700"
                 decoding="async">
        </a>
        <a href="https://www.angra.rj.gov.br/secretarias/secretaria-de-seguranca-publica/executivas/secretaria-executiva-de-ordem-publica-e-mobilidade-urbana"
           target="_blank" rel="noopener noreferrer" class="barra-topo-logo barra-topo-logo--ssp">
            <img src="<?php echo e(asset('pmar/assets/img/ssp.png')); ?>"
                 alt="<?php echo e(__('Secretaria de Segurança Pública')); ?>">
        </a>
    </header>

    <?php echo $__env->yieldContent('header'); ?>



    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    <?php echo $__env->yieldContent('footer'); ?>

    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/mobiangra/theme.blade.php ENDPATH**/ ?>