<?php $__env->startSection("title", env("APP_NAME") . " :: Cadastro de Pacientes com Fibromialgia"); ?>
<?php $__env->startSection('content'); ?>

    <div class="card shadow">

        <?php $headLine = "<i class='fa-solid fa-user-injured'></i> Cadastro de Pacientes com Fibromialgia"; ?>

        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.contaAngra.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

        <div class="card-body">
            
            <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.modal._modelProfile', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

            <hr>
           
            <div class="tab-content">
                <div class="mb-3">
                    
                    <?php echo $__env->make('admin.saude.fibromialgia.perfil.institucional', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    
                    <?php if($user->fibromialgia?->exists): ?>
                        <a class="btn btn-lg btn-primary"
                            href="<?php echo e(route("admin.saude.fibromialgia.perfil.show", $user->fibromialgia->id)); ?>">
                             <?php echo e(__("Você já fez a adesão ao cadastro de Paciente com Fibromialgia, deseja acessar a Página de Acompanhamento?")); ?>

                        </a>
                    <?php else: ?>
                        <?php echo $__env->make('components.modal._modalConfirmAdesao', [
                            'route' => 'admin.adesao.fibromialgia'], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    <?php endif; ?>
                    
                </div>
            </div>
            
        </div>
    </div>

<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/saude/fibromialgia/perfil/index.blade.php ENDPATH**/ ?>