@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Chamados do credenciamento'))
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-comment-dots'></i> " . __('Chamados') . ' – ' . ($musico->grupo_nome ?: optional($user)->name); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => ($perfil ?? false) ? route('admin.cultura.credenciamentoMusicos.perfil.index') : route('admin.cultura.credenciamentoMusicos.index'),
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'routeAdd' => ($perfil ?? false) ? 'admin.cultura.credenciamentoMusicos.perfil.chamados.create' : 'admin.cultura.credenciamentoMusicos.chamados.create',
            'routeAddParams' => [$musico->id],
            'nameAdd' => __('Abrir recurso administrativo'),
            'permission' => null,
        ])

        <div class="card-body">
            @include('errors.messageFlash')
            @if($chamados->isEmpty())
                <p class="text-muted mb-0">{{ __('Nenhum chamado vinculado a este credenciamento.') }}</p>
            @else
                <div class="table-responsive">
                    <table class="table table-sm">
                        <thead>
                            <tr>
                                <th>{{ __('Nº') }}</th>
                                <th>{{ __('Assunto') }}</th>
                                <th>{{ __('Status') }}</th>
                                <th>{{ __('Ações') }}</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($chamados as $chamado)
                                <tr>
                                    <td>{{ $chamado->numeroChamado }}</td>
                                    <td>{{ $chamado->assunto }}</td>
                                    <td>{{ $chamado->statusChamado ?? '–' }}</td>
                                    <td>
                                        <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.contaAngra.chamados.show', $chamado->id) }}">{{ __('Ver') }}</a>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
                {{ $chamados->links() }}
            @endif
        </div>
    </div>
@endsection
