<div class="form-group mb-3">
    <label for="source">Caminho de Origem *</label>
    <input type="text" class="form-control @error('source') is-invalid @enderror"
           id="source" name="source" value="{{ old('source', $url->source ?? '') }}" required>
    @error('source')
        <div class="invalid-feedback">{{ $message }}</div>
    @enderror
    <small class="form-text text-muted">Exemplo: "transparencia" ou "teste/lucas" (será acessível como /transparencia ou /teste/lucas)</small>
</div>

<div class="form-group mb-3">
    <label for="destination">URL de Destino *</label>
    <input type="url" class="form-control @error('destination') is-invalid @enderror"
           id="destination" name="destination" value="{{ old('destination', $url->destination ?? '') }}" required>
    @error('destination')
        <div class="invalid-feedback">{{ $message }}</div>
    @enderror
</div>

<div class="form-check mb-3">
    <input type="checkbox" class="form-check-input" id="active" name="active"
           value="1" @checked(old('active', $url->active ?? true))>
    <label class="form-check-label" for="active">Redirecionamento ativo</label>
</div>
