@forelse ($dadosUsuarios as $usuario)
    @if ($usuario->nome != 'Desconhecido')
        <tr>
            <td>{{ $usuario->nome }}</td>
            <td>{{ $usuario->total }}</td>
            <td class="text-end">
                <a href="{{ route('admin.ocorrencias-pca.fichaUsuario', ['id' => $usuario->id]) }}"
                   title="{{ __('Abrir ficha do usuário') }}">
                    <i class="fa-solid fa-file"></i>
                </a>
            </td>
        </tr>
    @endif
@empty
    <tr>
        <td colspan="3" class="text-center">{{ __('Nenhum usuário encontrado.') }}</td>
    </tr>
@endforelse
