@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Documentos da Empresa de Turismo")
@section('content')

    @php
        $filterParams = \App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource::listFilterParamsFromRequest(request());
    @endphp

    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                    @php $headLine = "<i class='fa-solid fa-water'></i> Documentos da Empresa de Turismo"; @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'routeBack' => 'admin.empresasDeTurismo.index',
                            'routeBackParams' => $filterParams,
                            'nameBack' => __("Voltar"),
                            "permission" => "GERENCIADOR_DE_EMPRESAS_DE_TURISMO",
                        ])

                    <div class="card-body">

                        <form action="{{ route('admin.empresasDeTurismo.clipboardUpdate', [$empresaTurismo->id]) }}" method="post" enctype="multipart/form-data">
                            @include('admin.turisAngra.empresasDeTurismo.sections._filterHidden', ['filterParams' => $filterParams])
                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                            <div class="col-12">
                                <hr/>
                                <h3 class="text-primary">
                                    {{ $empresa->razaoSocial ?? '-' }} <br>
                                    {{ __("CNPJ: ") . ($empresa->cnpj ?? '-') }}
                                </h3>
                                <hr/>
                            </div>

                            <div class="row">
                                <div class="col-12">
                                    @include('admin.turisAngra.empresasDeTurismo.sections.clipboardDocumentos')
                                </div>
                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack' => 'Voltar',
                                'textSend' => 'Salvar',
                                'routeBack' => 'admin.empresasDeTurismo.index'
                            ]
                        )
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
