<form autocomplete="off" method="post" action="{{ route('admin.salvarNovaSenha', $token) }}">
    @csrf
    <input type="hidden" name="token" value="{{ $token }}">
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Nome completo'),
        'name'=>'fullName',
        'id'=>null,
        'required'=>true,
        'type'=>null,
        'old'=>old('fullName'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Senha'),
        'name'=>'password',
        'id'=>null,
        'required'=>true,
        'type'=>'password',
        'old'=> old('password'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
    </div>
    <div class="mb-3">
        @include('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Repetir senha'),
        'name'=>'password_repeat',
        'id'=>null,
        'required'=>true,
        'type'=>'password',
        'old'=> old('password_repeat'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ])
    </div>
    <button class="btn btn-primary" type="submit">{{ __('Salvar') }}</button>
</form>
