@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: ' . $secretaria->name)
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <x-portal.breadcrumb :items="\App\Support\PortalBreadcrumb::forOrgSubpage($secretaria, __('Competências e Atribuições'))" />
                </div>

                <div class="col-12 col-sm-12 col-md-12 col-lg-9 col-xl-9 col-xxl-9 mb-5">
                    <div class="row mb-3">
                        <div class="col-12">
                            <h3 class="my-5">{{ __("Competências e Atribuições") }}</h3>
                            <h5>{{ __("Competências") }}</h5>
                            <div class="pdown"><p>{!! $secretaria->skills !!}</p></div>
                            <h5 class="mt-5">{{ __("Atribuições") }}</h5>
                            <div class="pdown"><p>{!! $secretaria->duties !!}</p></div>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
                    <div class="row">
                        <div class="col-12">
                            @include('paginas.parts.links')
                            @include('paginas.parts.servicos')
                            @include('paginas.parts.telefones')
                        </div>
                    </div>
                </div>

            </div>
        </div>
    </section>
@endsection

