
<div class="row gx-5">
    <div class="col-12 col-sm-12 col-md-6 col-lg-3 col-xl-3 col-xxl-3 d-flex">
        <div class="card rounded-4 d-flex flex-column">
            <div class="card-header rounded-top-4 text-center bg-success">
                <h5 class="card-title text-primary px-3 fs-4">{{ __("Água e Esgoto</h5>") }}
                </div>
                <img class="img-fluid" src="{{ asset('pmar/assets/img/medidor.png') }}" alt="">
                <div class="rounded-bottom-4 card-footer bg-primary mt-auto">
                    <button
                        class="btn border-0 rounded-4 bg-success text-start text-primary px-2 my-3 fw-bold">{{ __("SAAE") }}</button>
                    <p class="card-text text-white py-3 fw-bold fs-5">{{ __("2ª via de conta, atualização cadastral
                    (...)") }}</p>
                <button onclick="window.open('http://saaeangra.com.br/','_blank')"
                    class="px-3 btn border-1 btn-outline-light rounded-5 text-start p-2 mb-3">{{ __("Saiba
        mais") }}</button>
            </div>
        </div>
    </div>
            <div class="col-12 col-sm-12 col-md-6 col-lg-3 col-xl-3 col-xxl-3 d-flex mt-3">
                <div class="card border-0 rounded-4 h-100 d-flex flex-column">
                    <div class="card-header rounded-top-4 text-center bg-success">
                    <h5 class="card-title text-primary px-3 fs-4">{{ __("Trânsito</h5>") }}
            </div>
                    <img class="img-fluid" src="{{ asset('pmar/assets/img/idosa-dirigindo.jpg') }}"
                 alt="">
                        <div class="rounded-bottom-4 card-footer bg-primary mt-auto">
                <button
                        class="btn border-0 rounded-4 bg-success text-start text-primary px-2 my-3 fw-bold">{{ __("Credencial
				de Estacionamento") }}</button>
                        <p class="card-text text-white py-3 fw-bold fs-5">{{ __("Emissão da Credencial de Estacionamento
				para ") }}</p>
                <button
                    onclick="window.open('https://www.angra.rj.gov.br/transito-estacionamento-idoso.asp?IndexSigla=SEOPM&vNomeLink=Legisla%EF%BF%BD%EF%BF%BDo','_blank')"
            class="px-3 btn border-1 btn-outline-light rounded-5 text-start p-2 mb-3">{{ __("Saiba
            mais") }}</button>
            </div>
        </div>
    </div>
                    <div class="col-12 col-sm-12 col-md-6 col-lg-3 col-xl-3 col-xxl-3 d-flex mt-3">
        <div class="card border-0 rounded-4 h-100 d-flex flex-column">
                        <div class="card-header rounded-top-4 text-center bg-success">
                    <h5 class="card-title text-primary px-3 fs-4">{{ __("Turismo") }}</h5>
            </div>
                    <img class="img-fluid" src="{{ asset('pmar/assets/img/onibus.jpg') }}" alt="">
                        <div class="rounded-bottom-4 card-footer bg-primary mt-auto">
                <button
                        class="btn border-0 rounded-4 bg-success text-start text-primary px-2 my-3 fw-bold">{{ __("Fluxo
				de ônibus") }}</button>
                        <p class="card-text text-white py-3 fw-bold fs-5">{{ __("Entrada de ônibus de turismo no município") }}
                </p>
                <button
                    onclick="window.open('https://www.angra.rj.gov.br/tur-onibus.asp?IndexSigla=FTAR','_blank')"
            class="px-3 btn border-1 btn-outline-light rounded-5 text-start p-2 mb-3">{{ __("Saiba
				mais") }}</button>
            </div>
        </div>
    </div>
                    <div class="col-12 col-sm-12 col-md-6 col-lg-3 col-xl-3 col-xxl-3 d-flex mt-3">
        <div class="card border-0 rounded-4 h-100 d-flex flex-column">
                        <div class="card-header rounded-top-4 text-center bg-success">
                    <h5 class="card-title text-primary px-3 fs-4">{{ __("Licenciamento") }}</h5>
            </div>
                    <img class="img-fluid" src="{{ asset('pmar/assets/img/licenciamento.jpg') }}"
                 alt="">
                        <div class="rounded-bottom-4 card-footer bg-primary mt-auto">
                <button
                        class="btn border-0 rounded-4 bg-success text-start text-primary px-2 my-3 fw-bold">{{ __("Urbanístico
				e Ambiental") }}</button>
                        <p class="card-text text-white py-3 fw-bold fs-5">{{ __("Abra e acompanhe processos de
				licenciamentos (...)") }}</p>
                <button onclick="window.open('http://angra.licenciamento.net.br/','_blank')"
            class="px-3 btn border-1 btn-outline-light rounded-5 text-start p-2 mb-3">{{ __("Saiba
				mais") }}</button>
            </div>
        </div>
    </div>
</div>