@props([
    'empresasTurismo' => collect(),
])

@php
    use App\Http\Resources\TurisAngra\EmpresasDeTurismo\EmpresaTurismoResource;

    $empresasComAlerta = $empresasTurismo->filter(function ($empresaTurismo) {
        return EmpresaTurismoResource::cadasturMensagemAlertaVisual($empresaTurismo) !== null;
    })->values();

    $totalAlertas = $empresasComAlerta->count();
@endphp

@if($totalAlertas > 0)
    <div class="ca-cadastur-alert mb-4" role="alert" aria-live="polite">
        <div class="alert alert-warning border-0 shadow-sm mb-0">
            <div class="d-flex align-items-start">
                <div class="flex-shrink-0">
                    <div class="ca-cadastur-alert__icon-wrap bg-warning bg-opacity-25 rounded-circle d-flex align-items-center justify-content-center">
                        <i class="fa-solid fa-calendar-xmark text-warning fs-5" aria-hidden="true"></i>
                    </div>
                </div>
                <div class="flex-grow-1 ms-3 min-w-0">
                    <div class="d-flex align-items-center justify-content-between mb-2 flex-wrap gap-2">
                        <h2 class="h5 alert-heading mb-0 fw-bold text-dark">
                            <i class="fa-solid fa-bell text-danger me-2" aria-hidden="true"></i>
                            {{ __('Vencimento do CADASTUR') }}
                        </h2>
                        <span class="badge bg-warning text-dark rounded-pill">
                            {{ $totalAlertas }}
                        </span>
                    </div>

                    <p class="mb-3 text-dark">
                        <i class="fa-solid fa-info-circle me-2" aria-hidden="true"></i>
                        @if($totalAlertas === 1)
                            {{ __('Você possui 1 empresa com CADASTUR próximo do vencimento. Providencie a renovação junto aos órgãos competentes.') }}
                        @else
                            {{ __('Você possui :count empresas com CADASTUR próximo do vencimento. Providencie a renovação junto aos órgãos competentes.', ['count' => $totalAlertas]) }}
                        @endif
                    </p>

                    <ul class="list-unstyled mb-0 d-flex flex-column gap-2">
                        @foreach($empresasComAlerta as $empresaTurismo)
                            @php
                                $mensagem = EmpresaTurismoResource::cadasturMensagemAlertaVisual($empresaTurismo);
                                $nomeEmpresa = $empresaTurismo->companhia?->razaoSocial
                                    ?: $empresaTurismo->companhia?->nomeFantasia
                                    ?: __('Empresa de Turismo');
                                $diasRestantes = EmpresaTurismoResource::cadasturDiasRestantes($empresaTurismo);
                                $vencimentoFormatado = $empresaTurismo->cadastur_vencimento?->format('d/m/Y');
                            @endphp
                            <li class="ca-cadastur-alert__item">
                                <div class="d-flex align-items-start justify-content-between gap-2 flex-wrap">
                                    <div class="min-w-0">
                                        <p class="ca-cadastur-alert__empresa mb-1 fw-semibold text-dark">
                                            {{ $nomeEmpresa }}
                                        </p>
                                        <p class="ca-cadastur-alert__mensagem mb-0 small text-secondary">
                                            {{ $mensagem }}
                                        </p>
                                    </div>
                                    @if($diasRestantes !== null)
                                        <span class="badge ca-cadastur-alert__dias-badge rounded-pill flex-shrink-0">
                                            @if($diasRestantes === 0)
                                                {{ __('Vence hoje') }}
                                            @elseif($diasRestantes === 1)
                                                {{ __('1 dia') }}
                                            @else
                                                {{ __(':count dias', ['count' => $diasRestantes]) }}
                                            @endif
                                        </span>
                                    @endif
                                </div>
                                <div class="ca-cadastur-alert__meta d-flex flex-wrap gap-2 mt-2">
                                    <span class="badge bg-light text-dark border">
                                        {{ __('Cadastur') }}: {{ $empresaTurismo->cadastur }}
                                    </span>
                                    @if($vencimentoFormatado)
                                        <span class="badge bg-light text-dark border">
                                            {{ __('Vencimento') }}: {{ $vencimentoFormatado }}
                                        </span>
                                    @endif
                                </div>
                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
        </div>
    </div>
@endif
