<div class="row">
    <h3 class="subtitle-home"><?php echo e(__('Como podemos ajudar?')); ?></h3>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
        <a href="https://portal.angra.rj.gov.br/sad-consulta-processo.asp?IndexSigla=SAD" class="link-help">
            <h5><?php echo e(__('Consulta de Processos')); ?></h5>
            <i class="fa-solid fa-angle-right text-primary"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://www.spe.angra.rj.gov.br/senhaweb/login.aspx" target="_blank" class="link-help">
            <h5><?php echo e(__('Nota Fiscal Eletrônica')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://www.spe.angra.rj.gov.br/senhaweb/login.aspx" target="_blank" class="link-help">
            <h5><?php echo e(__('NF-e - Consulte seus Créditos')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://www.spe.angra.rj.gov.br/senhaweb/solicitacao.aspx" target="_blank" class="link-help">
            <h5><?php echo e(__('NF-e Solicitação de SENHA')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br/arrecadacao/cobranca/iss-fixo" target="_blank" class="link-help">
            <h5><?php echo e(__('ISS - Solicitação de Cadastro Mobiliário')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br/arrecadacao/cobranca/iss-fixo" target="_blank" class="link-help">
            <h5><?php echo e(__('ISS - Emissão de Taxa')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br/arrecadacao/cobranca/iptu" target="_blank" class="link-help">
            <h5><?php echo e(__('IPTU 2026')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://www.spe.angra.rj.gov.br/ipva/creditoIPVA.aspx" target="_blank" class="link-help">
            <h5><?php echo e(__('IPTU - Créditos de IPVA para o IPTU')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br" class="link-help">
            <h5><?php echo e(__('Parcelamento de Débitos Tributários e não Tributários')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br/itbi/declaracao" target="_blank" class="link-help">
            <h5><?php echo e(__('ITBI - Demonstrativo de Pagamento')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://siarm.angra.rj.gov.br/itbi/declaracao" target="_blank" class="link-help">
            <h5><?php echo e(__('ITBI - Solicitação de ITBI')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://www.spe.angra.rj.gov.br/Ajuda/legislacao.aspx" target="_blank" class="link-help">
            <h5><?php echo e(__('Legislação Tributária')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://portal.angra.rj.gov.br/sdc-trans-horarios-onibus.asp?IndexSigla=seopm" class="link-help">
            <h5><?php echo e(__('Transporte Coletivo - Horários e Itinerários ')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://angra.rj.gov.br/secretarias/secretaria-de-protecao-e-defesa-civil" class="link-help">
            <h5><?php echo e(__('Defesa Civil')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://portaldoservidor.angra.rj.gov.br/" target="_blank" class="link-help">
            <h5><?php echo e(__('Recursos Humanos online')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://portaldoservidor.angra.rj.gov.br/ouvidoria-interna" target="_blank" class="link-help">
            <h5><?php echo e(__('Ouvidoria Interna')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://angra.rj.gov.br/servicos/como-estagiar-na-prefeitura"
            class="link-help">
            <h5><?php echo e(__('Como estagiar na Prefeitura')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>

    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://planodiretor.angra.rj.gov.br" class="link-help">
            <h5><?php echo e(__('Plano Diretor do Município	')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>


    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://portal.angra.rj.gov.br/fusar-ouvidoria.asp?IndexSigla=SSA" class="link-help">
            <h5><?php echo e(__('Ouvidoria SUS')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>
    </div>


    <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">

        <a href="https://portal.angra.rj.gov.br/documentos" class="link-help">
            <h5><?php echo e(__('Autenticidade de Documentos')); ?></h5>
            <i class="text-primary fa-solid fa-angle-right"></i>
        </a>

    </div>



</div>
<?php /**PATH /var/www/html/portal/resources/views/paginas/partsHome/comoPodemosAjudar.blade.php ENDPATH**/ ?>