<!-- Saúde Pública -->
<div class="col-md-6 col-lg-4">
    <div class="card h-100 border-success">
        <div class="card-header {{ $cor }} text-dark">
            <div class="d-flex align-items-center">
                <i class="fas fa-hospital-user fa-2x me-3"></i>
                <h5 class="card-title mb-0">Saúde Pública</h5>
            </div>
        </div>
        <div class="card-body">
            <ul class="list-group list-group-flush">
                <li class="list-group-item"><i class="fas fa-syringe me-2 text-muted"></i> Vacinação <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-ambulance me-2 text-muted"></i> SAMU e emergências <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-notes-medical me-2 text-muted"></i> Vigilância sanitária <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item"><i class="fas fa-user-md me-2 text-muted"></i> Saúde da família (PSF) <small class="badge bg-info">em breve</small></li>
                <li class="list-group-item">
                    <i class="fas fa-clinic-medical me-2 text-muted"></i>
                    <a href="{{ route("servicos.unidadesSaude") }}" class="text-dark">Unidades de Saúde</a>
                </li>
                <li class="list-group-item">
                    <i class="fas fa-wheelchair me-2 text-muted"></i> 
                    <a href="{{ route("saude.fibromialgia") }}" class="text-dark">Cadastro de Paciente com Fibromialgia</a>
                </li>
            </ul>
        </div>
    </div>
</div>