@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Documentos')
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route('paginas.home') }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Autenticidade de Documentos") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-md-9 nopadding single-article espaco_conteudo">

                    <header class="article-header">
                        <!-- Title -->
                        <h1 class="title">{{ __("Consulta de autenticidade de documentos") }}</h1>
                        <!-- Excerpt -->
                    </header>
                    <article class="article-main">

                        <form id="formAutenticacao" name="formAutenticacao" method="post" action="documentos.asp"
                            role="form" class="contactForm top40" data-toggle="validator">

                            <div class="form-group col-md-6">
                                <label for="txtCodigo"><span class="red">*</span> {{ __("Código Verificador:") }} <i
                                        class="fa fa-question-circle"
                                        data-original-title="O Código verificador está localizado no rodapé do documento que será verificado"
                                        aria-hidden="true" data-toggle="tooltip"></i></label>
                                <input name="txtCodigo" id="txtCodigo" type="text" value=""
                                    class="form-control codigo" maxlength="8" data-mask="AAAAAAAA"
                                    placeholder="Informe o código verificador do documento" required />
                                <div class="help-block with-errors"></div>
                            </div>

                            <div class="clear"></div>

                            <div class="col-12 top30">
                                {{-- <script src='https://www.google.com/recaptcha/api.js?render=6Ldxgj0qAAAAAGl27ZkKwhSwk91Sga59cdhhRz67'></script> --}}
                                <input type="hidden" id="g-recaptcha-response" name="g-recaptcha-response" />
                                <input type="submit" name="Submit" id="btnEnviar" class="btn btn-large top30"
                                    value="Verificar" /><br>
                            </div>
                        </form>

                    </article>

                </div>
            </div>
        </div>
    </section>
@endsection
