<div class="accordion-item">
    <h2 class="accordion-header">
        <button class="accordion-button" type="button" data-bs-toggle="collapse" data-bs-target="#<?php echo e($accordion['collapse']); ?>" aria-expanded="<?php echo e($accordion['TF']); ?>" aria-controls="<?php echo e($accordion['collapse']); ?>">
            <?php echo $accordion['Titulo']; ?>

        </button>
    </h2>
    <div id="<?php echo e($accordion['collapse']); ?>" class="accordion-collapse collapse" data-bs-parent="#accordioncmgd">
        <div class="accordion-body">
            <?php $__currentLoopData = $itens; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <strong><?php echo e($item['nome']); ?></strong> <?php echo e($item['matricula'] ? '(' . $item['matricula'] . ')' : null); ?> <?php echo $item['cargo'] ? '- <i>' . $item['cargo'] . '</i>' : null; ?> <br>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        </div>
    </div>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/lists/_divAccordionCmgd.blade.php ENDPATH**/ ?>