<section class="bg-primary py-5" id="suporte">
    <div class="container">
        <!-- Cabeçalho -->
        <div class="row justify-content-center mb-5">
            <div class="col-lg-8 text-center">
                <span class="badge bg-light text-success rounded-pill px-3 py-2 mb-3 d-inline-flex align-items-center">
                    <i class="bi bi-headset me-2"></i>CANAIS DE AJUDA
                </span>
                <h2 class="display-5 fw-bold text-white mb-3">SUPORTE AO SEI</h2>
                <p class="lead text-white opacity-75 mb-0">Escolha abaixo o tipo de ajuda que você precisa e utilize o canal indicado.</p>
            </div>
        </div>

        <!-- Cartões -->
        <div class="row g-4">
            <!-- Cartão: Assuntos sobre PROCESSOS -->
            <div class="col-12 col-md-6 col-lg-4">
                <div class="card h-100 border-0 rounded-4 shadow-lg overflow-hidden hover-shadow-lg transition-all bg-white bg-opacity-100">
                    <div class="card-header bg-transparent py-4 border-0">
                        <div class="d-flex align-items-center">
                            <div class="bg-secondary bg-opacity-10 rounded-3 p-3 me-3">
                                <i class="bi bi-file-earmark-text fs-3 text-white"></i>
                            </div>
                            <h3 class="h5 fw-bold mb-0">Ajuda com PROCESSOS</h3>
                        </div>
                        <span class="mt-2 d-block bg-secondary opacity-50 badge text-white small">Usuário Interno (Servidor)</span>
                        <span class="mt-2 d-block bg-success opacity-50 badge text-dark small">Usuário Externo (Cidadão)</span>
                    </div>
                    <div class="card-body p-4">
                        <p class="card-text mb-4">
                            Abrir processo, acompanhar andamento, consultar ou resolver pendências, informações processuais.
                        </p>
                        <ul class="list-unstyled mb-0">
                            <li class="mb-3">
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Telefones</span>
                                        <a href="tel:+552433655396" class="text-decoration-none fw-semibold">(24) 3365-5396</a>
                                        <span class="mx-1">/</span>
                                        <a href="tel:+552433655405" class="text-decoration-none fw-semibold">(24) 3365-5405</a>
                                    </div>
                                </div>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Ramais</span>
                                        <span class="text-decoration-none fw-semibold">5396, 1131, 5405 e 1130</span>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-envelope text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">E-mail</span>
                                        <a href="mailto:sad.scp@angra.rj.gov.br" target="_blank" class="text-decoration-none fw-semibold">sad.scp@angra.rj.gov.br</a>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <div class="d-flex align-items-start mt-3">
                                    <i class="bi bi-building text-primary me-2 mt-1"></i>
                                    <div>
                                <span class="d-block text-muted small">Setor</span>
                                <span>Departamento de Protocolo (SMGP/DEPRO), da Secretaria de Modernização e Gestão de Pessoal (SMGP)</span>
                            </li>
                        </ul>
                    </div>
                    <div class="card-footer bg-transparent border-0 p-4 pt-0">
                        <a href="tel:+552433655396" class="btn btn-outline-success w-100 d-flex align-items-center justify-content-center">
                            <i class="bi bi-telephone me-2"></i>Ligar Agora
                        </a>
                    </div>
                </div>
            </div>

            <!-- Cartão: Assuntos sobre a SENHA DO USUÁRIO -->
            <div class="col-12 col-md-6 col-lg-4">
                <div class="card h-100 border-0 rounded-4 shadow-lg overflow-hidden hover-shadow-lg transition-all bg-white bg-opacity-100">
                    <div class="card-header bg-transparent py-4 border-0">
                        <div class="d-flex align-items-center">
                            <div class="bg-success bg-opacity-10 rounded-3 p-3 me-3">
                                <i class="bi bi-key-fill fs-3 text-white"></i>
                            </div>
                            <h3 class="h5 fw-bold mb-0">Problemas com SENHAS</h3>
                        </div>
                        <span class="my-2 d-block bg-secondary opacity-50 badge text-white small">Usuário Interno (Servidor)</span>
                    </div>
                    <div class="card-body p-4">
                        <p class="card-text mb-4">
                            Esqueci a senha, senha inválida, senha expirada, senha bloqueada, troca de senha.
                        </p>
                        <ul class="list-unstyled mb-0">
                            <li>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Telefone</span>
                                        <a href="tel:+552433778886" class="d-block fw-semibold mt-1">(24) 3377-8886</a>
                                    </div>
                                </div>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Ramais</span>
                                        <span class="fw-semibold">1277, 1981, 1276 e 9927</span>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <div class="d-flex align-items-start mt-3">
                                    <i class="bi bi-building text-primary me-2 mt-1"></i>
                                    <div>
                                <span class="d-block text-muted small">Secretaria</span>
                                <span>Modernização e Gestão de Pessoal - SMGP</span>
                            </li>
                            <li>
                                <div class="d-flex align-items-start mt-3">
                                    <i class="bi bi-building text-primary me-2 mt-1"></i>
                                    <div>
                                <span class="d-block text-muted small">Setor</span>
                                <span>Coordenação de Redes e Segurança da Informação (SMGP/DRSIN), da Secretaria de Modernização e Gestão de Pessoal (SMGP)</span>
                            </li>
                        </ul>
                    </div>
                    <div class="card-footer bg-transparent border-0 p-4 pt-0">
                        <a href="tel:+552433778886" class="btn btn-outline-success w-100 d-flex align-items-center justify-content-center">
                            <i class="bi bi-telephone me-2"></i>Ligar Agora
                        </a>
                    </div>
                </div>
            </div>

             <!-- Cartão: Assuntos sobre o SISTEMA -->
             <div class="col-12 col-md-6 col-lg-4">
                <div class="card h-100 border-0 rounded-4 shadow-lg overflow-hidden hover-shadow-lg transition-all bg-white bg-opacity-100">
                    <div class="card-header bg-transparent py-4 border-0">
                        <div class="d-flex align-items-center">
                            <div class="bg-warning bg-opacity-10 rounded-3 p-3 me-3">
                                <i class="bi bi-gear-wide-connected fs-3 text-dark"></i>
                            </div>
                            <h3 class="h5 fw-bold mb-0">Sobre o SISTEMA SEi</h3>
                        </div>
                        <span class="mt-2 d-block bg-secondary opacity-50 badge text-white small">Usuário Interno (Servidor)</span>
                        <span class="mt-2 d-block bg-success opacity-50 badge text-black small">Usuário Externo (Cidadão)</span>
                    </div>
                    <div class="card-body p-4">
                        <p class="card-text mb-4">
                            Ativação, inativação, liberação de usuários e unidades, erros ou problemas técnicos no sistema.
                        </p>
                        <ul class="list-unstyled mb-0">
                            <li class="mb-3">
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Telefone</span>
                                        <a href="tel:+552433684704" class="fw-semibold">(24) 3377-8886</a>
                                    </div>
                                </div>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-telephone text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">Ramal</span>
                                        <span class="d-block fw-semibold">1275</span>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <div class="d-flex align-items-start">
                                    <i class="bi bi-envelope text-primary me-2 mt-1"></i>
                                    <div>
                                        <span class="d-block text-muted small">E-mail</span>
                                        <a href="mailto:sei@angra.rj.gov.br" target="_blank" class="text-decoration-none fw-semibold">sei@angra.rj.gov.br</a>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <div class="d-flex align-items-start mt-3">
                                    <i class="bi bi-building text-primary me-2 mt-1"></i>
                                    <div>
                                <span class="d-block text-muted small">Setor</span>
                                <span>Coordenação Técnica de Processos Digitais (SMGP/CTPD), da Secretaria de Modernização e Gestão de Pessoal (SMGP)</span>
                            </li>
                        </ul>
                    </div>
                    <div class="card-footer bg-transparent border-0 p-4 pt-0">
                        <a href="tel:+552433778886" class="btn btn-outline-success w-100 d-flex align-items-center justify-content-center">
                            <i class="bi bi-telephone me-2"></i>Ligar Agora
                        </a>
                    </div>
                </div>
            </div>
        </div>

        <!-- Rodapé adicional -->
        <div class="row mt-5">
            <div class="col-12 text-center">
                <div class="bg-white bg-opacity-10 rounded-3 p-4 d-inline-flex align-items-center">
                    <i class="bi bi-info-circle fs-4 text-white me-3"></i>
                    <p class="text-white mb-0">
                        <span class="fw-semibold">Horário de atendimento:</span> Segunda a Sexta, das 8h30 às 17h00 (dias úteis).
                    </p>
                </div>
            </div>
        </div>
    </div>
</section>
