<div class="row empresas-turismo-field-row">
    <div class="col-sm-12 col-md-6">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Razão social') . ' *',
            'name' => 'razaoSocial',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('razaoSocial', $empresa->razaoSocial ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-6">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Nome fantasia') . ' *',
            'name' => 'nomeFantasia',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('nomeFantasia', $empresa->nomeFantasia ?? null),
            'oninput' => "javascript:this.value = this.value.toUpperCase()",
            'readonly' => false,
            'small' => null,
        ])
    </div>
</div>

<div class="row empresas-turismo-field-row">
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('CNPJ') . ' *',
            'name' => 'cnpj',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('cnpj', session('cnpjTmp', $empresa->cnpj ?? null)),
            'oninput' => "javascript:aplicarMascaraCNPJ(this)",
            'readonly' => true,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Inscrição municipal') . ' *',
            'name' => 'numeroInscricaoMunicipal',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('numeroInscricaoMunicipal', $empresa->numeroInscricaoMunicipal ?? null),
            'oninput' => "javascript:this.value = this.value.replace(/\\D/g, '')",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Cadastur') . ' *',
            'name' => 'cadastur',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('cadastur', $empresaTurismo->cadastur ?? null),
            'oninput' => "javascript:this.value = this.value.replace(/\\D/g, '')",
            'readonly' => false,
            'small' => null,
        ])
    </div>
</div>

<div class="row empresas-turismo-field-row">
    <div class="col-sm-12 col-md-6">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Vencimento CADASTUR'),
            'name' => 'cadasturVencimento',
            'id' => 'cadasturVencimento',
            'required' => false,
            'type' => 'date',
            'old' => old(
                'cadasturVencimento',
                isset($empresaTurismo) && $empresaTurismo->cadastur_vencimento
                    ? $empresaTurismo->cadastur_vencimento->format('Y-m-d')
                    : null
            ),
            'oninput' => null,
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-6">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Ano de abertura') . ' *',
            'name' => 'anoAbertura',
            'id' => 'datepickerYear',
            'required' => true,
            'type' => null,
            'old' => old('anoAbertura', $empresa->anoAbertura ?? null),
            'oninput' => "javascript:this.value = this.value.replace(/\\D/g, '').slice(0, 4)",
            'readonly' => false,
            'small' => null,
            'placeholder' => '2013',
        ])
    </div>
</div>

@once
    @push('styles')
        <link rel="stylesheet" href="{{ asset('turismo-nautico/css/empresas-de-turismo-form.css') }}?v={{ @filemtime(public_path('turismo-nautico/css/empresas-de-turismo-form.css')) ?: time() }}">
    @endpush
@endonce
