<?php $__env->startSection('title', __('Horários - MobiAngra') . ' - ' . config('app.name')); ?>

<?php $__env->startSection('content'); ?>
    <section class="mobiangra-subpage">
        <div class="container">
            <?php if (isset($component)) { $__componentOriginal64b445abe4d6b6e54d21775dae604123 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal64b445abe4d6b6e54d21775dae604123 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.breadcrumb','data' => ['items' => [
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Horários')],
            ]]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute([
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Horários')],
            ])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $attributes = $__attributesOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__attributesOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $component = $__componentOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__componentOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>

            <div class="mobiangra-subpage-card">
                <?php if (isset($component)) { $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.subpage-header','data' => ['title' => __('Horários')]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.subpage-header'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['title' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(__('Horários'))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $attributes = $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $component = $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>

                <div class="p-4 mobiangra-subpage-body">
                    <?php if($linhas->isEmpty()): ?>
                        <div class="text-center py-5 text-muted">
                            <i class="fa-solid fa-clock fa-3x mb-3 d-block text-primary" aria-hidden="true"></i>
                            <p><?php echo e(__('A grade de horários ainda não foi publicada. Volte em breve.')); ?></p>
                        </div>
                    <?php else: ?>
                        <?php if (isset($component)) { $__componentOriginal9e418308fd808b5dc2aca83ea420a99a = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal9e418308fd808b5dc2aca83ea420a99a = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.horarios-linha-combobox','data' => ['linhas' => $linhas,'linhaAtivaIdx' => $linhaAtivaIdx]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.horarios-linha-combobox'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['linhas' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($linhas),'linha-ativa-idx' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($linhaAtivaIdx)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal9e418308fd808b5dc2aca83ea420a99a)): ?>
<?php $attributes = $__attributesOriginal9e418308fd808b5dc2aca83ea420a99a; ?>
<?php unset($__attributesOriginal9e418308fd808b5dc2aca83ea420a99a); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal9e418308fd808b5dc2aca83ea420a99a)): ?>
<?php $component = $__componentOriginal9e418308fd808b5dc2aca83ea420a99a; ?>
<?php unset($__componentOriginal9e418308fd808b5dc2aca83ea420a99a); ?>
<?php endif; ?>

                        <div id="horarios-linhas-content">
                            <?php $__currentLoopData = $linhas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $idx => $linha): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <div id="linha-<?php echo e($linha->id); ?>"
                                     class="horarios-linha-panel <?php echo e($linhaAtivaIdx !== null && $idx === $linhaAtivaIdx ? '' : 'd-none'); ?>"
                                     role="region"
                                     aria-label="<?php echo e($linha->nome_completo); ?>">
                                    <?php if (isset($component)) { $__componentOriginal87ed0541a2cef233bac739107171df92 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal87ed0541a2cef233bac739107171df92 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.horarios-linha','data' => ['linha' => $linha]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.horarios-linha'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['linha' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($linha)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal87ed0541a2cef233bac739107171df92)): ?>
<?php $attributes = $__attributesOriginal87ed0541a2cef233bac739107171df92; ?>
<?php unset($__attributesOriginal87ed0541a2cef233bac739107171df92); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal87ed0541a2cef233bac739107171df92)): ?>
<?php $component = $__componentOriginal87ed0541a2cef233bac739107171df92; ?>
<?php unset($__componentOriginal87ed0541a2cef233bac739107171df92); ?>
<?php endif; ?>
                                </div>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php $__env->startPush('scripts'); ?>
    <script src="<?php echo e(asset('mobiangra-assets/js/mobiangra_busca_linhas.js')); ?>?v=<?php echo e(time()); ?>"></script>
    <script src="<?php echo e(asset('mobiangra-assets/js/horarios.js')); ?>?v=<?php echo e(time()); ?>"></script>
<?php $__env->stopPush(); ?>

<?php echo $__env->make('layouts.mobiangra.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/mobiangra/horarios.blade.php ENDPATH**/ ?>