@extends('layouts.reducaoderiscos.theme')
@section('title', 'Bem-vindo ao Plano Municipal de Redução de Riscos de Angra dos Reis')
@section('content')

    <main class="main">
        <section id="hero" class="hero section dark-background">

            <img src="{{ asset('rderiscos/assets/images/cidade-angra-color.png') }}" alt="" data-aos="fade-in">

            <div class="container d-flex flex-column">
                <h1 data-aos="fade-up" data-aos-delay="100"><span>Plano Municipal de Redução de Riscos</span></h1>
            </div>

        </section>

        <section id="sobre" class="about section">
            <div class="container section-title" data-aos="fade-up">
                <h2>O que é o </h2>
                <p>Plano Municipal de Desastres?</p>
            </div>
            <div class="container">
                <div class="row gy-4">
                    <div class="col-lg-6" data-aos="fade-up" data-aos-delay="100">
                        <p>
                            O Plano Municipal de Redução de Riscos (PMRR) é um instrumento estratégico voltado à prevenção e
                            mitigação de riscos no município de Angra dos Reis, com destaque para aqueles associados a
                            movimentos gravitacionais de massa - popularmente conhecidos como deslizamentos.
                        </p>
                        <p>
                            Na sua primeira versão, o PMRR de Angra dos Reis enfatiza os riscos relacionados a
                            deslizamentos, que correspondem a 98% do histórico de óbitos por desastres no município. Um de
                            seus produtos (<em>Estudo de Políticas Públicas e Plano Estratégico Municipal</em>) também
                            possui aplicação ampla e direta na prevenção e redução de riscos de desastres hidrológicos.
                        </p>
                    </div>
                    <div class="col-lg-6" data-aos="fade-up" data-aos-delay="250">

                        <div class="content ps-0 ps-lg-5">
                            <p class="fst-italic">
                                <strong>O PMRR tem importante papel:</strong>
                            </p>
                            <ul>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        No conhecimento dos setores de risco de deslizamentos em diferentes comunidades,
                                        permitindo a criação de mapas de risco detalhados, precisos e informativos;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Na indicação e valoração dos investimentos necessários em medidas e ações de redução
                                        de riscos de desastres;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        No apoio aos gestores públicos com informações sobre a priorização dos investimentos
                                        dos recursos públicos;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        No engajamento e formação da sociedade civil, universitários e servidores públicos
                                        na gestão participativa dos riscos de desastres.
                                    </span>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="row justify-content-center mt-5">
                    <div class="col-xl-8 col-lg-10 col-md-12 col-sm-12" data-aos="fade-up" data-aos-delay="100">
                        <div id="carouselExampleIndicators" class="carousel slide" data-bs-ride="carousel"
                            data-bs-interval="3000">
                            <div class="carousel-indicators">
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="0"
                                    class="active" aria-current="true" aria-label="Slide 1"></button>
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="1"
                                    aria-label="Slide 2"></button>
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="2"
                                    aria-label="Slide 3"></button>
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="3"
                                    aria-label="Slide 4"></button>
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="4"
                                    aria-label="Slide 5"></button>
                                <button type="button" data-bs-target="#carouselExampleIndicators" data-bs-slide-to="5"
                                    aria-label="Slide 6"></button>
                            </div>
                            <div class="carousel-inner">
                                <div class="carousel-item active">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-1.jpg') }}" class="d-block w-100"
                                        alt="Primeira Imagem de Vistorias do Município">
                                </div>
                                <div class="carousel-item">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-2.jpg') }}" class="d-block w-100"
                                        alt="Segunda Imagem de Vistorias do Município">
                                </div>
                                <div class="carousel-item">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-3.jpg') }}" class="d-block w-100"
                                        alt="Terceira Imagem de Vistorias do Município">
                                </div>
                                <div class="carousel-item">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-4.jpg') }}" class="d-block w-100"
                                        alt="Quarta Imagem de Vistorias do Município">
                                </div>
                                <div class="carousel-item">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-5.jpg') }}" class="d-block w-100"
                                        alt="Quinta Imagem de Vistorias do Município">
                                </div>
                                <div class="carousel-item">
                                    <img src="{{ asset('rderiscos/assets/images/vistorias-6.jpg') }}" class="d-block w-100"
                                        alt="Sexta Imagem de Vistorias do Município">
                                </div>
                            </div>
                            <button class="carousel-control-prev" type="button" data-bs-target="#carouselExampleIndicators"
                                data-bs-slide="prev">
                                <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                                <span class="visually-hidden">Previous</span>
                            </button>
                            <button class="carousel-control-next" type="button" data-bs-target="#carouselExampleIndicators"
                                data-bs-slide="next">
                                <span class="carousel-control-next-icon" aria-hidden="true"></span>
                                <span class="visually-hidden">Next</span>
                            </button>
                        </div>

                    </div>

                </div>
            </div>
        </section>

        <section class="about section light-background">
            <div class="container section-title" data-aos="fade-up">
                <h2>Parcerias</h2>
                <p>Quem somos?</p>
            </div>
            <div class="container">
                <div class="row gy-4">
                    <div class="col-lg-12" data-aos="fade-up" data-aos-delay="100">
                        <p>
                            O <strong>PMRR de Angra dos Reis</strong> foi elaborado pela <a href="https://www.uff.br/"
                                target="_blank">Universidade Federal Fluminense</a>, através do <a
                                href="https://dgp.cnpq.br/dgp/espelhogrupo/165198" target="_blank">Grupo de Pesquisa em
                                Desastres Sócio-Naturais</a> do <a href="http://iear.uff.br/" target="_blank">Instituto de
                                Educação de Angra dos Reis</a>, e pela Prefeitura Municipal de Angra dos Reis, através da
                            Secretaria de Proteção e Defesa Civil. Durante todo o processo de elaboração do PMRR foi
                            acompanhado e subsidiado pelo Comitê Municipal do PMRR.
                        </p>
                        <p>
                            O trabalho teve coordenação geral e financiamento do Ministério das Cidades, através do <a
                                href="https://www.gov.br/cidades/pt-br/acesso-a-informacao/institucional/quem-e-quem/secretaria-nacional-de-periferias/departamento-de-mitigacao-e-prevencao-de-risco"
                                target="_blank">Departamento de Mitigação e Prevenção de Risco</a> da Secretaria Nacional
                            de
                            Periferias, com apoio e intermediação da Fiocruz.
                        </p>

                        <div class="content">
                            <h4 class="mt-5">Parceria com a Universidade Federal Fluminense (UFF)</h4>
                            <p>
                                A parceria proposta para a elaboração dos PMRR no âmbito de cooperações técnico-científicas
                                de inovação com as universidades e pesquisadores fundamenta-se em:
                            </p>
                            <ul>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Elaborar Planos Municipais de Redução de Riscos tecnicamente consistentes e
                                        aplicáveis à gestão pública, com embasamento em bibliografias científicas já
                                        consolidadas no campo do mapeamento de riscos e desastres e da cartografia
                                        geotécnica;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Contemplar ações de enfrentamento de processos geradores de riscos e desastres
                                        associados às mudanças climáticas;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Aplicar as inovações metodológicas ao conteúdo do PMRR, tendo em vista a função
                                        essencial desse instrumento no planejamento territorial subsidiando as
                                        administrações públicas locais, as comunidades mapeadas e a sociedade em geral.
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        No engajamento e formação da sociedade civil, universitários e servidores públicos
                                        na gestão participativa dos riscos de desastres.
                                    </span>
                                </li>
                            </ul>

                            <h4 class="mt-5">Inovações alcançadas</h4>
                            <ul>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Aprimoramento dos processos de participação social e comunitária nas diversas
                                        etapas de elaboração do PMRR, bem como para a apropriação do conteúdo por parte dos
                                        usuários dos mapeamentos públicos e comunitários;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Elaboração do PMRR como uma tecnologia social em amplo processo formativo
                                        integrando acadêmicos, servidores municipais e comunitários;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Integração de equipe executiva por universitários e agentes de defesa civil via
                                        Acordo de Cooperação Técnica da Universidade Federal Fluminense e Prefeitura
                                        Municipal de Angra dos Reis;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Integração de métodos heurísticos e determinísticos na avaliação do perigo
                                        associados a movimentos de massa;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Criação do Índice de Vulnerabilidade a Movimentos de Massa;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Integração da vulnerabilidades na análise de risco e hierarquização de medidas
                                        estruturais;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Definição e valorização de medidas não estruturais no rol de medidas de redução
                                        dos riscos de desastres;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Priorização do processo de validação contínuo e participativo do PMRR por
                                        múltiplos atores chaves institucionais e locais;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Elaboração de ampla análise de políticas públicas setoriais e orçamentárias
                                        relacionadas com a gestão dos riscos de desastres;</span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>Construção participativa de Plano Estratégico Municipal de RRD;</span>
                                </li>
                            </ul>
                        </div>

                    </div>
                    <div class="col-lg-6" data-aos="fade-up" data-aos-delay="250">



                    </div>
                </div>
            </div>

        </section>

        <section class="about section">
            <div class="container section-title" data-aos="fade-up">
                <h2>Quais são os</h2>
                <p>Objetivos?</p>
            </div>
            <div class="container">
                <div class="row gy-4">
                    <div class="col-lg-12" data-aos="fade-up" data-aos-delay="100">
                        <div class="content">
                            <h4>Objetivo Geral</h4>
                            <p>
                                Construir um plano estratégico para a prevenção e redução de riscos associados a
                                deslizamentos, com três macro-objetivos:
                            </p>
                            <ul>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Obter informações qualificadas, atualizadas e, principalmente, contextualizadas que
                                        reflitam conhecimentos técnicos e sociais;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Sensibilizar atores-chave da gestão pública e a população em geral, em especial as
                                        pessoas em situação de risco, com foco na mobilização e engajamento social para o
                                        enfrentamento dos perigos;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Divulgar as atividades e os resultados do PMRR e fomentar sua utilização no
                                        planejamento e gestão urbana.
                                    </span>
                                </li>
                            </ul>

                            <h4 class="mt-5">Objetivos Específicos</h4>
                            <ul>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Realizar o mapeamento e o diagnóstico dos processos do meio físico geradores de
                                        risco na <strong>escala de detalhe</strong>, envolvendo a delimitação de setores, a
                                        estimativa de edificações e famílias afetadas e o estabelecimento de graus relativos
                                        de risco, considerando as vulnerabilidades e potencialidades individuais e
                                        comunitárias das localidades analisadas frente a essas ameaças;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Incorporar o conhecimento das comunidades em situação de risco na elaboração dos
                                        mapeamentos e na proposição de ações estruturais e não estruturais, de forma a
                                        proporcionar sua coprodução e apropriação para aumento da resiliência local;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Indicar <strong>medidas estruturais e não estruturais para a redução dos
                                            riscos</strong> em cada setor de risco mapeado considerando, sempre que
                                        possível, a integração entre soluções convencionais de engenharia e soluções
                                        baseadas na natureza, bem como a participação social para o entendimento da
                                        concepção das intervenções indicadas;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Propor critérios de <strong>hierarquização dos setores de risco</strong> alto e
                                        muito alto para o planejamento da execução das intervenções.
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Gerar informações que possam subsidiar a <strong>elaboração de um plano de
                                            ação</strong> tática para a gestão de riscos e desastres no âmbito municipal;
                                    </span>
                                </li>
                                <li><i class="bi bi-check-circle-fill"></i>
                                    <span>
                                        Desenvolver <strong>estratégias de comunicação</strong> do instrumento PMRR e de
                                        seus resultados.
                                    </span>
                                </li>
                            </ul>
                        </div>

                    </div>
                    <div class="col-lg-6" data-aos="fade-up" data-aos-delay="250">



                    </div>
                </div>
            </div>

        </section>

        <img src="{{ asset('rderiscos/assets/images/divider-angra.jpg') }}" class="img-fluid" alt="">

        <section id="realizacao" class="stats section light-background">
            <div class="container section-title" data-aos="fade-up">
                <h2>Como foi</h2>
                <p>Realizado<br></p>
            </div>
            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <p style="text-align: center; font-size: 1.25rem; font-weight: 600;">
                    O PMRR de Angra dos Reis foi elaborado em 5 etapas.
                </p>
            </div>
            <div class="container mt-5" data-aos="fade-up" data-aos-delay="100">
                <div class="row gy-5 gx-5 d-flex justify-content-center">

                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6">
                        <div class="stats-item d-flex align-items-center flex-column w-100 h-100">
                            <i class="bi bi-1-circle-fill flex-shrink-0" style="color: #c0504d;"></i>
                            <div>
                                <p class="areas-atuacao">Plano de Trabalho</p>
                            </div>
                        </div>
                    </div>

                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6">
                        <div class="stats-item d-flex align-items-center  flex-column w-100 h-100">
                            <i class="bi bi-2-circle-fill flex-shrink-0" style="color: #9bbb59;"></i>
                            <div>
                                <p class="areas-atuacao">Mapeamento de Risco</p>
                            </div>
                        </div>
                    </div>

                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6">
                        <div class="stats-item d-flex align-items-center  flex-column w-100 h-100">
                            <i class="bi bi-3-circle-fill flex-shrink-0" style="color: #8064a2;"></i>
                            <div>
                                <p class="areas-atuacao">Medidas estruturais e não estruturais</p>
                            </div>
                        </div>
                    </div>

                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6">
                        <div class="stats-item d-flex align-items-center  flex-column w-100 h-100">
                            <i class="bi bi-4-circle-fill flex-shrink-0" style="color: #4bacc6;"></i>
                            <div>
                                <p class="areas-atuacao">Estudos de políticas públicas e Planejamento estratégico</p>
                            </div>
                        </div>
                    </div>

                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6">
                        <div class="stats-item d-flex align-items-center  flex-column w-100 h-100">
                            <i class="bi bi-5-circle-fill flex-shrink-0" style="color: #f79646;"></i>
                            <div>
                                <p class="areas-atuacao">Relatório final</p>
                            </div>
                        </div>
                    </div>

                </div>
            </div>

            <div class="container table-pmrr-container" data-aos="fade-up" data-aos-delay="100"
                style="margin-top: 100px;">
                <table class="table table-pmrr table-bordered table-striped">
                    <thead>
                        <tr>
                            <th rowspan="2">Etapas</th>
                            <th colspan="9">2024</th>
                            <th colspan="9">2025</th>
                        </tr>
                        <tr>
                            <th>04</th>
                            <th>05</th>
                            <th>06</th>
                            <th>07</th>
                            <th>08</th>
                            <th>09</th>
                            <th>10</th>
                            <th>11</th>
                            <th>12</th>
                            <th>01</th>
                            <th>02</th>
                            <th>03</th>
                            <th>04</th>
                            <th>05</th>
                            <th>06</th>
                            <th>07</th>
                            <th>08</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td style="text-align: left"><strong>Etapa 1:</strong> Plano de trabalho</td>
                            <td>x</td>
                            <td>x</td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td style="text-align: left"><strong>Etapa 2:</strong> Mapeamento de risco</td>
                            <td></td>
                            <td></td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td style="text-align: left"><strong>Etapa 3:</strong> Medidas estruturais e não estruturais
                            </td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td style="text-align: left"><strong>Etapa 4:</strong> Estudos de políticas públicas e
                                Planejamento Estratégico</td>
                            <td></td>
                            <td></td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td style="text-align: left"><strong>Etapa 5:</strong> Relatório final</td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td>x</td>
                            <td>x</td>
                            <td>x</td>
                        </tr>
</tbody>

                </table>

            </div>
            
        </section>
        
        
        <section id="audiencia" class="team section">
            <div class="container section-title" data-aos="fade-up">
                <h2>Aundiência</h2>
                <p>Pública</p>
            </div>
            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <p>A Prefeitura de Angra dos Reis, por intermédio da Secretaria de Proteção e Defesa Civil, em parceria com o Instituto de Educação de Angra dos Reis – Universidade Federal Fluminense, convidam a população, as associações representativas da sociedade civil e servidores públicos para participarem da <strong>Audiência Pública do Plano Municipal de Redução de Risco de Angra dos Reis</strong>, com objetivo de informar os interessados e recolher indicações sobre o referido plano.</p>
                <p>A audiência pública será realizada no dia <strong>17/09/2025 das 18h00 às 21h00, na Câmara Municipal de Angra dos Reis</strong>,, localizada na Praça Nilo Peçanha s/n°, Centro, Angra dos Reis – RJ. A audiência pública será também transmitida ao vivo pelo Youtube através do canal “<a href="https://www.youtube.com/c/TVC%C3%A2maraAngradosReis" target="_blank">TV Câmara Angra dos Reis</a>”.</p>
                <p>Envie suas de indicações (dúvidas, sugestões, elogios e/ou críticas) para a Audiência Pública através do formulário abaixo.</p>
                
                <div class="row">
                    <div class="col-xl-8 col-lg-10 col-md-12 col-sm-12 mx-auto">
                        <a href="https://forms.gle/8vdUB1xSU6e6UsdD9" target="_blank"> 
                            <img src="{{ asset('rderiscos/assets/images/AudienciaPublica.jpg') }}" class="img-fluid" alt="Formuçário de participação da Audiência Pública">
                        </a>
                    </div>
                </div>
                
                <ul class="list_down mt-5">
                    <li>
                        <a href="https://drive.google.com/drive/folders/13oCNLYGi3xQXVO0WMSb3DubHa1mukMpA?usp=sharing"
                            target="_blank">
                            <strong>Relatórios e documentos</strong> <span class="preto">- Relatórios e documentos criados durante as etapas de elaboração do Plano Municipal de Redução de Riscos.</span>
                        </a>
                    </li>
                </ul>

            </div>
        </section>

        <section id="participacao" class="team section light-background">
            <div class="container section-title" data-aos="fade-up">
                <h2>Como foi a</h2>
                <p>Participação Social</p>
            </div>
            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <p>A participação social foi parte fundamental e necessária no processo de elaboração do PMRR de Angra dos
                    Reis. Esta participação pode ser efetivada nos eventos, nas oficinas de mapeamento participativo, nas
                    reuniões nas comunidades, audiências públicas etc.</p>
                <p>Nos gráficos abaixo estão indicadas o número de atividades realizadas e o total de participações na
                    elaboração do PMRR de Angra dos Reis. Ao longo do processo de elaboração do PMRR foram realizadas mais
                    de 200 atividades que contaram com mais de 3.200 participações.</p>

                <div class="row">
                    <div class="col-xl-8 col-lg-10 col-md-12 col-sm-12 mx-auto">
                        <img src="{{ asset('rderiscos/assets/images/grafico01.png') }}" class="img-fluid"
                            alt="Tipos e números de atividades realizadas">
                    </div>
                </div>

                <div class="row mt-4">
                    <div class="col-xl-8 col-lg-10 col-md-12 col-sm-12 mx-auto">
                        <img src="{{ asset('rderiscos/assets/images/grafico02.png') }}" class="img-fluid"
                            alt="Participações por atividades">
                    </div>
                </div>
                <div class="row mt-5">
                    <div class="col-xl-8 col-lg-10 col-md-12 col-sm-12 mx-auto">
                        <img src="{{ asset('rderiscos/assets/images/grafico03.png') }}" class="img-fluid"
                            alt="Participações nas atividades">
                    </div>
                </div>

            </div>
        </section>

        <img src="{{ asset('rderiscos/assets/images/divider-angra.jpg') }}" class="img-fluid" alt="">

        <section id="noticias" class="section">
            <div class="container section-title" data-aos="fade-up">
                <h2>Fique por dentro</h2>
                <p>Notícias</p>
            </div>
            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <div class="accordion borda-accord-index" id="accordionExample">
                    <div class="accordion-item">
                        <h3 class="accordion-header" id="headingOne">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseOne" aria-expanded="false" aria-controls="collapseOne">
                                Prefeitura de Angra dos Reis
                            </button>
                        </h3>
                        <div id="collapseOne" class="accordion-collapse collapse" aria-labelledby="headingOne"
                            data-bs-parent="#accordionExample">
                            <div class="accordion-body">
                                <ul>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/26-05-2025/angra-dos-reis-avanca-no-plano-municipal-de-reducao-de-riscos"
                                            target="_blank">angra.rj.gov.br/noticias/26-05-2025/angra-dos-reis-avanca-no-plano-municipal-de-reducao-de-riscos
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/noticias/20-11-2024/prefeitura-promove-oficinas-de-reducao-de-riscos-ambientais"
                                            target="_blank">angra.rj.gov.br/noticias/20-11-2024/prefeitura-promove-oficinas-de-reducao-de-riscos-ambientais
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/noticias/23-05-2025/angra-dos-reis-tera-programacao-especial-sobre-meio-ambiente-de-5-a-26-de-junho"
                                            target="_blank">angra.rj.gov.br/noticias/23-05-2025/angra-dos-reis-tera-programacao-especial-sobre-meio-ambiente-de-5-a-26-de-junho
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/noticias/13-06-2025/angra-realiza-conferencia-das-cidades-apos-intervalo-de-nove-anos"
                                            target="_blank">angra.rj.gov.br/noticias/13-06-2025/angra-realiza-conferencia-das-cidades-apos-intervalo-de-nove-anos
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/09-04-2024/plano-municipal-de-reducao-de-riscos-e-iniciado-em-angra"
                                            target="_blank">angra.rj.gov.br/noticias/09-04-2024/plano-municipal-de-reducao-de-riscos-e-iniciado-em-angra
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://portal.angra.rj.gov.br/downloads/bo/BO-2127_de_27-05-2025.pdf"
                                            target="_blank">portal.angra.rj.gov.br/downloads/bo/BO-2127_de_27-05-2025.pdf
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/19-06-2024/angra-na-fase-dois-do-plano-municipal-de-reducao-de-riscos"
                                            target="_blank">angra.rj.gov.br/noticias/19-06-2024/angra-na-fase-dois-do-plano-municipal-de-reducao-de-riscos
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://portal.angra.rj.gov.br/downloads/bo/BO-2127_de_27-05-2025.pdf"
                                            target="_blank">portal.angra.rj.gov.br/downloads/bo/BO-2127_de_27-05-2025.pdf
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://portal.angra.rj.gov.br/noticia.asp?vid_noticia=70532&IndexSigla=imp"
                                            target="_blank">portal.angra.rj.gov.br/noticia.asp?vid_noticia=70532&IndexSigla=imp
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/noticias/30-10-2024/oficinas-de-mapeamento-participativo-chegam-ao-bracui"
                                            target="_blank">angra.rj.gov.br/noticias/30-10-2024/oficinas-de-mapeamento-participativo-chegam-ao-bracui
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/pmar/assets/files/boletins/BO-1984-(Ed.-Extra)_de_10-10-2024.pdf"
                                            target="_blank">angra.rj.gov.br/pmar/assets/files/boletins/BO-1984-(Ed.-Extra)_de_10-10-2024.pdf
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/noticias/10-10-2024/oficinas-de-mapeamento-participativo-no-frade"
                                            target="_blank">angra.rj.gov.br/noticias/10-10-2024/oficinas-de-mapeamento-participativo-no-frade
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://angra.rj.gov.br/pmar/assets/files/boletins/BO-1907_de_19-06-2024.pdf"
                                            target="_blank">angra.rj.gov.br/pmar/assets/files/boletins/BO-1907_de_19-06-2024.pdf
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/09-04-2024/plano-municipal-de-reducao-de-riscos-e-iniciado-em-angra"
                                            target="_blank">angra.rj.gov.br/noticias/09-04-2024/plano-municipal-de-reducao-de-riscos-e-iniciado-em-angra
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/05-04-2024/prefeitura-inicia-plano-municipal-de-reducao-de-riscos"
                                            target="_blank">angra.rj.gov.br/noticias/05-04-2024/prefeitura-inicia-plano-municipal-de-reducao-de-riscos
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/noticias/20-02-2024/prefeitura-discute-plano-municipal-de-reducao-de-riscos"
                                            target="_blank">angra.rj.gov.br/noticias/20-02-2024/prefeitura-discute-plano-municipal-de-reducao-de-riscos
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.angra.rj.gov.br/pmar/assets/files/boletins/BO-1845_de_20-02-2024.pdf"
                                            target="_blank">angra.rj.gov.br/pmar/assets/files/boletins/BO-1845_de_20-02-2024.pdf
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div class="accordion-item mt-2">
                        <h3 class="accordion-header" id="headingTwo">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseTwo" aria-expanded="false" aria-controls="collapseTwo">
                                TV e Portais de Notícias
                            </button>
                        </h3>
                        <div id="collapseTwo" class="accordion-collapse collapse" aria-labelledby="headingTwo"
                            data-bs-parent="#accordionExample">
                            <div class="accordion-body">
                                <ul>
                                    <li>
                                        <a href="https://globoplay.globo.com/v/13081749/"
                                            target="_blank">globoplay.globo.com/v/13081749/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://avozdacidade.com/wp/angra-faz-entrega-do-relatorio-do-plano-de-trabalho-do-pmrr/#google_vignette"
                                            target="_blank">avozdacidade.com/wp/angra-faz-entrega-do-relatorio-do-plano-de-trabalho-do-pmrr/#google_vignette
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.correiodamanha.com.br/correio-sul-fluminense/regiao-do-vale/2024/04/125311-angra-dos-reis-inicia-plano-municipal-de-reducao-de-riscos-nesta-segunda.html"
                                            target="_blank">correiodamanha.com.br/correio-sul-fluminense/regiao-do-vale/2024/04/125311-angra-dos-reis-inicia-plano-municipal-de-reducao-de-riscos-nesta-segunda.html
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://diariodovale.com.br/tempo-real/angra-dos-reis-morros-do-centro-recebem-oficina-de-mapeamento-participativo/"
                                            target="_blank">diariodovale.com.br/tempo-real/angra-dos-reis-morros-do-centro-recebem-oficina-de-mapeamento-participativo/
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://odia.ig.com.br/angra-dos-reis/2024/07/6880156-morros-da-carioca-e-abel-em-angra-recebem-oficina-de-mapeamento-participativo.html"
                                            target="_blank">odia.ig.com.br/angra-dos-reis/2024/07/6880156-morros-da-carioca-e-abel-em-angra-recebem-oficina-de-mapeamento-participativo.html
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://avozdacidade.com/wp/morros-da-carioca-e-do-abel-recebem-oficina-de-mapeamento-participativo/"
                                            target="_blank">avozdacidade.com/wp/morros-da-carioca-e-do-abel-recebem-oficina-de-mapeamento-participativo/
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://avozdacidade.com/wp/oficinas-de-reducao-de-riscos-ambientais-sao-realizadas-em-angra-dos-reis/"
                                            target="_blank">avozdacidade.com/wp/oficinas-de-reducao-de-riscos-ambientais-sao-realizadas-em-angra-dos-reis/
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://diariodovale.com.br/tempo-real/angra-promove-oficina-de-mapeamento-participativo-em-comunidades/"
                                            target="_blank">diariodovale.com.br/tempo-real/angra-promove-oficina-de-mapeamento-participativo-em-comunidades/
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://avozdacidade.com/wp/oficinas-de-mapeamento-participativo-chegam-ao-bracui/#google_vignette"
                                            target="_blank">avozdacidade.com/wp/oficinas-de-mapeamento-participativo-chegam-ao-bracui/#google_vignette
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://odia.ig.com.br/angra-dos-reis/2024/11/6946454-aldeia-Sapukay-e-quilombo-do-bracui-recebem-oficinas-do-governo-federal.html"
                                            target="_blank">odia.ig.com.br/angra-dos-reis/2024/11/6946454-aldeia-Sapukay-e-quilombo-do-bracui-recebem-oficinas-do-governo-federal.html
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://acidadecostaverde.com.br/2024/11/agua-santa-e-monsuaba-recebem-oficinas-de-reducao-de-riscos-ambientais/"
                                            target="_blank">acidadecostaverde.com.br/2024/11/agua-santa-e-monsuaba-recebem-oficinas-de-reducao-de-riscos-ambientais/
                                            <i class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div class="accordion-item mt-2">
                        <h3 class="accordion-header" id="headingThree">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
                                Rádio e Podcasts
                            </button>
                        </h3>
                        <div id="collapseThree" class="accordion-collapse collapse" aria-labelledby="headingThree"
                            data-bs-parent="#accordionExample">
                            <div class="accordion-body">
                                <ul>
                                    <li>
                                        <a href="https://youtu.be/xHX4MwN1dXM?feature=shared"
                                            target="_blank">youtu.be/xHX4MwN1dXM?feature=shared <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://youtu.be/NyLNcvdrato?feature=shared"
                                            target="_blank">youtu.be/NyLNcvdrato?feature=shared <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div class="accordion-item mt-2">
                        <h3 class="accordion-header" id="headingFour">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseFour" aria-expanded="false" aria-controls="collapseFour">
                                TV Câmara de Angra dos Reis
                            </button>
                        </h3>
                        <div id="collapseFour" class="accordion-collapse collapse" aria-labelledby="headingFour"
                            data-bs-parent="#accordionExample">
                            <div class="accordion-body">
                                <ul>
                                    <li>
                                        <a href="https://www.youtube.com/watch?v=HycRnLd23Q0"
                                            target="_blank">youtube.com/watch?v=HycRnLd23Q0 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.youtube.com/watch?v=jRHCTwyQTAY"
                                            target="_blank">youtube.com/watch?v=jRHCTwyQTAY <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.youtube.com/watch?v=dScXz3rVIfY"
                                            target="_blank">youtube.com/watch?v=dScXz3rVIfY <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.youtube.com/watch?v=nszCHjsyWWI"
                                            target="_blank">youtube.com/watch?v=nszCHjsyWWI <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div class="accordion-item mt-2">
                        <h3 class="accordion-header" id="headingFive">
                            <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                                data-bs-target="#collapseFive" aria-expanded="false" aria-controls="collapseFive">
                                Instagram
                            </button>
                        </h3>
                        <div id="collapseFive" class="accordion-collapse collapse" aria-labelledby="headingFive"
                            data-bs-parent="#accordionExample">
                            <div class="accordion-body">
                                <ul>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C5je3Y0vqTz/?igsh=YTExOXpxNWg0cW0x"
                                            target="_blank">instagram.com/reel/C5je3Y0vqTz/?igsh=YTExOXpxNWg0cW0x <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C5DmcesuR8v/?igsh=MWFrcm9ocW43YzNmMQ=="
                                            target="_blank">instagram.com/p/C5DmcesuR8v/?igsh=MWFrcm9ocW43YzNmMQ== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C5iiWjvu3IT/?igsh=MWc0NG1wc2lwd3F3NA=="
                                            target="_blank">instagram.com/p/C5iiWjvu3IT/?igsh=MWc0NG1wc2lwd3F3NA== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C6ZpTAyOEX1/?igsh=MXcyZDNnZWU0Zzhxcw=="
                                            target="_blank">instagram.com/p/C6ZpTAyOEX1/?igsh=MXcyZDNnZWU0Zzhxcw== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C6qmY49OItN/?igsh=MTU4dnJxejN5MXBsYQ=="
                                            target="_blank">instagram.com/p/C6qmY49OItN/?igsh=MTU4dnJxejN5MXBsYQ== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C7PuFv3O7-O/?igsh=MXByNGE2a2lsMjNxeg=="
                                            target="_blank">instagram.com/p/C7PuFv3O7-O/?igsh=MXByNGE2a2lsMjNxeg== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C7gw1K1Ox7E/?igsh=Zm9rdHA2OGJ5eDcy"
                                            target="_blank">instagram.com/reel/C7gw1K1Ox7E/?igsh=Zm9rdHA2OGJ5eDcy <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C5hfi-4OFg7/?igsh=MWF4dW1uNDhqb2lhcA=="
                                            target="_blank">instagram.com/p/C5hfi-4OFg7/?igsh=MWF4dW1uNDhqb2lhcA== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C5vUpZTu1Fg/?igsh=cDNkZHhwN2twMzJx"
                                            target="_blank">instagram.com/p/C5vUpZTu1Fg/?igsh=cDNkZHhwN2twMzJx <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C5zF7UwPua3/?igsh=MWpldDl3MW9jM2VuZg=="
                                            target="_blank">instagram.com/reel/C5zF7UwPua3/?igsh=MWpldDl3MW9jM2VuZg== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C51mwfdv2hb/?igsh=MW12enlodzRoZHk1bQ=="
                                            target="_blank">instagram.com/p/C51mwfdv2hb/?igsh=MW12enlodzRoZHk1bQ== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C54jBgVO14v/?igsh=bWJ1eGZvZ3MxY3pr"
                                            target="_blank">instagram.com/p/C54jBgVO14v/?igsh=bWJ1eGZvZ3MxY3pr <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C56yfndp36h/?igsh=MXZ2dTNndTBwdW4wbQ=="
                                            target="_blank">instagram.com/p/C56yfndp36h/?igsh=MXZ2dTNndTBwdW4wbQ== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C5_F1pCuZYx/?igsh=MXhvNGk4dnExZDB1dQ=="
                                            target="_blank">instagram.com/p/C5_F1pCuZYx/?igsh=MXhvNGk4dnExZDB1dQ== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C6O-ZLsOLQD/?igsh=bzFjb2themRmNHpv"
                                            target="_blank">instagram.com/p/C6O-ZLsOLQD/?igsh=bzFjb2themRmNHpv <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C6YPSHqu-QK/?igsh=MWQ2aHNzOHdnY3hlbw=="
                                            target="_blank">instagram.com/p/C6YPSHqu-QK/?igsh=MWQ2aHNzOHdnY3hlbw== <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C6fOhEDOyRI/?igsh=eDVicHk4aXpyNXlo"
                                            target="_blank">instagram.com/p/C6fOhEDOyRI/?igsh=eDVicHk4aXpyNXlo <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C9iMibAvwgw/"
                                            target="_blank">instagram.com/reel/C9iMibAvwgw/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C-P4pbbOAoX/"
                                            target="_blank">instagram.com/reel/C-P4pbbOAoX/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/C_nXlCzu4Gn/"
                                            target="_blank">instagram.com/reel/C_nXlCzu4Gn/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/reel/DCApwwcvzN4/"
                                            target="_blank">instagram.com/reel/DCApwwcvzN4/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C7gw1K1Ox7E/"
                                            target="_blank">instagram.com/p/C7gw1K1Ox7E/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C9OALQnPn3R/?img_index=1"
                                            target="_blank">instagram.com/p/C9OALQnPn3R/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C97oEzQu4im/?img_index=1"
                                            target="_blank">instagram.com/p/C97oEzQu4im/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C-nNPT9ujT1/?img_index=1"
                                            target="_blank">instagram.com/p/C-nNPT9ujT1/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/C_z6ad8uEEF/?img_index=1"
                                            target="_blank">instagram.com/p/C_z6ad8uEEF/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DBQ4-cuOCN5/?img_index=1"
                                            target="_blank">instagram.com/p/DBQ4-cuOCN5/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DCKhE4ZvI9j/?img_index=1"
                                            target="_blank">instagram.com/p/DCKhE4ZvI9j/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DC-N84XPl2f/?img_index=1"
                                            target="_blank">instagram.com/p/DC-N84XPl2f/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DFyW8zJvGKm/?img_index=1"
                                            target="_blank">instagram.com/p/DFyW8zJvGKm/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DHb6f1WPhgH/?img_index=1"
                                            target="_blank">instagram.com/p/DHb6f1WPhgH/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DHy85WvSwGq/?img_index=1"
                                            target="_blank">instagram.com/p/DHy85WvSwGq/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DIFsspON1vv/?img_index=1"
                                            target="_blank">instagram.com/p/DIFsspON1vv/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DIFtTQFNGht/?img_index=1"
                                            target="_blank">instagram.com/p/DIFtTQFNGht/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DIRNPvIRDz9/?img_index=1"
                                            target="_blank">instagram.com/p/DIRNPvIRDz9/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DIwGxfGxLp7/?img_index=1"
                                            target="_blank">instagram.com/p/DIwGxfGxLp7/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DJKkvlyyGaj/?img_index=1"
                                            target="_blank">instagram.com/p/DJKkvlyyGaj/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DJeY6KIN-hd/?img_index=1"
                                            target="_blank">instagram.com/p/DJeY6KIN-hd/?img_index=1 <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                    <li>
                                        <a href="https://www.instagram.com/p/DKCs4nnNUgP/"
                                            target="_blank">instagram.com/p/DKCs4nnNUgP/ <i
                                                class="bi bi-box-arrow-up-right me-1"
                                                style="color: var(--accent-color)"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                </div>

            </div>
        </section>


        <section id="tecnica" class="stats section light-background">
            <div class="container section-title" data-aos="fade-up">
                <h2>Ficha</h2>
                <p>Técnica</p>
            </div>
            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <ul>
                    <li><strong>Presidente da República -</strong> Luís Inácio Lula da Silva</li>
                    <li><strong>Ministro das Cidades -</strong> Jader Fontenelle Barbalho Filho</li>
                    <li><strong>Secretário Nacional de Periferias -</strong> Guilherme Simões Pereira</li>
                    <li><strong>Chefe de Gabinete -</strong> Vitor Araripe Freire Pacheco</li>
                    <li><strong>Diretor do Departamento de Mitigação e Prevenção de Risco -</strong> Rodolfo Baesso Moura
                    </li>
                    <li><strong>Coordenador-Geral de Planos de Mitigação e Prevenção de Risco -</strong> Leonardo Santos
                        Salles Varallo</li>
                    <li><strong>Coordenação Técnica -</strong> Daniela Buosi Rohlfs, Leonardo Andrade de Souza</li>
                </ul>

                <h4 class="mt-5">Coordenação do Projeto Plano Municipal de Redução de Riscos</h4>
                <ul>
                    <li>Leonardo Santos Salles Varallo</li>
                    <li>Leonardo Andrade de Souza</li>
                    <li>Daniela Buosi Rohlfs</li>
                    <li>Fernando Rocha Nogueira</li>
                    <li>Luiz Belino Ferreira Sales</li>
                    <li>Jackeline Leite Pereira Pavin</li>
                    <li>Renan Duarte dos Santos Saraiva</li>
                    <li>Evellyne Porfiria Dourado Santos</li>
                    <li>Gustavo Henrique Fernandes Barreto</li>
                </ul>

                <h4 class="mt-5">PMRR de Angra dos Reis</h4>
                <p><strong>Equipe da Universidade Federal Fluminense</strong></p>
                <ul>
                    <li>Prof. Anderson Mululo Sato (UFF - Coordenador Geral)</li>
                    <li>Prof. Paulo Jorge Vaitsman Leal (UFF - Coordenador Geral)</li>
                    <li>Prof. Michael Alexandre Chetry (UFF)</li>
                    <li>Prof. Marcos Barreto de Mendonça (UFRJ)</li>
                    <li>Profª. Franciele Zanandrea (UFF)</li>
                    <li>Prof. Gean Paulo Michel (UFF e UFRGS)</li>
                    <li>Prof. Ivanovich Lache Salcedo (UFF)</li>
                    <li>Silvio Araujo da Silva (UFRJ)</li>
                    <li>Pamella Oliveira da Silva (UFF)</li>
                    <li>Daniel Mendes de Souza (UFF)</li>
                    <li>Victor Leonardo Silva Santos (UFF)</li>
                    <li>Livia Medeiros da Silva Bonifacio (Poli/UFRJ)</li>
                    <li>Luan Harder Gonsalves</li>
                    <li>Thálisson Vinicius Soares dos Santos (IEAR/UFF)</li>
                </ul>

                <p class="mt-4"><strong>Equipe da Secretaria de Proteção e Defesa Civil</strong></p>
                <ul>
                    <li>Fábio Junior da Silva Pires (Secretário)</li>
                    <li>Leandro da Silva Nunes</li>
                    <li>Pedro França Magalhães</li>
                    <li>Marcelo Lopes</li>
                    <li>Márcia Maria Furtado Gonzaga</li>
                    <li>Maykon da Silva de Oliveira</li>
                    <li>Suzana Cristina de Moura</li>
                    <li>Fabiano Jardim Clemente Santos</li>
                    <li>Alexandre Milczanowski Ribeiro</li>
                    <li>Nilson da Silveira Cabral</li>
                    <li>Milena Lima Vitor Alves</li>
                    <li>Patrick Rodrigues Gonçalves</li>
                    <li>João Victor Pires Woyames</li>
                    <li>Rodrigo Henrique Martins de Andrade</li>
                    <li>Natâny Pinho Rosa</li>
                    <li>Daniel Fernando Sales Ribeiro</li>
                    <li>Adriano Camargo de Oliveira</li>
                </ul>

                <h3 class="mt-5">Comitê Municipal do PMRR</h3>
                <p class="mt-4">O Comitê Municipal do Plano Municipal de Redução de Riscos (PMRR) Angra dos Reis foi
                    instituído oficialmente pelo <a
                        href="https://www.angra.rj.gov.br/pmar/assets/files/boletins/BO-1862_de_21-03-2024.pdf"
                        target="_blank"><strong>Decreto nº 13.455</strong></a>, de 21 de março de 2024, publicado no
                    Boletim Oficial do Município de Angra dos Reis Nº 1862/2024, e atualizado pelo <a
                        href="https://www.angra.rj.gov.br/pmar/assets/files/boletins/67d4974eda53b.pdf"
                        target="_blank"><strong>Decreto Nº 14.016</strong></a>, de 14 de março de 2025, publicado no
                    Boletim Oficial do Município de Angra dos Reis Nº 2088/2025. Segundo seu decreto de criação, o Comitê
                    tem como objetivo planejar, monitorar, acompanhar e apoiar a elaboração do PMRR Angra dos Reis, sendo
                    composto por representantes titulares e suplentes das seguintes secretarias, autarquias e instituições:
                </p>
                <ul class="mt-3">
                    <li><strong>Secretarias de Proteção e Defesa Civil (SPDC)</strong>
                        <ul>
                            <li>Titular: Fábio Júnior da Silva Pires - Matrícula 14.509</li>
                            <li>Suplente: Pedro França Magalhães - Matrícula 14.354</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Educação, Juventude e Inovação (SEJIN)</strong>
                        <ul>
                            <li>Titular: Matheus Pereira Carrara - Matrícula 26.669</li>
                            <li>Suplente: Diego Gomes Ferreira - Matrícula 29.439</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Desenvolvimento Social e Promoção da Cidadania (SDSP)</strong>
                        <ul>
                            <li>Titular: Thaísa Carneiro Bedê - Matrícula 30.236</li>
                            <li>Suplente: Ana Elisa de Almeida Araújo Rosa - Matrícula 26.096</li>
                        </ul>
                    </li>
                    <li><strong>Instituto Municipal de Meio Ambiente (IMAAR)</strong>
                        <ul>
                            <li>Titular: Eduardo de Lima Brasileiro - Matrícula 19.880</li>
                            <li>Suplente: Lauro Henrique Gomes Mendes - Matrícula 3.400.041</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Infraestrutura e Obras Públicas (SIOP)</strong>
                        <ul>
                            <li>Titular: Alan Bernardo Coelho de Souza - Matrícula 21.019</li>
                            <li>Suplente: Luciene Jordão Rabha - Matrícula 20.421</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Desenvolvimento Regional (SDR)</strong>
                        <ul>
                            <li>Titular: Giovanni Wicthoft Fedrizzi - Matrícula 20.242</li>
                            <li>Suplente: Miguel Arcanjo de Souza - Matrícula 30.616</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Obras e Habitação (SOH)</strong>
                        <ul>
                            <li>Titular: Maria Carolina Chaves da Rocha - Matrícula 28.093</li>
                            <li>Suplente: Mariana de Souza Gomes - Matrícula 32.714</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria Executiva de Comunicação (SAG.SECO)</strong>
                        <ul>
                            <li>Titular: Marlene Ponciano - Matrícula 32.573</li>
                            <li>Suplente: Ludmila da Silva Pereira - Matrícula 32.367</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Planejamento e Gestão (SPG)</strong>
                        <ul>
                            <li>Titular: Matheus Fernandes da Silva - Matrícula 27.959</li>
                            <li>Suplente: Rafaella Patrício Lima - Matrícula 30.055</li>
                        </ul>
                    </li>
                    <li><strong>Superintendência do Programa Comunidade de Angra (SRI. SUPCA)</strong>
                        <ul>
                            <li>Titular: Mariana da Fonseca Ornelas Azevedo - Matrícula 32.557</li>
                            <li>Suplente: André Porto Pereira - Matrícula 32.584</li>
                        </ul>
                    </li>
                    <li><strong>Secretaria de Saúde (SSA)</strong>
                        <ul>
                            <li>Titular: Mariana de Souza Barbosa - Matrícula 30.514</li>
                            <li>Suplente: Teresa Cristina Sampaio de Barros Leite - Matrícula 3.583</li>
                        </ul>
                    </li>
                    <li><strong>Serviço Autônomo de Captação de Água e Tratamento de Esgoto (SAAE)</strong>
                        <ul>
                            <li>Titular: Marc Helder Antoine de Touchet Olichon - Matrícula 191.122</li>
                            <li>Suplente: Alexandre Giovanetti Lima - Matrícula 190.539</li>
                        </ul>
                    </li>
                    <li><strong>Universidade Federal Fluminense (UFF)</strong>
                        <ul>
                            <li>Titular: Anderson Mululo Sato</li>
                            <li>Suplente: Paulo Jorge Vaitsman Leal</li>
                        </ul>
                    </li>
                </ul>
            </div>
        </section>



        <section id="contato" class="contact section">
            <div class="container section-title" data-aos="fade-up">
                <h2>Fale com a equipe do PMRR</h2>
                <p>Entre em contato</p>
            </div>

            <div class="container" data-aos="fade-up" data-aos-delay="100">
                <div class="row gy-4">
                    <div class="col-lg-4">
                        <div class="info-item h-100 d-flex flex-column justify-content-start align-items-center"
                            data-aos="fade-up" data-aos-delay="200">
                            <i class="bi bi-instagram"></i>
                            <h3 class="mt-4 mb-3">Acompanhe nosso Instagram</h3>
                            <p>Escanei o QR Code ou <a href="https://www.instagram.com/defesacivilangra"
                                    target="_blank"><strong>clique aqui</strong></a></p>
                            <img src="{{ asset('rderiscos/assets/images/qr-insta-spdc.png') }}" alt="QR Code"
                                class="img-fluid" style="max-width: 200px">
                        </div>
                    </div>

                    <div class="col-lg-4">
                        <div class="info-item h-100 d-flex flex-column justify-content-start align-items-center"
                            data-aos="fade-up" data-aos-delay="200">
                            <i class="bi bi-people"></i>
                            <h3 class="mt-4 mb-3">Secretaria de Proteção e Defesa Civil de Angra dos Reis</h3>
                            <p>Telefone: (24) 3377-6046</p>
                            <p>E-mail: defesacivil@angra.rj.gov.br</p>
                            <p>Avenida Almirante Júlio César de Noronha, 271, São Bento. Angra dos Reis – RJ</p>
                        </div>
                    </div>

                    <div class="col-lg-4">
                        <div class="info-item h-100 d-flex flex-column justify-content-start align-items-center"
                            data-aos="fade-up" data-aos-delay="200">
                            <i class="bi bi-mortarboard"></i>
                            <h3 class="mt-4 mb-3">Universidade Federal Fluminense - Instituto de Educação de Angra dos Reis
                            </h3>
                            <p>Telefone: (24) 3365-1642</p>
                            <p>E-mail: iear@id.uff.br</p>
                            <p>Avenida do Trabalhador, 179, Jacuecanga. Angra dos Reis – RJ. Cep: 23914-360</p>
                        </div>
                    </div>

                </div>
            </div>
        </section>

        <img src="{{ asset('rderiscos/assets/images/divider-angra.jpg') }}" class="img-fluid" alt="">

    </main>

    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const overlay = document.getElementById("overlay");
            const closeBtn = document.getElementById("closeBtn");

            // Mostrar o popup ao carregar
            overlay.style.display = "block";

            // Fechar ao clicar no botão X
            closeBtn.addEventListener("click", function() {
                overlay.style.display = "none";
            });

            // Fechar ao clicar fora do popup
            overlay.addEventListener("click", function(e) {
                if (e.target === overlay) {
                    overlay.style.display = "none";
                }
            });
        });
    </script>

@endsection
