@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Novo Programa'))
@section('content')
    <div class="card shadow-sm">
        @php
            $headLine = "<i class='fa-solid fa-plus'></i> " . __('Novo Programa');
        @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.projetosProgramas.index',
            'routeBackParams' => ['tab' => 'programas'],
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_PROJETOS_E_PROGRAMAS',
        ])

        <div class="card-body text-start">
            @include('errors.messageFlash')

            <form method="post" action="{{ route('admin.projetosProgramas.programas.store') }}" class="text-start">
                @csrf
                @include('admin.projetosProgramas.programas._form', ['programa' => $programa])
            </form>
        </div>
    </div>
@endsection

