{{ __('Prefeitura Municipal de Angra dos Reis') }}

{{ __('Vencimento do CADASTUR') }}
{{ __('Empresas de Turismo - TurisAngra') }}

{{ __('Prezado(a),') }}

{{ __('Informamos que o cadastro CADASTUR da sua empresa vence em 30 dias. Confira os dados abaixo e providencie a renovação junto aos órgãos competentes.') }}

{{ __('Razão Social') }}: {{ $empresaTurismo->companhia?->razaoSocial ?? '-' }}
{{ __('CNPJ') }}: {{ $empresaTurismo->companhia?->cnpj ?? '-' }}
{{ __('Cadastur') }}: {{ $empresaTurismo->cadastur }}
{{ __('Vencimento') }}: {{ $empresaTurismo->cadastur_vencimento?->format('d/m/Y') ?? '-' }}

{{ __('Atenção') }}: {{ $mensagem }}

---
{{ __('Prefeitura Municipal de Angra dos Reis') }}
{{ __('Este é um e-mail automático, por favor não responda.') }}
