<?php $__env->startSection("title", env("APP_NAME") . " :: Meu Perfil"); ?>
<?php $__env->startSection('content'); ?>
    <div class="container-fluid px-1    ">
        <div class="row">
            <div class="col-12">
                <div class="card shadow mx-0">
                    <form action="<?php echo e(route('admin.profile.update')); ?>" method="post" enctype="multipart/form-data">

                        <?php $headLine = "<i class='fa-regular fa-id-badge'></i> Meu Perfil"; ?>

                        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
                                'headLine' => __($headLine),
                                "permission" => "GUEST",
                            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                        <div class="card-body">
                            <?php echo csrf_field(); ?>
                            <?php echo method_field('post'); ?>

                            <?php echo $__env->make("errors.messageFlash", array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                            <?php echo $__env->make('components.modal._modelProfile', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

                            <hr/>
                            
                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                <!-- Campo Nome completo -->
                                    <?php echo $__env->make('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "Nome completo",
                                        "name" => "fullName",
                                        "id" => null,
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('fullName', $user->name),
                                        "oninput" => "javascript:this.value = this.value.toLocaleUpperCase('pt-BR').replace(/[^\p{L}\s]+/gu, '').replace(/\s{2,}/g,' ').trimStart()",
                                        "readonly" => false,
                                        "small" => null,
                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>


                                </div>
                                <div class="col-sm-12 col-md-6">

                                <!-- Campo Email -->
                                    <?php echo $__env->make('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "Email",
                                        "name" => "email",
                                        "id" => null,
                                        "required" => true,
                                        "type" => 'email',
                                        "old" => old('email', $user->email),
                                        "oninput" => "javascript:this.value = this.value.toLowerCase()",
                                        "readonly" => false,
                                        "small" => null,
                                        "placeholder" => "nome@email.com",
                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?> 
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-sm-12 col-md-6">
                                <!-- Campo Telefone -->
                                    <?php echo $__env->make('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "Telefone",
                                        "name" => "phoneNumber",
                                        "id" => null,
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('phoneNumber', $user->phoneNumber),
                                        "oninput" => "javascript:aplicarMascaraTelefone(this)",
                                        "readonly" => false,
                                        "small" => null,
                                    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                </div>
                                <div class="col-sm-12 col-md-6">
                                    <div style="width: 100%">
                                    <!-- Campo Foto -->
                                        <?php echo $__env->make('components.inputs._inputType',[
                                            "for" => null,
                                            "label" => "Foto",
                                            "name" => "photo",
                                            "id" => null,
                                            "required" => false,
                                            "type" => 'file',
                                            "old" => null,
                                            "oninput" => null,
                                            "readonly" => true,
                                            "small" => null,
                                            "accept" => 'image/jpeg,image/jpg,image/png,image/gif',
                                        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="row">
                                <div class="col-12">
                                    <?php echo $__env->make('components.buttons._backAndSend', [
                                    'textSend' => 'Atualizar', 
                                ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                                </div>
                            </div>
                        </div>

                    </div>


                </form>

            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/profile.blade.php ENDPATH**/ ?>