<section id="footer-section" class="footer-section">
            <div class="container">
                <div class="row">
                    <div class="col-md-3 col-sm-6 inforodape">
                        <div class="section-heading-2">
                            <h3 class="section-title">
                                <span>Instituto Municipal do Ambiente de Angra dos Reis</span>
                            </h3>
                        </div>
                        
                        <div class="footer-address">
                            <ul>
                                <li class="footer-contact"><i class="fa fa-home"></i>Rua do Comércio, 17. Centro</li>
                                <li class="footer-contact"><i class="fa fa-envelope"></i><a href="mailto:imaar.supma@angra.rj.gov.br">imaar.supma@angra.rj.gov.br</a></li>
                                <li class="footer-contact"><i class="fa fa-phone"></i><a href="tel:02433684435">+55 24 3368-4435</a></li>
                                <li class="footer-contact"><i class="fa fa-globe"></i><a href="http://angra.rj.gov.br" target="_blank">angra.rj.gov.br</a></li>
                            </ul>
                        </div>
                    </div><!--/.col-md-3 -->
                    
                    <div class="col-md-3 col-sm-6 inforodape">
                        <div class="section-heading-2">
                            <h3 class="section-title">
                                <span>Prefeitura de Angra dos Reis</span>
                            </h3>
                        </div>
                        
                        <div class="footer-address">
                            <ul>
                                <li class="footer-contact"><i class="fa fa-home"></i>Praça Nilo Peçanha, 186</li>
                                <li class="footer-contact"><i class="fa fa-envelope"></i><a href="mailto:ouvidoria@angra.rj.gov.br">ouvidoria@angra.rj.gov.br</a></li>
                                <li class="footer-contact"><i class="fa fa-phone"></i><a href="tel:02433684435">+55 24 3377-8311</a></li>
                            </ul>
                        </div>
                    </div><!--/.col-md-3 -->
                    
                    
                    <div class="col-md-3 col-sm-6 inforodape">
                        <div class="footer-address">
                            <img src="{{ asset('parquedacidade/asset/images/logo-parque-branco.png') }}" alt="" >
						</div>
                    </div>
					
                    <div class="col-md-3 col-sm-6 inforodape">
                        <div class="footer-address">
                            <img src="{{ asset('parquedacidade/asset/images/logo-pmar.svg') }}" class="logopmar" alt="" >
						</div>
					</div>
                    
                </div><!--/.row -->
            </div><!-- /.container -->
        </section>


<script src="https://plugin.handtalk.me/web/latest/handtalk.min.js"></script>
<script>
			var ht = new HT({
					token: "7a92081e27daf17bd3b2efe277d0648c",
					avatar: "MAYA",
					pageSpeech: true,
					maxTextSize: 1000
			 });
</script>