@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Novo conselho'))
@section('content')
<div class="card shadow-sm">
    @php $headLine = "<i class='fa-solid fa-people-group'></i> " . __('Novo conselho'); @endphp
    @include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.conselhosMunicipais.conselhos.index', 'nameBack' => __('Voltar'), 'permission' => 'GERENCIADOR_DE_CONSELHOS'])
    <div class="card-body">
        @include('errors.messageFlash')
        <form action="{{ route('admin.conselhosMunicipais.conselhos.store') }}" method="POST" enctype="multipart/form-data">@csrf
            @include('admin.conselhosMunicipais.conselhos._form')

            @include('components.buttons._backAndSend', [
            'textBack' => __('Voltar'),
            'textSend' => __('Cadastrar'),
            'routeBack' => 'admin.conselhosMunicipais.conselhos.index'
            ])

        </form>
    </div>
</div>
@endsection
