@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Cadastro de Pacientes com Fibromialgia")
@section('content')

    <div class="card shadow">

        @php $headLine = "<i class='fa-solid fa-user-injured'></i> Cadastro de Pacientes com Fibromialgia"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.contaAngra.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
        ])

        <div class="card-body">
            
            @include("errors.messageFlash")
            @include('components.modal._modelProfile')

            <hr>
           
            <div class="tab-content">
                <div class="mb-3">
                    
                    @include('admin.saude.fibromialgia.perfil.institucional')
                    
                    @if($user->fibromialgia?->exists)
                        <a class="btn btn-lg btn-primary"
                            href="{{ route("admin.saude.fibromialgia.perfil.show", $user->fibromialgia->id) }}">
                             {{ __("Você já fez a adesão ao cadastro de Paciente com Fibromialgia, deseja acessar a Página de Acompanhamento?") }}
                        </a>
                    @else
                        @include('components.modal._modalConfirmAdesao', [
                            'route' => 'admin.adesao.fibromialgia'])
                    @endif
                    
                </div>
            </div>
            
        </div>
    </div>

@endsection