<div class="mb-3">
    @if(isset($routeBack))
        @php
            $backParams = $backId ?? [];
            if (!is_array($backParams)) {
                $backParams = [$backParams];
            }
            if (request()->filled('q')) {
                $backParams['q'] = request()->input('q');
            }
            if (request()->filled('page')) {
                $backParams['page'] = request()->input('page');
            }
        @endphp
        <button class="btn btn-lg btn-secondary d-inline" onclick="javascript:window.location.href='{{ route($routeBack, $backParams) }}'" type="button">{{ __($textBack) }}</button>
    @endif
    <button class="btn btn-lg btn-dark  d-inline" type="submit">{{ __($textSend) }}</button>
</div>
