@extends('layouts.admin.theme')

@section('content')
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-12">
                <div class="card shadow">
                    <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
                        <h5 class="my-2">Editar Redirecionamento de URL</h5>
                    </div>
                    <div class="card-body">
                        <div class="card-header">Editar URL</div>

                        <div class="card-body">
                            <form action="{{ route('admin.urls.update', $url->id) }}" method="POST">
                                @csrf
                                @method('PUT')
                                @include('admin.urls.partials.form')

                                <div class="d-flex justify-content-between mt-4">
                                    <a href="{{ route('admin.urls.index') }}" class="btn btn-secondary">
                                        <i class="fas fa-arrow-left"></i> Voltar
                                    </a>
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-save"></i> Atualizar
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection