{{-- 
    @include("admin.components.btnDelete", [
        'route' => "id do serviço",
        'id' => "rota do serviço",
        'text' => "* Este serviço será excluído e esta ação não poderá ser desfeita, deseja continuar?",
    ])
--}}

@if (in_array('DELETE', explode(',', auth()->user()->papers)))
    <form class="del d-inline" action="{{ route($route, $id) }}" method="post" onsubmit="return confirmDelete(this)">
        @csrf
        @method('delete')
        <input type="hidden" name="page" value="{{ request()->input('page', 1) }}">
        <input type="hidden" name="confirm" value="{{  __($text) }}"/>
        <button class="btn btn-danger btn-sm flex-fill" type="submit">
            <span class="material-symbols-outlined" data-bs-toggle="tooltip" data-bs-placement="top" title="Excluir"><i class="fa-solid fa-trash"></i></span>
        </button>
    </form>
@endif
