<div class="container">
    <div class="row g-4 g-lg-5">
        <div class="col-12 col-lg-4">
            <a href="{{ route('paginas.home') }}" class="ma-footer__brand" title="{{ __('Portal da Prefeitura') }}">
                <img src="{{ asset('pmar/assets/img/logo-angra-branco.svg') }}"
                    alt="{{ __('Prefeitura de Angra dos Reis') }}" class="ma-footer__logo" width="220" height="80"
                    decoding="async">
            </a>
        </div>

        <div class="col-12 col-sm-6 col-lg-4">
            <h2 class="ma-footer__title">{{ __('Entre em contato') }}</h2>
            <ul class="ma-footer__list">
                <li>
                    <a href="tel:+5524333684704">
                        <i class="fa-solid fa-phone" aria-hidden="true"></i>
                        <span>{{ __('Tel: +55 (24) 3368-4704') }}</span>
                    </a>
                </li>
                <li>
                    <a href="http://portal.angra.rj.gov.br/downloads/Lista_Telefonica.pdf" target="_blank"
                        rel="noopener noreferrer">
                        <i class="fa-solid fa-book" aria-hidden="true"></i>
                        <span>{{ __('Lista de ramais') }}</span>
                    </a>
                </li>
                <li>
                    <a href="https://maps.app.goo.gl/14ovbkFQAySAGb1L8" target="_blank" rel="noopener noreferrer">
                        <i class="fa-solid fa-location-dot" aria-hidden="true"></i>
                        <span>{{ __('Praça Nilo Peçanha, nº 186 - Centro') }}<br>{{ __('Angra dos Reis, RJ - CEP: 23900-901') }}</span>
                    </a>
                </li>
                <li>
                    <span>
                        <i class="fa-solid fa-clock" aria-hidden="true"></i>
                        <span>{{ __('Horário de atendimento ao público:') }}<br>{{ __('segunda à sexta, das 10 às 16h.') }}</span>
                    </span>
                </li>
            </ul>
        </div>

        <div class="col-12 col-sm-6 col-lg-4">
            <h2 class="ma-footer__title">{{ __('Acompanhe, comente e compartilhe') }}</h2>
            <ul class="ma-footer__list">
                <li>
                    <a href="http://facebook.com/PrefeituradeAngra" target="_blank" rel="noopener noreferrer">
                        <i class="fa-brands fa-facebook" aria-hidden="true"></i>
                        <span>{{ __('Curta nossa página no Facebook') }}</span>
                    </a>
                </li>
                <li>
                    <a href="https://www.instagram.com/prefeituraangra" target="_blank" rel="noopener noreferrer">
                        <i class="fa-brands fa-instagram" aria-hidden="true"></i>
                        <span>{{ __('Siga nosso perfil no Instagram') }}</span>
                    </a>
                </li>
            </ul>

            <h2 class="ma-footer__title mt-4">{{ __('Outros sites relevantes') }}</h2>
            <ul class="ma-footer__list">
                <li>
                    <a href="https://visite.angra.rj.gov.br/" target="_blank" rel="noopener noreferrer">
                        <i class="fa-solid fa-sun" aria-hidden="true"></i>
                        <span>{{ __('Portal Visite Angra') }}</span>
                    </a>
                </li>
                <li>
                    <a href="https://saaeangra.com.br/" target="_blank" rel="noopener noreferrer">
                        <i class="fa-solid fa-droplet" aria-hidden="true"></i>
                        <span>{{ __('SAAE - Água e esgoto') }}</span>
                    </a>
                </li>
                <li>
                    <a href="https://www.angraprev.rj.gov.br/" target="_blank" rel="noopener noreferrer">
                        <i class="fa-solid fa-person" aria-hidden="true"></i>
                        <span>{{ __('Angraprev - Previdência Social') }}</span>
                    </a>
                </li>
                <li>
                    <a href="{{ route('paginas.protecao-de-dados-lgpd') }}">
                        <i class="fa-solid fa-shield-halved" aria-hidden="true"></i>
                        <span>{{ __('Proteção de Dados - LGPD') }}</span>
                    </a>
                </li>
            </ul>
        </div>
    </div>

    <button type="button" class="ma-back-to-top" id="ma-back-to-top" aria-label="{{ __('Voltar ao topo') }}" hidden>
        <i class="fa-solid fa-chevron-up" aria-hidden="true"></i>
    </button>
</div>

<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/js/bootstrap.bundle.min.js"
    crossorigin="anonymous" referrerpolicy="no-referrer"></script>
