@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: " . __('Detalhes do Convênio'))

@section('content')
<style>
    .bg-primary { background: linear-gradient(135deg, #0d6efd, #084298); }
    .landing-header {
        color: white;
        padding: 3rem 0 2.5rem 0;
        margin-bottom: 2rem;
        border-radius: 0 0 50px 50px;
        box-shadow: 0 10px 30px rgba(0,0,0,0.15);
        position: relative;
        overflow: hidden;
    }
    .landing-header.bg-primary::before {
        content: '';
        position: absolute;
        top: 0; left: 0; right: 0; bottom: 0;
        background: url('https://www.angra.rj.gov.br/uploads/2023/01/20230113110543.jpg') center/cover;
        opacity: 0.08;
        mix-blend-mode: overlay;
    }
    .detail-card {
        border-radius: 15px;
        box-shadow: 0 5px 20px rgba(0,0,0,0.08);
        border: none;
        overflow: hidden;
    }
    .detail-section-title {
        font-size: 1.1rem;
        font-weight: 700;
        color: #004e92;
        border-bottom: 2px solid #f0f2f5;
        padding-bottom: 10px;
        margin-bottom: 20px;
        margin-top: 10px;
    }
    .detail-label {
        font-size: 0.9rem;
        color: #6c757d;
        font-weight: 600;
        margin-bottom: 5px;
    }
    .detail-value {
        font-size: 1.05rem;
        color: #212529;
        font-weight: 500;
        margin-bottom: 20px;
    }
    .value-highlight {
        color: #004e92;
        font-weight: 700;
        font-size: 1.2rem;
    }
</style>

<div class="landing-header bg-primary text-center position-relative">
    <div class="container position-relative">
        <div class="d-flex justify-content-between align-items-start flex-wrap gap-3 mb-3">
            <div class="d-flex align-items-center gap-3">
                <div class="bg-white text-primary rounded-circle p-3 shadow-sm">
                    <i class="fa-solid fa-file-contract fa-2x"></i>
                </div>
                <div class="text-start">
                    <h2 class="h3 fw-bold mb-1 text-white">{{ __('Detalhes do Convênio') }}</h2>
                    <p class="opacity-75 mb-0 text-white">
                        {{ $convenio->show_proposta_id ? __('Proposta ID') . ': ' . ($convenio->proposta_id ?? 'N/D') : '' }}
                    </p>
                </div>
            </div>
            <div class="d-flex flex-wrap gap-2 ms-auto">
                <a href="{{ route('pppseconvenios') }}" class="btn btn-outline-light btn-sm rounded-pill">
                    <i class="fa-solid fa-arrow-left me-2"></i>{{ __('Início') }}
                </a>
                <a href="{{ route('convenios.public.list') }}" class="btn btn-outline-light btn-sm rounded-pill">
                    <i class="fa-solid fa-list me-2"></i>{{ __('Voltar à lista de Convênios') }}
                </a>
            </div>
        </div>
    </div>
</div>

<div class="container mb-5">
    <div class="row">
        <div class="col-lg-8">
            <div class="card detail-card p-4 mb-4">
                @if($convenio->show_objeto ?? true)
                <div class="detail-section-title"><i class="fa-solid fa-align-left me-2"></i> {{ __('Objeto do Convênio') }}</div>
                <p class="fs-5 text-dark">{{ $convenio->objeto }}</p>
                @endif
                <div class="detail-section-title mt-4"><i class="fa-solid fa-circle-info me-2"></i> {{ __('Informações Gerais') }}</div>
                <div class="row">
                    @if($convenio->show_programa ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Programa') }}</div>
                        <div class="detail-value">{{ $convenio->programa ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_tipo_programa ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Tipo de Programa') }}</div>
                        <div class="detail-value">{{ $convenio->tipo_programa ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_programa_pac ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Programa Nº PAC') }}</div>
                        <div class="detail-value">{{ $convenio->programa_pac ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_status_plataforma ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Status / Plataforma') }}</div>
                        <div class="detail-value"><span class="badge bg-secondary">{{ $convenio->status_plataforma ?? '-' }}</span></div>
                    </div>
                    @endif
                    @if($convenio->show_andamento ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Andamento') }}</div>
                        <div class="detail-value">{{ $convenio->andamento ?? '-' }}</div>
                    </div>
                    @endif
                </div>
            </div>
            <div class="card detail-card p-4 mb-4">
                <div class="detail-section-title"><i class="fa-solid fa-file-signature me-2"></i> {{ __('Acompanhamento do Instrumento') }}</div>
                <div class="row">
                    @if($convenio->show_numero_instrumento ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Número do instrumento') }}</div>
                        <div class="detail-value">{{ $convenio->numero_instrumento ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_numero_processo_sei ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Número do processo SEI') }}</div>
                        <div class="detail-value">{{ $convenio->numero_processo_sei ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_data_recebimento_recurso ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Data do recebimento do recurso') }}</div>
                        <div class="detail-value">{{ $convenio->data_recebimento_recurso ? $convenio->data_recebimento_recurso->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_data_assinatura_instrumento ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Data de assinatura do instrumento') }}</div>
                        <div class="detail-value">{{ $convenio->data_assinatura_instrumento ? $convenio->data_assinatura_instrumento->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_vigencia_clausula_suspensiva ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Vigência da cláusula suspensiva') }}</div>
                        <div class="detail-value">{{ $convenio->vigencia_clausula_suspensiva ? $convenio->vigencia_clausula_suspensiva->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_vigencia_prazo_contratual ?? true)
                    <div class="col-md-6">
                        <div class="detail-label">{{ __('Vigência do prazo de vigência contratual') }}</div>
                        <div class="detail-value">{{ $convenio->vigencia_prazo_contratual ? $convenio->vigencia_prazo_contratual->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                </div>
            </div>
            <div class="card detail-card p-4 mb-4">
                <div class="detail-section-title"><i class="fa-solid fa-location-dot me-2"></i> {{ __('Localização e Prazos') }}</div>
                <div class="row">
                    @if($convenio->show_local ?? true)
                    <div class="col-md-12">
                        <div class="detail-label">{{ __('Local') }}</div>
                        <div class="detail-value">{{ $convenio->local ?? '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_data ?? true)
                    <div class="col-md-4">
                        <div class="detail-label">{{ __('Data') }}</div>
                        <div class="detail-value">{{ $convenio->data ? $convenio->data->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_prazo_cadastro ?? true)
                    <div class="col-md-4">
                        <div class="detail-label">{{ __('Prazo de Cadastro') }}</div>
                        <div class="detail-value">{{ $convenio->prazo_cadastro ? $convenio->prazo_cadastro->format('d/m/Y') : '-' }}</div>
                    </div>
                    @endif
                    @if($convenio->show_prazo_execucao_meses ?? true)
                    <div class="col-md-4">
                        <div class="detail-label">{{ __('Prazo de Execução (Meses)') }}</div>
                        <div class="detail-value">{{ $convenio->prazo_execucao_meses ? $convenio->prazo_execucao_meses . ' ' . __('meses') : '-' }}</div>
                    </div>
                    @endif
                </div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="card detail-card p-4 mb-4 bg-light border-0">
                <div class="detail-section-title"><i class="fa-solid fa-coins me-2"></i> {{ __('Valores Financeiros') }}</div>
                @if($convenio->show_valor_global ?? true)
                <div class="detail-label">{{ __('Valor Global') }}</div>
                <div class="detail-value value-highlight text-success">{{ $convenio->valor_global ?? '-' }}</div>
                <hr>
                @endif
                @if($convenio->show_repasse ?? true)
                <div class="detail-label">{{ __('Repasse') }}</div>
                <div class="detail-value fw-bold">{{ $convenio->repasse ?? '-' }}</div>
                @endif
                @if($convenio->show_contrapartida ?? true)
                <div class="detail-label">{{ __('Contrapartida') }}</div>
                <div class="detail-value fw-bold">{{ $convenio->contrapartida ?? '-' }}</div>
                @endif
            </div>
            <div class="card detail-card p-4">
                <div class="detail-section-title"><i class="fa-solid fa-users me-2"></i> {{ __('Envolvidos') }}</div>
                @if($convenio->show_concedente ?? true)
                <div class="detail-label">{{ __('Concedente') }}</div>
                <div class="detail-value">{{ $convenio->concedente ?? '-' }}</div>
                @endif
                @if($convenio->show_executor_ordenador ?? true)
                <div class="detail-label">{{ __('Executor / Ordenador') }}</div>
                <div class="detail-value">{{ $convenio->executor_ordenador ?? '-' }}</div>
                @endif
            </div>
        </div>
    </div>
</div>
@endsection
