<header class="bg-light">
    <div class="container">
        <div class="row py-5 mx-3 text-center">
            <div class="col-12">
                <h1 class="display-1 fs-0 my-3">{{ __("Comitê Municipal de Governança Digital") }}</h1>
            </div>
            <div class="col-10 offset-1">
                <p class="my-5 fw-normal fs-5 text-muted">{{ __("O Comitê Municipal de Governança Digital (CMGD) de Angra dos Reis é o órgão responsável por deli berar sobre temas relacionados à transformação digital da gestão pública municipal. Compete ao CMGD definir diretrizes para o uso de recursos de tecnologia da informação e comunicação, promover a segurança da informação e assegurar a proteção de dados pessoais no âmbito da administração pública municipal.") }}</p>
                <p class="my-5 fw-normal fs-5 text-muted">{{ __("O Comitê conta com o apoio de sua Comissão Técnica, que tem a função de subsidiar as reuniões e deliberações, garantindo que as decisões estejam alinhadas às melhores práticas de governança digital, transparência e inovação voltadas ao cidadão.") }}</p>
            </div>
        </div>
    </div>
</header>