<?php $__env->startSection('title', __('Novo Boletim Meteorológico')); ?>

<?php $__env->startSection('content'); ?>
<?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<div class="card shadow-lg">
    <?php if(collect(auth()->user()?->listaPermissoes())->contains('GERENCIADOR_DE_BOLETINS_METEOROLOGICOS')): ?>
        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
            <h5 class="my-2">
                <i class="fas fa-cloud-sun-rain me-2"></i> <?php echo e(__('Novo Boletim Meteorológico')); ?>

            </h5>
            <div class="ms-auto">
                <?php echo $__env->make('components.buttons._backButton', ['url' => 'admin.boletim.meteorologico.index', 'label' => __('Voltar')], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </div>
        </div>
    <?php endif; ?>

    <?php echo $__env->make('admin.defesaCivil.boletim_meteorologico.partials.form', [
        'boletim' => null,
        'sobreavisos' => $sobreavisos,
        'options' => $options,
        'formAction' => route('admin.boletim.meteorologico.store'),
        'method' => 'POST',
        'submitLabel' => __('Salvar Boletim')
    ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
</div>

<?php $__env->startPush('styles'); ?>
<link rel="stylesheet" href="<?php echo e(asset('pmar/css/defesa-civil/boletim-meteorologico-admin.css')); ?>">
<?php $__env->stopPush(); ?>

<?php $__env->startPush('scripts'); ?>
<script src="<?php echo e(asset('pmar/js/defesa-civil/boletim-meteorologico-admin.js')); ?>"></script>
<?php $__env->stopPush(); ?>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/defesaCivil/boletim_meteorologico/create.blade.php ENDPATH**/ ?>