<!-- Quote/testimonial aside-->
<aside class="text-center bg-gradient-primary-to-secondary">
<div class="container px-5">
    <div class="row gx-5 justify-content-center">
        <div class="col-xl-12">
            <div class="h2 fs-1 text-white mb-4"><span class="shadow-text">Toda comunicação interna da
                        Prefeitura de Angra dos Reis será tramitada digitalmente. Esse modelo dará mais agilidade,
            transparência, eficiência e celeridade aos processos.</span></div>
        </div>
    </div>
</div>
</aside>
