<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    @include('layouts.parquedacidade.elements.head')
</head>

<body class="index-page">
    @include('layouts.parquedacidade.elements.nav')
    @yield('content')

    @include('layouts.parquedacidade.elements.footer')
    @include('layouts.parquedacidade.elements.scripts')
</body>

</html>