<?php $__env->startSection('title', __('Alertas e avisos') . ' - ' . __('MobiAngra') . ' - ' . config('app.name')); ?>

<?php $__env->startSection('content'); ?>
    <section class="mobiangra-subpage">
        <div class="container">
            <?php if (isset($component)) { $__componentOriginal64b445abe4d6b6e54d21775dae604123 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal64b445abe4d6b6e54d21775dae604123 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.breadcrumb','data' => ['items' => [
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Alertas e avisos')],
            ]]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute([
                ['label' => 'MobiAngra', 'url' => route('mobiangra.index')],
                ['label' => __('Alertas e avisos')],
            ])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $attributes = $__attributesOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__attributesOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal64b445abe4d6b6e54d21775dae604123)): ?>
<?php $component = $__componentOriginal64b445abe4d6b6e54d21775dae604123; ?>
<?php unset($__componentOriginal64b445abe4d6b6e54d21775dae604123); ?>
<?php endif; ?>

            <div class="mobiangra-subpage-card">
                <?php if (isset($component)) { $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.subpage-header','data' => ['title' => __('Alertas e avisos')]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.subpage-header'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['title' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(__('Alertas e avisos'))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $attributes = $__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__attributesOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00)): ?>
<?php $component = $__componentOriginal77000119758cd4a3e8c5a1fbb5379c00; ?>
<?php unset($__componentOriginal77000119758cd4a3e8c5a1fbb5379c00); ?>
<?php endif; ?>

                <div class="p-4 mobiangra-subpage-body">
                    <p class="lead mb-4">
                        <?php echo e(__('Informações sobre trânsito, transporte público e avisos gerais para os usuários do MobiAngra.')); ?>

                    </p>

                    <div class="ma-alerts ma-alerts--page">
                        <?php if (isset($component)) { $__componentOriginal9a9d7313c24d02bb1bb7adf158559aa8 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal9a9d7313c24d02bb1bb7adf158559aa8 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.alertas-list','data' => ['alertas' => $alertas,'emptyMessage' => __('Nenhum alerta publicado no momento. Volte em breve.')]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.alertas-list'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['alertas' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($alertas),'empty-message' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(__('Nenhum alerta publicado no momento. Volte em breve.'))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal9a9d7313c24d02bb1bb7adf158559aa8)): ?>
<?php $attributes = $__attributesOriginal9a9d7313c24d02bb1bb7adf158559aa8; ?>
<?php unset($__attributesOriginal9a9d7313c24d02bb1bb7adf158559aa8); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal9a9d7313c24d02bb1bb7adf158559aa8)): ?>
<?php $component = $__componentOriginal9a9d7313c24d02bb1bb7adf158559aa8; ?>
<?php unset($__componentOriginal9a9d7313c24d02bb1bb7adf158559aa8); ?>
<?php endif; ?>
                    </div>

                    <?php if($alertas->hasPages()): ?>
                        <div class="mt-4 d-flex justify-content-center">
                            <?php echo e($alertas->links()); ?>

                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.mobiangra.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/mobiangra/alertas.blade.php ENDPATH**/ ?>