@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Vice-Prefeito")
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Vice-Prefeito de Angra dos Reis</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">
                    <h1>Vice-Prefeito de Angra dos Reis</h1>
                </div>
                <hr />
                <div class="col-12 col-sm-12 col-md-12 col-lg-9 col-xl-9 col-xxl-9 mb-5">
                    <div class="row">
                        <div class="col-sm-12 col-md-4">
                            <img src="{{ asset($vicePrefeito["managerPhoto"]) }}" class="img-fluid img-thumbnail" alt="Vice-Prefeito de Angra dos Reis" title="Prefeito de Angra dos Reis" />
                        </div>
                        <div class="col-sm-12 col-md-8">
                            <h3>{{ $vicePrefeito["manager"] }}</h3>
                            <div>{!! $vicePrefeito["academicBackground"] !!} </div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-sm-12 col-md-12 col-lg-3 col-xl-3 col-xxl-3">
                    <div class="row">
                        <div class="col-12">
                            <div class="card-slug mb-3">
                                <a>
                                    <div class="d-flex w-100 justify-content-between">
                                        <h5 class="my-3 slug-title">{{ __("Contato") }}</h5>
                                    </div>
                                </a>
                                <div class="">
                                    <div class="">
                                        <h5 class="mb-1">
                                            <a class="text-decoration-none text-dark" href="{{ route("paginas.ouvidoria") }}">{{ __("Fale conosco") }}</a>
                                        </h5>
                                    </div>
                                </div>
                            </div>
                            <div class="card-slug mb-3">
                                <a>
                                    <div class="d-flex w-100 justify-content-between">
                                        <h5 class="my-2 slug-title">{{ __("Secretarias, Fundações e Autarquias") }}</h5>
                                    </div>
                                </a>
                            @foreach($secretarias as $secretaria)
                                    <hr class="fw-bold">
                                    <div class="d-flex w-100 justify-content-start">

                                        <h6 class="mb-1">
                                            <a class="text-decoration-none text-dark" href="{{ route("paginas.details", $secretaria["slug"]) }}">{{ $secretaria["name"] }}</a>
                                        </h6>

                                    </div>
                                @endforeach
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>
    </section>
@endsection