@extends('layouts.admin.theme')

@section('content')
    <div class="container text-start pb-5 mb-5">
    @if($errors->any())
    <div class="alert alert-danger mb-4">
        @foreach($errors->all() as $e) <div>{{ $e }}</div> @endforeach
    </div>
    @endif
        <div class="row mb-4">
            <div class="col text-start">
                <h3>{{ __('Identificação') }}</h3>
            </div>
            <div class="col text-end d-flex justify-content-end">

                <button type="button" class="btn btn-light bg-mediumGray me-2"
                    onclick="window.location='{{ route('admin.projetosProgramas.index', $projetosListagemReturnQuery ?? []) }}'">
                    <i class="fa fa-list me-1"></i> {{ __('Início') }}
                </button>
            </div>
        </div>
        @include('admin.projetosProgramas.partials.steps', [
            'current' => 'identificacao',
            'project' => $project ?? null,
            'projetosListagemReturnQuery' => $projetosListagemReturnQuery ?? [],
        ])
        @include('components.projetosProgramas._stickyProjectHeader', ['project' => $project ?? null])
        <form method="post" action="{{ route('admin.projetosProgramas.identificacao.store') }}" class="mt-3 text-start"
            id="proj_prog_form_identificacao"
            data-pp-bairro-todos-value="{{ config('projetos_programas.bairro_codigo_todos', 'todos') }}"
            data-msg-cep-digits="{{ __('Informe um CEP com 8 dígitos para buscar.') }}"
            data-msg-cep-not-found="{{ __('CEP não encontrado.') }}"
            data-msg-cep-fetch-error="{{ __('Não foi possível consultar o CEP. Verifique sua conexão.') }}"
            data-msg-cep-geo-none="{{ __('CEP encontrado; ajuste o ponto no mapa se a localização automática não for precisa.') }}"
            data-opencep-base="{{ rtrim((string) config('services.opencep.base_url'), '/') }}"
            data-pp-geocode-suffix="{{ config('projetos_programas.endereco_geocode_suffix') }}"
            data-msg-rua-min="{{ __('Digite pelo menos 8 caracteres na rua para buscar automaticamente.') }}"
            data-msg-rua-none="{{ __('Nenhum resultado no mapa para o texto informado na rua. Ajuste o texto ou use o CEP.') }}"
            data-msg-rua-fetch-error="{{ __('Não foi possível localizar o endereço digitado. Tente novamente.') }}">
            @csrf
            @include('components.projetosProgramas._pp_listagem_context_hiddens', ['query' => $projetosListagemReturnQuery ?? []])
            <input type="hidden" name="project_id" value="{{ old('project_id', $project->id ?? '') }}">
            @php
                $selectedPrograma = old('programa_ppa', $project->programa_ppa_codigo ?? null);
                $selectedBairro = old('bairro', $project->bairro_codigo ?? null);
                $fazParteObjetivo = old('faz_parte_objetivo', $project && $project->project_objective_id ? '1' : '0');
                $fazPartePrograma = old('faz_parte_programa', $project && $project->project_program_id ? '1' : '0');
            @endphp
            <div class="row">
                <div class="col-md-6">
                    <label class="form-label">{{ __('* Denominação') }}</label>
                    <input type="text" name="denominacao" class="form-control"
                        value="{{ old('denominacao', $project->denominacao ?? '') }}" required>
                </div>
                <div class="col-md-6">
                    <label class="form-label">{{ __('Nº Processo ADM') }}</label>
                    <input type="text" name="num_processo_adm" class="form-control"
                        value="{{ old('num_processo_adm', $project->num_processo_adm ?? '') }}">
                </div>

                <div class="col-md-6 mt-3">
                    <label class="form-label">{{ __('Empresa licitada') }}</label>
                    <input type="text" name="empresa_licitada" class="form-control"
                        value="{{ old('empresa_licitada', $project->empresa_licitada ?? '') }}">
                </div>

                <div class="col-md-6 mt-3">
                    <label class="form-label">{{ __('Nº (ordem hierárquica)') }}</label>
                    <input type="text" name="numero_ordem" class="form-control"
                        placeholder="{{ __('Ex: 1, 2, 2.1, 2.2, 2.1.2') }}"
                        value="{{ old('numero_ordem', $project->numero_ordem ?? '') }}"
                        aria-describedby="hint_numero_ordem">
                    <p id="hint_numero_ordem" class="form-text text-muted small mb-0 mt-1">
                        {{ __('Deixe em branco para preenchimento automático.') }}
                    </p>
                </div>

                <div class="col-md-6 mt-3">
                    <label class="form-label">{{ __('* Órgão Gestor') }}</label>
                    <select name="gestor_structure_id" class="form-select" required>
                        <option value="">{{ __('--- Selecione ---') }}</option>
                        @foreach($gestores as $g)
                            <option value="{{ $g->id }}" {{ old('gestor_structure_id', $project->gestor_structure_id ?? '') == $g->id ? 'selected' : '' }}>{{ $g->abbreviation ? $g->abbreviation . ' - ' . $g->name : $g->name }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="col-md-6 mt-3">
                    <label class="form-label">{{ __('* Tipo') }}</label>
                    <select name="tipo_id" class="form-select" required>
                        <option value="">{{ __('--- Selecione ---') }}</option>
                        @foreach($tipos as $t)
                            <option value="{{ $t->id }}" {{ old('tipo_id', $project->tipo_id ?? '') == $t->id ? 'selected' : '' }}>
                                {{ $t->nome }}</option>
                        @endforeach
                    </select>
                </div>

                <div class="col-md-6 mt-3" data-relacionado-objetivo-container>
                    <label class="form-label">{{ __('Faz parte de um Objetivo?') }}</label>
                    <div class="d-flex gap-3">
                        <div class="form-check">
                            <input class="form-check-input" type="radio"
                                name="faz_parte_objetivo" id="fazParteObjetivoSim" value="1"
                                {{ $fazParteObjetivo === '1' ? 'checked' : '' }}>
                            <label class="form-check-label" for="fazParteObjetivoSim">{{ __('Sim') }}</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="radio"
                                name="faz_parte_objetivo" id="fazParteObjetivoNao" value="0"
                                {{ $fazParteObjetivo === '0' ? 'checked' : '' }}>
                            <label class="form-check-label" for="fazParteObjetivoNao">{{ __('Não') }}</label>
                        </div>
                    </div>

                    <div data-relacionado-objetivo class="{{ $fazParteObjetivo === '1' ? '' : 'd-none' }} mt-2">
                        <select name="project_objective_id" class="form-select">
                            <option value="">{{ __('--- Selecione ---') }}</option>
                            @foreach($objetivos as $o)
                                <option value="{{ $o->id }}" {{ (string) old('project_objective_id', $project->project_objective_id ?? '') === (string) $o->id ? 'selected' : '' }}>
                                    {{ $o->nome }}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>

                <div class="col-md-6 mt-3" data-relacionado-programa-container>
                    <label class="form-label">{{ __('Faz parte de um Programa?') }}</label>
                    <div class="d-flex gap-3">
                        <div class="form-check">
                            <input class="form-check-input" type="radio"
                                name="faz_parte_programa" id="fazParteProgramaSim" value="1"
                                {{ $fazPartePrograma === '1' ? 'checked' : '' }}>
                            <label class="form-check-label" for="fazParteProgramaSim">{{ __('Sim') }}</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="radio"
                                name="faz_parte_programa" id="fazParteProgramaNao" value="0"
                                {{ $fazPartePrograma === '0' ? 'checked' : '' }}>
                            <label class="form-check-label" for="fazParteProgramaNao">{{ __('Não') }}</label>
                        </div>
                    </div>

                    <div data-relacionado-programa class="{{ $fazPartePrograma === '1' ? '' : 'd-none' }} mt-2">
                        <select name="project_program_id" class="form-select">
                            <option value="">{{ __('--- Selecione ---') }}</option>
                            @foreach($programas as $p)
                                <option value="{{ $p->id }}" {{ (string) old('project_program_id', $project->project_program_id ?? '') === (string) $p->id ? 'selected' : '' }}>
                                    {{ $p->rotuloExibicao() }}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>

                <div class="col-md-6 mt-3">
                    <label class="form-label">{{ __('Programa no PPA') }}</label>
                    <select name="programa_ppa" class="form-select">
                        <option value="">{{ __('--- Selecione ---') }}</option>
                        @foreach($programasPpa as $code => $label)
                            <option value="{{ $code }}" {{ $selectedPrograma == $code ? 'selected' : '' }}>{{ $label }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="col-md-6 mt-3">
                    <label class="form-label" for="bairro_select_pp">{{ __('Bairro') }}</label>
                    <select name="bairro" id="bairro_select_pp" class="form-select">
                        <option value="">{{ __('--- Selecione ---') }}</option>
                        @php $bairroCodigoTodos = config('projetos_programas.bairro_codigo_todos', 'todos'); @endphp
                        @foreach($bairrosList as $code => $label)
                            <option value="{{ $code }}"
                                @if($code === $bairroCodigoTodos) data-pp-bairro-reserved="1" @endif
                                {{ (string) $selectedBairro === (string) $code ? 'selected' : '' }}>{{ $label }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="col-12 mt-3">
                    <label class="form-label" for="endereco">{{ __('Rua') }}</label>
                    <input type="text" name="endereco" class="form-control"
                        id="endereco" value="{{ old('endereco', $project->endereco ?? '') }}"
                        autocomplete="address-line1"
                        aria-describedby="proj_prog_rua_feedback">
                    <p id="proj_prog_rua_feedback" class="form-text small text-muted mb-0" data-pp-rua-feedback role="status"></p>
                </div>
                <div class="col-md-6 mt-3">
                    <label class="form-label" for="proj_prog_cep">{{ __('CEP') }}</label>
                    <input type="text" name="cep" class="form-control" id="proj_prog_cep"
                        value="{{ old('cep', $project->cep ?? '') }}"
                        inputmode="numeric" maxlength="10" autocomplete="postal-code"
                        aria-describedby="proj_prog_cep_feedback">
                    <p id="proj_prog_cep_feedback" class="form-text small text-muted mb-0" data-pp-cep-feedback role="status"></p>
                </div>

                <div class="col-12 mt-3">
                    <div class="mb-2">
                        <span class="form-label text-bold d-block">
                            <i class="fas fa-map-marker-alt me-1 text-danger" aria-hidden="true"></i>
                            {{ __('Geolocalização') }}
                        </span>
                        <p class="text-muted small mb-2">
                            {{ __('Informe o CEP ou digite a rua para preencher CEP, mapa e bairro quando possível. Você também pode clicar no mapa, arrastar o marcador ou preencher latitude e longitude manualmente.') }}
                        </p>
                    </div>

                    <div class="row g-3 mb-3">
                        <div class="col-md-6">
                            <label class="form-label" for="latitude">{{ __('Latitude') }}</label>
                            <input type="text"
                                class="form-control @error('latitude') is-invalid @enderror"
                                name="latitude" id="latitude"
                                value="{{ old('latitude', $project->latitude ?? '') }}"
                                autocomplete="off"
                                placeholder="-23.0067">
                            @error('latitude')
                                <small class="text-danger">{{ $message }}</small>
                            @enderror
                        </div>
                        <div class="col-md-6">
                            <label class="form-label" for="longitude">{{ __('Longitude') }}</label>
                            <input type="text"
                                class="form-control @error('longitude') is-invalid @enderror"
                                name="longitude" id="longitude"
                                value="{{ old('longitude', $project->longitude ?? '') }}"
                                autocomplete="off"
                                placeholder="-44.3184">
                            @error('longitude')
                                <small class="text-danger">{{ $message }}</small>
                            @enderror
                        </div>
                    </div>

                    <div id="map"
                         data-lat="{{ old('latitude', $project->latitude ?? '') }}"
                         data-lng="{{ old('longitude', $project->longitude ?? '') }}"
                         data-nome="{{ old('denominacao', $project->denominacao ?? '') }}"
                         data-loading-msg-cep="{{ __('Buscando endereço e localização pelo CEP...') }}"
                         data-loading-msg-rua="{{ __('Buscando localização pela rua...') }}"
                         data-loading-msg-reverse="{{ __('Buscando endereço pela localização...') }}"
                         class="mb-3"
                         role="application"
                         aria-label="{{ __('Mapa para seleção de localização') }}">
                    </div>
                </div>
            </div>
            <div class="text-end mt-4 d-flex gap-3">
                <button type="submit" class="btn btn-green">
                    <i class="fa fa-arrow-right me-1"></i> {{ __('Salvar e Prosseguir') }}
                </button>
            </div>
        </form>

    </div>
    <script src="{{ asset('pmar/js/projetos-programas-form.js') }}"></script>
@endsection