<head>
    @php
        $ogTitle = html_entity_decode($noticia->title ?? 'Prefeitura de Angra dos Reis');
        $ogDescription = html_entity_decode($noticia->summary ?? 'Portal oficial da Prefeitura Municipal de Angra dos Reis.');
        $ogUrl = preg_replace('/^http:/i', 'https:', url()->current());
        $ogImage = !empty($noticia->featuredPhoto)
            ? preg_replace('/^http:/i', 'https:', url($noticia->featuredPhoto))
            : preg_replace('/^http:/i', 'https:', url('/pmar/assets/img/angra-default.png'));
    @endphp

    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <meta name="site" content="https://angra.rj.gov.br">

    <title>@yield('title')</title>

    <meta name="description" content="{{ $ogDescription }}" />
    <meta name="robots" content="noodp" />
    <link rel="canonical" href="{{ $ogUrl }}" />

    <meta property="og:locale" content="pt_BR" />
    <meta property="og:type" content="article" />
    <meta property="og:title" content="{{ $ogTitle }}" />
    <meta property="og:description" content="{{ $ogDescription }}" />
    <meta property="og:url" content="{{ $ogUrl }}" />
    <meta property="og:site_name" content="Prefeitura de Angra dos Reis" />
    <meta property="og:image" content="{{ $ogImage }}" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta name="twitter:card" content="summary_large_image" />
    <meta name="twitter:title" content="{{ $ogTitle }}" />
    <meta name="twitter:description" content="{{ $ogDescription }}" />
    <meta name="twitter:image" content="{{ $ogImage }}" />

    <meta http-equiv="cache-control" content="max-age=0" />
    <meta http-equiv="cache-control" content="no-cache" />
    <meta http-equiv="expires" content="0" />
    <meta http-equiv="expires" content="Tue, 01 Jan 2977 1:00:00 GMT" />
    <meta http-equiv="pragma" content="no-cache" />

    <link rel="apple-touch-icon" sizes="57x57" href="{{ asset("pmar/assets/fav/apple-icon-57x57-2026.png") }}">
    <link rel="apple-touch-icon" sizes="60x60" href="{{ asset("pmar/assets/fav/apple-icon-60x60-2026.png") }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ asset("pmar/assets/fav/apple-icon-72x72-2026.png") }}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{ asset("pmar/assets/fav/apple-icon-76x76-2026.png") }}">
    <link rel="apple-touch-icon" sizes="114x114" href="{{ asset("pmar/assets/fav/apple-icon-114x114-2026.png") }}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{ asset("pmar/assets/fav/apple-icon-120x120-2026.png") }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ asset("pmar/assets/fav/apple-icon-144x144-2026.png") }}">
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset("pmar/assets/fav/apple-icon-180x180-2026.png") }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset("pmar/assets/fav/favicon-32x32-2026.png") }}">
    <link rel="icon" type="image/png" sizes="96x96" href="{{ asset("pmar/assets/fav/favicon-96x96-2026.png") }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset("pmar/assets/fav/favicon-16x16-2026.png") }}">
    <link rel="manifest" href="{{ asset("pmar/assets/fiveicon/manifest.json") }}">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="{{ asset("pmar/assets/fav/ms-icon-144x144-2026.png") }}">
    <meta name="theme-color" content="#ffffff">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link rel="stylesheet" href="{{ asset('pmar/build/bootstrap/css/bootstrap.min.css') }}">
    <link rel="stylesheet" href="{{ asset('pmar/build/fontawesome/css/all.min.css') }}">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css" rel="stylesheet">
    <link rel="stylesheet" href="{{ asset('pmar/css/style.css') }}">
    <link rel="stylesheet" href="{{ route('temas.css', ['scope' => 'public']) }}?v={{ time() }}">
    <link rel="stylesheet" href="{{ asset('pmar/css/defaultBar.css') }}">
    <link rel="stylesheet" href="{{ route('temas.dark-mode.css', ['scope' => 'public']) }}?v={{ time() }}">
    <script src="{{ asset('pmar/js/dark-mode.js') }}"></script>
    <script src="{{ asset('pmar/build/bootstrap/js/bootstrap.bundle.min.js') }}"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
</head>
