<!DOCTYPE html>
<html lang="pt-BR">
<head>
<meta charset="UTF-8">
<title>Relatório - Pessoas Trans</title>

<style>

@page {
    margin: 20px;
}

body {
    font-family: DejaVu Sans, Arial, Helvetica, sans-serif;
    font-size: 10px;
    color: #333;
}

.header {
    text-align: center;
    border-bottom: 2px solid #0d6efd;
    padding-bottom: 10px;
    margin-bottom: 20px;
}

.header img {
    max-height: 60px;
    margin-bottom: 5px;
}

.header h1 {
    font-size: 20px;
    margin: 0;
    color: #0d6efd;
}

.header h2 {
    font-size: 14px;
    margin: 2px 0;
    color: #444;
}

.header p {
    margin: 4px 0;
    font-size: 11px;
    color: #666;
}

table {
    width: 100%;
    border-collapse: collapse;
}

th, td {
    border: 1px solid #ddd;
    padding: 4px;
    text-align: center;
    vertical-align: middle;
}

th {
    background-color: #0d6efd;
    color: #fff;
    font-size: 7px;
    text-transform: uppercase;
    word-break: keep-all;
    white-space: normal;
    line-height: 1.2;
}

td {
    font-size: 7px;
}

tr:nth-child(even) {
    background-color: #f5f5f5;
}

.col-numero {
    width: 15px;
}

</style>
</head>

<body>

<div class="header">
    <img src="{{ public_path('pmar/assets/fiveicon/brasao-angra-dos-reis.png') }}" alt="Brasão de Angra">
    <h1>Secretaria de Saúde</h1>
    <h2>Prefeitura Municipal de Angra dos Reis</h2>
    <p>Gerado em {{ now()->format('d/m/Y H:i') }}</p>
</div>

<table>

<thead>
<tr>

<th class="col-numero">#</th>

@foreach($campos as $label)
<th>{{ $label }}</th>
@endforeach

</tr>
</thead>

<tbody>

@foreach($registros as $idx => $registro)

<tr>

<td class="col-numero">
{{ $idx + 1 }}
</td>

@foreach($campos as $campo => $label)

<td>

@switch($campo)

@case('data_nascimento')
{{ optional($registro->data_nascimento)->format('d/m/Y') }}
@break

@case('usou_esf_6m')
@case('iniciou_hormonizacao')
@case('participa_movimento')
@case('contato_telefone')
@case('contato_whatsapp')
@case('contato_email')

@if($registro->$campo === null)
-
@else
{{ $registro->$campo ? 'Sim' : 'Não' }}
@endif

@break

@default
{{ $registro->$campo }}

@endswitch

</td>

@endforeach

</tr>

@endforeach

</tbody>

</table>

</body>
</html>