@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Arquivos do ' . $corredor->corredor)
@section('content')

    <div class="card shadow-sm">

        @php $headLine = "<i class='fa-solid fa-route fa-2x'></i> Visite Angra - Corredores Turísticos - Lista de Arquivos do {$corredor->corredor}"; @endphp
        
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.visiteAngra.corredores.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.visiteAngra.corredores.arquivos.create',
            'routeAddParams' => [$corredor->id], 
            'nameAdd' => __('Novo arquivo'),
            'permission' => 'GERENCIADOR_VISITE_ANGRA',
            'routeDeleteAll' => 'admin.visiteAngra.corredores.arquivos.removeAll',
            'routeDeleteAllParameters' => [$corredor->id], 
            'messageDeleteAll' => '* Todos os arquivos deste corredor serão removidos, deseja continuar?', 
            'nameDeleteAll' => 'Remover todos os arquivos',
        ])

        <div class="card-body">
            
            @include("errors.messageFlash")

            <x-tables._table :thead="['#','Tipo','Data','Pertence a','Nome', 'Status', 'Ações']" :pagination="$arquivos->links()">
                <x-slot name="body">
                    @php $index = 0 @endphp
                        @foreach($arquivos as $arquivo)

                        <tr>
                            <td style="width: 200px;">
                                @include('components.tables._openPhoto',[
                                        'asset' => $arquivo->link,
                                        'alt' => $arquivo->nome,
                                        'title' => $arquivo->nome,
                                        'text' => 'Visualizar foto',
                                        "permission" => "GERENCIADOR_VISITE_ANGRA",
                                    ])
                            </td>
                            <td>{{ $arquivo->tipo }}</td>
                            <td>{{ date("d/m/Y H:m:s", strtotime($arquivo->created_at)) }}</td>
                            <td>
                                <a href="{{ route("admin.visiteAngra.corredores.edit", $corredor->id) }}" class="text-dark">
                                    {{ $arquivo->corredor->corredor }}
                                </a>
                            </td>
                            <td>{{ $arquivo->nome }}</td>
                            <td>

                                @include('components/buttons/_status', [
                                        "index" => $index,
                                        "route" => "admin.visiteAngra.corredores.arquivos.status",
                                        "id" => [$corredor->id, $arquivo->id],
                                        "status" => $arquivo->status,
                                        "permission" => "GERENCIADOR_VISITE_ANGRA",
                                    ])

                            </td>
                            <td>
                                <div class="btn-group" role="group">

                                    @include('components/buttons/_deleteButton', [
                                    "message" => "* Este arquivo será excluído e esta ação não poderá ser desfeita, deseja continuar?",
                                    "route" => "admin.visiteAngra.corredores.arquivos.destroy",
                                    "id" => [$corredor->id, $arquivo->id],
                                    "fontawesome" => null,
                                    "title" => "Excluir",
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])

                                </div>
                            </td>
                        </tr>

                        @php $index++ @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>

        </div>
    </div>
@endsection