@import url('https://fonts.googleapis.com/css2?family=Source+Sans+Pro:ital,wght@0,200;0,300;0,400;0,600;0,700;0,900;1,200;1,300;1,400;1,600;1,700;1,900&display=swap');
@import url('https://fonts.googleapis.com/css2?family=Outfit:wght@100..900&display=swap');
@import url('https://fonts.googleapis.com/css2?family=Merienda:wght@300..900&family=Outfit:wght@100..900&display=swap');

@font-face {
  font-family: Fontastique;
  src: url("assets/fontastique.ttf")
}


.b-example-divider {
	height: 3rem;
	background-color: rgba(0, 0, 0, .1);
	border: solid rgba(0, 0, 0, .15);
	border-width: 1px 0;
	box-shadow: inset 0 .5em 1.5em rgba(0, 0, 0, .1), inset 0 .125em .5em rgba(0, 0, 0, .15);
}

@media (min-width: 992px) {
	.rounded-lg-3 {
		border-radius: .3rem;
	}
}

body {
	font-family: 'Outfit', 'Source Sans Pro', sans-serif;
	color: #ffffff;
	background: linear-gradient(142deg, rgba(17,73,158,1) 0%, rgba(0,159,227,1) 100%);
	background-attachment: fixed;

}

/*---------- START OF TRANSITION AND ANIMATION -----------*/
section .topo {
	position: relative;
}


/*---------- END OF TRANSITION AND ANIMATION -----------*/

main p {
	font-size: 16pt;
	margin-bottom: 15px;
	text-align: center;
	line-height: normal;
}

main p.obs {
	font-size: 15pt;
	margin-bottom: 40px;
}

strong.data {
	color: #AEE0F4;
	font-weight: 600;
}

main p.obs a, main p.obs a:visited, main p.obs a:active, main p.obs a:focus, main p.obs a:hover {
	color: #fdf4d2;
	text-decoration: none;
}

.evento {
	display: inline-block;
	background: #00F;
	color: #FFF;
	font-size: 9pt;
	font-weight: 600;
	padding: 0px 4px;
	border-radius: 3px;
}

.cultural {
	background-color: #E64190;
}

.esportivo {
	background-color: #F0821F;	
}

.religioso {
	background-color: #D2AB66;	
}

.turistico {
	background-color: #A1C73D;	
}

.comunitario {
	background-color: #D2AB66;	
}

.gastronomico {
	background-color: #E51B28;	
}

.corporativo {
	background-color: #9fcff1;
	color: #2a57a4;
}

main p.legenda {
	font-size: 12pt;
}

.local {
	font-size: 13pt;
	font-style: italic;
	display: block;
}

.noites {
	font-weight: 600;
	text-transform: uppercase;
	margin-top: 35px;
	color: #ffdb6f;
	font-size: 14pt;
	text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.3);
}

.noites i {
	font-size: 13pt;
}

.topo {
	display: flex;
	align-items: center;
}

.img-titulo {
	width: 100%;
	height: fit-content;
	z-index: 3;
}

.img-arte {
	width: 100%;
}

.programacao {
	margin-bottom: 100px;
	position: relative;
	z-index: 10;
}

h2 {
	font-size: 5rem;
	letter-spacing: -4px;
	color: #FECE16;
	font-family: 'Merienda', 'Fontastique', 'Montserrat', sans-serif;
	text-align: center;
	margin: 40px 0!important;
	margin-bottom: 10px;
	text-shadow: 3px 3px 3px rgba(0, 0, 0, 0.3);
}

h3 {
	font-size: 32pt;
	letter-spacing: -3px;
	color: #FECE16;
	font-family: 'Merienda', 'Fontastique', 'Montserrat', sans-serif;
	text-align: center;
	margin: 0 auto;
	margin-bottom: 25px;
	text-shadow: 3px 3px 2px rgba(0, 0, 0, 0.3);
}

footer.footer-section {
	background-image: url("assets/images/papel-amassado.png");
	background-repeat: no-repeat;
	background-position: top left;
	background-size: cover;
	
	padding-top: 80px;
	padding-bottom: 80px;
}

.img-footer {
	width: 80%;
	max-width: 250px;
	height: fit-content;
}

@media (max-width: 1200px) {

	
}

@media (max-width: 992px) {
	.img-arte {
		margin-top: -80px;
	}
	main p.obs {
    margin-bottom: 10px;
	}	
}

@media (max-width: 768px) {
	h2 {
		font-size: 3.4rem;
	}
	h3 {
		font-size: 32pt;
		margin-bottom: 15px;
    margin-top: 0;
	}
	
	.main p {
		font-size: 15pt;
	}
}

@media (max-width: 576px) {
	.img-titulo {
		width: 80%;
	}
	.img-arte {
		margin-top: -100px;
	}
}


@media (max-width: 380px) {
	.img-arte {
		margin-top: -60px;
	}
	h2 {
		font-size: 3rem;
	}
	h3 {
		font-size: 30pt;
		margin-bottom: 15px;
    margin-top: 0;
	}
	main p.obs {
    margin-bottom: 10px;
	}	
}

section .programacao {
	z-index: 10;
}


/* ------------ BOTÃO GO TO TOP ------------ */

button#gotop{
	position: fixed;
	right: 3%;
	bottom: 3%;
	opacity: 0;
	visibility: hidden;
	
	/*para melhor aparencia do botão*/
	font-family: sans-serif;
	font-size: 14pt;
	line-height: 0;
	color: #0d6efd;
	background-color: #ffc107;
	border: none;
	border-radius: 50px;
	box-shadow: rgba(0,0,0,.4) 0.1em 0.1em 0.1em;
	outline: none;
	cursor: pointer;
	padding: 18px 18px;
	margin: 0;
	z-index: 100;
}