@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Credenciamento de Músicos")
@section('content')

    <div class="card shadow">

        @php $headLine = "<i class='fa-solid fa-guitar'></i> Credenciamento de Músicos"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.contaAngra.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            "permission" => "GERENCIADOR_DE_CONTA_ANGRA",
        ])

        <div class="card-body">
            
            @include("errors.messageFlash")
            @include('components.modal._modelProfile')

            <hr>
           
            <div class="tab-content">
                <div class="mb-3">
                    @include('admin.cultura.credenciamentoMusicos.perfil.institucional')

                    @if($user->musicos->isNotEmpty())
                        <h5 class="mt-3 mb-2">{{ __('Meus Credenciamentos') }}</h5>
                        <div class="row g-3 mb-3">
                            @foreach($user->musicos as $musico)
                                <div class="col-12 col-md-6 col-lg-4">
                                    <div class="card h-100">
                                        <div class="card-body">
                                            <h6 class="card-title">
                                                {{ $musico->grupo_nome ?: ($musico->user->firstName ?? __('Credenciamento')) }}
                                                <span class="badge bg-secondary">{{ $musico->tipo_pessoa ?? 'PF' }}</span>
                                                @if($musico->isExpirado())
                                                    <span class="badge bg-danger">{{ __('Expirado') }}</span>
                                                @elseif($musico->vencimentoProximo(30))
                                                    <span class="badge bg-warning text-dark">{{ __('Vencimento em :dias dias', ['dias' => $musico->diasParaExpiracao()]) }}</span>
                                                @endif
                                            </h6>
                                            <p class="card-text small text-muted">{{ $musico->statusCadastro }}</p>
                                            @if($musico->data_expiracao)
                                                <p class="card-text small">{{ __('Vigência até') }}: {{ \Carbon\Carbon::parse($musico->data_expiracao)->format('d/m/Y') }}</p>
                                            @endif
                                            <div class="d-flex flex-wrap gap-1">
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.dadosPessoais', $musico->id) }}">{{ __('Dados Pessoais') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.documentos', $musico->id) }}">{{ __('Documentos') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.endereco', $musico->id) }}">{{ __('Endereço') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.arquivos', $musico->id) }}">{{ __('Arquivos') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.convocacoes', $musico->id) }}">{{ __('Convocações') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.chamados.index', $musico->id) }}">{{ __('Chamados') }}</a>
                                                <a class="btn btn-sm btn-outline-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.carteirinha', $musico->id) }}">{{ __('Carteirinha') }}</a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            @endforeach
                        </div>
                        <div class="d-grid gap-2 d-md-block mb-3">
                            <a class="btn btn-success me-2" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.novo') }}">{{ __('Novo Credenciamento') }}</a>
                            <a class="btn btn-secondary" href="{{ route('admin.contaAngra.chamados.index') }}">{{ __('Chamados') }}</a>
                        </div>
                    @else
                        <p class="mb-3">{{ __('Você ainda não possui credenciamentos. Clique abaixo para aderir e criar seu primeiro credenciamento (Pessoa Física ou Pessoa Jurídica).') }}</p>
                        <div class="d-grid gap-2 d-md-block mb-3">
                            <a class="btn btn-primary me-2" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.novo') }}">{{ __('Novo Credenciamento') }}</a>
                            <a class="btn btn-secondary" href="{{ route('admin.contaAngra.chamados.index') }}">{{ __('Chamados') }}</a>
                        </div>
                        @include('components.modal._modalConfirmAdesao', [
                            'route' => 'admin.adesao.credenciamentoMusicos'])
                    @endif
                </div>
            </div>
            
        </div>
    </div>

@endsection
