@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Editar arquivo para " . $conselho->nome)
@section('content')

    <form action="{{ route('admin.conselhos.arquivos.update', [$conselho->id, $arquivo->id]) }}" method="post" enctype="multipart/form-data">
        <div class="container">
            <div class="row">
                <div class="col-sm-12 col-md-6">
                    <div class="card shadow">
                        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center mb-3">
                            <h5 class="mb-0">{{ "Editar arquivo para " . $conselho->nome }}</h5>
                        </div>
                        <div class="card-body">
                            @csrf
                            @method('PUT')
                            @include("errors.messageFlash")

                            <div class="mb-3">
                                <label for="tipo" class="form-label text-bold">Tipo de arquivo: <span class="span-admin-create">*</span></label>
                                <select class="form-control @error('tipo') is-invalid @enderror" name="tipo" id="tipo">
                                    @php
                                        $tipos = [
                                            "Ata de sessão extraordinária",
                                            "Ata de sessão ordinária",
                                            "Carta Aberta",
                                            "Comunicado",
                                            "Convocação",
                                            "Deliberação",
                                            "Edital",
                                            "Memorando",
                                            "Moção",
                                            "Ofício",
                                            "Parecer",
                                            "Plano de Ação",
                                            "Portaria",
                                            "Recomendação",
                                            "Regimento Interno",
                                            "Relatório",
                                            "Resolução",
                                        ];
                                        sort($tipos); 
                                    @endphp
                                    @foreach($tipos as $tipo)
                                        <option value="{{ $tipo }}" {{ old("tipo", $arquivo->tipo) == $tipo ? "selected" : "" }}>{{ $tipo }}</option>
                                    @endforeach
                                </select>
                                @error('tipo')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>


                            <div class="mb-3">
                                <hr>
                                <div>
                                    <a href="{{ asset($arquivo->link) }}" target="_blank" class="text-dark">
                                        <i class="fa-solid fa-cloud-arrow-up"></i> Visualizar arquivo
                                    </a>
                                </div>
                                <hr>
                                <label for="link" class="form-label text-bold">Arquivo:</label>
                                <input type="file" class="form-control @error('link') is-invalid @enderror" name="link" id="link" accept="application/pdf"/>

                                @error('link')
                                    <small class="text-danger text-bold">{{ $message }}</small><br>
                                @enderror
                                <small class="text-info text-bold">* Apenas documento em PDF</small>
                            </div>
                            <hr/>

                            <div class="mb-3">
                                <label for="nome" class="form-label text-bold">Nome do documento: <span class="span-admin-create">*</span></label>
                                <input type="text" class="form-control @error('nome') is-invalid @enderror" name="nome" id="nome" autocomplete="off" value="{{ old('nome', $arquivo->nome) }}" >
                                @error('nome')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>
                            <div class="mb-3">
                                <label for="evento_at" class="form-label text-bold">Data do evento: <span class="span-admin-create">*</span></label>
                                <input type="date" class="form-control @error('evento_at') is-invalid @enderror" name="evento_at" id="evento_at" autocomplete="off" value="{{ old('evento_at', $arquivo->evento_at) }}">
                    @error('evento_at')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <div class="mb-3">
                                <label for="status" class="form-label text-bold">Status: <span
                                class="span-admin-create">*</span></label>
                                <select class="form-control @error('status') is-invalid @enderror" name="status"
                                    id="status">
                                    @foreach(App\Enums\StatusEnum::cases() as $status)
                                        <option value="{{ $status->name }}" {{ old('status', $arquivo->status) === $status->name ? 'selected' : '' }}>
                                            {{ $status->value }}
                                        </option>
                                    @endforeach
                                </select>
                                @error('status')
                                    <small class="text-danger text-bold">{{ $message }}</small>
                                @enderror
                            </div>

                            <div class="mb-3">
                                <button class="btn btn-lg btn-secondary d-inline" onclick="javascript:window.location.href='{{ route("admin.conselhos.arquivos.index", $conselho->id) }}'" type="button">{{ __("Voltar") }}</button>
                                <button class="btn btn-lg btn-dark  d-inline" type="submit">{{ __('Atualizar') }}</button>       
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </form>

@endsection