<?php $__env->startSection('title', env('APP_NAME') . ' :: ' . __('Editar Ata')); ?>

<?php $__env->startSection('content'); ?>
    <?php echo $__env->make('errors.messageFlash', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <div class="card shadow-sm">
        <?php $headLine = "<i class='fa-solid fa-file-signature'></i> " . __('Editar Ata'); ?>
        <?php echo $__env->make('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.atas.index',
            'routeBackParams' => request()->only(\App\Http\Resources\AtaResource::ADMIN_FILTER_KEYS),
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_ATAS',
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

        <div class="card-body">
            <?php
                $filterParams = $filterParams ?? request()->only(\App\Http\Resources\AtaResource::ADMIN_FILTER_KEYS);
            ?>
            <form method="post" action="<?php echo e(route('admin.atas.update', array_merge([$ata->id_ata], $filterParams))); ?>" enctype="multipart/form-data">
                <?php echo csrf_field(); ?>
                <?php echo method_field('PUT'); ?>
                <?php echo $__env->make('admin.atas._filterHidden', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                <?php echo $__env->make('admin.atas._form', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </form>
        </div>
    </div>
<?php $__env->stopSection(); ?>


<?php echo $__env->make('layouts.admin.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/admin/atas/edit.blade.php ENDPATH**/ ?>