<div class="mb-3">
    <label for="contratoSocial" class="form-label text-bold">{{ __("Contrato Social") }} <small>({{ __("ou Estatuto Social") }})</small>:</label>
    <input type="file" class="form-control @error('contratoSocial') is-invalid @enderror" name="contratoSocial" id="contratoSocial" accept="application/pdf,image/jpeg,image/png"/>
    @error('contratoSocial')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("Documento que descreve a criação da empresa e contém informações sobre sócios, capital social, atividades e regras.") }}</small>
</div>
<div class="mb-3">
    <label for="cartaoCNPJ" class="form-label text-bold">{{ __("Cartão CNPJ") }}:</label>
    <input type="file" class="form-control @error('cartaoCNPJ') is-invalid @enderror" name="cartaoCNPJ" id="cartaoCNPJ" accept="application/pdf,image/jpeg,image/png"/>
    @error('cartaoCNPJ')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("O Cadastro Nacional da Pessoa Jurídica, emitido pela Receita Federal, é o \"RG\" da empresa.") }}</small>
</div>
<div class="mb-3">
    <label for="registroJuntaComercial" class="form-label text-bold">{{ __("Registro na Junta Comercial") }}:</label>
    <input type="file" class="form-control @error('registroJuntaComercial') is-invalid @enderror" name="registroJuntaComercial" id="registroJuntaComercial" accept="application/pdf,image/jpeg,image/png"/>
    @error('registroJuntaComercial')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("É o registro do Contrato Social e a legalização da empresa na Junta Comercial do estado.") }}</small>
</div>
<div class="mb-3">
    <label for="alvaraDeFuncionamento" class="form-label text-bold">{{ __("Alvará de Funcionamento") }}:</label>
    <input type="file" class="form-control @error('alvaraDeFuncionamento') is-invalid @enderror" name="alvaraDeFuncionamento" id="alvaraDeFuncionamento" accept="application/pdf,image/jpeg,image/png"/>
    @error('alvaraDeFuncionamento')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("Emitido pela prefeitura, é a permissão para a empresa funcionar no local especificado.") }}</small>
</div>
<div class="mb-3">
    <label for="inscricaoEstadual" class="form-label text-bold">{{ __("Inscrição Estadual") }}:</label>
    <input type="file" class="form-control @error('inscricaoEstadual') is-invalid @enderror" name="inscricaoEstadual" id="inscricaoEstadual" accept="application/pdf,image/jpeg,image/png"/>
    @error('inscricaoEstadual')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("Obrigatória para atividades de comércio, indústria e serviços de comunicação, transporte e energia.") }}</small>
</div>
<div class="mb-3">
    <label for="inscricaoMunicipal" class="form-label text-bold">{{ __("Inscrição Municipal") }}:</label>
    <input type="file" class="form-control @error('inscricaoMunicipal') is-invalid @enderror" name="inscricaoMunicipal" id="inscricaoMunicipal" accept="application/pdf,image/jpeg,image/png"/>
    @error('inscricaoMunicipal')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
    <small>{{ __("Necessária para empresas que prestam serviços, permitindo a emissão de notas fiscais de serviço (ISS).") }}</small>
</div>
