<?php $__env->startSection("title", env("APP_NAME") . " :: ". $html->title); ?>
<?php $__env->startSection('content'); ?>
    <div class="container">
        <div class="row">
            <div class="col-12 my-3">
                <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => \App\Support\PortalBreadcrumb::forServicosHtmlPage(
                    $secretaria,
                    $html->title,
                    ! empty($html->structure_id)
                )]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute(\App\Support\PortalBreadcrumb::forServicosHtmlPage(
                    $secretaria,
                    $html->title,
                    ! empty($html->structure_id)
                ))]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
            </div>
        </div>
    </div>

    <section class="internas-secretarias-home-title">
        <div class="container">
            <div class="row">
                <div class="col">
                    <?php if(isset($secretaria->pertence->name)): ?>
                        <h1><?php echo e($secretaria->name); ?></h1>
                        <p><?php echo e($secretaria->pertence->name); ?> (<?php echo e($secretaria->pertence->abbreviation); ?>)</p>
                    <?php else: ?>
                        <h1><?php echo e($secretaria->name); ?></h1>
                        
                    <?php endif; ?>
                    <h3 class="text-center"><?php echo e($html->title); ?></h3>
                    <p class="text-center"><?php echo $html->summary; ?></p>
                </div>
            </div>
        </div>
    </section>

    <div class="container">
        <div class="row gx-5 gy-5">
            <div class="internas-secretarias-home-news col-lg-9 col-md-9 col-sm-12">
                <?php echo $viewContent; ?>

            </div>

            <div class="internas-secretarias-home-aside col-lg-3 col-md-3 col-sm-12">
                <?php echo $__env->make('paginas.parts.html-custom-menu', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                <?php echo $__env->make('paginas.parts.links', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                <?php echo $__env->make('paginas.parts.servicos', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                <?php echo $__env->make('paginas.parts.telefones', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            </div>
        </div>
    </div>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/html.blade.php ENDPATH**/ ?>