<?php if(isset($htmls) && $htmls->count() > 0): ?>
    <div class="col-12 mb-3">
        <div class="row d-flex flex-column align-items-center">
            <div class="col">
                <div class="card-slug">
                    <h2 class="slug-telefone"><?php echo e(__("Serviços")); ?></h2>

                    <ul id="telefones-container" class="list-unstyled">

                        <?php $__currentLoopData = $htmls; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $html): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>

                            <h5 class="slug-summary mt-3">
                                <i class="fa-solid fa-screwdriver-wrench" style="color: #94ff28;"></i>
                                <a class="text-dark text-decoration-none tel-number" href="<?php echo e(url("servicos/".$html->slug)); ?>" alt="<?php echo e($html->title); ?>" title="<?php echo e($html->title); ?>">
                                    <?php echo e($html->title); ?>

                                </a>
                            </h5>
                            <ul class="list-unstyled">
                                <li>
                                    <small><?php echo $html->summary; ?></small>
                                </li>
                            </ul>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>

                </div>
            </div>
        </div>
    </div>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/servicos.blade.php ENDPATH**/ ?>