<?php $__env->startSection('title', __('Calendário de Eventos 2026 em Angra dos Reis')); ?>
<?php $__env->startSection('og_title', __('Calendário de Eventos 2026/2027')); ?>

<?php $__env->startSection('content'); ?>

<header>
    <section class="topo-section">
        <div class="container">
            <div class="row align-items-center g-5 py-5 pb-sm-0">
                <div class="col d-flex justify-content-center align-items-center">
                    <img src="<?php echo e(asset('calendario-de-eventos/assets/images/calendario-eventos-2026.svg')); ?>"
                         class="img-titulo"
                         alt="<?php echo e(__('Calendário de Eventos de Angra dos Reis 2026')); ?>">
                </div>
            </div>
        </div>
    </section>
</header>

<main class="main-content">
    <section class="programacao-section">
        <div class="container">
            <div class="row">

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Janeiro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 01')); ?> - </strong> <?php echo e(__('Procissão Marítima')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 05')); ?> - </strong> <?php echo e(__('Corrida Santos Reis')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 06')); ?> - </strong> <?php echo e(__('Aniversário da Cidade - 524 anos')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 20')); ?> - </strong> <?php echo e(__('Festa de São Sebastião')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span><br><span class="local-evento"><?php echo e(__('Vila do Abraão e Frade')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25')); ?> - </strong> <?php echo e(__('Festival de Verão Futebol Sub-13')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Fevereiro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 02')); ?> - </strong> <?php echo e(__('Festa de Iemanjá')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 06 a 08')); ?> - </strong> <?php echo e(__('Pré-Carnaval & Sesc Verão')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11 a 17')); ?> - </strong> <?php echo e(__('Carnaval')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Março')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 07')); ?> - </strong> <?php echo e(__('Regata do Bracuí')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 08')); ?> - </strong> <?php echo e(__('1º Encontro de Mulheres (Jiu-Jitsu)')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 16')); ?> - </strong> <?php echo e(__('TV Rio Sul de Futsal')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 23')); ?> - </strong> <?php echo e(__('Corrida São José do Operário')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 29 a 04')); ?> - </strong> <?php echo e(__('Semana Santa')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Abril')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 02')); ?> - </strong> <?php echo e(__('Caminhada de Conscientização do Autismo')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p>
                        <strong class="data-evento"><?php echo e(__('Dia 03')); ?> - </strong> <?php echo e(__('Paixão de Cristo')); ?>

                        <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span>
                        <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span><br>
                        <span class="local-evento"><?php echo e(__('Centro')); ?></span>
                    </p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 06')); ?> - </strong> <?php echo e(__('Festa do Glorioso São Benedito')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p>
                        <strong class="data-evento"><?php echo e(__('Dia 18')); ?> - </strong> <?php echo e(__('Festa Peixe com Banana')); ?>

                        <span class="badge-evento badge-gastronomico" title="<?php echo e(__('Evento Gastronômico')); ?>">G</span>
                    </p>
                   
                    <p><strong class="data-evento"><?php echo e(__('Dia 23')); ?> - </strong> <?php echo e(__('Festa de São Jorge')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Maio')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 01')); ?> - </strong> <?php echo e(__('Festa de São José Operário')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 01')); ?> - </strong> <?php echo e(__('1ª Etapa de Natação de Águas Abertas')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 03')); ?> - </strong> <?php echo e(__('Festa do Bonfim')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 09')); ?> - </strong> <?php echo e(__('1ª Etapa de Canoagem Oceânica')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 12 a 15')); ?> - </strong> <?php echo e(__('Semana dos Museus')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p>
                        <strong class="data-evento"><?php echo e(__('Dia 15 a 17')); ?> - </strong> <?php echo e(__('XTERRA Ilha grande')); ?>

                        <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span>
                    </p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 16')); ?> - </strong> <?php echo e(__('1ª Etapa de Natação em Piscina')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 22 e 24')); ?> - </strong> <?php echo e(__('Festa do Divino Espírito Santo')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 23')); ?> - </strong> <?php echo e(__('Copa de Ginástica Artística')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 24')); ?> - </strong> <?php echo e(__('Aniversário do Centro Cultural Theóphilo Massad')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 24')); ?> - </strong> Semear <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 24')); ?> - </strong> Festa da Divina Sardinha <span class="badge-evento badge-gastronomico" title="<?php echo e(__('Evento Gastronômico')); ?>">G</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 31')); ?> - </strong> <?php echo e(__('Festa Santíssima Trindade')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Junho')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 01 a 30')); ?> - </strong> <?php echo e(__('Semana Nacional do Meio Ambiente')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 04')); ?> - </strong> Corpus Christi <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 12')); ?> - </strong> <?php echo e(__('Sagrado Coração de Jesus Centro e Monsuaba')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 13')); ?> - </strong> <?php echo e(__('Quadrangular de Handebol')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 20 a 21')); ?> - </strong> <?php echo e(__('Festival do Mexilhão')); ?> <span class="badge-evento badge-gastronomico" title="<?php echo e(__('Evento Gastronômico')); ?>">G</span><br><span class="local-evento"><?php echo e(__('Araçatiba')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 27 a 28')); ?> - </strong> <?php echo e(__('Festival do Mexilhão')); ?> <span class="badge-evento badge-gastronomico" title="<?php echo e(__('Evento Gastronômico')); ?>">G</span><br><span class="local-evento"><?php echo e(__('Praia da Longa')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 29')); ?> - </strong> <?php echo e(__('Dia do Pescador')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Julho')); ?></h3>
                    <p>
                        <strong class="data-evento"><?php echo e(__('Dia 03 a 05')); ?> - </strong> <?php echo e(__('Festival de Música e Ecologia da Ilha Grande')); ?>

                        <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span><br>
                        <span class="local-evento"><?php echo e(__('Vila do Abraão')); ?></span></p></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 09')); ?> - </strong> <?php echo e(__('Corrida da Defesa Civil')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11')); ?> - </strong> <?php echo e(__('Campeonato Municipal de Futebol Sub-15')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 16')); ?> - </strong> <?php echo e(__('Festa de Nossa Senhora do Carmo')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 17 a 20')); ?> - </strong> UJADESF <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p>
                        <strong class="data-evento"><?php echo e(__('Dia 17 a 19')); ?> - </strong> <?php echo e(__('Arraiá Du Abraão')); ?>

                        <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br>
                        <span class="local-evento"><?php echo e(__('Vila do Abraão')); ?></span>
                    </p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 23 a 26')); ?> - </strong> <?php echo e(__('28º Angra Moto Fest')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span><br><span class="local-evento"><?php echo e(__('Praia do Anil')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 28')); ?> - </strong> <?php echo e(__('Dia do Agricultor')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 31 a 02/08')); ?> - </strong> <?php echo e(__('Arraiá da Cidade')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Agosto')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 03')); ?> - </strong> <?php echo e(__('Corrida do Colégio Naval')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 13')); ?> - </strong> <?php echo e(__('Festa de Santa Dulce dos Pobres')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11 a 18')); ?> - </strong> <?php echo e(__('Semana da Juventude')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 15 a 17')); ?> - </strong> <?php echo e(__('Torneio Interestadual de Quadrilha')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 22')); ?> - </strong> <?php echo e(__('Quadrangular de Handebol')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 22 a 07/09')); ?> - </strong> <?php echo e(__('16ª FITA - Festa Internacional de Teatro de Angra')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25')); ?> - </strong> <?php echo e(__('Aniversário da Casa de Cultura Poeta Brasil dos Reis')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Setembro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 07')); ?> - </strong> <?php echo e(__('Desfile Cívico da Independência')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 08')); ?> - </strong> <?php echo e(__('Nossa Senhora dos Remédios')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span><br><span class="local-evento"><?php echo e(__('Ribeira')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 05 a 07')); ?> - </strong> <?php echo e(__('Festa Country da Monsuaba')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Monsuaba')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 10 a 12')); ?> - </strong> <?php echo e(__('11ª Angra Expo')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11')); ?> - </strong> <?php echo e(__('Dia C de Cooperar')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 19')); ?> - </strong> <?php echo e(__('Campeonato dos Servidores')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 21')); ?> - </strong> <?php echo e(__('Meia Maratona do Parque Mambucaba')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span><br><span class="local-evento"><?php echo e(__('Vila Histórica de Mambucaba')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25 a 30')); ?> - </strong> <?php echo e(__('Encontro de Teatro de Rua')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 26')); ?> - </strong> <?php echo e(__('3ª Edição da Festa da Sardinha')); ?> <span class="badge-evento badge-gastronomico" title="<?php echo e(__('Evento Gastronômico')); ?>">G</span><br><span class="local-evento"><?php echo e(__('Praça do Mercado do Peixe')); ?></span></p>

                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Outubro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 05')); ?> - </strong> <?php echo e(__('Corrida de Nossa Senhora Aparecida')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span><br><span class="local-evento"><?php echo e(__('Cantagalo')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11')); ?> - </strong> <?php echo e(__('Festival das Crianças')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 11')); ?> - </strong> <?php echo e(__('Dia do Cooperar')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 12')); ?> - </strong> <?php echo e(__('Festa de Nossa Senhora Aparecida')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 24')); ?> - </strong> <?php echo e(__('Interpolo de Futevôlei')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25')); ?> - </strong> <?php echo e(__('Campeonato dos Servidores')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span><br><span class="local-evento"><?php echo e(__('Vila do Abraão')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25')); ?> - </strong> <?php echo e(__('Circuito Cervejeiro de Corrida')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span><br><span class="local-evento"><?php echo e(__('Vila do Abraão')); ?></span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Novembro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 05')); ?> - </strong> <?php echo e(__('Dia Nacional da Cultura')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 15')); ?> - </strong> <?php echo e(__('4º Louvarte')); ?> <span class="badge-evento badge-religioso" title="<?php echo e(__('Evento Religioso')); ?>">R</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 20')); ?> - </strong> <?php echo e(__('Dia da Consciência Negra')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 22')); ?> - </strong> <?php echo e(__('Corrida RosAzul')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 25')); ?> - </strong> <?php echo e(__('Abertura da Vila Noel')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span></p>
                </div>

                
                <div class="col-lg-6 px-4 mt-5">
                    <h3 class="titulo-mes"><?php echo e(__('Dezembro')); ?></h3>
                    <p><strong class="data-evento"><?php echo e(__('Dia 05')); ?> - </strong> <?php echo e(__('Natal sem Fome - Futebol')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 06')); ?> - </strong> <?php echo e(__('Interpolo de Handebol')); ?> <span class="badge-evento badge-esportivo" title="<?php echo e(__('Evento Esportivo')); ?>">E</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 08')); ?> - </strong> <?php echo e(__('Festa de Nossa Senhora da Conceição')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 12')); ?> - </strong> <?php echo e(__('Aniversário da Casa Laranjeiras')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span><br><span class="local-evento"><?php echo e(__('Centro')); ?></span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 13')); ?> - </strong> <?php echo e(__('Festa de Santa Luzia')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 15')); ?> - </strong> <?php echo e(__('Prêmio Movimenta Angra')); ?> <span class="badge-evento badge-cultural" title="<?php echo e(__('Evento Cultural')); ?>">C</span></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 21 a 23')); ?> - </strong> <?php echo e(__('Movimenta Angra Natal')); ?> <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span><br><span class="local-evento"></p>
                    <p><strong class="data-evento"><?php echo e(__('Dia 30 e 31')); ?> - </strong> Réveillon <span class="badge-evento badge-turistico" title="<?php echo e(__('Evento Turístico')); ?>">T</span><br><span class="local-evento"><?php echo e(__('Praia do Anil')); ?></span></p>
                </div>

            </div>

            
            <div class="row">
                <div class="col-12 d-flex justify-content-center legenda-section">
                    <p class="legenda">
                        <?php echo e(__('Legenda:')); ?>

                        <span class="d-inline-block ms-3"><span class="badge-evento badge-cultural">C</span> <?php echo e(__('Cultural')); ?></span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-turistico">T</span> <?php echo e(__('Turístico')); ?></span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-esportivo">E</span> <?php echo e(__('Esportivo')); ?></span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-gastronomico">G</span> <?php echo e(__('Gastronômico')); ?></span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-religioso">R</span> <?php echo e(__('Religioso')); ?></span>
                        <span class="d-inline-block ms-3"><span class="badge-evento badge-corporativo">C</span> <?php echo e(__('Corporativo')); ?></span>
                    </p>
                </div>
            </div>

        </div>
    </section>

    
    <button id="btn-go-top" class="btn-go-top" aria-label="<?php echo e(__('Voltar ao topo')); ?>">
        <i class="fas fa-chevron-up" aria-hidden="true"></i>
    </button>
</main>


<footer class="footer-eventos">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-lg-6 col-md-6 col-sm-12 mb-5 d-flex justify-content-center align-items-center">
                <img src="<?php echo e(asset('calendario-de-eventos/assets/images/Logo-prefeitura-footer-cor.svg')); ?>"
                     class="img-footer"
                     alt="<?php echo e(__('Prefeitura de Angra dos Reis')); ?>">
            </div>
        </div>
    </div>
</footer>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.landing_pages.calendariodeeventos.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/calendariodeeventos/index.blade.php ENDPATH**/ ?>