<a href="{{ route($route) }}" target="{{ $target }}" class="text-decoration-none">
    <li
        class="d-flex align-items-center px-3 py-2 mb-3 bg-light rounded {{ request()->routeIs($route) ? 'active' : '' }}">
        {{ $text }}
    </li>
</a>