<section class="ma-features" aria-labelledby="ma-features-title">
    <div class="container">
        <h2 id="ma-features-title" class="visually-hidden"><?php echo e(__('Serviços do MobiAngra')); ?></h2>
        <div class="ma-features__grid">
            <?php if (isset($component)) { $__componentOriginal517c12c4bc4a769c9965f612c82b27a0 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal517c12c4bc4a769c9965f612c82b27a0 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.feature-alertas-card','data' => ['alertas' => $alertasDestaque ?? collect()]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.feature-alertas-card'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['alertas' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($alertasDestaque ?? collect())]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal517c12c4bc4a769c9965f612c82b27a0)): ?>
<?php $attributes = $__attributesOriginal517c12c4bc4a769c9965f612c82b27a0; ?>
<?php unset($__attributesOriginal517c12c4bc4a769c9965f612c82b27a0); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal517c12c4bc4a769c9965f612c82b27a0)): ?>
<?php $component = $__componentOriginal517c12c4bc4a769c9965f612c82b27a0; ?>
<?php unset($__componentOriginal517c12c4bc4a769c9965f612c82b27a0); ?>
<?php endif; ?>

            <article class="ma-features__card">
                <span class="ma-features__icon ma-features__icon--purple" aria-hidden="true">
                    <i class="fa-solid fa-route"></i>
                </span>
                <h3 class="ma-features__title"><?php echo e(__('Itinerários')); ?></h3>
                <p class="ma-features__text">
                    <?php echo e(__('Veja o trajeto completo de cada linha e seus pontos de parada.')); ?>

                </p>
                <a href="<?php echo e(route('mobiangra.itinerarios')); ?>" class="ma-features__link">
                    <?php echo e(__('Ver itinerários')); ?>

                    <i class="fa-solid fa-arrow-right" aria-hidden="true"></i>
                </a>
            </article>

            <article class="ma-features__card">
                <span class="ma-features__icon ma-features__icon--orange" aria-hidden="true">
                    <i class="fa-solid fa-star"></i>
                </span>
                <h3 class="ma-features__title"><?php echo e(__('Linhas Favoritas')); ?></h3>
                <p class="ma-features__text">
                    <?php echo e(__('Acesse rapidamente as linhas que você marcou como favoritas no mapa.')); ?>

                </p>
                <a href="<?php echo e(route('mobiangra.mapa', ['modo' => 'favoritas'])); ?>" class="ma-features__link">
                    <?php echo e(__('Ver favoritas')); ?>

                    <i class="fa-solid fa-arrow-right" aria-hidden="true"></i>
                </a>
            </article>
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/feature-grid.blade.php ENDPATH**/ ?>