<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
    @include('layouts.sei.elements.head')   
    <body>

    <nav>
        @include('layouts.sei.elements.nav')
    </nav>
    <main>
        <div class="container-fluid">
            <div class="row">
                <div class="col-12">
                    <div class="text-center"><img src="{{ asset("pmar/assets/img/icons/prefeitura-angra-dos-reis.jpg") }}" class="card-img-top" title="{{ __("Prefeitura Municipal de Angra dos Reis") }}" alt="{{ __("Prefeitura Municipal de Angra dos Reis") }}" class="img-fluid text-center" style="width: 10%;"/></div>
                    <hr/>
                </div>                
            </div>
        </div>
        <div class="container-fluid my-3">
            <div class="row">
                <div class="col-2">
                    @include('layouts.admin.elements.menu')   
                </div>
                <div class="col-10">
                    @yield('content')
                </div>
            </div>
        </div>
    </main>
    <footer>
        @include('layouts.pmar.elements.modal')   
        @include('layouts.admin.elements.footer')   
    </footer>
</body>
</html>