@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Novo Tema de Mapa'))

@section('content')
    @include('errors.messageFlash')
    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-layer-group'></i> " . __('Novo Tema de Mapa'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.observatorio.mapaTemas.index',
            'routeBackParams' => request()->only(['q', 'page']),
            'nameBack' => __('Voltar'),
        ])

        <div class="card-body">
            <form method="post" action="{{ route('admin.observatorio.mapaTemas.store', request()->only(['q', 'page'])) }}" enctype="multipart/form-data">
                @csrf
                @include('admin.observatorio.mapa-temas._form')
            </form>
        </div>
    </div>
@endsection
