<form action="{{ route('admin.cadastroDeAmbulantes.ambulantes.documentosIndex', $ambulante->id) }}" method="post" enctype="multipart/form-data">


    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">

                        <div class="mb-3 p-5 bg-secondary text-white rounded">
                            <h1>{{ $ambulante->proprietario->firstName }} {{ $ambulante->proprietario->lastName }}</h1>
                            <p class="text-white">CPF: {{ $ambulante->proprietario->cpf }}</p>
                            <p class="text-white">Telefone: {{ $ambulante->proprietario->phoneNumber }}</p>
                            <p class="text-white">Email: {{ $ambulante->proprietario->email }}</p>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="container my-3">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">

                        <h5 class="card-title">Demais informações</h5>
                        <div class="container">
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        @csrf
                                        @method('POST')
                                        <label for="contratoSocial" class="form-label text-bold">Contrato Social <small>(ou Estatuto Social)</small>:</label>
                                        <input type="file" class="form-control @error('contratoSocial') is-invalid @enderror" name="contratoSocial" id="contratoSocial" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('contratoSocial')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>Documento que descreve a criação da empresa e contém informações sobre sócios, capital social, atividades e regras.</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->contratoSocial != null || $comercio->contratoSocial != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->contratoSocial,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="cartaoCNPJ" class="form-label text-bold">Cartão CNPJ:</label>
                                        <input type="file" class="form-control @error('cartaoCNPJ') is-invalid @enderror" name="cartaoCNPJ" id="cartaoCNPJ" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('cartaoCNPJ')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>O Cadastro Nacional da Pessoa Jurídica, emitido pela Receita Federal, é o "RG" da empresa.</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->cartaoCNPJ != null || $comercio->cartaoCNPJ != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->cartaoCNPJ,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="registroJuntaComercial" class="form-label text-bold">Registro na Junta Comercial:</label>
                                        <input type="file" class="form-control @error('registroJuntaComercial') is-invalid @enderror" name="registroJuntaComercial" id="registroJuntaComercial" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('registroJuntaComercial')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>É o registro do Contrato Social e a legalização da empresa na Junta Comercial do estado.</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->registroJuntaComercial != null || $comercio->registroJuntaComercial != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->registroJuntaComercial,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="alvaraDeFuncionamento" class="form-label text-bold">Alvará de Funcionamento:</label>
                                        <input type="file" class="form-control @error('alvaraDeFuncionamento') is-invalid @enderror" name="alvaraDeFuncionamento" id="alvaraDeFuncionamento" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('alvaraDeFuncionamento')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>Emitido pela prefeitura, é a permissão para a empresa funcionar no local especificado.</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->alvaraDeFuncionamento != null || $comercio->alvaraDeFuncionamento != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->alvaraDeFuncionamento,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="inscricaoEstadual" class="form-label text-bold">Inscrição Estadual:</label>
                                        <input type="file" class="form-control @error('inscricaoEstadual') is-invalid @enderror" name="inscricaoEstadual" id="inscricaoEstadual" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('inscricaoEstadual')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>Obrigatória para atividades de comércio, indústria e serviços de comunicação, transporte e energia.</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->inscricaoEstadual != null || $comercio->inscricaoEstadual != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->inscricaoEstadual,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-sm-12 col-md-7">
                                    <div class="mb-3">
                                        <label for="inscricaoMunicipal" class="form-label text-bold">Inscrição Municipal:</label>
                                        <input type="file" class="form-control @error('inscricaoMunicipal') is-invalid @enderror" name="inscricaoMunicipal" id="inscricaoMunicipal" accept="application/pdf,image/jpeg,image/png"/>
                                        @error('inscricaoMunicipal')
                                            <small class="text-danger text-bold">{{ $message }}</small><br>
                                        @enderror
                                        <small>Necessária para empresas que prestam serviços, permitindo a emissão de notas fiscais de serviço (ISS).</small>
                                    </div>
                                </div>
                                <div class="col-sm-12 col-md-5">
                                    @if(isset($comercio->id) && ($comercio->inscricaoMunicipal != null || $comercio->inscricaoMunicipal != ""))
                                        <div style="width: 90px;">
                                            @include('components.tables._openPhotoAndPdf',[
                                        'asset' => $comercio->inscricaoMunicipal,
                                        'alt' => "Comprovante de " . $comercio->razaoSocial,
                                        'title' => "Comprovante de " . $comercio->razaoSocial,
                                        'text' => 'Visualizar foto',
                                        'index' => 4,
                                    ])
                                        </div>
                                    @endif
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="d-flex justify-content-between mt-4">
        <a class="btn btn-outline-secondary" href="{{ route("admin.cadastroDeAmbulantes.ambulantes.demaisInformacaoesIndex", $ambulante->id ) }}">
            <i class="fa-solid fa-arrow-left-long"></i> Anterior
        </a>
        <button class="btn btn-primary d-inline" type="submit">
            <i class="fa-solid fa-user-plus"></i> Salvar e Prosseguir
        </button>
    </div>





</form>