<section class="bg-light" id="atas-comite">
    <div class="container mb-5">
        <div class="row">
            <div class="col-12 p-3 text-center">
                <h1><?php echo e(__('Comitê Gestor')); ?></h1>
            </div>
        </div>
        <div class="row justify-content-center align-items-center g-2">
            <div
                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Presidente')); ?></strong>:
                                <?php echo e(__('Rodolfo Orion Lebres Bontempo')); ?> <br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('SMGP')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('33882')); ?> <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i
                                        class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Vice-Presidente')); ?></strong>:
                                <?php echo e(__('João Vitor Costa da Silva Carvalho')); ?><br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('CGM')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('28249')); ?> <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Secretária')); ?></strong>:
                                <?php echo e(__('Bárbara Di Sarli de Carvalho')); ?> <br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('PGM')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('32684')); ?> <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Membro')); ?></strong>:
                                <?php echo e(__('Lucas Soares dos Santos')); ?><br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('SMGP')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('33870')); ?> <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Membro')); ?></strong>:
                                <?php echo e(__('Daniel Silva de Azevedo')); ?> <br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('SMGP')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('19183')); ?> <br>
                            </p>
                        </div>
                        <div class="col-md-6">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Membro')); ?></strong>:
                                <?php echo e(__('Matheus Silva Lopes')); ?> <br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('PGM')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('32376')); ?> <br>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="my-5">
                    <div class="row justify-content-center">
                        <div class="col-md-6 mx-auto">
                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;<?php echo e(__('Membro')); ?></strong>:
                                <?php echo e(__('Bruno Santana de Lima')); ?> <br>
                                <strong><?php echo e(__('Órgão')); ?></strong>: <?php echo e(__('CGM')); ?> <br>
                                <strong><?php echo e(__('Matrícula')); ?></strong>: <?php echo e(__('26744')); ?> <br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="row">
            <div class="col-md-6">
                <?php
                    $colorStyleAtasReuniao = 'color: #696969; cursor: pointer;';
                ?>
                <div class="p-3">
                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                        style="<?php echo e($colorStyleAtasReuniao); ?>">
                        <?php echo e(__('Atas de Reunião')); ?> <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                    </h3>
                    <div class="content d-none">
                        <div class="mt-5 mb-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3431"
                                    target="_blank"><strong><?php echo e(__('Nº 001/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 7 de Março de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a
                                    href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3437"target="_blank"><strong><?php echo e(__('Nº 002/2024')); ?>,
                                        <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 7 de Março de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3800"
                                    target="_blank"><strong><?php echo e(__('Nº 003/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 11 de Março de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=6526"
                                    target="_blank"><strong><?php echo e(__('Nº 004/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 15 de Março de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=7531"
                                    target="_blank"><strong><?php echo e(__('Nº 005/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 19 de Março de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=34324"
                                    target="_blank"><strong><?php echo e(__('Nº 006/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 20 de Maio de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=77901"
                                    target="_blank"><strong><?php echo e(__('Nº 007/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 05 de Agosto de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=116957"
                                    target="_blank"><strong><?php echo e(__('Nº 008/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 20 de Setembro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=118357"
                                    target="_blank"><strong><?php echo e(__('Nº 009/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 23 de Setembro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=190267"
                                    target="_blank"><strong><?php echo e(__('Nº 010/2024')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 11 de Dezembro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=317111"
                                    target="_blank"><strong><?php echo e(__('Nº 001/2025')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 20 de Fevereiro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="p-3">
                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                        style="<?php echo e($colorStyleAtasReuniao); ?>">
                        <?php echo e(__('Pareceres')); ?> <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                    </h3>
                    <div class="content d-none">
                        <div class="mt-5 mb-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162463"
                                    target="_blank"><strong><?php echo e(__('Parecer 1')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 30 de Outubro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162579"
                                    target="_blank"><strong><?php echo e(__('Parecer 2')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 30 de Outubro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=219494"
                                    target="_blank"><strong><?php echo e(__('Parecer 3')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 11 de Dezembro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                        <div class="my-3">
                            <p class="fw-normal text-muted mb-lg-0">
                                <a href="https://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=229393"
                                    target="_blank"><strong><?php echo e(__('Parecer 4')); ?>, <span
                                            style="<?php echo e($colorStyleAtasReuniao); ?>"><?php echo e(__('de 17 de Dezembro de 2024')); ?></span>
                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section><?php /**PATH /var/www/html/portal/resources/views/sei/sections/atasComite.blade.php ENDPATH**/ ?>