<div class="mb-3">
    @if($label)
        <label for="{{ $id ?? $name }}" class="form-label text-bold">
            {{ $label }} @if(isset($required) && $required)<span class="span-admin-create">*</span>@endif
        </label>
    @endif

    <textarea
        class="form-control {{ $class ?? '' }} @if(isset($name)) @error($name) is-invalid @enderror @endif"
        name="{{ $name ?? '' }}"
        id="{{ $id ?? $name }}"
        rows="{{ $rows ?? 1 }}"
        @if(isset($height) && $height) style="height: {{ $height }}" @endif >{{ $value }}</textarea>

    @error(isset($name) && $name)
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
