<?php
    $meteocons = [
        'Ensolarado' => 'pmar/assets/img/icons/weather/ensolarado.svg',
        'Sol com poucas nuvens' => 'pmar/assets/img/icons/weather/sol-com-poucas-nuvens.svg',
        'Sol com muitas nuvens' => 'pmar/assets/img/icons/weather/sol-com-muitas-nuvens.svg',
        'Nublado' => 'pmar/assets/img/icons/weather/nublado.svg',
        'Sol com possibilidade de chuva' => 'pmar/assets/img/icons/weather/sol-com-possibilidade-de-chuva.svg',
        'Nublado com possibilidade de chuva' => 'pmar/assets/img/icons/weather/nublado-com-possibilidade-de-chuva.svg',
        'Chuvoso' => 'pmar/assets/img/icons/weather/chuvoso.svg',
        'Pancadas de chuva e trovoada' => 'pmar/assets/img/icons/weather/pancadas-de-chuva-e-trovoada.svg',
        'Pancadas de chuva' => 'pmar/assets/img/icons/weather/pancadas-de-chuva.svg',
        'Sem nuvens' => 'pmar/assets/img/icons/weather/sem-nuvens.svg',
        'Poucas nuvens' => 'pmar/assets/img/icons/weather/poucas-nuvens.svg',
        'Muitas nuvens' => 'pmar/assets/img/icons/weather/muitas-nuvens.svg',
        'Muitas nuvens com possibilidade de chuva' => 'pmar/assets/img/icons/weather/muitas-nuvens-com-possibilidade-de-chuva.svg',
    ];

    $cores = [
        'VIGILÂNCIA' => 'green',
        'OBSERVAÇÃO' => 'warning',
        'ATENÇÃO' => 'danger',
        'ALERTA' => 'red',
        'ALERTA MÁXIMO' => 'indigo',
    ];
    $nivelAtual = old('nivel_de_acao', $boletim?->nivel_de_acao ?? 'VIGILÂNCIA');
    $corNivel = $cores[$nivelAtual] ?? 'secondary';

    $estadoManha = old('estado_manha', $boletim?->estado_manha ?? null);
    $estadoTarde = old('estado_tarde', $boletim?->estado_tarde ?? null);
    $estadoNoite = old('estado_noite', $boletim?->estado_noite ?? null);
?>

<!-- Modal Sobreaviso -->
<div class="modal fade" id="modalSobreaviso" tabindex="-1" aria-labelledby="modalSobreavisoLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header bg-primary text-white">
                <h5 class="modal-title" id="modalSobreavisoLabel">
                    <i class="fas fa-bell me-2"></i><?php echo e(__('Novo Sobreaviso')); ?>

                </h5>
                <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="<?php echo e(__('Fechar')); ?>"></button>
            </div>
            <form method="POST" action="<?php echo e(route('admin.sobreavisos.quick-store')); ?>" data-quick-sobreaviso-form>
                <?php echo csrf_field(); ?>
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label fw-bold" for="novo_nome_sobreaviso"><?php echo e(__('Nome do Sobreaviso')); ?> *</label>
                        <input type="text" name="nome" id="novo_nome_sobreaviso" class="form-control"
                            value="<?php echo e(old('nome')); ?>"
                            placeholder="<?php echo e(__('Ex: João Silva')); ?>" required>
                        <div class="form-text"><?php echo e(__('Nome do agente de sobreaviso')); ?></div>
                        <?php $__errorArgs = ['nome'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                        <div class="text-danger small"><?php echo e($message); ?></div>
                        <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal"><?php echo e(__('Cancelar')); ?></button>
                    <button type="button" class="btn btn-success js-save-sobreaviso">
                        <i class="fas fa-save me-2"></i><?php echo e(__('Salvar')); ?>

                    </button>
                </div>
            </form>
        </div>
    </div>
    <input type="hidden" data-quick-sobreaviso-message="<?php echo e(__('Agente salvo com sucesso!')); ?>">
</div>

<div class="card shadow-lg">
    <div class="card-body">
        <form action="<?php echo e($formAction); ?>" method="POST" id="boletimMeteorologicoForm">
            <?php echo csrf_field(); ?>
            <?php if($method !== 'POST'): ?>
                <?php echo method_field($method); ?>
            <?php endif; ?>

            <div class="row mb-4">
                <div class="col-12">
                    <h5 class="border-bottom pb-2 mb-3 text-primary">
                        <i class="fas fa-info-circle me-2"></i><?php echo e(__('Informações Básicas')); ?>

                    </h5>
                </div>
                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold" for="numero_boletim"><?php echo e(__('Número do Boletim')); ?></label>
                    <input type="text" name="numero_boletim" id="numero_boletim" class="form-control" readonly
                        value="<?php echo e($boletim?->numero_boletim ?? __('Será gerado automaticamente')); ?>"
                        placeholder="<?php echo e(__('Gerado automaticamente pela data')); ?>">
                    <div class="form-text"><?php echo e(__('Número gerado automaticamente baseado na data')); ?></div>
                </div>
                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold" for="data"><?php echo e(__('Data')); ?> *</label>
                    <input type="date" name="data" id="data" class="form-control"
                        value="<?php echo e(old('data', $boletim?->data?->format('Y-m-d') ?? date('Y-m-d', strtotime('+1 day')))); ?>" required>
                    <div class="form-text"><?php echo e(__('Data de referência do boletim')); ?></div>
                </div>
            </div>

            <div class="row mb-4">
                <div class="col-12">
                    <h5 class="border-bottom pb-2 mb-3 text-primary">
                        <i class="fas fa-sun me-2"></i><?php echo e(__('Previsão por Período')); ?>

                    </h5>
                </div>

                <?php $__currentLoopData = ['manha' => __('Manhã'), 'tarde' => __('Tarde'), 'noite' => __('Noite')]; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $periodo => $label): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <?php
                        $estado = $periodo === 'manha' ? $estadoManha : ($periodo === 'tarde' ? $estadoTarde : $estadoNoite);
                        $iconUrl = $estado && isset($meteocons[$estado]) ? asset($meteocons[$estado]) : null;
                    ?>
                    <div class="col-md-12 mb-4">
                        <div class="card border-0 shadow-sm">
                            <div class="card-header bg-soft text-black fw-bold d-flex justify-content-between align-items-center">
                                <span><?php echo e($label); ?></span>
                            </div>
                            <div class="card-body">
                                <label class="form-label fw-bold" for="estado_<?php echo e($periodo); ?>"><?php echo e(__('Estado')); ?> <?php echo e($label); ?> *</label>
                                <div class="d-flex align-items-center gap-3 flex-wrap">
                                    <div class="flex-shrink-0 d-flex align-items-center justify-content-center bg-light rounded-3 border" style="width: 64px; height: 64px;">
                                        <img src="<?php echo e($iconUrl ?? asset('pmar/assets/img/icons/weather/nublado.svg')); ?>" alt="" class="estado-select-icon img-fluid" style="max-width: 56px; max-height: 56px; <?php echo e(!$iconUrl ? 'opacity:0.3;' : ''); ?>" data-estado-icon="<?php echo e($periodo); ?>">
                                    </div>
                                    <div class="flex-grow-1" style="min-width: 200px;">
                                        <select name="estado_<?php echo e($periodo); ?>" id="estado_<?php echo e($periodo); ?>" class="form-select form-select-lg js-weather-select" required>
                                            <option value=""><?php echo e(__('Selecione o estado...')); ?></option>
                                            <?php $__currentLoopData = $options['estados']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $est): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                                <option value="<?php echo e($est); ?>" data-icon="<?php echo e(asset($meteocons[$est])); ?>"
                                                    <?php echo e(old("estado_{$periodo}", $boletim?->{"estado_{$periodo}"}) === $est ? 'selected' : ''); ?>>
                                                    <?php echo e(__($est)); ?>

                                                </option>
                                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                        </select>
                                    </div>
                                </div>
                                <div class="form-text mt-1"><?php echo e(__('Define o ícone exibido no boletim')); ?></div>
                            </div>
                        </div>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>

            <div class="row mb-4">
                <div class="col-12">
                    <h5 class="border-bottom pb-2 mb-3 text-primary">
                        <i class="fas fa-thermometer-half me-2"></i><?php echo e(__('Dados Meteorológicos')); ?>

                    </h5>
                </div>
                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="temperatura_minima"><?php echo e(__('Temperatura Mínima (°C)')); ?> *</label>
                    <input type="number" name="temperatura_minima" id="temperatura_minima" class="form-control"
                        value="<?php echo e(old('temperatura_minima', $boletim->temperatura_minima ?? null)); ?>"
                        step="0.1" min="-50" max="50"
                        placeholder="<?php echo e(__('Ex: 18.5')); ?>" required>
                    <div class="form-text"><?php echo e(__('Temperatura mínima prevista (use ponto para decimais)')); ?></div>
                </div>
                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="temperatura_maxima"><?php echo e(__('Temperatura Máxima (°C)')); ?> *</label>
                    <input type="number" name="temperatura_maxima" id="temperatura_maxima" class="form-control"
                        value="<?php echo e(old('temperatura_maxima', $boletim->temperatura_maxima ?? null)); ?>"
                        step="0.1" min="-50" max="50"
                        placeholder="<?php echo e(__('Ex: 28.5')); ?>" required>
                    <div class="form-text"><?php echo e(__('Temperatura máxima prevista (use ponto para decimais)')); ?></div>
                </div>

                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="probabilidade_chuva"><?php echo e(__('Probabilidade de Chuva (%)')); ?> *</label>
                    <input type="number" name="probabilidade_chuva" id="probabilidade_chuva" class="form-control"
                        value="<?php echo e(old('probabilidade_chuva', $boletim->probabilidade_chuva ?? null)); ?>"
                        min="0" max="100"
                        placeholder="<?php echo e(__('Ex: 30')); ?>" required>
                    <div class="form-text"><?php echo e(__('0% a 100% (apenas números inteiros)')); ?></div>
                </div>
                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="volume_chuva"><?php echo e(__('Volume de Chuva (mm)')); ?> *</label>
                    <input type="number" name="volume_chuva" id="volume_chuva" class="form-control"
                        value="<?php echo e(old('volume_chuva', $boletim->volume_chuva ?? null)); ?>"
                        step="0.1" min="0"
                        placeholder="<?php echo e(__('Ex: 100')); ?>" required>
                    <div class="form-text"><?php echo e(__('Volume total previsto (use ponto para decimais)')); ?></div>
                </div>
                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="umidade_minima"><?php echo e(__('Umidade Mínima do Ar (%)')); ?> *</label>
                    <input type="number" name="umidade_minima" id="umidade_minima" class="form-control"
                        value="<?php echo e(old('umidade_minima', $boletim->umidade_minima ?? null)); ?>"
                        step="0.1" min="0" max="100"
                        placeholder="<?php echo e(__('Ex: 30')); ?>" required>
                    <div class="form-text"><?php echo e(__('Umidade mínima prevista (use ponto para decimais)')); ?></div>
                </div>
                <div class="col-md-3 mb-3">
                    <label class="form-label fw-bold" for="umidade_maxima"><?php echo e(__('Umidade Máxima do Ar (%)')); ?> *</label>
                    <input type="number" name="umidade_maxima" id="umidade_maxima" class="form-control"
                        value="<?php echo e(old('umidade_maxima', $boletim->umidade_maxima ?? null)); ?>"
                        step="0.1" min="0" max="100"
                        placeholder="<?php echo e(__('Ex: 80')); ?>" required>
                    <div class="form-text"><?php echo e(__('Umidade máxima prevista (use ponto para decimais)')); ?></div>
                </div>
            </div>

            <div class="row mb-4">
                <div class="col-12">
                    <h5 class="border-bottom pb-2 mb-3 text-primary">
                        <i class="fas fa-signal me-2"></i><?php echo e(__('Nível de Ação e Alertas')); ?>

                    </h5>
                </div>

                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold" for="nivel_de_acao"><?php echo e(__('Nível de Ação')); ?> *</label>
                    <div class="rounded-3 border border-start border-nivel-acao border-<?php echo e($corNivel); ?> border-5 p-3 bg-light bg-opacity-50" id="nivel-acao-input-wrap">
                        <div class="d-flex align-items-center gap-2 flex-wrap">
                            <span class="flex-shrink-0">
                                <i class="fa-solid fa-signal fa-lg text-<?php echo e($corNivel); ?>"></i>
                            </span>
                            <select name="nivel_de_acao" id="nivel_de_acao" class="form-select form-select-lg js-nivel-acao-select flex-grow-1" style="max-width: 280px;" required>
                        <?php $__currentLoopData = $options['niveis_acao']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $nivel): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <option value="<?php echo e($nivel); ?>" data-cor="<?php echo e($cores[$nivel] ?? 'secondary'); ?>"
                                <?php echo e(old('nivel_de_acao', $boletim?->nivel_de_acao ?? 'VIGILÂNCIA') === $nivel ? 'selected' : ''); ?>>
                                <?php echo e(__($nivel)); ?>

                            </option>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </select>
                    </div>
                    <div class="form-text mt-2 mb-0"><?php echo e(__('Define a cor e gravidade mostrada no boletim')); ?></div>
                    </div>
                </div>

                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold"><?php echo e(__('Avisos Meteorológicos')); ?></label>
                    <div class="border rounded p-3 bg-light">
                        <div class="row">
                            <?php $__currentLoopData = [
                                'status_aviso_chuva' => ['label' => __('Chuva'), 'icon' => 'fas fa-cloud-rain'],
                                'status_aviso_vento' => ['label' => __('Vento'), 'icon' => 'fas fa-wind'],
                                'status_aviso_ressaca' => ['label' => __('Ressaca'), 'icon' => 'fas fa-water'],
                            ]; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $campo => $info): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <div class="col-md-4 mb-2">
                                    <label class="form-label small fw-bold" for="<?php echo e($campo); ?>"><?php echo e($info['label']); ?></label>
                                    <select name="<?php echo e($campo); ?>" id="<?php echo e($campo); ?>" class="form-select form-select-sm">
                                        <?php $__currentLoopData = $options['status_avisos']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $statusAviso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                            <option value="<?php echo e($statusAviso); ?>" <?php echo e(old($campo, $boletim->{$campo} ?? 'DESATIVADO') === $statusAviso ? 'selected' : ''); ?>>
                                                <?php echo e(__($statusAviso)); ?>

                                            </option>
                                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                    </select>
                                </div>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </div>
                        <div class="form-text"><?php echo e(__('Avisos ativados mostram ícones especiais no boletim')); ?></div>
                    </div>
                </div>
            </div>

            <div class="row mb-4">
                <div class="col-12">
                    <h5 class="border-bottom pb-2 mb-3 text-primary">
                        <i class="fas fa-circle-info me-2"></i><?php echo e(__('Informações Complementares')); ?>

                    </h5>
                </div>
                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold" for="sobreaviso_cemaden_id"><?php echo e(__('Sobreaviso CEMADEN')); ?> *</label>
                    <div class="input-group">
                        <select name="sobreaviso_cemaden_id" class="form-select" id="sobreaviso_cemaden_id" required data-sobreaviso-select>
                            <option value=""><?php echo e(__('Selecione o sobreaviso...')); ?></option>
                            <?php $__currentLoopData = $sobreavisos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $sobreaviso): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <option value="<?php echo e($sobreaviso->id); ?>" <?php echo e(old('sobreaviso_cemaden_id', $boletim->sobreaviso_cemaden_id ?? null) == $sobreaviso->id ? 'selected' : ''); ?>>
                                <?php echo e($sobreaviso->nome); ?>

                            </option>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </select>
                        <button type="button" class="btn btn-outline-secondary btn-add-sobreaviso" data-bs-toggle="modal" data-bs-target="#modalSobreaviso">
                            <i class="fas fa-plus"></i>
                        </button>
                    </div>
                    <div class="form-text"><?php echo e(__('Agente de sobreaviso designado')); ?></div>
                </div>
                <div class="col-md-6 mb-3">
                    <label class="form-label fw-bold" for="status"><?php echo e(__('Status do Boletim')); ?> *</label>
                    <select name="status" id="status" class="form-select" required>
                        <?php $__currentLoopData = $options['status_publicacao']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $statusPublicacao): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <option value="<?php echo e($statusPublicacao); ?>" <?php echo e(old('status', $boletim->status ?? 'ATIVO') === $statusPublicacao ? 'selected' : ''); ?>>
                                <?php echo e(__($statusPublicacao === 'ATIVO' ? 'Ativo' : 'Inativo')); ?>

                            </option>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </select>
                    <div class="form-text"><?php echo e(__('Status de publicação do boletim')); ?></div>
                </div>
                <div class="col-md-12 mb-3">
                    <label class="form-label fw-bold" for="acoes_programadas"><?php echo e(__('Ações Programadas da Defesa Civil')); ?></label>
                    <textarea name="acoes_programadas" id="acoes_programadas" class="form-control" rows="5"
                        placeholder="<?php echo e(__('Descreva as ações programadas pela Defesa Civil...')); ?>"><?php echo e(old('acoes_programadas', $boletim->acoes_programadas ?? '')); ?></textarea>
                    <div class="form-text"><?php echo e(__('Campo opcional para descrever ações programadas (não obrigatório)')); ?></div>
                </div>
                <div class="col-md-12 mb-3">
                    <label class="form-label fw-bold" for="observacao"><?php echo e(__('Observação')); ?></label>
                    <textarea name="observacao" id="observacao" class="form-control" rows="5"
                        placeholder="<?php echo e(__('Adicione observações gerais sobre o boletim...')); ?>"><?php echo e(old('observacao', $boletim->observacao ?? '')); ?></textarea>
                    <div class="form-text"><?php echo e(__('Campo opcional para observações gerais (não obrigatório)')); ?></div>
                </div>
            </div>

            <div class="d-flex justify-content-between align-items-center border-top pt-4">
                <a href="<?php echo e(route('admin.boletim.meteorologico.index')); ?>" class="btn btn-secondary">
                    <i class="fas fa-times me-2"></i><?php echo e(__('Cancelar')); ?>

                </a>
                <button type="submit" class="btn btn-success btn-lg">
                    <i class="fas fa-save me-2"></i><?php echo e($submitLabel); ?>

                </button>
            </div>
        </form>
    </div>
</div>

<?php /**PATH /var/www/html/portal/resources/views/admin/defesaCivil/boletim_meteorologico/partials/form.blade.php ENDPATH**/ ?>