@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Castração Animal - Verificar")
@section('content')

    @if (session('error'))
        <div class="alert alert-danger text-center">{{ session('error') }}</div>
    @endif

    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card shadow">
                        
                        @php $headLine = "<i class='fa-solid fa-paw'></i> Castração Animal - Verificar"; @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'routeBack' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
                            'routeBackParams' => [],
                            'nameBack' => __("Voltar"),
//                            'routeAdd' => 'admin.meioAmbiente.castracaoAnimal.verified',
//                            'routeAddParams' => [],
//                            'nameAdd' => __('Novo tutor'),
                            "permission" => "GERENCIADOR_DE_CASTRACAO_ANIMAL",
                            "tabs" => [
                                ['route' => 'admin.meioAmbiente.castracaoAnimal.racas.index', 'class' => 'fa-solid fa-dog', 'label' => 'Lista de raças', 'permission' => 'GERENCIADOR_DE_CASTRACAO_ANIMAL'],
                            ],
                        ])
                        
                        <div class="card-body">
                        <form action="{{ route('admin.meioAmbiente.castracaoAnimal.verify') }}" method="post" enctype="multipart/form-data">
                            @include('errors.messageFlash')
                            @csrf
                            @method('post')

                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                            <div class="mb-3">
                                
                                <!-- Campo CPF -->
                                @include('components.inputs._inputType',[
                                    "for" => null,
                                    "label" => "CPF",
                                    "name" => "cpf",
                                    "id" => null,
                                    "required" => true,
                                    "type" => null,
                                    "old" => old('cpf'),
                                    "oninput" => "javascript:aplicarMascaraCPF(this)",
                                    "readonly" => false,
                                    "small" => null,
                                ])
                                
                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack' => __('Voltar'),
                                'textSend' => __('Verificar'),
                                'routeBack' => 'admin.meioAmbiente.castracaoAnimal.tutores.index',
                            ])
                        </form>
                    </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection