<section class="ma-help-bar" aria-label="{{ __('Canais de atendimento') }}">
    <div class="container">
        <a href="{{ route('mobiangra.fale_conosco') }}" class="ma-help-bar__card">
            <span class="ma-help-bar__card-text">{{ __('Precisa de ajuda?') }}</span>
            <span class="ma-help-bar__card-icon" aria-hidden="true">
                <i class="fa-solid fa-comment-dots"></i>
            </span>
        </a>
    </div>
</section>
