<form id="formNovaConta" name="formNovaConta" autocomplete="off" method="post" action="<?php echo e(route('admin.novaContaStore', $token)); ?>">
    <?php echo csrf_field(); ?>
    <input type="hidden" name="token" value="<?php echo e($token); ?>">
    <input type="hidden" name="recaptcha" id="recaptchaNovaContaInput">
    <div class="mb-3">
        <?php echo $__env->make('components.inputs._inputType',[
            'for'=>null,
            'label'=>__('Nome completo'),
            'name'=>'fullName',
            'id'=>'fullName',
            'required'=>true,
            'type'=>null,
            'old'=>old('fullName'),
            'oninput'=>null,
            'readonly'=>false,
            'small'=>null,
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
    <div class="mb-3">
        <?php echo $__env->make('components.inputs._inputType',[
            'for'=>null,
            'label'=>__('Telefone'),
            'name'=>'phoneNumber',
            'id'=>'phoneNumberNovaConta',
            'required'=>true,
            'type'=>null,
            'old'=>old('phoneNumber'),
            'oninput'=>'javascript:aplicarMascaraTelefone(this)',
            'readonly'=>false,
            'small'=>null,
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
    <div class="mb-3">
        <?php echo $__env->make('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Senha'),
        'name'=>'password',
        'id'=>'passwordNovaConta',
        'required'=>true,
        'type'=>'password',
        'old'=> old('password'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
    <div class="mb-3">
        <?php echo $__env->make('components.inputs._inputType',[
        'for'=>null,
        'label'=>__('Repetir senha'),
        'name'=>'password_repeat',
        'id'=>'passwordRepeatNovaConta',
        'required'=>true,
        'type'=>'password',
        'old'=> old('password_repeat'),
        'oninput'=>null,
        'readonly'=>false,
        'small'=>null,
        ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </div>
    <div class="my-3">
        <button class="fs-5 rounded-4 btn m-auto btn-primary w-100" type="submit" id="submitNovaConta"><?php echo e(__('Salvar')); ?></button>
    </div>
    <hr/>
    <div class="my-3 text-center">
        <a href="<?php echo e(route("admin.login")); ?>" class="text-white">Login</a> | <a href="<?php echo e(route("admin.esqueceuSenha")); ?>" class="text-white">Esqueceu senha?</a>
    </div>
</form>
<?php /**PATH /var/www/html/portal/resources/views/components/auth/new-account.blade.php ENDPATH**/ ?>