<div style="text-align: center; margin-bottom: 30px;">
    <img src="{{ public_path('pmar/assets/fiveicon/brasao-angra-dos-reis.png') }}" style="max-height: 90px;"
        alt="Brasão Angra dos Reis">
    <h3 style="margin: 10px 0 0; font-family: sans-serif; font-size: 14pt; color: #003366;">
        SECRETARIA DE PLANEJAMENTO E GESTÃO
    </h3>
</div>

<table border="1" cellpadding="5" cellspacing="0" style="width: 100%; border-collapse: collapse;">
    <thead>
        <tr style="background-color: #003366; color: #ffffff;">
            <th colspan="2" style="font-size: 14pt; padding: 10px;">RELATÓRIO DA PARCERIA PÚBLICO-PRIVADA</th>
        </tr>
    </thead>
    <tbody>
        <!-- Identificação -->
        <tr style="background-color: #e9ecef;">
            <td colspan="2"><strong><br>Identificação</strong></td>
        </tr>
        <tr>
            <td><strong>Projeto</strong></td>
            <td>{{ $ppp->projeto ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Status</strong></td>
            <td>{{ $ppp->status ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Andamento</strong></td>
            <td>{{ $ppp->andamento ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Conclusão (%)</strong></td>
            <td>{{ $ppp->porcentagem_conclusao ?? 0 }}%</td>
        </tr>
        <tr>
            <td><strong>Empresa</strong></td>
            <td>{{ $ppp->empresa ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Secretaria Responsável</strong></td>
            <td>{{ $ppp->secretaria_responsavel ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Critério de Julgamento</strong></td>
            <td>{{ $ppp->criterio_julgamento ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Próxima Etapa</strong></td>
            <td>{{ $ppp->proxima_etapa ?? '-' }}</td>
        </tr>

        <!-- Prazos -->
        <tr style="background-color: #e9ecef;">
            <td colspan="2"><strong><br>Prazos</strong></td>
        </tr>
        <tr>
            <td><strong>Prazo de Concessão</strong></td>
            <td>{{ $ppp->prazo_concessao ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Prazo de Implantação</strong></td>
            <td>{{ $ppp->prazo_implantacao ?? '-' }}</td>
        </tr>

        <!-- Valores / Financeiro -->
        <tr style="background-color: #e9ecef;">
            <td colspan="2"><strong><br>Dados Financeiros</strong></td>
        </tr>
        <tr>
            <td><strong>Valor Estimado do Contrato</strong></td>
            <td>{{ $ppp->valor_estimado_contrato ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Investimento Total</strong></td>
            <td>{{ $ppp->investimento_total ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Aporte do Município</strong></td>
            <td>{{ $ppp->aporte_municipio ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Contraprestação Mensal</strong></td>
            <td>{{ $ppp->contraprestacao_mensal ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Outorga Fixa</strong></td>
            <td>{{ $ppp->outorga_fixa ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Outorga Variável</strong></td>
            <td>{{ $ppp->outorga_variavel ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Payback</strong></td>
            <td>{{ $ppp->payback ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>TIR</strong></td>
            <td>{{ $ppp->tir ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>CAPEX</strong></td>
            <td>{{ $ppp->capex ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>OPEX</strong></td>
            <td>{{ $ppp->opex ?? '-' }}</td>
        </tr>

        <!-- Complementares -->
        <tr style="background-color: #e9ecef;">
            <td colspan="2"><strong><br>Informações Complementares</strong></td>
        </tr>
        <tr>
            <td><strong>Obrigações</strong></td>
            <td>{{ $ppp->obrigacao ?? '-' }}</td>
        </tr>
        <tr>
            <td><strong>Observações</strong></td>
            <td>{{ $ppp->observacoes ?? '-' }}</td>
        </tr>

    </tbody>
</table>

<br>

<table border="1" cellpadding="5" cellspacing="0" style="width: 100%; border-collapse: collapse; margin-top:20px;">
    <thead>
        <tr style="background-color: #003366; color: #ffffff;">
            <th colspan="3" style="font-size: 14pt; padding: 10px;">HISTÓRICO DE TRAMITAÇÃO / OBSERVAÇÕES</th>
        </tr>
        <tr style="background-color: #dcdcdc;">
            <th>Data e Hora</th>
            <th>Órgão / Organização</th>
            <th>Observação / Andamento / Tempo</th>
        </tr>
    </thead>
    <tbody>
        @forelse($ppp->historicos as $historico)
            <tr>
                <td style="width: 15%">
                    {{ $historico->data ? \Carbon\Carbon::parse($historico->data)->format('d/m/Y') : $historico->created_at->format('d/m/Y H:i') }}
                </td>
                <td style="width: 25%">{{ $historico->orgao ?? '-' }}</td>
                <td style="width: 60%">{{ $historico->observacao ?? '-' }}</td>
            </tr>
        @empty
            <tr>
                <td colspan="3" style="text-align:center;">Nenhum histórico registrado no sistema.</td>
            </tr>
        @endforelse
    </tbody>
</table>