@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: Visite Angra - Novo Corredor Turístico")
@section('content')


    <div class="container">
        <div class="row">
            <div class="col-12 mt-5">
                <div class="card shadow">

                    @php $headLine = "<i class='fa-solid fa-route fa-2x'></i> Visite Angra - Novo Corredor Turístico"; @endphp

                    @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        'routeBack' => 'admin.visiteAngra.corredores.index',
                        'routeBackParams' => [], 
                        'nameBack' => __("Voltar"),
                        "permission" => "GERENCIADOR_VISITE_ANGRA",
                    ])

                    <div class="card-body">
                        <form action="{{ route('admin.visiteAngra.corredores.store') }}" method="post" enctype="multipart/form-data">
                            @csrf
                            @include("errors.messageFlash")

                            <div class="mb-3">
                                <input type="hidden" name="slug" value="{{ old('slug') }}">

                            <!-- Campo Nome do corredor -->
                                @include('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "Nome do corredor",
                                        "name" => "corredor",
                                        "id" => null,
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('corredor'),
                                        "oninput" => null,
                                        "readonly" => false,
                                        "small" => null,
                                    ])

                            </div>

                            <div class="mb-3">

                            <!-- Campo Subtitulo -->
                                @include('components.inputs._inputType',[
                                        "for" => null,
                                        "label" => "Subtitulo",
                                        "name" => "subtitulo",
                                        "id" => null,
                                        "required" => true,
                                        "type" => null,
                                        "old" => old('subtitulo'),
                                        "oninput" => null,
                                        "readonly" => false,
                                        "small" => null,
                                    ])

                            </div>

                            <div class="mb-3">

                            <!-- Campo Foto Destaque -->
                                @include('components.inputs._inputType',[
                                            "for" => null,
                                            "label" => "Foto Destaque",
                                            "name" => "foto",
                                            "id" => null,
                                            "required" => true,
                                            "type" => 'file',
                                            "old" => null,
                                            "oninput" => null,
                                            "readonly" => true,
                                            "small" => "Formatos permitidos: JPEG, PNG ou GIF. Tamanho máximo: 5 MB.",
                                            "accept" => 'image/jpeg,image/jpg,image/png,image/gif',
                                        ])

                            </div>

                            <div class="mb-3">

                            <!-- Campo Status -->
                                @include('components.inputs._selectType', [
                                        "for" => "status",
                                        "label" => "Status",
                                        "name" => "status",
                                        "required" => true,
                                        "readonly" => false,
                                        "options" => collect(App\Enums\StatusEnum::cases())
                                            ->mapWithKeys(fn($status) => [$status->name => $status->value])
                                            ->toArray(),
                                        "selected" => old('status'),
                                        "placeholder" => "Selecione o status...",
                                        "small" => "Informe o status atual do corredor turístico.",
                                        "onchange" => null
                                    ])

                            </div>

                            @include('components.buttons._backAndSend',[
                                'routeBack' => 'admin.visiteAngra.corredores.index',
                                'textBack' => "Voltar",
                                'textSend' => "Cadastrar",
                            ])
                        </form>
                    </div>

                </div>
            </div>
        </div>
    </div>


@endsection