@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Verificar Empresa de Turismo'))
@section('content')

    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <div class="card shadow">

                    @php $headLine = "<i class='fa-solid fa-water'></i> " . __('Verificar Empresa de Turismo'); @endphp

                    @include('components.buttons._headLineButtonsBackAdd', [
                        'headLine' => __($headLine),
                        'routeBack' => 'admin.empresasDeTurismo.index',
                        'routeBackParams' => [],
                        'nameBack' => __('Voltar'),
                        'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                    ])

                    <div class="card-body">
                        <form action="{{ route('admin.empresasDeTurismo.verify') }}" method="post" enctype="multipart/form-data">
                            @include('errors.messageFlash')
                            @csrf
                            @method('post')

                            <div class="mb-3">
                                @include('components.inputs._inputType',[
                                    'for' => null,
                                    'label' => __('CNPJ'),
                                    'name' => 'cnpj',
                                    'id' => null,
                                    'required' => true,
                                    'type' => null,
                                    'old' => old('cnpj'),
                                    'oninput' => "javascript:aplicarMascaraCNPJ(this)",
                                    'readonly' => false,
                                    'small' => null,
                                ])
                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack' => __('Voltar'),
                                'textSend' => __('Verificar'),
                                'routeBack' => 'admin.empresasDeTurismo.index',
                            ])
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
