@extends('layouts.pmar.theme')
@section('title', env('APP_NAME') . ' :: Credenciamento de Músicos de Angra dos Reis')
@section('content')
<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item">
                            <a href="{{ route('paginas.home') }}">{{ __('Portal') }}</a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">
                            {{ __('Credenciamento de Músicos de Angra dos Reis') }}
                        </li>
                    </ol>
                </nav>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <h1 class="mb-3">{{ __('Credenciamento de Músicos de Angra dos Reis') }}</h1>

                <p class="mb-3">{{ __("Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.") }}</p>
                <p class="mb-3">{{ __("Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.") }}</p>
                <p class="mb-3">{{ __("O acompanhamento do processo é de responsabilidade do músico, e a retirada do cartão deverá ser feita presencialmente na sede da Secretaria de Cultura.") }}</p>
                <p class="mb-3">{{ __("De acordo com a ") }}<strong>{{ __("Lei Municipal nº 0.0000, de xx de novembro de xxxx") }}</strong>{{ __(", desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for.") }}</p>

                <p class="mb-3">{{ __("Antes de iniciar o preenchimento, certifique-se de ter em mãos toda a documentação digitalizada necessária para emissão do cartão de identificação.") }}</p>

                <ol class="list-group list-group-numbered mb-3">
                    <li class="list-group-item">{{ __("Laudo Médico com a descrição da condição de fibromialgia (CID10 M79.7);") }}</li>
                    <li class="list-group-item">{{ __("01 foto tamanho 3x4;") }}</li>
                    <li class="list-group-item">{{ __("Comprovante de residência;") }}</li>
                    <li class="list-group-item">{{ __("RG;") }}</li>
                    <li class="list-group-item">{{ __("CPF e;") }}</li>
                    <li class="list-group-item">{{ __("Cartão SUS.") }}</li>
                </ol>

                <p class="alert alert-info mb-3">{{ __("Lembramos que é de responsabilidade do usuário acompanhar pelo sistema o andamento do processo e a retirada do cartão deverá ser feita na Secretaria de Cultura.") }}</p>

                <hr>

                <div class="mb-3">
                    <a class="btn btn-lg btn-primary" href="{{ route('admin.cultura.credenciamentoMusicos.perfil.index') }}"></a>
                    {{ __("Sim, desejo fazer a adesão ao Credenciamento de Músicos de Angra dos Reis.") }}
                    </a>
                </div>

            </div>
        </div>
    </div>
</section>
@endsection
