<div class="mb-3">
    <?php if(isset($routeBack)): ?>
        <?php
            $backParams = $backId ?? [];
            if (!is_array($backParams)) {
                $backParams = [$backParams];
            }
            if (request()->filled('q')) {
                $backParams['q'] = request()->input('q');
            }
            if (request()->filled('page')) {
                $backParams['page'] = request()->input('page');
            }
        ?>
        <button class="btn btn-lg btn-secondary d-inline" onclick="javascript:window.location.href='<?php echo e(route($routeBack, $backParams)); ?>'" type="button"><?php echo e(__($textBack)); ?></button>
    <?php endif; ?>
    <button class="btn btn-lg btn-dark  d-inline" type="submit"><?php echo e(__($textSend)); ?></button>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/buttons/_backAndSend.blade.php ENDPATH**/ ?>