@extends('layouts.admin.theme')

@section('content')
    <div class="container text-start pb-5 mb-5">
        @if($errors->any())
            <div class="alert alert-danger mb-4" role="alert">
                @foreach($errors->all() as $e)
                    <div>{{ $e }}</div>
                @endforeach
            </div>
        @endif
        <div class="row mb-4">
            <div class="col text-start">
                <h3>{{ __('Dados') }}</h3>
            </div>
            <div class="col text-end d-flex justify-content-end">
                <button type="button" class="btn btn-light bg-mediumGray me-2"
                    onclick="window.location='{{ route('admin.projetosProgramas.index', $projetosListagemReturnQuery ?? []) }}'">
                    <i class="fa fa-list me-1"></i> {{ __('Início') }}
                </button>
            </div>
        </div>
        @include('admin.projetosProgramas.partials.steps', [
            'current' => 'dados',
            'project' => $project,
            'projetosListagemReturnQuery' => $projetosListagemReturnQuery ?? [],
        ])
        @include('components.projetosProgramas._stickyProjectHeader', ['project' => $project])
        @php
            $orgaosSelecionados = old('orgaos', $project->orgaosEnvolvidos->pluck('id')->toArray());
        @endphp
        <form method="post" action="{{ route('admin.projetosProgramas.dados.store', $project->id) }}" class="mt-3 text-start">
            @csrf
            @include('components.projetosProgramas._pp_listagem_context_hiddens', ['query' => $projetosListagemReturnQuery ?? []])
            <div class="row g-3">
                <div class="col-md-10">
                    <label class="form-label" for="descricao_objeto">{{ __('Descrição do objeto') }}</label>
                    <textarea name="descricao_objeto" id="descricao_objeto" rows="3"
                        class="form-control">{{ old('descricao_objeto', $project->descricao_objeto) }}</textarea>
                </div>
                <div class="col-md-10">
                    <label class="form-label" for="gargalos">{{ __('Gargalos (dificuldades)') }}</label>
                    <textarea name="gargalos" id="gargalos" rows="3"
                        class="form-control">{{ old('gargalos', $project->gargalos) }}</textarea>
                </div>
                <div class="col-md-10">
                    <label class="form-label" for="observacoes">{{ __('Observação') }}</label>
                    <textarea name="observacoes" id="observacoes" rows="3"
                        class="form-control">{{ old('observacoes', $project->observacoes) }}</textarea>
                </div>
            </div>
            <hr class="my-4">
            <div>
                <span class="fw-semibold">{{ __('Órgãos envolvidos') }}</span>
                <div class="row mt-2">
                    @foreach($orgaos as $o)
                        <div class="col-md-3">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="orgaos[]" value="{{ $o->id }}"
                                    id="oe{{ $o->id }}" {{ in_array($o->id, $orgaosSelecionados ?? [], true) ? 'checked' : '' }}>
                                <label class="form-check-label" for="oe{{ $o->id }}">{{ $o->abbreviation }}</label>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
            <div class="text-end mt-4 d-flex gap-3">
                <button type="submit" class="btn btn-green">
                    <i class="fa fa-arrow-right me-1"></i> {{ __('Salvar e Prosseguir') }}
                </button>
            </div>
        </form>
    </div>
@endsection
