@props([
    'structureId' => null,
    'mainColClass' => 'internas-secretarias-home-news col-lg-9 col-md-9 col-sm-12',
])

<div {{ $attributes->merge(['class' => 'container']) }}>
    <div class="row gx-5 gy-5 my-5">
        <div class="{{ $mainColClass }}">
            {{ $slot }}
        </div>

        <x-portal.structure-sidebar :structure-id="$structureId" />
    </div>
</div>
