@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Editar Startup'))
@section('content')
    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-lightbulb'></i> " . __('Editar Startup'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.parqueTecnologico.index',
            'routeBackParams' => ['tab' => 'startups'],
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_PARQUE_TECNOLOGICO',
        ])
        <div class="card-body">
            @include('errors.messageFlash')
            <form action="{{ route('admin.parqueTecnologico.startups.update', $startup->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                @include('admin.parqueTecnologico.startups._form', ['startup' => $startup])

                @include('components.buttons._backAndSend', [
                    'textBack' => __('Voltar'),
                    'textSend' => __('Salvar'),
                    'routeBack' => 'admin.parqueTecnologico.index',
                    'routeBackParams' => ['tab' => 'startups'],
                ])
            </form>
        </div>
    </div>
@endsection

