<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <title>{{ __('Vencimento CADASTUR') }}</title>
</head>
<body style="margin:0; padding:0; background-color:#f2f2f2; font-family: Arial, sans-serif;">

    <table width="100%" cellpadding="0" cellspacing="0" style="background-color:#f2f2f2; padding:20px 0;">
        <tr>
            <td align="center">

                <table width="600" cellpadding="0" cellspacing="0" style="background:#ffffff; border-radius:8px; overflow:hidden; box-shadow:0 2px 10px rgba(0,0,0,0.06);">

                    @include('emails.partials._pmar_institucional_header')

                    <tr>
                        <td style="padding:30px; color:#333333; font-size:15px; line-height:1.6;">

                            <p style="margin:0 0 15px; color:#007bc3; font-size:18px; font-weight:bold;">
                                {{ __('Vencimento do CADASTUR') }}
                            </p>
                            <p style="margin:0 0 15px; color:#666666; font-size:13px;">
                                {{ __('Empresas de Turismo - TurisAngra') }}
                            </p>

                            <p style="margin:0 0 15px;">
                                {{ __('Prezado(a),') }}
                            </p>

                            <p style="margin:0 0 20px;">
                                {{ __('Informamos que o cadastro CADASTUR da sua empresa vence em 30 dias. Confira os dados abaixo e providencie a renovação junto aos órgãos competentes.') }}
                            </p>

                            <p style="margin:0 0 8px;"><strong>{{ __('Razão Social') }}:</strong> {{ $empresaTurismo->companhia?->razaoSocial ?? '-' }}</p>
                            <p style="margin:0 0 8px;"><strong>{{ __('CNPJ') }}:</strong> {{ $empresaTurismo->companhia?->cnpj ?? '-' }}</p>
                            <p style="margin:0 0 8px;"><strong>{{ __('Cadastur') }}:</strong> {{ $empresaTurismo->cadastur }}</p>
                            <p style="margin:0 0 20px;"><strong>{{ __('Vencimento') }}:</strong> {{ $empresaTurismo->cadastur_vencimento?->format('d/m/Y') ?? '-' }}</p>

                            <div style="background:#fff3cd; border:1px solid #ffeeba; color:#856404; padding:15px; border-radius:6px; margin:15px 0;">
                                <strong>{{ __('Atenção') }}</strong><br>
                                {{ $mensagem }}
                            </div>

                        </td>
                    </tr>

                    @include('emails.partials._pmar_institucional_footer')

                </table>

            </td>
        </tr>
    </table>

</body>
</html>
