@php
    $portariaListFilters = request()->only(\App\Http\Resources\LegislacaoResource::PORTARIA_FILTER_KEYS);
@endphp
@if (isset($portaria))
    <div class="card shadow-sm mb-3 mt-3">
        <div class="card-header bg-light">
            <span class="fw-semibold">{{ __('Correções na portaria') }}</span>
        </div>
        <div class="card-body">
            <form method="post" action="{{ route('admin.legislacao.portarias.retificacoes.store', $portaria) }}"
                class="row g-3 border-bottom pb-3 mb-3">
                @csrf
                @foreach($portariaListFilters as $key => $value)
                    @if($value !== null && $value !== '')
                        <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                    @endif
                @endforeach
                <div class="col-md-4">
                    <label class="form-label">{{ __('Tipo') }}</label>
                    <select name="cd_tipo" class="form-select" required>
                        <option value="">{{ __('Selecione') }}</option>
                        <option value="1">{{ __('Errata') }}</option>
                        <option value="2">{{ __('Republicação') }}</option>
                    </select>
                </div>
                <div class="col-md-8">
                    <label class="form-label">{{ __('Descrição') }}</label>
                    <textarea name="ds_descricao" class="form-control" rows="2">{{ old('ds_descricao') }}</textarea>
                </div>
                <div class="col-md-8">
                    <label class="form-label">{{ __('Boletim oficial') }}</label>
                    @php
                        $pBoPanelSelId = old('id_boletim_oficial', '');
                    @endphp
                    <select name="id_boletim_oficial" class="form-select js-legislacao-boletim-api" required
                        data-api-url="{{ route('api.boletinsOficiais') }}"
                        data-placeholder="{{ __('Selecione') }}"
                        data-selected-id="{{ $pBoPanelSelId }}"
                        data-selected-label="">
                        <option value="">{{ __('Selecione') }}</option>
                    </select>
                </div>
                <div class="col-md-4 d-flex align-items-end">
                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                        <button type="submit" class="btn btn-primary w-100">{{ __('Incluir correção') }}</button>
                    @endif
                </div>
            </form>

            <div class="table-responsive">
                <table class="table table-striped align-middle">
                    <thead>
                        <tr>
                            <th>{{ __('Tipo') }}</th>
                            <th>{{ __('Boletim') }}</th>
                            <th>{{ __('Descrição') }}</th>
                            <th class="text-end">{{ __('Ações') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse ($portaria->retificacoes as $ret)
                            <tr>
                                <td>{{ (int) $ret->cd_tipo === 1 ? __('Errata') : __('Republicação') }}</td>
                                <td>
                                    @include('components.legislacao._boletimNumeroLink', ['boletim' => $ret->boletim])
                                </td>
                                <td>{{ \Illuminate\Support\Str::limit($ret->ds_descricao ?? '', 120) }}</td>
                                <td class="text-end">
                                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                        <a class="btn btn-sm btn-warning"
                                            href="{{ route('admin.legislacao.portarias.retificacoes.edit', [$portaria, $ret] + $portariaListFilters) }}">
                                            <i class="fa-solid fa-pen-to-square"></i>
                                        </a>
                                    @endif
                                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                        <form class="d-inline" method="post"
                                            action="{{ route('admin.legislacao.portarias.retificacoes.destroy', [$portaria, $ret]) }}"
                                            onsubmit="return confirmDelete(this)">
                                            @csrf
                                            @method('delete')
                                            @foreach($portariaListFilters as $key => $value)
                                                @if($value !== null && $value !== '')
                                                    <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                @endif
                                            @endforeach
                                            <input type="hidden" name="confirm"
                                                value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                            <button type="submit" class="btn btn-sm btn-danger"><i class="fa-solid fa-trash"></i></button>
                                        </form>
                                    @endif
                                </td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="4" class="text-center text-muted">{{ __('Nenhuma correção cadastrada.') }}</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endif
