@extends('layouts.admin.theme')

@section('title', env('APP_NAME') . ' :: Arte Sacra - Lista de Paças')

@section('content')
    <div class="card shadow-sm">
        
        @php $headLine = "<i class='fa-solid fa-church'></i> Arte Sacra - Lista de Paças"; @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
//            'routeBack' => 'admin.turismoNautico.index',
//            'routeBackParams' => [],
//            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.cultura.arteSacra.create',
            'routeAddParams' => [],
            'nameAdd' => __('Nova peça'),
            "permission" => "GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA",
            "tabs" => [
                ['route' => 'admin.cultura.arteSacra.options', 'class' => 'fa-list', 'label' => 'Edição de Opções', 'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA'],
                ['route' => 'admin.cultura.arteSacra.report', 'class' => 'fa-list-check', 'label' => 'Relatório Geral', 'permission' => 'GERENCIADOR_DO_CADASTRO_DE_ARTE_SACRA'],
                ['route' => 'admin.cultura.arteSacra.trash', 'class' => 'fa-trash', 'label' => 'Lixeira', 'permission' => 'DIRETOR_DE_ARTE_SACRA'],
                ['route' => 'admin.cultura.arteSacra.logs.usuarios', 'class' => 'fa-user-secret', 'label' => 'Logs de Usuários', 'permission' => 'DIRETOR_DE_ARTE_SACRA'],
            ],
        ])
        
        <div class="card-body">
            
            @include('errors.messageFlash')
            
            @include('components.buttons._searchAndClean', [
                'url' => 'admin.cultura.arteSacra.index', 'label1' => 'Buscar', 'label2' => 'Limpar', 'search' => 'busca', 'placeholder' => 'Buscar peças ...'
            ])
            
            
            <x-tables._table :thead="['Imagem', 'Data de Cadastro', 'Código Acervo', 'Nome da Peça', 'Ano da Peça', 'Tipo', 'Modo de Aquisição', 'Material', 'Proprietário', 'Localização', 'Exibição Publica', 'Ações']" :pagination="$artes->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                     @foreach($artes as $arte)
                        <tr>
                            <td style="width:150px">
                                
                                @include('components.tables._openPhotoAndPdf',[
                                    'asset' => file_exists($arte->imagem) ? $arte->imagem : 'pmar/assets/img/icons/default.png',
                                    'alt' => $arte->nome_peca,
                                    'title' => $arte->nome_peca,
                                    'text' => 'Foto',
                                    'index' => $index,
                                ])
                            </td>
                            <td>{{ date('d/m/Y H:m:s', strtotime($arte->created_at)) }}</td>
                            <td>{{ $arte->codigo_acervo }}</td>
                            <td>{{ $arte->nome_peca }}</td>
                            <td>{{ $arte->ano_arte }}</td>
                            <td>{{ optional($arte->tipo)->tipo ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->modoAquisicao)->modo_aquisicao ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->material)->material ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->proprietario)->proprietario ?? 'Não informado' }}</td>
                            <td>{{ optional($arte->localizacao)->proprietario ?? 'Não informado' }}</td>
                            <td>{{ $arte->permitir_exibicao }}</td>
                            <td class="text-nowrap text-center align-middle">
                                <div class="d-flex justify-content-center flex-wrap gap-1">
                                    <a href="{{ route('admin.cultura.arteSacra.edit', $arte->id) }}"
                                        class="btn btn-sm btn-primary" title="Editar Arte">
                                        <i class="fa-solid fa-pen-to-square"></i>
                                    </a>
                                    <a href="{{ route('admin.cultura.arteSacra.relatorios.reportCard', ['id' => $arte->id]) }}"
                                        class="btn btn-sm btn-outline-primary" title="Gerar Ficha Técnica"
                                        target="_blank">
                                        <i class="fa-solid fa-file-lines"></i>
                                    </a>
                                    <a href="{{ route('admin.cultura.arteSacra.avaliacaoTecnica', $arte->id) }}"
                                        class="btn btn-sm btn-outline-primary" title="Avaliação Técnica"
                                        target="_blank">
                                        <i class="fa-solid fa-screwdriver-wrench"></i>
                                    </a>
                                    <a href="{{ route('admin.cultura.arteSacra.historico', $arte->id) }}"
                                        class="btn btn-sm btn-outline-primary" title="Histórico da Arte"
                                        target="_blank">
                                        <i class="fa-solid fa-clock-rotate-left"></i>
                                    </a>
                                    <a href="{{ route('admin.cultura.arteSacra.historiaArte', $arte->id) }}"
                                        class="btn btn-sm btn-outline-primary" title="Historia da Arte" target="_blank">
                                        <i class="fas fa-book"></i>
                                    </a>
                                    <form method="POST"
                                        action="{{ route('admin.cultura.arteSacra.inativarOuAtivar', $arte->id) }}"
                                        class="d-inline"
                                        onsubmit="return confirm('Confirma a inativação desta peça?\n\nAo realizar a inativação, o item será movido para a lixeira.\nRessaltamos que somente o diretor terá permissão para restaurá-lo posteriormente.')">
                                        @csrf
                                        <button type="submit" class="btn btn-sm btn-danger float-start"
                                            title="Inativar Peça">
                                            <i class="fa-solid fa-trash"></i>
                                        </button>
                                    </form>
                                </div>
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>
            
        </div>
    </div>
@endsection
