<div class="row">
    <main>
        <section style="padding-top: 0 !important;" id="responsabilidades-usuario-externo">

            <div class="container">
                <h2 class="text-dark text-center py-5 fs-1">Manual do Usuário Externo</h2>
                <div class="row">
                    <p>Este material apresenta os principais conceitos e funcionalidades do SEI ANGRA para
                        usuários externos, além de abordar as normas definidas para a utilização do sistema,
                        no âmbito do Município de Angra dos Reis. Este manual é a junção dos manuais
                        de usuário externo e peticionamento eletrônico.</p>
                    <p>Para isso, sempre destacaremos os dados mais relevantes com ajuda dos ícones
                        indicados abaixo:</p>
                </div>
                <div class="row">
                    <div class="bg-blue col d-flex justify-content-center align-items-center shadow rounded-5 m-2">
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/lampada.png') }}"
                            alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                        <span class="p-2"> Destaca procedimentos e atividades que facilitam o trabalho no
                            sistema.</span>
                    </div>
                    <div class="bg-green col d-flex justify-content-center align-items-center shadow rounded-5 m-2">
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                            alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                        <span class="p-2">Destaca informações às quais o usuário sempre deve estar atento ao
                            utilizar o
                            SEI-RJ.</span>
                    </div>
                </div>
                <div class="row">
                    <p></p>
                </div>
            </div>
            <div class="container pt-3 mt-3">

                <h2 class="text-primary">Responsabilidades do Usuário Externo</h2>
                <hr>
                <p>
                    O cadastro como Usuário Externo no SEI é <strong>personalíssimo</strong>, ou seja,
                    sua operação é sob a responsabilidade da pessoa que opera o sistema,
                    tendo como consequência a responsabilidade pelo uso indevido das ações efetuadas, as
                    quais poderão ser passíveis de apuração
                    <strong>civil, penal e administrativa</strong>.
                </p>
                <p>
                    É destinado à <strong>pessoa física</strong> que participe de processos
                    junto aos órgãos, independentemente de vinculação a determinada pessoa jurídica, para
                    fins de:
                </p>
                <ul>
                    <li>Peticionamento (iniciar processos e inserir documentos em processos existentes);
                    </li>
                    <li>Visualização de processos com restrição de acesso aos quais foram concedidos acesso
                        externo;</li>
                    <li>Assinatura de contratos, convênios, termos, acordos e outros instrumentos congêneres
                        celebrados com o órgão.</li>
                </ul>
                <p>
                    Para realizar peticionamento ou assinar documentos, é necessário <strong>cadastro
                        prévio</strong> e autorização da Unidade Gestora do SEI,
                    mediante a apresentação de documentos.
                </p>
                <p>
                    Listaremos agora, algumas normas sobre a utilização do SEI já definidas no decreto
                    <strong>Nº 13.367 de 03 de janeiro de 2024</strong>.
                </p>
                <strong class="mt-4">Quanto à utilização do SEI:</strong>
                <ul>
                    <li>O sigilo da senha relativa à assinatura eletrônica, não sendo oponível, em qualquer
                        hipótese, alegação de uso indevido por outrem.</li>
                    <li>A atualização dos seus dados cadastrais.</li>
                    <li>
                        A conformidade entre os dados informados no formulário eletrônico de peticionamento
                        e aqueles contidos no documento enviado,
                        incluindo o preenchimento dos campos obrigatórios e anexação dos documentos
                        essenciais e complementares.
                    </li>
                    <li>
                        A confecção da petição e dos documentos digitais em conformidade com os requisitos
                        estabelecidos pelo sistema,
                        no que se refere ao formato e ao tamanho dos arquivos transmitidos eletronicamente.
                    </li>
                    <li>
                        A conservação dos originais em papel de documentos digitalizados enviados por meio
                        de peticionamento eletrônico
                        até que decaia o direito da Administração de rever os atos praticados no processo,
                        para que, caso solicitado,
                        sejam apresentados ao Poder Executivo do Município de Angra dos Reis para qualquer
                        tipo
                        de conferência.
                    </li>
                    <li>
                        A verificação, por meio do recibo eletrônico de protocolo, do recebimento das
                        petições e dos documentos transmitidos eletronicamente.
                    </li>
                </ul>
            </div>
        </section>

        <section id="interface-sei-rj">
            <div class="container">
                <h2 id="collapseInterface" class="text-primary">A Interface do SEI</h2>
                <hr>

                <div class="d-flex align-items-center shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                        alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">&nbsp;&nbsp;&nbsp;
                        O sistema SEI é amplamente usado nos órgãos governamentais. <strong>Atente-se para o
                            endereço do SEI acessado</strong>.
                    </p>
                </div>
            </div>
            <div class="container pt-5 mt-5">
                <h3 id="cadastro-usuario-externo" class="text-primary">Cadastro de Usuário Externo</h3>
                <hr>
                <div class="card-body">
                    <p class="card-text">
                        O cadastro de usuário externo é necessário para inclusão de documentos em
                        processos e assinatura de contratos, convênios, termos, acordos e outros
                        instrumentos congêneres celebrados com o órgão por meio do SEI.
                    </p>
                    <p class="card-text">
                        O cadastro também pode ser requerido para acesso a processos categorizados como
                        restritos ou sigilosos.
                    </p>
                </div>
            </div>
            <div class="container pt-5 mt-5">
                <h4 id="passos-cadastro">Cadastro</h4>

                <ol>
                    <li>
                        <strong>Acesse o ambiente Usuário Externo do SEI;</strong>
                    </li>
                    <li>
                        <strong>Clique na opção “Clique aqui para se cadastrar”;</strong>
                    </li>
                    <li>
                        <strong>Leia com atenção as orientações da tela seguinte.</strong>
                    </li>
                    <li>
                        <strong>Opte por continuar e preencha todos os campos da tela “Cadastro de
                            Usuário Externo” com os seus dados pessoais (os obrigatórios estão em
                            negrito).</strong><br>
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/cadastroexterno.png') }}"
                            class="img-fluid" alt="Cadastro Externo">
                    </li>
                    <li>
                        <strong>Após realizar o cadastro online, onde serão registrados o seu e-mail e
                            senha, será enviado um e-mail com as instruções para ativação do seu
                            cadastro.</strong><br>
                        <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                            <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                                alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                            &nbsp;&nbsp;&nbsp;
                            <p class="mb-0 ">
                                O e-mail e a senha informados no formulário de cadastro serão utilizados
                                para
                                acessar o sistema e assinar documentos.
                            </p>
                        </div>
                        <br>
                        <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                            <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                                alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                            &nbsp;&nbsp;&nbsp;
                            <p class="mb-0 ">
                                Sugerimos que não sejam utilizados e-mails institucionais no cadastro.
                            </p>
                        </div>
                        <br>
                        <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                            <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/lampada.png') }}"
                                alt="Lâmpada" class="me-3" style="max-width: 100px;"> &nbsp;&nbsp;&nbsp;
                            <p class="mb-0 ">
                                Lembre-se de que este é o seu cadastro de usuário externo. Não inclua
                                informações da sua empresa ou da pessoa jurídica que você representa.
                                Certifique-se de que o endereço de e-mail pessoal foi digitado corretamente
                                e em letras minúsculas. Crie uma senha segura e não a compartilhe com outras
                                pessoas.
                            </p>
                        </div>
                    </li>
                    <br>
                    <li>
                        <strong>Os documentos necessários são:</strong>
                        <ul>
                            <li>Comprovante de Residência;</li>
                            <li>RG e CPF ou passaporte (para estrangeiros);</li>
                            <li>Termo de Declaração de Concordância e Veracidade preenchido e assinado.</li>
                        </ul>
                    </li>
                    <li>
                        <strong>Os documentos podem ser entregues:</strong>
                        <ul>
                            <li><strong>Presencialmente:</strong> Leve cópia dos documentos juntamente com o
                                original para autenticação.</li>
                            <li><strong>Por correios:</strong> As cópias devem ser autenticadas em cartório
                                e o Termo assinado com reconhecimento de firma.</li>
                            <li><strong>Eletronicamente:</strong> Enviar os documentos através do e-mail ou
                                do Atende SEI, com duas opções de autenticação.</li>
                        </ul>
                    </li>

                    <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}" alt="Megafone"
                            class="me-3" style="max-width: 100px;"> &nbsp;&nbsp;&nbsp;
                        <p class="mb-0 ">
                            Documentos complementares podem ser solicitados para a efetivação do
                            cadastro.
                        </p>
                    </div>
                    <br>

                    <li>
                        <strong>Obs:</strong> O usuário externo deve guardar os documentos originais pois
                        podem ser futuramente solicitados.
                    </li>
                    <li>
                        <strong>Após a análise da documentação, você receberá um e-mail confirmando a
                            conclusão da análise e confirmação do cadastro.</strong>
                    </li>
                </ol>
            </div>
            <div class="container">
                <h4 id="alteracao-dados-cadastrais">Alteração de dados Cadastrais</h4>
            </div>
            <div class="container">

                <p>Para alterar os dados cadastrados no SEI, é
                    necessária a abertura de um chamado junto ao Atende SEI. Os pedidos devem vir
                    acompanhados de Termo de Declaração de Concordância e Veracidade preenchido com os novos
                    dados e assinado.</p>

                <p><strong>Em casos de alteração de nome ou endereço, é necessário o envio do comprovante
                        atualizado.</strong></p>
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}" alt="Megafone"
                        class="me-3" style="max-width: 100px;"> &nbsp;&nbsp;&nbsp;
                    <p class="mb-0 ">
                        Atenção: apenas o portador do CPF cadastrado no sistema pode solicitar alterações em
                        seu
                        cadastro!
                    </p>
                </div>
                <br>
            </div>
            <div class="container pt-5 mt-5">
                <h3 class="text-primary">Login e Recuperação de Senha</h3>
                <hr>

                <h4>Tela de Login</h4>
                <p>Somente depois do cadastro liberado será possível realizar login na página de Acesso
                    Externo do SEI.</p>
                <p>Você receberá um e-mail quando o seu cadastro for liberado. Até lá, ao tentar efetuar o
                    login, o SEI exibirá a seguinte mensagem:</p>

                <div class="alert alert-info">
                    Caso já tenha recebido o e-mail informando sua liberação, acesse o sistema usando o
                    e-mail e a senha cadastrados anteriormente e clique em "Entrar".
                </div>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/login.png') }}" alt="Tela de Login"
                    class="img-fluid">

                <h4>Recuperar Senha de Acesso</h4>
                <p>Caso tenha esquecido a senha de acesso, SOMENTE SE O CADASTRO JÁ ESTIVER LIBERADO, será
                    possível recuperá-la. Para isso, basta clicar na opção “<strong>Esqueci minha
                        senha</strong>” na tela inicial:</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/login2.png') }}"
                    alt="Tela Esqueci minha senha" class="img-fluid">

                <p>A tela abaixo será exibida, onde você deve digitar o e-mail informado no momento do
                    cadastro online para que uma nova senha seja gerada e enviada para o e-mail cadastrado.
                    <strong>Atenção:</strong> lembre-se de verificar a caixa de spam de seu e-mail caso a
                    nova senha não esteja na sua caixa de entrada.
                </p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/novasenha.png') }}" alt="Tela Nova Senha"
                    class="img-fluid">

                <p>Caso o e-mail digitado esteja correto e o cadastro já tenha sido liberado, a seguinte
                    mensagem aparecerá na tela:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/aviso-email.png') }}"
                    alt="Aviso E-mail" class="img-fluid">


                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}" alt="Megafone"
                        class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">
                        <strong>Dica:</strong> Copie e cole a senha recebida para evitar erros de digitação.
                    </p>
                    <br>
                </div>
                <br>

                <h4>Alterar Senha</h4>
                <p>Acesse o link informado no e-mail, efetue o login com a senha gerada pelo sistema e
                    realize a alteração da senha.</p>

                <p>Para alterar a senha, acesse no menu lateral a opção "<strong>Alterar senha</strong>" e
                    siga os passos abaixo:</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/91230.png') }}" alt="Alterar Senha"
                    class="img-fluid">

                <p>Após preencher os campos e clicar em "Salvar", caso não haja erros de digitação, a
                    seguinte mensagem será exibida, confirmando a alteração:</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/senhaalterada.png') }}"
                    alt="Alteração de Senha" class="img-fluid">
            </div>
            <div class="container pt-5 mt-5">
                <div id="controle-acessos-externos" class="container pt-5 mt-5">
                    <h3 class="text-primary">Controle de Acessos Externos</h3>
                    <hr>
                    <p>Após realizar o login no ambiente de usuário externo do SEI, você será direcionado
                        para a tela "Controle de Acessos Externos". Nesta tela, serão exibidos todos os
                        processos disponíveis para consulta ou interação com seu usuário externo.</p>

                    <h4>Menu Lateral</h4>
                    <p>No menu lateral, são exibidas as funcionalidades disponíveis para usuários externos
                        do
                        SEI:</p>
                    <ul>
                        <li><strong>Controle de Acessos Externos:</strong> Retorna para a tela inicial do
                            usuário logado;</li>
                        <li><strong>Alterar Senha:</strong> Permite que o usuário altere a senha;</li>
                        <li><strong>Pesquisa Pública:</strong> Permite que o usuário realize pesquisa de
                            processos e documentos no âmbito do SEI;</li>
                        <li><strong>Peticionamento:</strong> Permite que usuários criem processos ou insiram
                            documentos em processos existentes no SEI;</li>
                        <li><strong>Recibos Eletrônicos de Protocolo:</strong> Permite consultar o recibo de
                            todos os peticionamentos realizados pelo usuário no SEI;</li>
                        <li><strong>Intimações Eletrônicas:</strong> Permite consultar as intimações geradas
                            para seu usuário no SEI.</li>
                    </ul>
                    <p>Na tela “Controle de Acessos Externos” estarão listados os processos liberados para
                        acesso externo, assinatura de documentos e/ou inclusão de documentos.
                    </p>
                    <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                            alt="Megafone" class="me-3" style="max-width: 100px;"> &nbsp;&nbsp;&nbsp;
                        <p class="mb-0 ">
                            A mensagem "Nenhum registro encontrado" indica que não foi disponibilizado
                            processo
                            nem realizado peticionamento para seu usuário até o momento.
                        </p>

                    </div>
                    <br>
                    <p>Na tela “Controle de Acessos Externos”, estarão listados os processos liberados para
                        acesso externo, assinatura de documentos e/ou inclusão de documentos.</p>
                    <p>Aqui estão os detalhes dos ícones e funcionalidades:</p>
                    <ul>
                        <li>Os documentos liberados para assinatura são sinalizados com o ícone <img
                                style="width: 1.7rem;" src="{{ asset('sei-angra/assets/manual/assinar-icone.png') }}"
                                class="img-fluid"> na coluna ações.</li>
                        <li>Os processos com permissão para inclusão de documentos são sinalizados com o
                            ícone
                            <img class="img-fluid" src="../assets/manual/upload-01.png" alt="Ícone de Upload"
                                style="width: 20px;" /> na coluna ações.
                        </li>
                    </ul>

                    <h4>Consulta de Processos Expirados ou Válidos</h4>
                    <p>Você pode clicar em <strong>"Ver expirados"</strong> para consultar os processos onde
                        o
                        prazo de disponibilização está vencido. Para retornar à tela anterior, clique em
                        <strong>"Ver válidos"</strong>.
                    </p>

                    <h4>Visualização de Processos</h4>
                    <p>Os processos e documentos disponíveis para visualização são sinalizados pela
                        numeração em
                        azul. Clique sobre o número azul para acessar o conteúdo.</p>

                    <h4>Menu Lateral</h4>
                    <p>O botão <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/menu4.png') }}"
                            alt="Ícone de Menu" style="width: 20px;" />
                        permite ocultar ou mostrar o menu lateral do sistema.</p>

                    <h4>Logout</h4>
                    <p>Utilize o botão <img class="img-fluid"
                            src="{{ asset('sei-angra/assets/manual/logoutsei.png') }}" alt="Ícone de Logout"
                            style="width: 20px;" /> para sair do sistema com
                        segurança.</p>

                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/controleexterno1.png') }}"
                        alt="Imagem do Controle de Acessos Externos" class="img-fluid">
                </div>
            </div>

            <div class="container pt-5 mt-5">
                <div class="container pt-5 mt-5">
                    <h3 class="text-primary">Acesso Externo aos Processos</h3>
                    <hr>

                    <p>Quando é concedido Acesso Externo aos processos?</p>
                    <p>O acesso será concedido nas seguintes situações:</p>
                    <ul>
                        <li><strong>Durante o trâmite do processo:</strong> O acesso será concedido aos
                            interessados, quando houver uma ação de um usuário interno. Caso o usuário
                            externo
                            tenha realizado um peticionamento, ao ser tomada uma decisão pela autoridade
                            competente, ele receberá um e-mail para ciência da decisão.</li>
                        <li><strong>Pedido de vistas:</strong> Quando o processo for restrito e não
                            acessível
                            na “Pesquisa Pública” do SEI, o usuário externo deve entrar em contato com a
                            unidade responsável para solicitar a liberação de acesso.</li>
                    </ul>
                    <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                        <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                            alt="Megafone" class="me-3" style="max-width: 100px;"> &nbsp;&nbsp;&nbsp;
                        <p class="mb-0 ">
                            A
                            liberação do processo só pode ser feita pelo setor responsável pelo processo ou
                            por
                            onde
                            o processo já tenha passado. A Equipe SEI não realiza a liberação de processos
                            de
                            outros órgãos ou setores.
                        </p>
                    </div>
                    <br>

                    <p><strong>Tipos de Acesso Externo</strong> </p>
                    <p>Existem duas formas de acesso externo ao processo: Integral ou Parcial. O acesso será
                        disponibilizado por um período limitado. Para acessar o processo, não é necessário
                        ter
                        cadastro no SEI, mas para interações adicionais, como a inclusão de documentos ou
                        peticionamento, será necessário ter cadastro.</p>

                    <p>Quando um processo for disponibilizado, os documentos estarão acessíveis e marcados
                        com
                        um link azul. O tipo de liberação pode ser confirmado no topo da tela de consulta ao
                        processo.</p>

                    <div class="row">
                        <div class="col-6">
                            <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/acessointegral.png') }}"
                                    alt="Acesso Integral" class="img-fluid"></p>
                        </div>
                        <div class="col-6">
                            <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/acessoparcial.png') }}"
                                    alt="Acesso Parcial" class="img-fluid"></p>
                        </div>
                    </div>

                    <h3 class="text-primary mt-5 pt-5">Acesso com Permissão de Inclusão de Documento</h3>
                    <hr>
                    <p>A versão 4.0 do SEI trouxe a possibilidade de incluir documentos ao disponibilizar um
                        processo para o usuário externo. Quando disponível, o ícone <img
                            src="{{ asset('sei-angra/assets/manual/upload-01.png') }}" alt="Ícone de Upload"
                            style="width: 20px;" />
                        aparece na coluna ações.</p>

                    <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/incdocumento.png') }}"
                            alt="Inclusão de Documento" class="img-fluid"></p>

                    <h4>Como Incluir um Documento?</h4>
                    <ol>
                        <li>Clique no ícone de seta ao lado do processo para abrir a tela de Inclusão de
                            Documento.</li>
                        <li>Selecione o tipo de documento que deseja incluir no processo.</li>
                        <li>Clique em "Escolher Arquivo..." para selecionar o arquivo desejado do seu
                            computador.</li>
                    </ol>

                    <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/inctipo.png') }}"
                            alt="Seleção do Tipo de Documento" class="img-fluid"></p>

                    <p>Após selecionar o arquivo, o sistema irá carregá-lo e o nome do arquivo será exibido
                        na
                        tela. Clique em "Salvar" para concluir a inclusão.</p>

                    <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/incescolher.png') }}"
                            alt="Escolha do Arquivo" class="img-fluid">
                    </p>
                    <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/incsalvar.png') }}"
                            alt="Salvar Documento" class="img-fluid">
                    </p>

                    <p>Após salvar, o sistema mostrará a confirmação de que o documento foi incluído no
                        processo. O Número SEI do documento inserido será exibido na parte superior da tela.
                    </p>

                    <p><img class="img-fluid" src="{{ asset('sei-angra/assets/manual/confirmacaoexterno.png') }}"
                            alt="Confirmação de Inclusão" class="img-fluid"></p>

                    <h3 class="text-primary mt-5 pt-5">Assinatura Externa</h3>
                    <hr>
                    <p>Para assinar documentos como usuário externo no SEI, você deve primeiro ter cadastro
                        e
                        estar liberado para acessar o ambiente de usuário externo. Após isso, a área
                        responsável
                        pela criação do documento pode liberá-lo para sua assinatura.</p>

                    <p>O sistema enviará um aviso por e-mail quando um documento estiver disponível para
                        assinatura. É importante também checar periodicamente os processos e documentos
                        disponíveis dentro do SEI.</p>

                    <h4>Como Assinar um Documento?</h4>
                    <p>Na tela Controle de Acessos Externos, os processos com Acesso Externo aparecerão
                        listados, e a coluna "Ações" exibirá as funcionalidades específicas. O ícone <img
                            style="width: 1.7rem;" src="{{ asset('sei-angra/assets/manual/assinar-icone.png') }}"
                            class="img-fluid">
                        indica que há um documento para ser assinado. Clique sobre o
                        número azul na coluna "Documento para assinatura" para consultar o conteúdo antes de
                        assiná-lo.</p>

                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/assinaturadoc.png') }}"
                        alt="Assinatura de Documento" class="img-fluid">

                    <p>Após consultar, clique no ícone da caneta para abrir a janela de “Assinatura de
                        Documento”. Insira a senha e, caso o campo "Cargo/Função" esteja vazio, selecione
                        "Usuário Externo". Depois, clique em “Assinar” para concluir.</p>

                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/consultadoc.png') }}"
                        alt="Consulta ao Documento" class="img-fluid">
                    <br>
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/assinardoc.png') }}"
                        alt="Assinatura de Documento" class="img-fluid">
                </div>
            </div>

            <div class="container pt-5 mt-5">
                <h2 class="text-primary">Peticionamento Eletrônico</h2>
                <hr>
                <p>O Peticionamento Eletrônico é uma ferramenta do SEI que permite ao cidadão o envio de
                    documentos eletrônicos, com o objetivo de formar um novo processo ou compor um processo
                    já existente. Para utilizar essa funcionalidade, o interessado deve estar previamente
                    credenciado no SEI.</p>

                <p><strong>Existem duas formas de peticionamento:</strong></p>

                <ul>
                    <li><strong>Processo Novo:</strong> Os documentos protocolizados serão formalizados em
                        um novo processo, que será enviado para uma unidade predefinida no sistema.</li>
                    <li><strong>Intercorrente:</strong> Os documentos protocolizados podem:
                        <ul>
                            <li>Ser formalizados em um novo processo, que será relacionado automaticamente
                                ao processo indicado pelo usuário externo no momento do peticionamento. O
                                processo será enviado para a unidade onde o processo principal teve sua
                                última tramitação ou onde está em andamento. Caso o processo indicado esteja
                                concluído, ele será reaberto automaticamente nessa unidade.</li>
                            <li>Ser incluídos diretamente no processo informado pelo usuário externo. Caso o
                                processo indicado esteja concluído, ele será reaberto automaticamente na
                                última unidade por onde tramitou.</li>
                        </ul>
                    </li>
                </ul>

                <p><strong>ATENÇÃO!</strong> O usuário externo receberá automaticamente acesso ao conteúdo
                    dos documentos peticionados
                    por ele. No entanto, ele não terá acesso aos novos documentos gerados internamente no
                    SEI, quando categorizados como restritos, até que a unidade por onde o processo tramita
                    disponibilize o acesso.</p>

            </div>

            <div class="container pt-5 mt-5">
                <h3 id="peticionamento-processos-novos">Peticionamento Eletrônico de Processos Novos</h3>
                <hr>
                <p>Para realizar o peticionamento, acesse o ambiente de usuário externo com seu login e
                    senha cadastrados. No menu lateral da tela "Controle de Acessos Externos", clique na
                    opção <strong>Peticionamento</strong> ▼ e depois em <strong>Processo Novo</strong>.</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/petnovo.png') }}"
                    alt="Tela de peticionamento de processo novo">

                <p>A tela "Peticionamento de Processo Novo" será exibida. Leia com atenção as Orientações
                    Gerais e escolha o tipo de processo que deseja iniciar. Caso não saiba qual tipo
                    escolher, selecione "Peticionamento: Manifestação de Usuário Externo".</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/peticnovoescolha.png') }}"
                    alt="Escolha do tipo de processo">
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/lampada.png') }}"
                        alt="Dica sobre tipos de processo" class="me-3" style="max-width: 100px;">
                    &nbsp;&nbsp;&nbsp;
                    <p class="mb-0 ">
                        Ao passar o cursor sobre os tipos de processos, você terá mais informações sobre
                        cada um.
                    </p>
                </div>
                <br>


                <h4>Após selecionar o Tipo do Processo:</h4>
                <p>Você será direcionado para a página de inclusão de documentos e informações no processo.
                    No painel "Formulário de Peticionamento", insira a especificação do processo e indique o
                    interessado.</p>
                <ul>
                    <li><strong>Especificação:</strong> Insira uma descrição que permita identificar seu
                        pedido facilmente (limite de 100 caracteres).</li>
                    <li><strong>Interessados:</strong> Informe se o pedido é referente a uma Pessoa Física
                        (informe o CPF) ou Pessoa Jurídica (informe o CNPJ). Clique em "Validar". Se o
                        interessado não estiver cadastrado, uma tela de cadastro será aberta.</li>
                </ul>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/formpeticionamento.png') }}"
                    alt="Formulário de peticionamento">
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/lampada.png') }}"
                        alt="Dica sobre tipos de processo" class="me-3" style="max-width: 100px;">
                    &nbsp;&nbsp;&nbsp;
                    <p class="mb-0 ">
                        Verifique, no topo da tela, se o tipo de processo escolhido é o correto, caso não
                        seja, clique em voltar.
                    </p>
                </div>
                <br>

                <h4>Adicionando Interessados:</h4>
                <p>Repita os passos até adicionar todos os interessados. Após isso, é hora de inserir os
                    documentos no processo.</p>
                <br>
                <h4>Inserção de Documentos:</h4>
                <p>O peticionamento de Processo Novo é composto por três grupos de documentos:</p>
                <ul>
                    <li><strong>Documento Principal:</strong> O documento onde você faz a solicitação. Pode
                        ser interno (editado no SEI) ou externo (anexo, em formato pdf).</li>
                    <li><strong>Documentos Essenciais:</strong> São documentos essenciais para análise do
                        peticionamento. Todos devem ser anexados.</li>
                    <li><strong>Documentos Complementares:</strong> Esses documentos são opcionais, mas
                        podem ser anexados para complementar sua solicitação.</li>
                </ul>
                <br>

                <h4 id="documento-principal-interno">Documento Principal Interno:</h4>
                <p>Documentos internos são aqueles gerados no editor de textos do SEI. Caso o processo
                    escolhido tenha como documento principal um interno, a tela mostrará um link para abrir
                    o editor de textos.</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/docprincipalinterno.png') }}"
                    alt="Documento principal interno">
                <br>
                <p>Preencha o documento com os dados de sua solicitação e clique em "Salvar".</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/editorSEI.png') }}"
                    alt="Editor de documentos SEI">
                <br>
                <h4 id="documentos-externos">Documentos Externos:</h4>
                <p>Documentos externos são gerados fora do SEI. Ao inserir um documento externo, clique
                    em "Escolher Arquivo", selecione o arquivo e preencha as informações sobre o documento.
                </p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/docprincipalexterno.png') }}"
                    alt="Escolher arquivo para documento externo">
                <br>
                <p>A inclusão de um documento externo é feita em seis passos:</p>
                <ol>
                    <li>Escolher o arquivo a ser inserido (preferencialmente em formato PDF).</li>
                    <li>Selecionar o tipo de documento inserido.</li>
                    <li>Preencher o complemento com a informação sobre o documento.</li>
                    <li>Escolher o nível de acesso: Público ou Restrito.</li>
                    <li>Informar se o documento é Digitalizado ou Nato-digital.</li>
                    <li>Clicar em "Adicionar" para carregar o arquivo.</li>
                </ol>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/docexternopet.png') }}"
                    alt="Formato de documento externo">
                <br>
                <h4 id="formato-documento">Formato do documento</h4>
                <ul>
                    <li>Nato-digital: Documento criado no meio eletrônico, como um documento word, planilha
                        excel, planta do autocad;</li>
                    <li>Digitalizado: Documento que foi digitalizado a partir de um documento em papel. Ao
                        escolher o formato do tipo digitalizado, o campo conferência será exibido:</li>
                </ul>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/formato-doc.png') }}"
                    alt="Formato de documento externo">
                <h4>Atenção Especial para Documentos Essenciais:</h4>
                <p>O sistema só permitirá concluir o peticionamento após a inclusão de, pelo menos, um
                    arquivo para cada tipo de documento solicitado. Caso falte algum documento, o sistema
                    mostrará a mensagem de erro correspondente.</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/docsessenciais.png') }}"
                    alt="Exemplo de documentos essenciais">
                <br>
                <h4 id="concluindo-peticionamento">Conclusão do Peticionamento:</h4>
                <p>Após preencher todos os campos do "Formulário de Peticionamento" e incluir todos os
                    documentos solicitados, clique em "Peticionar".</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/Concluirpetnovo.png') }}"
                    alt="Concluir peticionamento">
                <br>
                <p>O sistema abrirá a janela "Concluir Peticionamento - Assinatura Eletrônica", onde será
                    necessário inserir a senha para confirmar o peticionamento.</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/concluirpetnovo2.png') }}"
                    alt="Assinatura eletrônica para concluir peticionamento">
                <br>
                <h4>Após o Processamento:</h4>
                <p>O sistema gera automaticamente um Recibo Eletrônico de Protocolo e o inclui no processo.
                    O órgão/setor responsável dará prosseguimento à análise e atendimento da sua
                    solicitação.</p>
            </div>

            <div class="container pt-5 mt-5">
                <h3 id="peticionamento-intercorrente">Peticionamento Eletrônico para Processos Já Existentes
                    (Intercorrente)</h3>
                <hr>
                <p>Para realizar o peticionamento, acesse o ambiente de usuário externo com seu login e
                    senha cadastrados. No menu lateral da tela "Controle de Acessos Externos", clique na
                    opção <strong>Peticionamento</strong> ▼ e depois em <strong>Intercorrente</strong>.</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/controle-de-acessor-externo1.png') }}"
                    alt="Tela de Resposta à Intimação" class="img-fluid mb-3">


                <p>A tela "Peticionamento Intercorrente" será exibida. Leia com atenção as Orientações
                    Gerais, informe o número do processo no qual deseja incluir documentos e clique em
                    <strong>Validar</strong>. Se o número informado estiver correto, irá aparecer no campo
                    "Tipo" o tipo processual da numeração informada, estando de acordo, clique em
                    <strong>Adicionar</strong>.
                </p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/peticionamento-intercorrente1.png') }}"
                    alt="" class="img-fluid mb-3">

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/Petintercorrentedocs (1).png') }}"
                    alt="" class="img-fluid mb-3">

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/Petintercorrentedocs (2).png') }}"
                    alt="" class="img-fluid mb-3">
                <br>
                <p>Após a indicar o número do processo em que deseja realizar o peticionamento, a seção
                    “Documentos” é exibida. Basta seguir os passos descritos acima. O sistema critica os
                    campos obrigatórios e também as extensões de arquivos permitidas.</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/passos-documentos1.png') }}"
                    alt="" class="img-fluid mb-3">~
                <br>
                <p>Depois de adicionar todos os documentos que pretende peticionar, clique em "Peticionar".
                    O sistema abrirá a janela "Concluir Peticionamento - Assinatura Eletrônica" onde será
                    necessário inserir a senha para confirmar o peticionamento. Caso não venha preenchido o
                    campo "Cargo/Função", selecione a opção "Usuário Externo" e depois digite sua senha e
                    clique em “Assinar”.</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/concluir-peticionamento.png') }}"
                    alt="" class="img-fluid mb-3">
                <br>
                <p>Depois que o processamento do peticionamento é finalizado, o sistema gera automaticamente
                    um Recibo Eletrônico de Protocolo para o usuário externo, que também é incluído no
                    processo.</p>
                <p>Os processos de peticionamento intercorrente serão apresentados nas unidades onde o
                    processo indicado pelo usuário externo está em andamento, ou onde foi concluído (neste
                    caso, é reaberto).</p>
            </div>

            <div class="container pt-5 mt-5">
                <h3 id="recibos-eletronicos">Recibos Eletrônicos</h3>
                <hr>
                <p>Todos os peticionamentos realizados por usuários externos no SEI geram um Recibo
                    Eletrônico de Protocolo que fica disponível dentro do processo e pode ser consultado
                    através da opção "Recibos Eletrônicos de Protocolo" no menu lateral.</p>
                <img class="img-fluid"
                    src="{{ asset('sei-angra/assets/manual/recibos-eletronicos-de-protocolos.png') }}" alt=""
                    class="img-fluid mb-3">

                <p>Para visualizar o conteúdo de um recibo, basta clicar no ícone Consultar-01.png e uma
                    nova aba será aberta para exibir o conteúdo.</p>
                <p>No Recibo Eletrônico, você pode visualizar as seguintes informações:</p>
                <ul>
                    <li>Data e horário do peticionamento realizado;</li>
                    <li>Tipo de Peticionamento (novo ou intercorrente);</li>
                    <li>Número de Processo em que o peticionamento foi realizado;</li>
                    <li>Interessados informados no processo;</li>
                    <li>Lista de documentos inseridos através do Peticionamento com o número SEI.</li>
                </ul>


                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/recibo.png') }}"
                    alt="Recibo Eletrônico" class="img-fluid mb-3">
                <p>Para visualizar o conteúdo de um recibo, basta clicar no ícone correspondente.</p>
            </div>

            <div class="container pt-5 mt-5">
                <h2 class="text-primary">Intimação Eletrônica</h2>
                <hr>
                <p>A funcionalidade de intimação eletrônica permite aos órgãos a comunicação direta com os
                    usuários externos para ciência, cumprimento de exigências e outras comunicações
                    necessárias. Quando uma intimação for direcionada a um usuário externo, este receberá em
                    seu e-mail cadastrado uma notificação para verificar esta intimação.</p>
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                        alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">&nbsp;&nbsp;&nbsp;
                        Mesmo que o usuário não verifique este e-mail, se faz necessário o acesso ao módulo
                        do usuário externo periodicamente para a verificação se existe ou não intimações a
                        receber.
                    </p>
                </div>

                <br>
                <h3 id="consultar-intimacao">Consultar Intimação</h3>
                <hr>
                <p>As intimações são exibidas na tela de controle de processos do módulo:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/iconeintimacao.png') }}"
                    alt="Ícone de Intimação" class="img-fluid mb-3">

                <p>Para acessar o processo e consultar a intimação, clique no ícone "Controle de Acessos
                    Externos". A tela abaixo será exibida:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/consultaintimacao.png') }}"
                    alt="Tela de Consulta de Intimação" class="img-fluid mb-3">

                <h4>Confirmar Intimação</h4>
                <p>Clique no cadeado para consultar a intimação e liberar o acesso ao documento. Após a
                    confirmação, novos ícones estarão disponíveis para ações:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/confirmarintimacao.png') }}"
                    alt="Confirmar Intimação" class="img-fluid mb-3">


                <p>O ícone <img style="width: 2.5rem;"
                        src="{{ asset('sei-angra/assets/manual/intimacao_cumprida_doc_principal.png') }}"
                        alt="Confirmar Intimação" class="img-fluid"> permite o acesso ao documento da
                    intimação.</p>
                <p>O ícone <img style="width: 2.5rem;"
                        src="{{ asset('sei-angra/assets/manual/certidao-verde.png') }}" alt="Confirmar Intimação"
                        class="img-fluid"> permite o acesso a Certidão de
                    Intimação, gerada no momento da confirmação a consulta.
                </p>
                <p>O ícone <img style="width: 2.5rem;" src="{{ asset('sei-angra/assets/manual/int_responder.png') }}"
                        alt="Confirmar Intimação" class="img-fluid"> da carta com uma seta azul permite a
                    realização de peticionamento intercorrente para resposta a uma intimação.</p>

                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                        alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">&nbsp;&nbsp;&nbsp;
                        Os termos "Intimação cumprida" e "Intimação respondida" correspondem a situações
                        diferentes. Uma intimação só será respondida após a efetivação do Peticionamento de
                        Resposta à Intimação.
                    </p>
                </div>
                <br>
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                        alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">&nbsp;&nbsp;&nbsp;
                        O ícone "Responder Intimação Eletrônica" só ficará disponível durante o prazo de
                        resposta da intimação, máximo de 30 dias.
                    </p>
                </div>
                <br>
                <p>Também é possível consultar todas as intimações geradas para seu usuário externo clicando
                    em "Intimações Eletrônicas" no menu lateral. As intimações serão exibidas da seguinte
                    forma:</p>

                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/consultaintimacoes.png') }}"
                    alt="Tela de Consultar Intimações" class="img-fluid mb-3">

                <h4 id="responder-intimacao">Responder a Intimação</h4>
                <p>As respostas às intimações são realizadas por meio de peticionamento. Ao clicar no ícone
                    "Responder Intimação", a tela abaixo será exibida:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/respintimacao.png') }}"
                    alt="Tela de Resposta à Intimação" class="img-fluid mb-3">

                <p>O campo "Tipo de Resposta" lista as opções disponíveis para a intimação, caso esteja
                    dentro do prazo. Caso não esteja, utilize a opção de Peticionamento Intercorrente no
                    menu principal.</p>
                <p>Selecione o tipo de resposta desejado e o painel de documentos será exibido para que você
                    inclua a petição.</p>

                <h5>Incluir Documentos</h5>
                <p>Para incluir os documentos de resposta, basta seguir os passos descritos acima:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/petrespintimacao.png') }}"
                    alt="Incluir Documentos de Resposta" class="img-fluid mb-3">

                <h5>Recibo de Resposta</h5>
                <p>Após concluir o peticionamento, o andamento do processo será atualizado. O ícone "Recibo"
                    permitirá a consulta do recibo do peticionamento de resposta realizado:</p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/recibo-de-resposta.png') }}"
                    alt="Recibo de Resposta" class="img-fluid mb-3">
                <p>A intimação será marcada como "Intimação Respondida" após o peticionamento.</p>
            </div>
            <div class="container pt-5 mt-5">
                <h3 class="text-primary" id="pesquisar-processos">Pesquisar Processos</h3>
                <hr>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/pesquisa-publica.png') }}"
                    alt="Pesquisa Pública" class="img-fluid mb-3">
                <ol>
                    <li>Informe o número do processo ou documento que deseja consultar;</li>
                    <li>Insira o código de validação. Atenção para a diferença entre letras maiúsculas e
                        minúsculas;</li>
                    <li>Clique em Pesquisar.</li>
                </ol>
                <p>O resultado da pesquisa será exibido. Para visualizá-lo clique no número do processo, que
                    estará destacado em azul.
                </p>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/resultado-pesquisa.png') }}"
                    alt="Pesquisa Pública" class="img-fluid mb-3">
                <p>Você será direcionado para a tela com as informações gerais do processo, seus documentos
                    e os andamentos/movimentações do processo.</p>
                <p>O primeiro bloco de informações, chamado Autuação traz as informações gerais do processo,
                    como data de registro, tipo processual e os interessados do processo, se houver.</p>
                <p>Logo abaixo, virá a Lista de Protocolos, que mostra todos os documentos vinculados ao
                    processo. Apenas documentos públicos inseridos em processos públicos ficarão disponíveis
                    para consulta de seu conteúdo.</p>
                <p>Por fim, a Lista de Andamentos traz as informações sobre a tramitação e interação com
                    usuários externos realizada no processo.</p>
                <br>
                <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/consulta-de-processos-pesq.png') }}"
                    alt="Pesquisa Pública" class="img-fluid mb-3">
                <br>
                <div class="d-flex align-items-center mt-4 shadow p-4 rounded-3">
                    <img class="img-fluid" src="{{ asset('sei-angra/assets/manual/megafone.png') }}"
                        alt="Ícone de megafone" class="me-3" style="max-width: 100px;">
                    <p class="mb-0 ">&nbsp;&nbsp;&nbsp;
                        Os documentos restritos não estarão disponíveis para visualização na Pesquisa
                        Pública.
                    </p>
                </div>
            </div>

            <div class="container pt-5 mt-5">
                <h3 class="text-primary" id="acesso-externo-processos">Acesso Externo aos Processos</h3>
                <hr>
                <p>O acesso a documentos públicos de um processo público pode ser realizado livremente, sem
                    necessidade de cadastro como usuário externo, conforme explicado abaixo:</p>
                <h4>Pesquisa Pública</h4>
                <p>A Pesquisa Pública do SEI é uma ferramenta que possibilita a transparência de processos e
                    documentos dos órgãos e entidades do Poder Executivo do Município de Angra dos Reis.</p>
                <p>Ela não é a mesma usada pelo usuário interno dentro do sistema, quando ele clica em
                    "Pesquisa" no menu na Tela de Controle de processos, conforme demonstrado aqui. A
                    pesquisa pública é um módulo separado com interface própria. Portanto, ao realizar uma
                    pesquisa internamente no SEI, o sistema terá um comportamento diferente do apresentado
                    pelo módulo da pesquisa pública.</p>

                <h5>Comportamento do sistema na pesquisa interna:</h5>
                <hr>
                <div class="container pt-5 mt-5">
                    <table class="table table-bordered table-hover text-center">
                        <thead class="table-dark">
                            <tr>
                                <th class="fw-bold">Processo</th>
                                <th class="fw-bold">Documentos</th>
                                <th class="fw-bold">Conteúdo dos documentos</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>Público</td>
                                <td>Todos públicos</td>
                                <td>Todos disponíveis</td>
                            </tr>
                            <tr>
                                <td>Público</td>
                                <td>Existe ao menos um restrito</td>
                                <td><strong>Todos indisponíveis</strong></td>
                            </tr>
                            <tr>
                                <td>Restrito</td>
                                <td>Todos públicos</td>
                                <td><strong>Todos indisponíveis</strong></td>
                            </tr>
                            <tr>
                                <td>Restrito</td>
                                <td>Existe ao menos um restrito</td>
                                <td><strong>Todos indisponíveis</strong></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                <p>O SEI não mostra o conteúdo dos documentos que estejam autuados em processos restritos ou
                    que tenham assumido o comportamento de restrito (que ocorre quando qualquer documento
                    inserido em um processo público é classificado como restrito), ainda que este documento
                    esteja classificados como público.</p>
                <h6>Comportamento do sistema na pesquisa externa (pesquisa pública):</h6>
                <div class="container pt-5 mt-5">
                    <table class="table table-bordered table-hover text-center">
                        <thead class="table-dark">
                            <tr>
                                <th class="fw-bold">Processo</th>
                                <th class="fw-bold">Documentos</th>
                                <th class="fw-bold">Conteúdo dos documentos</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>Público</td>
                                <td>Todos públicos</td>
                                <td>Todos disponíveis</td>
                            </tr>
                            <tr>
                                <td>Público</td>
                                <td>Existe ao menos um restrito</td>
                                <td>
                                    Documento(s) <strong>restrito(s) indisponível(is)</strong>; Documentos
                                    públicos disponíveis
                                </td>
                            </tr>
                            <tr>
                                <td>Restrito</td>
                                <td>Todos públicos</td>
                                <td><strong>Todos indisponíveis</strong></td>
                            </tr>
                            <tr>
                                <td>Restrito</td>
                                <td>Existe ao menos um restrito</td>
                                <td><strong>Todos indisponíveis</strong></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                <p>Já na pesquisa pública, os documentos públicos tem seu conteúdo disponibilizado, desde
                    que autuado em processo público. Processos restritos e seus respectivos documentos,
                    assim como os documentos classificados como restritos, não poderão ser consultados
                    através da pesquisa pública e o pedido de vistas ao processo deverá ser realizado junto
                    ao órgão que estiver de posse do processo.</p>
                <p>Também é importante ressaltar que o módulo de pesquisa pública do SEI apenas dá acesso
                    aos documentos e processos do Poder Executivo do Município de Angra dos Reis. Essa
                    observação é relevante pois diversos órgãos de outros Poderes, Estados, Municípios e
                    União utilizam o SEI, mas seus documentos precisam ser consultados em suas páginas
                    próprias.</p>


                <p>Quando existir documentos restritos no processo, não sendo acessíveis na Pesquisa Pública
                    do SEI, ou quando o usuário externo necessita acompanhar o andamento do processo do qual
                    é interessado ou procurador legal, bem como assinar contratos, convênios, termos,
                    acordos e outros documentos relativos ao Poder Executivo do Município de Angra dos Reis,
                    é possivel que seja dado vistas ao processo. </p>
            </div>

        </section>

        <!-- Outras seções... -->
    </main>
</div>
