<div class="topo">
    <div class="container">
        <div class="row">
            <div class="col-md-5 col-lg-5 col-xl-5 col-xl-5 col-xxl-5">
                <a href="https://angra.rj.gov.br">
                    <img src="{{ asset('pmar/assets/img/cmgd-logo.svg') }}" class="" alt="Comitê de Governancia Digital" style="width: 100%;">
                </a>
            </div>
        </div>
    </div>
</div>

<div class="topo-nav">
    <nav class="navbar bg-light navbar-expand-lg shadow-lg py-2 rounded-4" id="mainNav">
        <div class="container">
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarResponsive" aria-controls="navbarResponsive" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarResponsive">
                <ul class="navbar-nav my-3 my-lg-0">
                    <li class="nav-item fw-bold"><a class="nav-link me-lg-3 text-dark" href="#estrategia">{{ __("Estratégias Digitais") }}</a></li>
                    <li class="nav-item fw-bold"><a class="nav-link me-lg-3 text-dark" href="#comite">Comitê Gestor</a></li>
                    <li class="nav-item fw-bold"><a class="nav-link me-lg-3 text-dark" href="#atas">Atas e Pareceres</a></li>
                    <li class="nav-item fw-bold"><a class="nav-link me-lg-3 text-dark" href="#legislacao">Legislação</a></li>
                    <li class="nav-item fw-bold"><a class="nav-link me-lg-3 text-dark" href="#cmgd">CMGD</a></li>
                </ul>
            </div>
            <div class="collapsee" id="navbarRespon">
                <a href="#contato" class="my-2 bg-success btn text-white fw-bolder me-lg-3">
                    <i class="fa-solid fa-phone "></i>  Entre em Contato
                </a>
            </div>
        </div>
    </nav>
</div>