<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
    @include('layouts.window.elements.head')
    <meta name="robots">
    <body>
    <section>
        <div class="container-fluid">
            @yield('content')
            @include('layouts.window.elements.footer')
        </div>
    </section>
</body>
</html>
