@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Autores'))

@section('content')
    @include('errors.messageFlash')
    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-user'></i> " . __('Autores'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.legislacao.index',
            'routeBackParams' => request()->only(['q', 'page', 'ano']),
            'nameBack' => __('Legislações'),
            'routeAdd' => 'admin.legislacao.autores.create',
            'routeAddParams' => [],
            'nameAdd' => __('Novo autor'),
            'permission' => 'GERENCIADOR_DE_LEGISLACAO',
        ])
        <div class="card-body">
            <x-tables._table :thead="['#', __('Nome'), __('Cargo'), __('Ações')]" :pagination="$autores->links()">
                <x-slot name="body">
                    @php $i = $autores->firstItem(); @endphp
                    @forelse ($autores as $autor)
                        <tr>
                            <td>{{ $i }}</td>
                            <td>{{ $autor->nm_autor }}</td>
                            <td>{{ $autor->cargo->nm_cargo ?? '-' }}</td>
                            <td>
                                <div class="d-flex justify-content-center gap-2">
                                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['editar'])
                                        <a class="btn btn-sm btn-warning" href="{{ route('admin.legislacao.autores.edit', $autor) }}">
                                            <i class="fa-solid fa-pen-to-square"></i>
                                        </a>
                                    @endif
                                    @if (auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_LEGISLACAO')['excluir'])
                                        <form class="d-inline" method="post" action="{{ route('admin.legislacao.autores.destroy', $autor) }}"
                                            onsubmit="return confirmDelete(this)">
                                            @csrf
                                            @method('delete')
                                            <input type="hidden" name="confirm"
                                                value="{{ __('* Este registro será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                            <button type="submit" class="btn btn-sm btn-danger"><i class="fa-solid fa-trash"></i></button>
                                        </form>
                                    @endif
                                </div>
                            </td>
                        </tr>
                        @php $i++; @endphp
                    @empty
                        <tr>
                            <td colspan="4" class="text-center">{{ __('Nenhum registro encontrado.') }}</td>
                        </tr>
                    @endforelse
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection
