{{ __('Prefeitura Municipal de Angra dos Reis') }}

{{ __('Aviso interno - vencimento CADASTUR') }}
{{ __('Empresas de Turismo - TurisAngra') }}

{{ __('Uma empresa de turismo cadastrada no sistema possui vencimento de CADASTUR previsto para os próximos 30 dias.') }}

{{ __('Razão Social') }}: {{ $empresaTurismo->companhia?->razaoSocial ?? '-' }}
{{ __('Nome Fantasia') }}: {{ $empresaTurismo->companhia?->nomeFantasia ?? '-' }}
{{ __('CNPJ') }}: {{ $empresaTurismo->companhia?->cnpj ?? '-' }}
{{ __('E-mail') }}: {{ $empresaTurismo->companhia?->email ?? '-' }}
{{ __('Cadastur') }}: {{ $empresaTurismo->cadastur }}
{{ __('Vencimento') }}: {{ $empresaTurismo->cadastur_vencimento?->format('d/m/Y') ?? '-' }}

{{ __('Atenção') }}: {{ $mensagem }}

---
{{ __('Prefeitura Municipal de Angra dos Reis') }}
{{ __('Este é um e-mail automático, por favor não responda.') }}
