<tr @if($item->isEmAndamento()) class="table-warning" @endif>
    <td class="fw-semibold">{{ $item->numero }}</td>
    <td>{{ $item->solicitante_nome }}</td>
    <td>{{ $item->unidade->abbreviation ?? '—' }}</td>
    <td>{{ $item->setor_nome ?? $item->setor?->nome ?? '—' }}</td>
    <td>{{ $item->assunto_nome ?? $item->assunto?->nome ?? '—' }}</td>
    <td>{{ $item->subassunto_nome ?? $item->subassunto?->nome ?? '—' }}</td>
    <td>
        @php
            $statusLabel = \App\Models\IndicadoresTi\Chamado::STATUS[$item->status] ?? $item->status;
            $statusClass = match ($item->status) {
                'pendente'     => 'warning',
                'em_andamento' => 'info',
                'atendido'     => 'success',
                default        => 'secondary',
            };
        @endphp
        <span class="badge bg-{{ $statusClass }}">{{ __($statusLabel) }}</span>
    </td>
    <td>
        @php
            $prioLabel = \App\Models\IndicadoresTi\Chamado::PRIORIDADE[$item->prioridade] ?? $item->prioridade;
            $prioClass = match ($item->prioridade) {
                'alta'   => 'danger',
                'critica'=> 'danger',
                'media'  => 'warning',
                'baixa'  => 'success',
                default  => 'secondary',
            };
        @endphp
        <span class="badge bg-{{ $prioClass }}">{{ __($prioLabel) }}</span>
    </td>
    <td>{{ $item->atendente->name ?? '—' }}</td>
    <td>{{ optional($item->data_abertura)->format('d/m/Y H:i') }}</td>
    <td>{{ optional($item->data_fechamento)->format('d/m/Y H:i') ?? '—' }}</td>
    <td>
        @if ($item->isEmAndamento() && $item->data_abertura)
            <span class="badge bg-warning text-dark tempo-em-andamento"
                data-inicio="{{ ($item->data_reabertura ?? $item->data_abertura)->toIsoString() }}"
                data-acumulado="{{ $item->tempo_acumulado ?? 0 }}">
                <i class="fa-solid fa-spinner fa-spin me-1"></i>
                {{ $item->getTempoAtendimentoFormatado() }}
            </span>
        @elseif ($item->data_fechamento)
            <small class="text-muted">{{ $item->getTempoAtendimentoFormatado() }}</small>
        @else
            <small class="text-muted">—</small>
        @endif
    </td>
    <td class="text-center">
        <div class="d-flex gap-1 justify-content-center">
            <a href="{{ route('admin.indicadoresTi.show', ['chamado' => $item->id] + request()->only(['status', 'prioridade', 'setor_id', 'busca'])) }}"
                class="btn btn-sm btn-primary" title="{{ __('Abrir') }}">
                <i class="fa-solid fa-pen-to-square"></i>
            </a>
            @if ($item->status !== 'atendido')
                <form action="{{ route('admin.indicadoresTi.concluir', $item->id) }}" method="POST"
                    onsubmit="return confirm('{{ __('Deseja concluir este chamado?') }}')">
                    @csrf
                    @foreach (request()->only(['status', 'prioridade', 'setor_id', 'busca']) as $k => $v)
                        @if ($v) <input type="hidden" name="{{ $k }}" value="{{ $v }}"> @endif
                    @endforeach
                    <button class="btn btn-sm btn-success" title="{{ __('Concluir') }}">
                        <i class="fa-solid fa-check"></i>
                    </button>
                </form>
            @endif
            @if (
                auth()->user()->getPermissaoDetalhes('SYSADMIN')['excluir']
                || $item->atendente_id === auth()->id()
                || $item->participantes->contains('id', auth()->id())
            )
                <form action="{{ route('admin.indicadoresTi.destroy', $item->id) }}" method="POST"
                    onsubmit="return confirm('{{ __('Excluir permanentemente?') }}')">
                    @csrf @method('DELETE')
                    @foreach (request()->only(['status', 'prioridade', 'setor_id', 'busca']) as $k => $v)
                        @if ($v) <input type="hidden" name="{{ $k }}" value="{{ $v }}"> @endif
                    @endforeach
                    <button class="btn btn-sm btn-danger" title="{{ __('Excluir') }}">
                        <i class="fa-solid fa-trash"></i>
                    </button>
                </form>
            @endif
        </div>
    </td>
</tr>
