@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: Visite Angra - Lista de Atrativos Turísticos')
@section('content')

    @include("errors.messageFlash")

    <div class="card shadow-sm">
        
        @php $headLine = "<i class='fa-solid fa-umbrella-beach fa-2x'></i> Visite Angra - Lista de Atrativos Turísticos"; @endphp
        
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.visiteAngra.index',
            'routeBackParams' => [], 
            'nameBack' => __("Voltar"),
            'routeAdd' => 'admin.visiteAngra.atrativos.create',
            'routeAddParams' => [], 
            'nameAdd' => __('Novo atrativo'),
            "permission" => "GERENCIADOR_VISITE_ANGRA",
        ])

        @include("components.cards._cardNavVisiteAngra")
        
        <div class="card-body">
            
            @include("errors.messageFlash")

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "visiteAngraListaPontoTuristico", 
                "placeholder" => "Pesquisar por atrativo...",
                "permission" => "GERENCIADOR_VISITE_ANGRA",
            ])

            <div class="table-responsive">
            <table class="table table-bordered table-hover table-striped align-middle text-center">
                    @include('components.tables._thead',[
                        "thead" => [
                            'Foto',
                            'Corredor Turístico',
                            'Ponto Turístico',
                            'Atrativo',
                            'Subtitulo',
                            'Status',
                            'Ações',
                        ]
                    ])
                <tbody>
                        @php $index = 0 @endphp
                        @forelse($atrativos as $atrativo)
                    <tr>
                        <td style="width: 200px;">
                                    @include('components.tables._openPhoto',[
                                        'asset' => $atrativo->foto,
                                        'alt' => $atrativo->atrativo,
                                        'title' => $atrativo->atrativo,
                                        'text' => 'Visualizar corredor',
                                        "permission" => "GERENCIADOR_VISITE_ANGRA",
                                    ])
                        </td>
                        <td>{{ $atrativo->corredor?->corredor }}</td>
                        <td>{{ $atrativo->ponto?->ponto }}</td>
                        <td>{{ $atrativo->atrativo }}</td>
                        <td>{{ $atrativo->subtitulo }}</td>
                        <td>
                                    @include('components/buttons/_status', [
                                        "index" => $index,
                                        "route" => "admin.visiteAngra.atrativos.status",
                                        "id" => $atrativo->id,
                                        "status" => $atrativo->status,
                                        "permission" => "GERENCIADOR_VISITE_ANGRA",
                                    ])

                        </td>
                        <td>
                            <div class="btn-group" role="group">
                                @include('components/buttons/_editButton', [
                                    "route" => "admin.visiteAngra.atrativos.edit",
                                    "id" => $atrativo->id,
                                    "fontawesome" => null,
                                    "title" => "Editar",
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])
                                
                                @include("components.buttons._upload",[
                                    "route" => "admin.visiteAngra.atrativos.arquivos.index",
                                    "id" => $atrativo->id,
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])

                                @include('components/buttons/_deleteButton', [
                                    "message" => "* Este atrativo será excluído e esta ação não poderá ser desfeita?",
                                    "route" => "admin.visiteAngra.atrativos.destroy",
                                    "id" => $atrativo->id,
                                    "fontawesome" => null,
                                    "title" => "Excluir",
                                    "permission" => "GERENCIADOR_VISITE_ANGRA",
                                ])
                            </div>
                        </td>
                    </tr>
                            @php $index++ @endphp
                        @empty
                    <tr>
                        <td colspan="7" class="text-muted fst-italic">* Nenhum registro encontrado!</td>
                    </tr>
                        @endforelse
                </tbody>
            </table>
        </div>

        <div class="d-flex justify-content-center mt-4">
                {!! $atrativos->links() !!}
        </div>
    </div>
</div>
@endsection