@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Lista de Empresas de Turismo'))

@push('styles')
    <link rel="stylesheet" href="{{ asset('turismo-nautico/css/empresas-de-turismo-list.css') }}?v={{ @filemtime(public_path('turismo-nautico/css/empresas-de-turismo-list.css')) ?: time() }}">
@endpush

@section('content')

    <div class="card shadow-sm">

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => "<i class='fa-solid fa-water'></i> " . e(__('Lista de Empresas de Turismo')),
            'routeAdd' => 'admin.empresasDeTurismo.verify',
            'routeAddParams' => [],
            'nameAdd' => __('Nova empresa de turismo'),
            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
        ])

        <div class="card-body">
            @include('errors.messageFlash')

            @php $totalRegistros = $empresasTurismo->total(); @endphp
            <div class="pt-3 mb-2" aria-live="polite">
                <span
                    class="badge empresas-turismo-total-badge rounded-pill"
                    title="{{ __(':total registro(s)', ['total' => $totalRegistros]) }}"
                >
                    {{ $totalRegistros }} {{ __('registro(s)') }}
                </span>
            </div>

            @include('admin.turisAngra.empresasDeTurismo.sections._filtrosListagem', [
                'filterParams' => $filterParams,
            ])

            @php
                $listFilterParams = $filterParams;
                $perms = auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_EMPRESAS_DE_TURISMO');
            @endphp

            <x-tables._table
                :thead="[__('Data de Cadastro'), __('Informações'), __('Contatos'), __('Status'), __('Ações')]"
                :theadWidths="['9rem', '', '', '5.5rem', '11rem']"
                tableClass="empresas-turismo-list-table"
                :responsive="false"
                :pagination="$empresasTurismo->links()"
            >
                <x-slot name="body">
                    @php $index = 0; @endphp
                    @foreach($empresasTurismo as $empresaTurismo)
                        @php $empresa = $empresaTurismo->companhia; @endphp

                        <tr>
                            <td>{{ date('d/m/Y H:i', strtotime($empresaTurismo->created_at)) }}</td>
                            <td class="text-start">
                                <strong>{{ __('Razão Social') }}</strong>: {{ $empresa->razaoSocial ?? '-' }}<br>
                                <strong>{{ __('Nome Fantasia') }}</strong>: {{ $empresa->nomeFantasia ?? '-' }}<br>
                                <strong>{{ __('CNPJ') }}</strong>: {{ $empresa->cnpj ?? '-' }}<br>
                                <strong>{{ __('Inscrição Municipal') }}</strong>: {{ $empresa->numeroInscricaoMunicipal ?? '-' }}<br>
                                <strong>{{ __('Cadastur') }}</strong>: {{ $empresaTurismo->cadastur }}
                                @include('components.badges._cadasturVencimentoAlerta', ['empresaTurismo' => $empresaTurismo])
                                <br>
                                <strong>{{ __('Vencimento CADASTUR') }}</strong>:
                                {{ $empresaTurismo->cadastur_vencimento ? $empresaTurismo->cadastur_vencimento->format('d/m/Y') : '-' }}<br>
                            </td>

                            <td class="text-start">
                                <strong>{{ __('E-mail') }}</strong>: {{ $empresa?->email ?: '-' }}<br>
                                <strong>{{ __('Celular') }}</strong>:
                                @if($empresa?->celular)
                                    {{ $empresa->celular }}
                                    @if($empresa->possui_whatsapp && $empresa->celular_whatsapp_url)
                                        <a href="{{ $empresa->celular_whatsapp_url }}"
                                           target="_blank"
                                           rel="noopener noreferrer"
                                           class="text-success ms-1"
                                           title="{{ __('Abrir WhatsApp') }}">
                                            <i class="fa-brands fa-whatsapp fa-sm" aria-hidden="true"></i>
                                            <span class="visually-hidden">{{ __('Abrir WhatsApp') }}</span>
                                        </a>
                                    @endif
                                @else
                                    -
                                @endif
                                <br>
                                <strong>{{ __('Telefone') }}</strong>: {{ $empresa?->telefone ?: '-' }}
                            </td>
                            <td>
                                @include('components/buttons._status', [
                                    'index' => $index,
                                    'route' => 'admin.empresasDeTurismo.status',
                                    'id' => $empresaTurismo->id,
                                    'status' => $empresaTurismo->status,
                                    'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                    'queryParams' => $listFilterParams,
                                ])
                            </td>
                            <td>
                                <div class="d-flex flex-wrap gap-1 justify-content-center empresas-turismo-actions" role="group" aria-label="{{ __('Ações') }}">
                                    @if(($perms['visualizar'] ?? false))
                                        @php
                                            $companhia = $empresaTurismo->companhia;
                                            $responsavelId = $companhia && $companhia->responsavel ? $companhia->responsavel->id : null;
                                            $sede = $empresaTurismo->sede;
                                            $sedeId = $sede ? $sede->id : null;
                                        @endphp

                                        @if($responsavelId)
                                            @include('components.buttons._navButton', [
                                                'route' => 'admin.empresasDeTurismo.proprietario',
                                                'id' => [$empresaTurismo->id, $responsavelId],
                                                'fontawesome' => '<i class="fa-solid fa-person" data-bs-toggle="tooltip" title="' . __('Responsável Legal') . '"></i>',
                                                'title' => __('Proprietário'),
                                                'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                                'queryParams' => $listFilterParams,
                                            ])
                                        @endif

                                        @include('components.buttons._navButton', [
                                            'route' => 'admin.empresasDeTurismo.preposto',
                                            'id' => $empresaTurismo->id,
                                            'fontawesome' => '<i class="fa-solid fa-people-arrows" data-bs-toggle="tooltip" title="' . __('Preposto') . '"></i>',
                                            'title' => __('Preposto'),
                                            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                            'queryParams' => $listFilterParams,
                                        ])

                                        @if($sedeId)
                                            @include('components.buttons._navButton', [
                                                'route' => 'admin.empresasDeTurismo.endereco',
                                                'id' => [$empresaTurismo->id, $sedeId],
                                                'fontawesome' => '<i class="fa-solid fa-location-dot" data-bs-toggle="tooltip" title="' . __('Endereço') . '"></i>',
                                                'title' => __('Endereço'),
                                                'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                                'queryParams' => $listFilterParams,
                                            ])
                                        @endif
                                    @endif

                                    @if(($perms['editar'] ?? false))
                                        @include('components/buttons._editButton', [
                                            'route' => 'admin.empresasDeTurismo.edit',
                                            'id' => $empresaTurismo->id,
                                            'fontawesome' => null,
                                            'title' => __('Editar'),
                                            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                            'queryParams' => $listFilterParams,
                                        ])

                                        @include('components/buttons._editButton', [
                                            'route' => 'admin.empresasDeTurismo.clipboard',
                                            'id' => $empresaTurismo->id,
                                            'fontawesome' => "<i class='fa-solid fa-clipboard-list'></i>",
                                            'title' => __('Documentos'),
                                            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                            'queryParams' => $listFilterParams,
                                        ])
                                    @endif

                                    @if(($perms['visualizar'] ?? false))
                                        @include('components.buttons._navButton', [
                                            'route' => 'admin.empresasDeTurismo.fichaComprovacaoPdf',
                                            'id' => $empresaTurismo->id,
                                            'fontawesome' => '<i class="fa-solid fa-file-pdf" data-bs-toggle="tooltip" title="' . __('Ficha de comprovação') . '"></i>',
                                            'title' => __('Ficha de comprovação'),
                                            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                            'target' => '_blank',
                                        ])

                                        @include('components/buttons._verifyEmbarcacaoEmpresa', [
                                            'route' => 'admin.embarcacoes.index',
                                            'id' => ['empresaTurismo' => $empresaTurismo->id],
                                            'fontawesome' => null,
                                            'title' => __('Embarcações'),
                                            'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                            'queryParams' => $listFilterParams,
                                        ])
                                    @endif

                                    @include('components/buttons._deleteButton', [
                                        'message' => __('* Esta empresa será excluída e esta ação não poderá ser desfeita?'),
                                        'route' => 'admin.empresasDeTurismo.destroy',
                                        'id' => $empresaTurismo->id,
                                        'fontawesome' => null,
                                        'title' => __('Excluir'),
                                        'permission' => 'GERENCIADOR_DE_EMPRESAS_DE_TURISMO',
                                        'queryParams' => $listFilterParams,
                                    ])
                                </div>
                            </td>
                        </tr>

                        @php $index++; @endphp
                    @endforeach
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection
