<div class="row">
    <div class="col-12">
        <h1 class="mb-3">{{ __('Credenciamento de Músicos') }}</h1>

        <p class="mb-3">{{ __("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget ligula eu lectus lobortis condimentum. Aliquam nonummy auctor massa. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Nulla at risus. Quisque purus magna, auctor et, sagittis ac, posuere eu, lectus. Nam mattis, felis ut adipiscing.") }}</p>
        <p class="mb-3">{{ __("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget ligula eu lectus lobortis condimentum. Aliquam nonummy auctor massa. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Nulla at risus. Quisque purus magna, auctor et, sagittis ac, posuere eu, lectus. Nam mattis, felis ut adipiscing.") }}</p>
        <p class="mb-3">{{ __("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget ligula eu lectus lobortis condimentum. Aliquam nonummy auctor massa. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Nulla at risus. Quisque purus magna, auctor et, sagittis ac, posuere eu, lectus. Nam mattis, felis ut adipiscing.") }}</p>
        <p class="mb-3">{{ __("De acordo com a ") }}<strong>{{ __("Lei Municipal nº x.xxx, de xx de novembro de xxxx") }}</strong>{{ __(", o credenciamento .... Lorem ipsum dolor sit amet, consectetur adipisicing elit.") }}</p>

        <p class="mb-3">{{ __("Antes de iniciar o preenchimento, certifique-se de ter em mãos toda a documentação digitalizada necessária para emissão do cartão de identificação.") }}</p>

        <ol class="list-group list-group-numbered mb-3">
            <li class="list-group-item">{{ __("Registro profissional (DRT / OMB)") }}</li>
            <li class="list-group-item">{{ __("01 foto tamanho 3x4;") }}</li>
            <li class="list-group-item">{{ __("Comprovante de residência;") }}</li>
            <li class="list-group-item">{{ __("RG;") }}</li>
            <li class="list-group-item">{{ __("CPF e;") }}</li>
            <li class="list-group-item">{{ __("Cartão SUS.") }}</li>
        </ol>

        <p class="alert alert-info mb-3">{{ __("Lembramos que é de responsabilidade do usuário acompanhar pelo sistema o andamento
        do processo e a retirada do cartão deverá ser feita na Secretaria de Cultura.") }}</p>

        <hr>

    </div>
</div>