@extends('layouts.pmar.app')

@section('title', 'Redefinir Senha - Credenciamento de Músicos')

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h3 class="card-title text-center">Redefinir Senha</h3>
                </div>
                <div class="card-body">
                    <p class="text-center mb-4">Para sua segurança, você deve redefinir sua senha.</p>
                    
                    <form method="POST" action="{{ route('paginas.credenciamento-musico.resetPassword') }}">
                        @csrf
                        
                        <div class="form-group">
                            <label for="password">Nova Senha *</label>
                            <input type="password" name="password" id="password" class="form-control @error('password') is-invalid @enderror" 
                                   required>
                            @error('password')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="form-group">
                            <label for="password_repeat">Repetir Nova Senha *</label>
                            <input type="password" name="password_repeat" id="password_repeat" class="form-control @error('password_repeat') is-invalid @enderror" 
                                   required>
                            @error('password_repeat')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary btn-block">
                                <i class="fas fa-save"></i> Redefinir Senha
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
