<div class="row">
    <div class="col">
        <div class="sideCanvas offcanvas offcanvas-start" data-bs-scroll="true" data-bs-backdrop="false"
             tabindex="-1" id="offcanvasScrolling" aria-labelledby="offcanvasScrollingLabel">
            <div class="offcanvas-header">
                <h5 class="offcanvas-title" id="offcanvasScrollingLabel">SUMÁRIO DO MANUAL</h5>
                <button type="button" class="btn-close" data-bs-dismiss="offcanvas"
                aria-label="Close"></button>
            </div>
            <div class="offcanvas-body">
                <div class="row">
                    <nav class="d-md-block sidebar">
                        <div class="position-sticky">
                            <ul class="nav flex-column">
                                <!-- A Interface do SEI -->
                                <li class="nav-item my-2">
                                    <a class="nav-link text-black border-0 shadow rounded-2"
                                       data-bs-toggle="collapse" href="#collapseInterface" role="button"
                                        aria-expanded="false" aria-controls="collapseInterface"><i
                                        class="bi-chevron-down toggle-icon"></i> A
                                    Interface do SEI</a>
                                    <div class="collapse" id="collapseInterface">
                                        <ul class="list-unstyled ms-3">
                                            <li><a class="nav-link text-black"
                                                   href="#cadastro-usuario-externo">Cadastro de
                                            Usuário Externo</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#alteracao-dados-cadastrais">Alteração
                                            de dados cadastrais</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#controle-acessos-externos">Controle de
                                            Acessos Externos</a></li>
                                        </ul>
                                    </div>
                                </li>

                                <!-- Peticionamento Eletrônico -->
                                <li class="nav-item my-2">
                                    <a class="nav-link text-black border-0 shadow rounded-2"
                                       data-bs-toggle="collapse" href="#collapsePeticionamento"
                                       role="button" aria-expanded="false"
                                        aria-controls="collapsePeticionamento"><i
                                        class="bi-chevron-down toggle-icon"></i>
                                    Peticionamento Eletrônico</a>
                                    <div class="collapse" id="collapsePeticionamento">
                                        <ul class="list-unstyled ms-3">
                                            <li><a class="nav-link text-black"
                                                   href="#peticionamento-processos-novos">Peticionamento
                                                    Eletrônico de
                                            Processos Novos</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#documento-principal-interno">Documento
                                            Principal Interno</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#documentos-externos">Documentos
                                            Externos</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#formato-documento">Formato do
                                            documento</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#concluindo-peticionamento">Conclusão
                                            do Peticionamento:</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#peticionamento-intercorrente">Peticionamento
                                                    Eletrônico para
                                            processos já existentes (Intercorrente)</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#recibos-eletronicos">Recibos
                                            Eletrônicos</a></li>
                                        </ul>
                                    </div>
                                </li>

                                <!-- Intimação Eletrônica -->
                                <li class="nav-item my-2">
                                    <a class="nav-link text-black border-0 shadow rounded-2"
                                       data-bs-toggle="collapse" href="#collapseIntimacao" role="button"
                                        aria-expanded="false" aria-controls="collapseIntimacao"><i
                                        class="bi-chevron-down toggle-icon"></i>
                                    Intimação Eletrônica</a>
                                    <div class="collapse" id="collapseIntimacao">
                                        <ul class="list-unstyled ms-3">
                                            <li><a class="nav-link text-black"
                                                   href="#consultar-intimacao">Consultar
                                            Intimação</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#responder-intimacao">Responder a
                                            Intimação</a></li>
                                        </ul>
                                    </div>
                                </li>

                                <!-- Pesquisa Pública -->
                                <li class="nav-item my-2">
                                    <a class="nav-link text-black border-0 shadow rounded-2"
                                       data-bs-toggle="collapse" href="#collapsePesquisa" role="button"
                                        aria-expanded="false" aria-controls="collapsePesquisa"><i
                                        class="bi-chevron-down toggle-icon"></i>
                                    Pesquisa Pública</a>
                                    <div class="collapse" id="collapsePesquisa">
                                        <ul class="list-unstyled ms-3">
                                            <li><a class="nav-link text-black"
                                                   href="#pesquisar-processos">Pesquisar
                                            Processos</a></li>
                                            <li><a class="nav-link text-black"
                                                   href="#acesso-externo-processos">Acesso
                                            Externo aos Processos</a></li>
                                        </ul>
                                    </div>

                                </li>

                            </ul>
                        </div>
                    </nav>
                </div>
            </div>
        </div>
    </div>
</div><?php /**PATH /var/www/html/portal/resources/views/sei/sectionsManual/slideCanva.blade.php ENDPATH**/ ?>