<div class="card shadow-sm border-0 rounded-4">
    <div class="card-body p-4">

        <h4 class="fw-bold text-primary mb-4 border-bottom pb-2">
            <i class="fa-solid fa-file-contract me-2"></i>
            Cadastro de Convênio
        </h4>

        {{-- ================= INFORMAÇÕES GERAIS ================= --}}
        <h5 class="fw-bold text-secondary mb-3 mt-4">
            Informações Gerais
        </h5>

        {{-- OBJETO --}}
        <div class="row">
            <div class="col-md-12 mb-4">
                <div class="d-flex justify-content-between align-items-center">
                    <label class="form-label fw-semibold">Objeto</label>
                    <div class="form-check form-switch">
                        <input type="hidden" name="show_objeto" value="0">
                        <input class="form-check-input" type="checkbox"
                               name="show_objeto" value="1"
                               {{ old('show_objeto', $convenio->show_objeto ?? 1) ? 'checked' : '' }}>
                    </div>
                </div>

                <textarea class="form-control"
                          name="objeto"
                          rows="3">{{ old('objeto', $convenio->objeto ?? '') }}</textarea>
            </div>
        </div>

        <div class="row">
            <div class="col-md-6 mb-4">
                <div class="d-flex justify-content-between align-items-center">
                    <label class="form-label fw-semibold">Executor Ordenador</label>
                    <div class="form-check form-switch">
                        <input type="hidden" name="show_executor_ordenador" value="0">
                        <input class="form-check-input" type="checkbox"
                               name="show_executor_ordenador" value="1"
                               {{ old('show_executor_ordenador', $convenio->show_executor_ordenador ?? 1) ? 'checked' : '' }}>
                    </div>
                </div>

                <input type="text" class="form-control"
                       name="executor_ordenador"
                       value="{{ old('executor_ordenador', $convenio->executor_ordenador ?? '') }}">
            </div>

            <div class="col-md-6 mb-4">
                <div class="d-flex justify-content-between align-items-center">
                    <label class="form-label fw-semibold">Concedente</label>
                    <div class="form-check form-switch">
                        <input type="hidden" name="show_concedente" value="0">
                        <input class="form-check-input" type="checkbox"
                               name="show_concedente" value="1"
                               {{ old('show_concedente', $convenio->show_concedente ?? 1) ? 'checked' : '' }}>
                    </div>
                </div>

                <input type="text" class="form-control"
                       name="concedente"
                       value="{{ old('concedente', $convenio->concedente ?? '') }}">
            </div>
        </div>

        <hr class="my-4">

        {{-- ================= DADOS DO PROGRAMA ================= --}}
        <h5 class="fw-bold text-secondary mb-3">
            Dados do Programa
        </h5>

        @php
            $programaFields = [
                'status_plataforma' => 'Status/Plataforma',
                'programa' => 'Programa',
                'programa_pac' => 'Programa N° PAC',
                'tipo_programa' => 'Tipo de Programa',
                'proposta_id' => 'Proposta ID N°',
                'porcentagem_conclusao' => 'Porcentagem de Conclusão (%)',
            ];
        @endphp

        <div class="row">
            @foreach($programaFields as $field => $label)
                <div class="col-md-4 mb-4">
                    <div class="d-flex justify-content-between align-items-center">
                        <label class="form-label fw-semibold">{{ $label }}</label>
                        <div class="form-check form-switch">
                            <input type="hidden" name="show_{{ $field }}" value="0">
                            <input class="form-check-input" type="checkbox"
                                   name="show_{{ $field }}" value="1"
                                   {{ old("show_$field", $convenio->{"show_$field"} ?? 1) ? 'checked' : '' }}>
                        </div>
                    </div>

                    <input type="text"
                           name="{{ $field }}"
                           class="form-control"
                           value="{{ old($field, $convenio->$field ?? '') }}">
                </div>
            @endforeach
        </div>

        <hr class="my-4">

        {{-- ================= ACOMPANHAMENTO DO INSTRUMENTO ================= --}}
        <h5 class="fw-bold text-secondary mb-3">
            {{ __('Acompanhamento do Instrumento') }}
        </h5>

        @isset($alertasAtivos)
            @if(count($alertasAtivos) > 0)
                <div class="mb-4" role="alert" aria-live="polite">
                    @foreach($alertasAtivos as $alerta)
                        <div class="alert alert-{{ $alerta['nivel'] === 'danger' ? 'danger' : 'warning' }} py-2 mb-2">
                            <i class="fa-solid fa-bell me-2" aria-hidden="true"></i>
                            {{ $alerta['mensagem'] }}
                        </div>
                    @endforeach
                </div>
            @endif
        @endisset

        @php
            $instrumentoFields = [
                'numero_instrumento' => __('Número do instrumento'),
                'numero_processo_sei' => __('Número do processo SEI'),
                'data_recebimento_recurso' => __('Data do recebimento do recurso'),
                'data_assinatura_instrumento' => __('Data de assinatura do instrumento'),
                'andamento' => __('Andamento'),
                'vigencia_clausula_suspensiva' => __('Vigência da cláusula suspensiva'),
                'vigencia_prazo_contratual' => __('Vigência do prazo de vigência contratual'),
            ];
            $instrumentoDateFields = [
                'data_recebimento_recurso',
                'data_assinatura_instrumento',
                'vigencia_clausula_suspensiva',
                'vigencia_prazo_contratual',
            ];
        @endphp

        <div class="row">
            @foreach($instrumentoFields as $field => $label)
                <div class="col-md-6 mb-4">
                    <div class="d-flex justify-content-between align-items-center">
                        <label class="form-label fw-semibold" for="convenio-{{ $field }}">{{ $label }}</label>
                        <div class="form-check form-switch">
                            <input type="hidden" name="show_{{ $field }}" value="0">
                            <input class="form-check-input" type="checkbox"
                                   id="convenio-show-{{ $field }}"
                                   name="show_{{ $field }}" value="1"
                                   {{ old("show_$field", $convenio->{"show_$field"} ?? 1) ? 'checked' : '' }}>
                        </div>
                    </div>

                    @if($field === 'andamento')
                        <input type="text"
                               id="convenio-{{ $field }}"
                               name="{{ $field }}"
                               class="form-control"
                               value="{{ old($field, $convenio->$field ?? '') }}">
                    @else
                        <input type="{{ in_array($field, $instrumentoDateFields, true) ? 'date' : 'text' }}"
                               id="convenio-{{ $field }}"
                               name="{{ $field }}"
                               class="form-control"
                               value="{{ old($field,
                                    isset($convenio->$field) && $convenio->$field instanceof \Carbon\Carbon
                                    ? $convenio->$field->format('Y-m-d')
                                    : ($convenio->$field ?? '')
                               ) }}">
                    @endif

                    @if($field === 'data_recebimento_recurso')
                        <div class="form-text">{{ __('Alertas automáticos aos 30 e 150 dias após o recebimento.') }}</div>
                    @elseif($field === 'vigencia_clausula_suspensiva')
                        <div class="form-text">{{ __('Alerta automático 70 dias antes do vencimento.') }}</div>
                    @elseif($field === 'vigencia_prazo_contratual')
                        <div class="form-text">{{ __('Alerta automático 70 dias antes do vencimento.') }}</div>
                    @endif
                </div>
            @endforeach
        </div>

        <hr class="my-4">

        {{-- ================= PRAZOS ================= --}}
        <h5 class="fw-bold text-secondary mb-3">
            {{ __('Prazos') }}
        </h5>

        @php
            $prazoFields = [
                'prazo_cadastro' => 'Prazo Cadastro',
                'data' => 'Data',
                'prazo_execucao_meses' => 'Prazo Execução (Meses)',
                'local' => 'Local',
            ];
        @endphp

        <div class="row">
            @foreach($prazoFields as $field => $label)
                <div class="col-md-6 mb-4">
                    <div class="d-flex justify-content-between align-items-center">
                        <label class="form-label fw-semibold">{{ $label }}</label>
                        <div class="form-check form-switch">
                            <input type="hidden" name="show_{{ $field }}" value="0">
                            <input class="form-check-input" type="checkbox"
                                   name="show_{{ $field }}" value="1"
                                   {{ old("show_$field", $convenio->{"show_$field"} ?? 1) ? 'checked' : '' }}>
                        </div>
                    </div>

                    <input type="{{ in_array($field, ['prazo_cadastro','data']) ? 'date' : 'text' }}"
                           name="{{ $field }}"
                           class="form-control"
                           value="{{ old($field,
                                isset($convenio->$field) && $convenio->$field instanceof \Carbon\Carbon
                                ? $convenio->$field->format('Y-m-d')
                                : ($convenio->$field ?? '')
                           ) }}">
                </div>
            @endforeach
        </div>

        <hr class="my-4">

        {{-- ================= VALORES ================= --}}
        <h5 class="fw-bold text-secondary mb-3">
            Dados Financeiros
        </h5>

        @php
            $valorFields = [
                'contrapartida' => 'Contrapartida',
                'repasse' => 'Repasse',
                'valor_global' => 'Valor Global',
            ];
        @endphp

        <div class="row">
            @foreach($valorFields as $field => $label)
                <div class="col-md-4 mb-4">
                    <div class="d-flex justify-content-between align-items-center">
                        <label class="form-label fw-semibold">{{ $label }}</label>
                        <div class="form-check form-switch">
                            <input type="hidden" name="show_{{ $field }}" value="0">
                            <input class="form-check-input" type="checkbox"
                                   name="show_{{ $field }}" value="1"
                                   {{ old("show_$field", $convenio->{"show_$field"} ?? 1) ? 'checked' : '' }}>
                        </div>
                    </div>

                    <input type="text"
                           name="{{ $field }}"
                           class="form-control"
                           value="{{ old($field, $convenio->$field ?? '') }}">
                </div>
            @endforeach
        </div>

        <div class="d-flex justify-content-end mt-4">
            <button type="submit" class="btn btn-primary px-4 py-2 rounded-3 shadow-sm">
                <i class="fa-solid fa-save me-2"></i>
                Salvar
            </button>
        </div>

    </div>
</div>