@extends('layouts.admin.theme')
@php $tituloHeader = env("APP_NAME") . " :: Lista de Secretarias, Fundações e Autarquias"; @endphp
@section("title", $tituloHeader)
@section('content')

    <div class="card shadow">
        <div class="card-header bg-primary text-white d-flex justify-content-between align-items-center">
            <h5 class="my-2">Lista de Secretarias, Fundações e Autarquias</h5>
        </div>
        <div class="card-body">
            <div class="mb-3">
                <span class="badge bg-primary fs-6">
                    <i class="fa-solid fa-building-columns me-1"></i>
                    {{ __('Total de secretarias') }}: <strong>{{ number_format($totalSecretarias, 0, ',', '.') }}</strong>
                </span>
            </div>
            <hr>
            @include("errors.messageFlash")
            <ul class="nav nav-pills mb-3 justify-content-center bg-light p-2 rounded shadow-sm" role="tablist">
               @component('components.lists._liLinkBtnNavInterna', [
                            'items' => [
                                ["hash" => "gabinetes", "label" => "Gabinetes", "class" => ""],
                                ["hash" => "secretarias", "label" => "Secretarias", "class" => "active"],
                                ["hash" => "executivas", "label" => "Executivas", "class" => ""],
                                ["hash" => "autarquias", "label" => "Autarquias", "class" => ""],
                                ["hash" => "superintendencias", "label" => "Superintendências", "class" => ""],
                                ["hash" => "diretorias", "label" => "Diretorias", "class" => ""],
                                ["hash" => "departamentos", "label" => "Departamentos", "class" => ""],
                            ]
                        ])
                @endcomponent
            </ul>

            <div class="tab-content">
                <div class="tab-pane" id="gabinetes">
                    @include('admin.secretarias.sections.gabinetes')
                </div>
                <div class="tab-pane active" id="secretarias">
                    @include('admin.secretarias.sections.secretarias')
                </div>
                <div class="tab-pane" id="executivas">
                    @include('admin.secretarias.sections.executivas')
                </div>
                <div class="tab-pane" id="autarquias">
                    @include('admin.secretarias.sections.autarquias')
                </div>
                <div class="tab-pane w-100" id="superintendencias">
                    @include('admin.secretarias.sections.superintendencias')
                </div>
                <div class="tab-pane" id="diretorias">
                    @include('admin.secretarias.sections.diretorias')
                </div>
                <div class="tab-pane" id="departamentos">
                    @include('admin.secretarias.sections.departamentos')
                </div>
            </div>
        </div>
    </div>
@endsection
