@extends('layouts.admin.theme')
@php $tituloHeader = env('APP_NAME') . ' :: Lista de Informativos, Legislações, Ordens de Serviços e Normatizações do RH'; @endphp
@section('title', $tituloHeader)
@section('content')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-circle-info'></i> " . __('Informativos, Legislações, Ordens de Serviços e Normatizações do RH'); @endphp

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => $headLine,
            'routeBack' => 'admin.dashboard',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.informativos_recursos_humanos.create',
            'routeAddParams' => [],
            'nameAdd' => __('Novo Informe'),
            'permission' => 'GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS',
        ])

        <div class="card-body">

            @include("errors.messageFlash")


            @if(auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS')['adicionar'])
                @include('components/buttons/_addDefaut', [
                    "route" => 'admin.informativos_recursos_humanos.create', 
                    "fontawesome" => '<i class="fa-solid fa-plus"></i>', 
                    "text" => __('Novo Informe'), 
                ])
            @endif

            @include('components/forms/_filtroPesquisaDefault', [ 
                "id" => "informativosRecursosHumanos", 
                "placeholder" => __("Pesquisar informe...")])

            <div class="table-responsive">
                <table class="table table-bordered table-hover table-striped align-middle text-center">

                    @include("components/tables/_thead",[
                        "thead" => [
                            __("Arquivo"),
                            __("Tipo"),
                            __("Data de Publicação"),
                            __("Número"),
                            __("Descrição"),
                            __("Status"),
                            __("Ações"),
                        ]
                    ])

                    <tbody>
                        
                        @php $index = 0 @endphp
                        @forelse($informativos as $informativo)
                            <tr>
                                <td>
                                    @include("components/tables/_downloadFile", [
                                        "fontawesome" => null,
                                        "text" => "Baixar PDF",
                                        "url" => $informativo->arquivo,
                                    ])
                                </td>
                                <td>
                                    @include("components/tables/_getEnumValue",[
                                        "EnumClass" => App\Enums\StatusInformativosRecursosHumanos::cases(),
                                        "arg" => $informativo->categoria,
                                    ])
                                </td>
                                <td>{{ date("d/m/Y", strtotime($informativo->dataPublicacao)) }}</td>
                                <td>{{ $informativo->numero }}</td>
                                <td>{!! Str::limit($informativo->descricao, 100) !!}</td>
                                <td>
                                    @include('components/buttons/_status', [
                                        "index" => $index,
                                        "route" => "admin.informativos_recursos_humanos.status",
                                        "id" => $informativo->id,
                                        "status" => $informativo->status,
                                        "permission" => "GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS",
                                    ])
                                </td>
                                <td>
                                    <div class="d-flex justify-content-center align-items-center gap-2">
                                        @include('components/buttons/_editButton', [
                                            "route" => "admin.informativos_recursos_humanos.edit",
                                            "id" => $informativo->id,
                                            "fontawesome" => null,
                                            "title" => __("Editar"),
                                            "permission" => "GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS",
                                        ])

                                        @include('components/buttons/_deleteButton', [
                                            "message" => "* Este informe será excluído e esta ação não poderá ser desfeita, deseja continuar?",
                                            "route" => "admin.informativos_recursos_humanos.destroy",
                                            "id" => $informativo->id,
                                            "fontawesome" => null,
                                            "title" => __("Excluir"),
                                            "permission" => "GERENCIADOR_DE_INFORMATIVOS_RECURSOS_HUMANOS",
                                        ])
                                    </div>
                                </td>
                            </tr>
                            @php $index++ @endphp
                        @empty
                            <tr>
                                <td colspan="7" class="text-muted fst-italic">{{ __('* Nenhum registro encontrado!') }}</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>

            <div class="d-flex justify-content-center mt-4">
                {!! $informativos->links() !!}
            </div>
        </div>
    </div>
@endsection