<?php $__env->startSection("title", env("APP_NAME") . " :: " . __('Contratos')); ?>

<?php $__env->startSection('content'); ?>
<link rel="stylesheet" href="<?php echo e(asset('pmar/css/paginas/licitacoes-publicas.css')); ?>">
<link rel="stylesheet" href="<?php echo e(asset('pmar/css/paginas/contratos.css')); ?>">

<div class="lp-hero lp-wrap">
    <div class="lp-hero-inner">
        <div class="container">
            <nav aria-label="breadcrumb">
                <ol class="breadcrumb">
                    <li class="breadcrumb-item"><a href="<?php echo e(route('paginas.home')); ?>"><?php echo e(__('Portal')); ?></a></li>
                    <li class="breadcrumb-item active" aria-current="page"><?php echo e(__('Contratos')); ?></li>
                </ol>
            </nav>

            <div class="lp-hero-body">
                <div class="lp-hero-icon"><i class="fa-solid fa-file-contract text-primary"></i></div>
                <div>
                    <h1 class="lp-hero-title text-primary"><?php echo e(__('Contratos')); ?></h1>
                    <p class="lp-hero-sub text-primary"><?php echo e(__('Consulte os contratos publicados pela administração')); ?></p>
                </div>
            </div>
        </div>
        <div class="lp-hero-bar"></div>
    </div>
</div>

<section class="lp-main lp-wrap">
    <div class="container">
        <div class="lp-filter-card">
            <div class="lp-filter-header">
                <div class="lp-filter-header-left">
                    <div class="lp-filter-icon"><i class="fa-solid fa-sliders"></i></div>
                    <span class="lp-filter-title"><?php echo e(__('Filtros')); ?></span>
                    <span class="lp-filter-sub"><?php echo e(__('Refine sua pesquisa')); ?></span>
                </div>
                <button class="btn-lp-clear" id="btn-limpar-filtros" type="button">
                    <i class="fa-solid fa-xmark"></i><?php echo e(__('Limpar filtros')); ?>

                </button>
            </div>
            <div class="lp-filter-body">
                <form id="form-filtros-contratos">
                    <div class="row g-3">

                        
                        <div class="col-12 col-md-6">
                            <div class="row g-3">
                                <div class="col-12">
                                    <label for="filtro-numero" class="lp-field-label"><?php echo e(__('N° do Contrato')); ?></label>
                                    <input id="filtro-numero" name="numero" type="text" class="form-control" placeholder="">
                                </div>
                                <div class="col-12">
                                    <label for="filtro-favorecido" class="lp-field-label"><?php echo e(__('Favorecido')); ?></label>
                                    <input id="filtro-favorecido" name="favorecido" type="text" class="form-control" placeholder="">
                                </div>
                                <div class="col-12">
                                    <label for="filtro-objeto" class="lp-field-label"><?php echo e(__('Objeto/Descrição')); ?></label>
                                    <input id="filtro-objeto" name="objeto" type="text" class="form-control" placeholder="">
                                </div>
                                <div class="col-12">
                                    <label for="filtro-ano" class="lp-field-label"><?php echo e(__('Ano do contrato')); ?></label>
                                    <div class="lp-field-wrap">
                                        <select class="form-select" id="filtro-ano" name="ano">
                                            <option value=""><?php echo e(__('--- Todos ---')); ?></option>
                                        </select>
                                        <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        
                        <div class="col-12 col-md-6">
                            <div class="row g-3">
                                <div class="col-12">
                                    <label for="filtro-secretaria-gestora" class="lp-field-label"><?php echo e(__('Secretaria gestora')); ?></label>
                                    <div class="lp-field-wrap">
                                        <select class="form-select" id="filtro-secretaria-gestora" name="secretaria_gestora">
                                            <option value=""><?php echo e(__('--- Todas ---')); ?></option>
                                        </select>
                                        <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <label for="filtro-cpf-cnpj" class="lp-field-label"><?php echo e(__('CPF ou CNPJ do Favorecido')); ?></label>
                                    <input id="filtro-cpf-cnpj" name="cpf_cnpj" type="text" class="form-control" placeholder="">
                                </div>
                                <div class="col-12">
                                    <label for="filtro-situacao" class="lp-field-label"><?php echo e(__('Situação')); ?></label>
                                    <div class="lp-field-wrap">
                                        <select class="form-select" id="filtro-situacao" name="status">
                                            <option value=""><?php echo e(__('--- Todas ---')); ?></option>
                                        </select>
                                        <span class="lp-select-arrow"><i class="fa-solid fa-chevron-down"></i></span>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <span class="lp-field-label" id="filtro-covid-label"><?php echo e(__('Combate ao Coronavírus')); ?></span>
                                    <label class="lp-filter-option lp-filter-option--inline" for="filtro-covid">
                                        <input type="checkbox"
                                            class="lp-filter-option-input"
                                            name="covid"
                                            value="1"
                                            id="filtro-covid"
                                            aria-labelledby="filtro-covid-label">
                                        <span class="lp-filter-option-box" aria-hidden="true">
                                            <i class="fa-solid fa-check"></i>
                                        </span>
                                        <span class="lp-filter-option-desc">
                                            <?php echo e(__('Exibe apenas contratos vinculados a ações de combate ao coronavírus (COVID-19).')); ?>

                                        </span>
                                    </label>
                                </div>
                            </div>
                        </div>

                    </div>

                    <div class="lp-filter-actions">
                        <button class="btn-lp-apply" type="submit">
                            <i class="fa-solid fa-magnifying-glass"></i>
                            <?php echo e(__('Pesquisar')); ?>

                        </button>
                    </div>
                </form>
            </div>
        </div>

        <div class="lp-result-bar-wrap">
            <p class="lp-result-bar mb-0" id="total-resultados-texto"><?php echo e(__('Carregando resultados...')); ?></p>
            <a href="#" class="lp-download-link" id="btn-download-csv" aria-label="<?php echo e(__('Download em CSV')); ?>">
                <i class="fa-solid fa-download"></i><?php echo e(__('Download em CSV')); ?>

            </a>
        </div>

        <div id="contratos-lista" aria-live="polite"></div>
        <div id="contratos-paginacao" class="lp-pagination d-flex justify-content-center mt-4"></div>
        <div id="contratos-estado-vazio" class="lp-empty d-none" role="status">
            <p><?php echo e(__('Nenhum resultado encontrado para os filtros informados.')); ?></p>
        </div>
        <div id="contratos-erro" class="lp-error d-none" role="alert">
            <?php echo e(__('Não foi possível carregar os dados no momento. Tente novamente em instantes.')); ?>

        </div>
    </div>
</section>

<div id="contratos-config"
    class="d-none"
    data-endpoint-lista="<?php echo e(url('/api/contratos')); ?>"
    data-endpoint-filtros="<?php echo e(url('/api/contratos/filtros')); ?>"
    data-url-detalhe-template="<?php echo e(url('/contratos')); ?>/__ID__"
    data-url-licitacao-template="<?php echo e(url('/licitacoes-e-procedimentos')); ?>/__ID__"
    data-texto-numero="<?php echo e(__('N.º')); ?>"
    data-texto-publicado-em="<?php echo e(__('Publicado em')); ?>"
    data-texto-ano="<?php echo e(__('Ano')); ?>"
    data-texto-modalidade="<?php echo e(__('Modalidade')); ?>"
    data-texto-situacao="<?php echo e(__('Situação')); ?>"
    data-texto-objeto="<?php echo e(__('Objeto')); ?>"
    data-texto-instituicao="<?php echo e(__('Instituição')); ?>"
    data-texto-data-ini="<?php echo e(__('Data de início')); ?>"
    data-texto-data-fim="<?php echo e(__('Data de término')); ?>"
    data-texto-prorrogado-ate="<?php echo e(__('Prorrogado até')); ?>"
    data-texto-pelo-anexo="<?php echo e(__('pelo anexo n°')); ?>"
    data-texto-favorecido="<?php echo e(__('Favorecido')); ?>"
    data-texto-valor="<?php echo e(__('Valor')); ?>"
    data-texto-processo="<?php echo e(__('N° do processo')); ?>"
    data-texto-fiscais="<?php echo e(__('Fiscais do Contrato')); ?>"
    data-texto-licitacao="<?php echo e(__('Licitação')); ?>"
    data-texto-arquivos="<?php echo e(__('Arquivos')); ?>"
    data-texto-arquivo="<?php echo e(__('Arquivo')); ?>"
    data-texto-sem-arquivos="<?php echo e(__('Sem arquivos vinculados.')); ?>"
    data-texto-documentos-encontrados="<?php echo e(__('documento(s) encontrado(s)')); ?>">
</div>

<script src="<?php echo e(asset('pmar/js/paginas/contratos.js')); ?>"></script>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/contratos.blade.php ENDPATH**/ ?>