@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: Concursos Públicos e Processos de Seleção")
@section('content')

    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">{{ __("Portal") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.index") }}">{{ __("Concursos Públicos e Processos de Seleção") }}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.concursos.andamento", $concurso->id_concurso) }}">{{ __("Andamento") }}</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __("Editais de Publicação") }}</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-12">

                    <h1>Ano: {{ $concurso->ds_ano }}</h1>

                    <hr>

                    <h3 class="top30">EDITAIS DE PUBLICAÇÃO</h3>

                    <ul>
                        @foreach($arquivos as $arquivo)
                            <li>
                                <a href="{{ url("/concursos/" . $arquivo->nm_arquivo) }}" target="_blank">{{ $arquivo->ds_link_arquivo}} <i class="fa-solid fa-download"></i></a>
                                <br>
                                {{ $arquivo->ds_arquivo}}
                            </li>
                        @endforeach
                    </ul>


                </div>
            </div>
        </div>
    </section>


@endsection