
<div class="container">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">

                    <div class="mb-3 p-5 bg-secondary text-white rounded">
                        <h1>{{ $ambulante->proprietario->firstName }} {{ $ambulante->proprietario->lastName }}</h1>
                        <p class="text-white">CPF: {{ $ambulante->proprietario->cpf }}</p>
                        <p class="text-white">Telefone: {{ $ambulante->proprietario->phoneNumber }}</p>
                        <p class="text-white">Email: {{ $ambulante->proprietario->email }}</p>
                    </div>

                </div>
            </div>
        </div>
    </div>
</div>

<div class="container my-3">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">

                    <h5 class="card-title">Fotos do comércio ambulante</h5>
                    <div class="container">
                        <form action="{{ route('admin.cadastroDeAmbulantes.ambulantes.fotosStore', $ambulante->id ) }}" method="post" enctype="multipart/form-data">
                            @csrf
                            @method('POST')

                            <div class="mb-3">
                                <label for="link" class="form-label text-bold">Escolhas as imagens:</label>
                                <input type="hidden" name="tipo" id="tipo" value="Imagem">
                                <input type="file"  class="form-control @error('link') is-invalid @enderror"  name="link[]"  id="link"  accept="image/*"  multiple required />
                                @error('link')
                                    <small class="text-danger text-bold">{{ $message }}</small><br>
                                @enderror
                                <small class="text-info text-bold">
                                    * Apenas documentos de imagem: JPG, JPEG, PNG, GIF, BMP, WEBP.
                                </small>
                            </div>
                            <div class="mb-3">
                                <button class="btn btn-md btn-dark  d-inline" type="submit">{{ __('Enviar') }}</button>       
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="container my-3">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">

                    <h5 class="card-title">Lista de Fotos</h5>
                    <div class="container">
                        <div class="row">
                            <div class="col-12">
                                <div class="mb-3">
                                    <table class="table table-striped">
                                        @php $index = 0; @endphp
                                        @foreach($arquivos as $arquivo)
                                            <tr>
                                                <td>
                                                    @if(isset($arquivo->id))
                                                        <div style="width: 90px;">
                                                            @include('components.tables._openPhoto',[
                                                                'asset' => $arquivo->link,
                                                                'alt' => $proprietario->firstName . " " . $proprietario->lastName,
                                                                'title' => $proprietario->firstName . " " . $proprietario->lastName,
                                                                'text' => 'Visualizar foto',
                                                                'index' => 1,
                                                            ])
                                                        </div>
                                                    @endif
                                                </td>
                                                <td>
                                                    @include('components/buttons/_status', [
                                                        "index" => $index,
                                                        "route" => "admin.cadastroDeAmbulantes.ambulantes.fotosStatus",
                                                        "id" => [$ambulante->id, $arquivo->id],
                                                        "status" => $arquivo->status,
                                                    ])
                                                </td>
                                                <td>
                                                    <div class="btn-group" role="group">
                                                        @include('components/buttons/_deleteButton', [
                                                                "message" => "* Este imagem será excluída e esta ação não poderá ser desfeita?",
                                                                "route" => "admin.cadastroDeAmbulantes.ambulantes.fotosDestroy",
                                                                "id" => [$ambulante->id, $arquivo->id],
                                                                "fontawesome" => null,
                                                                "title" => "Excluir",
                                                            ])
                                                    </div>
                                                </td>
                                            </tr>
                                            @php $index++; @endphp
                                        @endforeach
                                    </table>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<div class="d-flex justify-content-between mt-4">
    <a class="btn btn-outline-secondary" href="{{ route("admin.cadastroDeAmbulantes.ambulantes.documentosIndex", $ambulante->id) }}">
        <i class="fa-solid fa-arrow-left-long"></i> Anterior
    </a>
    <a class="btn btn-primary d-inline" href="{{ route("admin.cadastroDeAmbulantes.ambulantes.index") }}">
        <i class="fa-solid fa-arrow-left-long"></i> Salvar e Finalizar
    </a>
</div>

