@php
    $modalId = 'modalConfirm_' . uniqid();
    $modalLabel = 'modalLabel_' . uniqid();
@endphp

<a class="btn btn-lg btn-primary"
   href="javascript:void(0);"
   data-bs-toggle="modal"
   data-bs-target="#{{ $modalId }}">
    {{ __("Sim, desejo realizar o meu cadastro!") }}
</a>

<div class="modal fade" id="{{ $modalId }}" tabindex="-1" aria-labelledby="{{ $modalLabel }}" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">

            <div class="modal-header">
                <h5 class="modal-title" id="{{ $modalLabel }}">
                    {{ __("O que é LGPD?") }}
                </h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Fechar"></button>
            </div>

            <div class="modal-body">
                <p class="mb-3">{{ __("A Lei Geral de Proteção de Dados Pessoais (LGPD) estabelece diretrizes importantes e obrigatórias para a coleta, processamento e armazenamento de dados pessoais. Ela foi inspirada na GDPR (General Data Protection Regulation), que entrou em vigência em 2018 na União Europeia, trazendo grandes impactos para empresas e consumidores.") }}</p>
                <p class="mb-3">{{ __("No Brasil, a LGPD (Lei nº 13.709, de 14/8/2018) entrou em vigor em 18 de setembro de 2020, representando um passo importante para o Brasil. Com isso, passamos a fazer parte de um grupo de países que contam com uma legislação específica para a proteção de dados dos seus cidadãos. Diante dos atuais casos de uso indevido, comercialização e vazamento de dados, as novas regras garantem a privacidade dos brasileiros, além de evitar entraves comerciais com outros países.") }}</p>
                <p class="mb-3 fw-bold">{{ __("A legislação se fundamenta em diversos valores e tem como principais objetivos:") }}</p>
                <ul class="list-group mb-3 border rounded">
                    <li class="px-3"><i class="fa-solid fa-circle-check text-success"></i> {{ __("Assegurar o direito à privacidade e à proteção de dados pessoais dos usuários, por meio de práticas transparentes e seguras, garantindo direitos fundamentais.") }}</li>
                    <li class="px-3"><i class="fa-solid fa-circle-check text-success"></i> {{ __("Estabelecer regras claras sobre o tratamento de dados pessoais.") }}</li>
                    <li class="px-3"><i class="fa-solid fa-circle-check text-success"></i> {{ __("Fortalecer a segurança das relações jurídicas e a confiança do titular no tratamento de dados pessoais, garantindo a livre iniciativa, a livre concorrência e a defesa das relações comerciais e de consumo.") }}</li>
                    <li class="px-3"><i class="fa-solid fa-circle-check text-success"></i> {{ __("Promover a concorrência e a livre atividade econômica, inclusive com portabilidade de dados.") }}</li>
                </ul>
                <h5>{{ __("Atuação da PREFEITURA") }}</h5>
                <p class="mb-3">{{ __("A Prefeitura Municipal de Angra dos Reis (PMAR) está aderindo e se adequando à LGPD. Promovendo avanços nos seus sistemas além de elaborar um plano de orientações para seus servidores e fornecedores com relação ao tema da privacidade de dados.") }}<hr></p>
                <p class="mb-3">{{ __("Você gostaria de compreender melhor a relação entre a Lei e a pessoa natural?") }}</p>
                <p class="mb-3">{{ __("Caso deseje se aprofundar no assunto, recomendamos a leitura da LGPD (Lei nº 13.709, de 14/8/2018).") }}</p>
                <p class="mb-3">{{ __("Conheça também a nossa ") }}<a class="text-primary" style="text-decoration: none;" target="_blank" href="{{ route("paginas.protecao-de-dados-lgpd") }}">{{ __("Política de Privacidade") }}</a></p>
                <p class="mb-3">{{ __("Informamos que no Portal do Servidor possui publicada uma ") }}<a target="_blank" class="text-primary" style="text-decoration: none;" href="https://angra.rj.gov.br/downloads/LGPD/cartilha-de-boas-praticas-de-seguranca-da-informacao-v1.pdf">{{ __("Cartilha de Medidas e Boas Práticas de Segurança da Informação") }}</a>, contendo algumas recomendações, orientações e procedimentos simplificados relacionados a proteção dos dados pessoais no ambiente de trabalho."</p>
                <p class="mb-3">{{ __("Informamos também a utilização dos dados em levantamentos de estatísticas, bem como a possibilidade de compartilhamento com outros órgãos da administração pública.") }}</p>
                <p class="mb-3">{{ __("Ao enviar o formulário o usuário manifesta total concordância com os termos acima.") }}</p>
            </div>
            
            <div class="modal-footer bg-white">
                <button type="button" class="btn btn-lg btn-secondary me-3" data-bs-dismiss="modal">
                    {{ __("Cancelar") }}
                </button>

                <a href="{{ route($route) }}"
                   class="btn btn-lg btn-primary">
                    {{ __("Sim, aceito continuar.") }}
                </a>
            </div>

        </div>

    </div>
</div>
