<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'linhas',
    'placeholder' => __('Digite a linha, bairro ou destino'),
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'linhas',
    'placeholder' => __('Digite a linha, bairro ou destino'),
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<div class="ma-hero__search horarios-linha-combobox horarios-linha-select-wrap"
    id="horarios-linha-combobox"
    data-msg-sem-resultados="<?php echo e(__('Nenhuma linha encontrada.')); ?>">

    <label class="visually-hidden" for="horarios-linha-search">
        <?php echo e(__('Buscar linha, bairro ou destino')); ?>

    </label>

    <div class="horarios-linha-combobox__control ma-hero__search-inner"
        role="combobox"
        aria-expanded="false"
        aria-haspopup="listbox"
        aria-owns="horarios-linha-listbox">

        <i class="fa-solid fa-magnifying-glass ma-hero__search-icon" aria-hidden="true"></i>

        <input type="search"
            id="horarios-linha-search"
            class="ma-hero__search-input horarios-linha-combobox__input"
            placeholder="<?php echo e($placeholder); ?>"
            autocomplete="off"
            aria-autocomplete="list"
            aria-controls="horarios-linha-listbox"
            aria-label="<?php echo e(__('Buscar linha')); ?>"
            enterkeyhint="search">

        <button type="button" class="btn ma-hero__search-btn d-none d-lg-inline-flex" id="ma-hero-search-submit">
            <?php echo e(__('Buscar')); ?>

        </button>
    </div>

    <ul id="horarios-linha-listbox"
        class="horarios-linha-combobox__list d-none"
        role="listbox"
        aria-label="<?php echo e(__('Linhas')); ?>"
        tabindex="-1"></ul>

    <select id="horarios-linha-combobox-source"
        class="d-none"
        aria-hidden="true"
        tabindex="-1">
        <?php $__currentLoopData = $linhas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $linha): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <option value="<?php echo e($linha->codigo); ?>"
                data-linha-id="<?php echo e($linha->id); ?>"
                data-codigo="<?php echo e($linha->codigo); ?>"
                data-nome="<?php echo e($linha->nome); ?>"
                data-label="<?php echo e($linha->codigo); ?> - <?php echo e($linha->nome); ?>">
                <?php echo e($linha->codigo); ?> - <?php echo e($linha->nome); ?>

            </option>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </select>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/hero-linha-combobox.blade.php ENDPATH**/ ?>