@extends('layouts.admin.theme')
@section("title", env("APP_NAME") . " :: " . __('Fluxo de Ônibus - Editar Agendamento - Verificar Empresa'))
@section('content')

    <form action="{{ route('admin.turisAngra.fluxoDeOnibus.onibusTurismo.verify') }}" method="post" enctype="multipart/form-data">
        <div class="container mt-5">
            <div class="row">
                <div class="col-12">
                    <div class="card shadow">
                        @php $headLine = "<i class='fa-solid fa-bus-simple'></i> " . __('Fluxo de Ônibus - Editar Agendamento - Verificar Empresa'); @endphp

                        @include('components.buttons._headLineButtonsBackAdd', [
                            'headLine' => __($headLine),
                            'routeBack' => 'admin.turisAngra.fluxoDeOnibus.onibusTurismo.index', 
                            'nameBack' => __('Lista de agendamentos'), 
                            'fontawesomeBack' => '<i class="fa-solid fa-list"></i>', 
                            'permission' => 'GERENCIADOR_DE_FLUXO_DE_ONIBUS'])

                        <div class="card-body">
                            @include("errors.messageFlash")
                            @csrf
                            @method('post')

                            <div class="mb-3">

                            <!-- Campo CNPJ -->
                            @include('components.inputs._inputType',[
                                    "for" => 'cnpj',
                                    "label" => "CNPJ",
                                    "name" => "cnpj",
                                    "id" => null,
                                    "required" => true,
                                    "type" => null,
                                    "old" => old('cpf'),
                                    "oninput" => "javascript:aplicarMascaraCNPJ(this)",
                                    "readonly" => false,
                                    "small" => null,
                                ])

                            </div>

                            @include('components.buttons._backAndSend', [
                                'textBack' => __('Voltar'),
                                'textSend' => __('Verificar'),
                                'routeBack' => 'admin.turisAngra.fluxoDeOnibus.onibusTurismo.index'
                            ]
                        )
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </form>

@endsection
