<div class="col-12 mb-3">
    <div class="row d-flex flex-column align-items-center">
        <div class="col">
            <div class="card-slug">
                <h2 class="slug-telefone"><?php echo e(__("Saiba mais")); ?></h2>
                <ul class="list-unstyled">
                    <li>
                        <a class="text-decoration-none link-secretarias" href="<?php echo e(route("paginas.formacao-academica", $secretaria->slug)); ?>" target="_SELF">
                            <div class="text-dark">
                                <?php if($secretaria->type == 'SECRETARIA'): ?>
                                    <?php if($secretaria->pronunciation == 'SECRETARIO'): ?>
                                        <?php echo e(__('Secretário')); ?>

                                    <?php elseif($secretaria->pronunciation == 'PROCURADO_GERAL_DO_MUNICIPIO'): ?>
                                        <?php echo e(__('Procurador-Geral')); ?>

                                    <?php elseif($secretaria->pronunciation == 'CONTROLADOR_GERAL_DO_MUNICIPIO'): ?>
                                        <?php echo e(__('Controlador-Geral')); ?>

                                    <?php else: ?>
                                        <?php echo e(__('Secretária')); ?>

                                    <?php endif; ?>
                                <?php elseif($secretaria->type == 'FUNDACAO' || $secretaria->type == 'AUTARQUIA'): ?>
                                    <?php echo e(__('Presidente')); ?>

                                <?php elseif($secretaria->type == 'SUPERINTENDENCIA'): ?>
                                    <?php echo e(__('Superintendente')); ?> 
                                <?php elseif($secretaria->type == 'DIRETORIA'): ?>
                                    <?php if($secretaria->pronunciation == 'DIRETOR'): ?>
                                        <?php echo e(__('Diretor')); ?>

                                    <?php else: ?>
                                        <?php echo e(__('Diretora')); ?> 
                                    <?php endif; ?>
                                <?php elseif($secretaria->type == 'SECRETARIA_EXECUTIVA'): ?>
                                    <?php if($secretaria->pronunciation == 'SECRETARIO_EXECUTIVO'): ?>
                                        <?php echo e(__('Secretário Executivo')); ?>

                                    <?php else: ?>
                                        <?php echo e(__('Secretária Executiva')); ?>

                                    <?php endif; ?>
                                <?php endif; ?>
                            </div>
                            <i class="text-primary fa-solid fa-angle-right"></i>
                        </a>
                    </li>
                    <li>
                        <a class="text-decoration-none link-secretarias" href="<?php echo e(route("paginas.competencias-e-atribuicoes", $secretaria->slug)); ?>" target="_SELF">
                            Competências e atribuições
                            <svg class="svg-inline--fa fa-angle-right text-primary" aria-hidden="true" focusable="false" data-prefix="fas" data-icon="angle-right" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512" data-fa-i2svg=""><path fill="currentColor" d="M278.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-160 160c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L210.7 256 73.4 118.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l160 160z"></path></svg><!-- <i class="text-primary fa-solid fa-angle-right"></i> Font Awesome fontawesome.com -->
                        </a>
                    </li>
                    <li>
                        <a class="text-decoration-none link-secretarias"
                           href="<?php echo e(\App\Support\StructurePublicUrls::faleConoscoUrl($secretaria)); ?>"
                           <?php if(request()->routeIs('paginas.orgao.fale-conosco*')): ?> aria-current="page" <?php endif; ?>>
                            <div class="text-dark"><?php echo e(__('Fale conosco')); ?></div>
                            <i class="text-primary fa-solid fa-angle-right" aria-hidden="true"></i>
                        </a>
                    </li>
                    <?php $__currentLoopData = $links; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $link): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <?php if(\App\Support\StructurePublicUrls::isAdministrativeFaleConoscoTitulo($link['titulo'] ?? null)): ?>
                            <?php continue; ?>
                        <?php endif; ?>
                        <li>
                            <a class="text-decoration-none text-dark link-secretarias" href="<?php echo e(url($link['link'])); ?>" target="<?php echo e($link['status']); ?>">
                                <?php echo e($link['titulo']); ?>

                                <i class="text-primary fa-solid fa-angle-right"></i>
                            </a>
                        </li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </ul>
            </div>
        </div>
    </div>
</div>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/links.blade.php ENDPATH**/ ?>