@foreach ($array_tab as $tab)
<li class="nav-item p-0" role="presentation">
    <button 
        class="nav-link {{ $tab ['class'] }}" 
        id="{{ $tab ['nome'] }}" 
        data-bs-toggle="tab"
        data-bs-target="#{{ $tab ['hash']}}" 
        type="button" 
        role="tab"
        aria-controls="{{ $tab ['elements'] }}" 
        aria-selected="{{ $tab ['selecionar'] }}">
        <label for="css"class="form-label text-bold">{{ $tab ['label'] }}:</label></button>
</li>
@endforeach