<?php if(! empty($secretaria)): ?>
    <section class="ma-org-info" aria-label="<?php echo e(__('Informações do órgão')); ?>">
        <div class="container">
            <div class="row g-4 align-items-start">
                <div class="col-12 col-lg-6">
                    <?php if (isset($component)) { $__componentOriginal8254caf7bbe3c201e4fb6652ac3a59bc = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal8254caf7bbe3c201e4fb6652ac3a59bc = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.saiba-mais-links','data' => ['secretaria' => $secretaria,'links' => $links ?? collect()]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.saiba-mais-links'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['secretaria' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($secretaria),'links' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($links ?? collect())]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal8254caf7bbe3c201e4fb6652ac3a59bc)): ?>
<?php $attributes = $__attributesOriginal8254caf7bbe3c201e4fb6652ac3a59bc; ?>
<?php unset($__attributesOriginal8254caf7bbe3c201e4fb6652ac3a59bc); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal8254caf7bbe3c201e4fb6652ac3a59bc)): ?>
<?php $component = $__componentOriginal8254caf7bbe3c201e4fb6652ac3a59bc; ?>
<?php unset($__componentOriginal8254caf7bbe3c201e4fb6652ac3a59bc); ?>
<?php endif; ?>
                </div>
                <div class="col-12 col-lg-6">
                    <?php if (isset($component)) { $__componentOriginalb5e4bdacb1f47afab97e63244d16b81d = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalb5e4bdacb1f47afab97e63244d16b81d = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.contatos-list','data' => ['telefones' => $telefones ?? []]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.contatos-list'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['telefones' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($telefones ?? [])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalb5e4bdacb1f47afab97e63244d16b81d)): ?>
<?php $attributes = $__attributesOriginalb5e4bdacb1f47afab97e63244d16b81d; ?>
<?php unset($__attributesOriginalb5e4bdacb1f47afab97e63244d16b81d); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalb5e4bdacb1f47afab97e63244d16b81d)): ?>
<?php $component = $__componentOriginalb5e4bdacb1f47afab97e63244d16b81d; ?>
<?php unset($__componentOriginalb5e4bdacb1f47afab97e63244d16b81d); ?>
<?php endif; ?>
                </div>
            </div>
        </div>
    </section>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/org-info.blade.php ENDPATH**/ ?>