@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Lista de Empresas'))
@section('content')

    @php $headLine = "<i class='fa-solid fa-building'></i> " . __('Lista de Empresas'); @endphp

    <div class="card shadow-sm">

        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeAdd' => 'admin.empresas.verify',
            'routeAddParams' => [],
            'nameAdd' => __('Nova empresa'),
            'permission' => 'GERENCIADOR_DE_EMPRESAS',
        ])

        <div class="card-body">
            @include("errors.messageFlash")

            @include('components/forms/_filtroPesquisaDefault', [
                "id" => "cadastroDeEmpresas",
                "placeholder" => __("Pesquisar por empresa...")
            ])

            @php $permissoes = auth()->user()->getPermissaoDetalhes('GERENCIADOR_DE_EMPRESAS'); @endphp

            <x-tables._table :thead="[
                __('Data de Cadastro'),
                __('Razão Social'),
                __('Nome Fantasia'),
                __('CNPJ'),
                __('E-mail'),
                __('Celular'),
                __('Telefone'),
                __('Status'),
                __('Ações'),
            ]" :pagination="$empresas->links()">
                <x-slot name="body">
                    @php $index = 0; @endphp
                    @forelse($empresas as $empresa)
                        <tr>
                            <td>{{ $empresa->created_at?->format('d/m/Y H:i') }}</td>
                            <td>{{ $empresa->razaoSocial }}</td>
                            <td>{{ $empresa->nomeFantasia }}</td>
                            <td>{{ $empresa->cnpj }}</td>
                            <td>{{ $empresa->email }}</td>
                            <td>{{ $empresa->celular }}</td>
                            <td>{{ $empresa->telefone }}</td>
                            <td>
                                @if(!empty($permissoes['editar']))
                                    @include('components/buttons/_status', [
                                        "index" => $index,
                                        "route" => "admin.empresas.status",
                                        "id" => $empresa->id,
                                        "status" => $empresa->status,
                                        "permission" => "GERENCIADOR_DE_EMPRESAS",
                                    ])
                                @else
                                    <span class="text-muted">-</span>
                                @endif
                            </td>
                            <td>
                                @php $podeEditar = !empty($permissoes['editar']); $podeExcluir = !empty($permissoes['excluir']); @endphp
                                @if($podeEditar || $podeExcluir)
                                    <div class="btn-group" role="group">
                                        @include('components/buttons/_editButton', [
                                            "route" => "admin.empresas.edit",
                                            "id" => $empresa->id,
                                            "fontawesome" => null,
                                            "title" => __("Editar"),
                                            "permission" => "GERENCIADOR_DE_EMPRESAS",
                                        ])

                                        @include('components/buttons/_deleteButton', [
                                            "message" => "* Esta empresa será excluída e esta ação não poderá ser desfeita?",
                                            "route" => "admin.empresas.destroy",
                                            "id" => $empresa->id,
                                            "fontawesome" => null,
                                            "title" => __("Excluir"),
                                            "permission" => "GERENCIADOR_DE_EMPRESAS",
                                        ])
                                    </div>
                                @else
                                    <span class="text-muted">-</span>
                                @endif
                            </td>
                        </tr>
                        @php $index++; @endphp
                    @empty
                        <tr>
                            <td colspan="9" class="text-muted fst-italic">{{ __('* Nenhum registro encontrado!') }}</td>
                        </tr>
                    @endforelse
                </x-slot>
            </x-tables._table>
        </div>
    </div>
@endsection
