<div class="mb-3">
    <label for="email1" class="form-label text-bold">Email principal: <span class="span-admin-create">*</span></label>
    <input type="email" class="form-control @error('email1') is-invalid @enderror" name="email1" id="email1" autocomplete="off" value="{{ old('email1') }}">
                            @error('email1')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="email2" class="form-label text-bold">Email 1:</label>
    <input type="email" class="form-control @error('email2') is-invalid @enderror" name="email2" id="email2" autocomplete="off" value="{{ old('email2') }}">
    @error('email2')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>

<div class="mb-3">
    <label for="email3" class="form-label text-bold">Email 2:</label>
    <input type="email" class="form-control @error('email3') is-invalid @enderror" name="email3" id="email3" autocomplete="off" value="{{ old('email3') }}">
    @error('email2')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>