<button class="btn btn-light text-dark"
    onclick="window.location.href='<?php echo e(route($url)); ?>'">
    <i class="fa-solid fa-arrow-left"></i> <?php echo e($label); ?>

</button>
<?php /**PATH /var/www/html/portal/resources/views/components/buttons/_backButton.blade.php ENDPATH**/ ?>