<!DOCTYPE html>
<html lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
    <?php echo $__env->make('layouts.landing_pages.calendariodeeventos.elements.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <body class="calendario-eventos">
        <?php echo $__env->yieldContent('content'); ?>
        <?php echo $__env->make('layouts.landing_pages.calendariodeeventos.elements.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    </body>
</html>
<?php /**PATH /var/www/html/portal/resources/views/layouts/landing_pages/calendariodeeventos/theme.blade.php ENDPATH**/ ?>