<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
@include('layouts.pmar.elements.head')

<body class="fade-in">
    <header>
        @include('layouts.pmar.elements.nav')
    </header>
    <main class="bg-white">
        <div class="container">
            <div class="row section-404">
                <div class="col-lg-6 text_404 text-center">
                    <h2>500</h2>
                    <p><strong>Ops! O endereço digitado está errado ou a página foi removida.</strong></p>
                    <p><a href="/">Ir para a página Inicial</a></p>

                    <!-- <p><strong>Nosso site está em manutenção para receber melhorias que tornarão sua navegação ainda melhor. Estaremos de volta em instantes.</strong></p> -->
                </div>
                <div class="col-lg-6 img_404">
                    <img src="{{ asset("pmar/assets/img/404.gif") }}" class="img-fluid" alt="">
                </div>
            </div>
        </div>
    </main>
    <footer class="footer-pmar">
        @include('layouts.pmar.elements.modal')
        @include('layouts.pmar.elements.defaultFooter')
    </footer>
</body>

</html>
