@foreach ($rows as $row)
<div class="mb-3">
    <label class="form-label">{{ $row['label'] }}</label>
    <input type="{{ $row['tipo'] }}" name="{{ $row["nome"] }}" class="form-control" value="{{ old($row['nome'], $row['valor']) }}" required>
</div>
@endforeach