<div class="mb-3">
    <input type="hidden" name="owner_id" id="owner_id" value="{{ auth()->user()->id }}"/>
    <label for="razaoSocial" class="form-label text-bold">{{ __("Razão social") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('razaoSocial') is-invalid @enderror" name="razaoSocial" id="razaoSocial" autocomplete="off" value="{{ old('razaoSocial', $empresa->razaoSocial) }}">
    @error('razaoSocial')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="nomeFantasia" class="form-label text-bold">{{ __("Nome fantasia") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('nomeFantasia') is-invalid @enderror" name="nomeFantasia" id="nomeFantasia" autocomplete="off" value="{{ old('nomeFantasia', $empresa->nomeFantasia) }}">
    @error('nomeFantasia')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="numeroInscricaoMunicipal" class="form-label text-bold">{{ __("Inscrição municipal") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('numeroInscricaoMunicipal') is-invalid @enderror" name="numeroInscricaoMunicipal" id="numeroInscricaoMunicipal" autocomplete="off" value="{{ old('numeroInscricaoMunicipal', $empresa->numeroInscricaoMunicipal) }}" data-mask="digits">
    @error('numeroInscricaoMunicipal')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="cnpj" class="form-label text-bold">{{ __("CNPJ") }}: <span class="span-admin-create">*</span></label>
    <input type="text" class="form-control @error('cnpj') is-invalid @enderror" name="cnpj" id="cnpj" autocomplete="off" value="{{ old('cnpj', $empresa->cnpj) }}" data-mask="cnpj" readonly="true">
    @error('cnpj')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3">
    <label for="anoAbertura" class="form-label text-bold">{{ __("Ano de abertura") }}: <span class="span-admin-create">*</span></label>
    <input type="year" class="form-control @error('anoAbertura') is-invalid @enderror" name="anoAbertura" id="datepickerYear" autocomplete="off" value="{{ old('anoAbertura', $empresa->anoAbertura) }}">
    @error('anoAbertura')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
<div class="mb-3 text-wrap">
    <label for="principalAtividade" class="form-label text-bold">{{ __("Principal atividade") }}: </label>
    <textarea class="form-control @error('principalAtividade') is-invalid @enderror textarea-comments" rows="4" name="principalAtividade" id="principalAtividade">{{ old('principalAtividade', $empresa->principalAtividade) }}</textarea>
    @error('principalAtividade')
        <small class="text-danger text-bold">{{ $message }}</small><br>
    @enderror
</div>
<div class="mb-3">
    <label for="status" class="form-label text-bold">{{ __("Status") }}: <span
    class="span-admin-create">*</span></label>
    <select class="form-control @error('status') is-invalid @enderror" name="status"
            id="status">
        @foreach(App\Enums\StatusEnum::cases() as $status)
            <option value="{{ $status->name }}" {{ old('status', $empresa->status) === $status->name ? 'selected' : '' }}>
                {{ $status->value }}
            </option>
        @endforeach
    </select>
                                @error('status')
        <small class="text-danger text-bold">{{ $message }}</small>
    @enderror
</div>
