@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Nova Licitação/Procedimento'))

@section('content')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-scale-balanced'></i> " . __('Licitações e Procedimentos'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.licitacoesProcedimentos.index',
            'routeBackParams' => request()->only(['ano', 'tipo_processo', 'tipo', 'status', 'nr_processo', 'page']),
            'nameBack' => __('Voltar'),
            'permission' => 'GERENCIADOR_DE_LICITACOES_E_PROCEDIMENTOS',
        ])

        <div class="card-body">
            <form method="post" action="{{ route('admin.licitacoesProcedimentos.store') }}" enctype="multipart/form-data">
                @include('admin.licitacoesProcedimentos._form')
            </form>
        </div>
    </div>
@endsection

@push('scripts')
    <script src="{{ asset('pmar/js/admin/licitacoes-procedimentos.js') }}?v={{ @filemtime(public_path('pmar/js/admin/licitacoes-procedimentos.js')) ?: time() }}"></script>
@endpush

