<?php $__env->startSection('title', env('APP_NAME') . ' - ' . ($servico->cds_titulo ?? __('Serviço'))); ?>

<?php $__env->startPush('styles'); ?>
<link rel="stylesheet" href="<?php echo e(asset('pmar/css/servicos/cartaservicos.css')); ?>">
<?php $__env->stopPush(); ?>

<?php $__env->startSection('content'); ?>


<section>
    <div class="container">
        <div class="row">
            <hr />
            <div class="col-12">
                <?php if (isset($component)) { $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.portal.breadcrumb','data' => ['items' => [
                    \App\Support\PortalBreadcrumb::home(),
                    \App\Support\PortalBreadcrumb::cartaServicos(),
                    \App\Support\PortalBreadcrumb::current(\Illuminate\Support\Str::limit($servico->cds_titulo ?? __('Serviço'), 60)),
                ]]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['items' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute([
                    \App\Support\PortalBreadcrumb::home(),
                    \App\Support\PortalBreadcrumb::cartaServicos(),
                    \App\Support\PortalBreadcrumb::current(\Illuminate\Support\Str::limit($servico->cds_titulo ?? __('Serviço'), 60)),
                ])]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $attributes = $__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__attributesOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003)): ?>
<?php $component = $__componentOriginal3d8365296ed4a4d5ce6037e216cc1003; ?>
<?php unset($__componentOriginal3d8365296ed4a4d5ce6037e216cc1003); ?>
<?php endif; ?>
            </div>
        </div>
    </div>
</section>


<section class="bg-light py-4 border-bottom">
    <div class="container">

        
        <?php if($servico->categorias->isNotEmpty()): ?>
            <div class="d-flex flex-wrap gap-2 mb-3">
                <?php $__currentLoopData = $servico->categorias; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $categoria): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <a href="<?php echo e(route('servicos.index', ['t' => $categoria->id_tipo])); ?>"
                        class="badge rounded-pill bg-primary bg-opacity-10 text-white text-decoration-none fw-semibold px-3 py-2 cs-hero-cat-pill">
                        <?php if(\Illuminate\Support\Str::startsWith((string) $categoria->tip_class, 'storage/')): ?>
                            <img src="<?php echo e(asset($categoria->tip_class)); ?>" alt="" width="13" height="13"
                                class="rounded-1 me-1 cs-badge-img">
                        <?php else: ?>
                            <i class="fa <?php echo e($categoria->tip_class ?? 'fa-circle'); ?> me-1 cs-badge-icon" aria-hidden="true"></i>
                        <?php endif; ?>
                        <?php echo e($categoria->tip_descricao); ?>

                    </a>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
        <?php endif; ?>

        
        <h1 class="h3 fw-bold text-primary mb-3 lh-sm"><?php echo e($servico->cds_titulo); ?></h1>

        
        <div class="d-flex flex-wrap align-items-center gap-2 mt-1">
            <a href="<?php echo e(route('servicos.index')); ?>"
                class="d-inline-flex align-items-center gap-1 text-muted text-decoration-none fw-semibold cs-back-link">
                <i class="fa-solid fa-chevron-left cs-back-chevron" aria-hidden="true"></i>
                <?php echo e(__('Voltar aos Serviços')); ?>

            </a>

            <?php if(!empty($servico->cds_solicitacao)): ?>
                <span class="text-muted" aria-hidden="true">·</span>
                <a href="<?php echo e($servico->cds_solicitacao); ?>" target="_blank" rel="noopener noreferrer"
                    class="btn btn-success btn-sm rounded-pill fw-semibold px-3 shadow-sm cs-online-btn">
                    <i class="fa-solid fa-up-right-from-square me-1" aria-hidden="true"></i>
                    <?php echo e(__('Acessar Serviço Online')); ?>

                </a>
            <?php endif; ?>
        </div>

    </div>
</section>


<section class="py-4 py-md-5">
    <div class="container">
        <div class="row g-4">

            
            <div class="col-12 col-lg-8">

                
                <div class="card border-0 shadow-sm rounded-3 overflow-hidden">

                    
                    <?php if(!empty($servico->cds_descricao)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-file-lines" aria-hidden="true"></i>
                                <?php echo e(__('Descrição')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-desc-text">
                                <?php echo nl2br(e($servico->cds_descricao)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->orgao_responsavel) || !empty($servico->cds_setor)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <?php if(!empty($servico->orgao_responsavel)): ?>
                                <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                    <i class="fa-solid fa-building" aria-hidden="true"></i>
                                    <?php echo e(__('Órgão Responsável')); ?>

                                </p>
                                <p class="mb-0 <?php if(!empty($servico->cds_setor)): ?> mb-3 <?php endif; ?>">
                                    <span class="badge bg-light text-primary border fw-semibold px-3 py-2 rounded-3 cs-badge-detail">
                                        <?php echo e($servico->orgao_responsavel); ?>

                                    </span>
                                </p>
                            <?php endif; ?>
                            <?php if(!empty($servico->cds_setor)): ?>
                                <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                    <i class="fa-solid fa-briefcase" aria-hidden="true"></i>
                                    <?php echo e(__('Setor')); ?>

                                </p>
                                <p class="mb-0">
                                    <span class="badge bg-light text-primary border fw-semibold px-3 py-2 rounded-3 cs-badge-detail">
                                        <?php echo e($servico->cds_setor); ?>

                                    </span>
                                </p>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_quem)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-user" aria-hidden="true"></i>
                                <?php echo e(__('Quem pode solicitar')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_quem)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_quando)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-calendar" aria-hidden="true"></i>
                                <?php echo e(__('Quando pode solicitar')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_quando)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_atendimento)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-users" aria-hidden="true"></i>
                                <?php echo e(__('Atendimento')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_atendimento)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_entrada)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-location-dot" aria-hidden="true"></i>
                                <?php echo e(__('Local(is) de entrada')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_entrada)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_requisitos)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-list-check" aria-hidden="true"></i>
                                <?php echo e(__('Requisitos e Documentos necessários')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_requisitos)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_prazo) && $servico->cds_prazo !== '0'): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-clock" aria-hidden="true"></i>
                                <?php echo e(__('Prazos')); ?>

                            </p>
                            <span class="badge bg-light text-primary border fw-semibold px-3 py-2 rounded-3 cs-badge-detail">
                                <?php echo e($servico->cds_prazo); ?>

                            </span>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_taxas)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-dollar-sign" aria-hidden="true"></i>
                                <?php echo e(__('Taxas')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_taxas)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_legislacao)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-book" aria-hidden="true"></i>
                                <?php echo e(__('Legislação')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_legislacao)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_etapas)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-stairs" aria-hidden="true"></i>
                                <?php echo e(__('Etapas')); ?>

                            </p>
                            <div class="text-secondary lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_etapas)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_contato) || !empty($servico->cds_telefone) || !empty($servico->cds_email)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-3 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-phone" aria-hidden="true"></i>
                                <?php echo e(__('Contato')); ?>

                            </p>
                            <div class="d-flex flex-column gap-2">
                                <?php if(!empty($servico->cds_contato)): ?>
                                    <div class="text-secondary lh-lg cs-body-text">
                                        <?php echo nl2br(e($servico->cds_contato)); ?>

                                    </div>
                                <?php endif; ?>
                                <?php if(!empty($servico->cds_telefone)): ?>
                                    <span class="badge bg-light text-primary border fw-semibold px-3 py-2 rounded-3 d-inline-flex align-items-center gap-2 cs-badge-detail cs-badge-fit">
                                        <i class="fa-solid fa-phone fa-xs" aria-hidden="true"></i>
                                        <?php echo e($servico->cds_telefone); ?>

                                    </span>
                                <?php endif; ?>
                                <?php if(!empty($servico->cds_email)): ?>
                                    <a href="mailto:<?php echo e($servico->cds_email); ?>"
                                        class="badge bg-light text-primary border fw-semibold px-3 py-2 rounded-3 d-inline-flex align-items-center gap-2 text-decoration-none cs-badge-detail cs-badge-fit">
                                        <i class="fa-solid fa-envelope fa-xs" aria-hidden="true"></i>
                                        <?php echo e($servico->cds_email); ?>

                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if(!empty($servico->cds_obs)): ?>
                        <div class="card-body border-bottom px-4 py-4">
                            <p class="text-uppercase fw-bold mb-2 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-circle-info" aria-hidden="true"></i>
                                <?php echo e(__('Observações')); ?>

                            </p>
                            <div class="alert alert-warning border-0 rounded-3 mb-0 lh-lg cs-body-text">
                                <?php echo nl2br(e($servico->cds_obs)); ?>

                            </div>
                        </div>
                    <?php endif; ?>

                    
                    <?php if($servico->tem_mapa): ?>
                        <div class="card-body px-4 py-4">
                            <p class="text-uppercase fw-bold mb-3 d-flex align-items-center gap-2 cs-section-label">
                                <i class="fa-solid fa-map" aria-hidden="true"></i>
                                <?php echo e(__('Mapa de Localização')); ?>

                            </p>
                            <div class="ratio ratio-16x9 rounded-3 overflow-hidden">
                                <iframe
                                    src="<?php echo e($servico->cds_mapa); ?>"
                                    title="<?php echo e(__('Mapa do serviço')); ?>"
                                    loading="lazy"
                                    referrerpolicy="no-referrer-when-downgrade">
                                </iframe>
                            </div>
                        </div>
                    <?php endif; ?>

                </div>
            </div>

            
            <aside class="col-12 col-lg-4" aria-label="<?php echo e(__('Navegação lateral')); ?>">
                <div class="sticky-top cs-sidebar-sticky">

                    
                    <nav class="card-slug mb-3" aria-label="<?php echo e(__('Categorias de serviço')); ?>">
                        <h2 class="slug-telefone"><?php echo e(__('Categorias')); ?></h2>
                        <ul class="list-unstyled mb-0">
                            <?php $__empty_1 = true; $__currentLoopData = $categorias; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $categoria): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                                <li>
                                    <a
                                        href="<?php echo e(route('servicos.index', ['t' => $categoria->id_tipo])); ?>"
                                        class="link-secretarias <?php echo e(in_array((int) $categoria->id_tipo, $tipoIdsAtivos, true) ? 'fw-bold text-primary' : 'text-dark'); ?>"
                                    >
                                        <span><?php echo e($categoria->tip_descricao); ?></span>
                                        <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                    </a>
                                </li>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
                                <li class="text-muted small"><?php echo e(__('Sem categorias disponíveis.')); ?></li>
                            <?php endif; ?>
                        </ul>
                    </nav>

                    
                    <div class="card-slug">
                        <h2 class="slug-telefone"><?php echo e(__('Acesso Rápido')); ?></h2>
                        <ul class="list-unstyled mb-0">
                            <li>
                                <a href="<?php echo e(route('servicos.index', ['pq' => 'IPTU'])); ?>"
                                    class="link-secretarias text-dark">
                                    <span>IPTU</span>
                                    <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                </a>
                            </li>
                            <li>
                                <a href="<?php echo e(route('servicos.index', ['pq' => 'Nota Fiscal'])); ?>"
                                    class="link-secretarias text-dark">
                                    <span><?php echo e(__('Nota Fiscal')); ?></span>
                                    <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                </a>
                            </li>
                            <li>
                                <a href="<?php echo e(route('servicos.index', ['pq' => 'Recursos'])); ?>"
                                    class="link-secretarias text-dark">
                                    <span><?php echo e(__('Recursos')); ?></span>
                                    <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                </a>
                            </li>
                            <li>
                                <a href="<?php echo e(route('servicos.index', ['pq' => 'Matrícula'])); ?>"
                                    class="link-secretarias text-dark">
                                    <span><?php echo e(__('Matrícula')); ?></span>
                                    <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                </a>
                            </li>
                            <li>
                                <a href="<?php echo e(route('servicos.index', ['pq' => 'Abertura de Processo'])); ?>"
                                    class="link-secretarias text-dark">
                                    <span><?php echo e(__('Abertura de Processo')); ?></span>
                                    <i class="fa-solid fa-angle-right text-primary" aria-hidden="true"></i>
                                </a>
                            </li>
                        </ul>
                    </div>

                </div>
            </aside>

        </div>
    </div>
</section>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/servicos/show.blade.php ENDPATH**/ ?>