<?php if(isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar']): ?>
    <?php $formId = 'checkStatus_' . (isset($idPrefix) ? $idPrefix . '_' : '') . $index; ?>
    <form id="<?php echo e($formId); ?>" class="fix" action="<?php echo e(route($route, $id)); ?>" method="post">
        <?php echo csrf_field(); ?>
        <?php if(!empty($queryParams)): ?>
            <?php $__currentLoopData = $queryParams; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $value): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <?php if($value !== null && $value !== ''): ?>
                    <input type="hidden" name="<?php echo e($key); ?>" value="<?php echo e($value); ?>">
                <?php endif; ?>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        <?php else: ?>
            <input type="hidden" name="page" value="<?php echo e(request()->input('page', 1)); ?>">
            <?php if(request()->filled('q')): ?>
                <input type="hidden" name="q" value="<?php echo e(request()->input('q')); ?>">
            <?php endif; ?>
        <?php endif; ?>
        <?php if($status == "ATIVADO" || $status == 1 ): ?>
            <div class="form-check form-switch d-flex justify-content-center">
                <input type="hidden" name="checkStatus" value="DESATIVADO">
                <input class="form-check-input" type="checkbox" checked
                   onclick="javascript:document.getElementById('<?php echo e($formId); ?>').submit()">
            </div>
        <?php else: ?>
            <div class="form-check form-switch d-flex justify-content-center">
                <input type="hidden" name="checkStatus" value="ATIVADO">
                <input class="form-check-input" type="checkbox"
                   onclick="javascript:document.getElementById('<?php echo e($formId); ?>').submit()">
            </div>
        <?php endif; ?>
    </form>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/components/buttons/_status.blade.php ENDPATH**/ ?>