<div class="{{ $columnClass ?? 'col-12 col-xl-6' }}">
    <div class="card shadow-sm h-100">
        <div class="card-header bg-white border-0 d-flex justify-content-between align-items-center flex-wrap gap-2">
            <div class="d-flex align-items-center gap-3">
                <span class="badge text-bg-primary rounded-circle p-3">
                    <i class="{{ $section['icon'] ?? 'fa-solid fa-chart-line' }}"></i>
                </span>
                <div>
                    <h5 class="mb-0">{{ __($section['title']) }}</h5>
                    <small class="text-muted">{{ __($section['subtitle']) }}</small>
                </div>
            </div>
        </div>

        <div class="card-body">
            @if (!empty($section['metrics']))
            <div class="row g-2 d-flex justify-content-center">
                @foreach ($section['metrics'] as $metric)
                <div class="col-12 col-sm-6 col-lg-4">
                    <div class="border rounded-3 p-3 h-100 bg-light">
                        <p class="text-muted small mb-1">{{ __($metric['label']) }}</p>
                        <p class="display-6 fw-semibold mb-0">
                            {{ number_format((int) ($metric['value'] ?? 0), 0, ',', '.') }}
                        </p>
                    </div>
                </div>
                @endforeach
            </div>
            @endif

        </div>
    </div>
</div>
