<section class="ma-hero-block" aria-labelledby="ma-hero-title">
    <div class="container ma-hero-block__container">
        <div class="ma-hero">
            <img src="<?php echo e(asset('mobiangra-assets/images/banner-mobiangra.png')); ?>"
                class="ma-hero__banner"
                alt=""
                width="1920"
                height="640"
                decoding="async"
                fetchpriority="high"
                aria-hidden="true">
            <div class="ma-hero__overlay" aria-hidden="true"></div>

            <div class="ma-hero__container">
                <div class="ma-hero__panel">
                    <div class="ma-hero__content">
                        <h1 id="ma-hero-title" class="ma-hero__title"><?php echo e(__('Mobilidade que conecta Angra')); ?></h1>
                        <p class="ma-hero__subtitle">
                            <?php echo e(__('Consulte horários, itinerários e acompanhe seu ônibus em tempo real.')); ?>

                        </p>

                        <?php if(($linhas ?? collect())->isNotEmpty()): ?>
                            <?php if (isset($component)) { $__componentOriginal272a6032dbeb3c07e89494d9783841db = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal272a6032dbeb3c07e89494d9783841db = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.hero-linha-combobox','data' => ['linhas' => $linhas]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.hero-linha-combobox'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['linhas' => \Illuminate\View\Compilers\BladeCompiler::sanitizeComponentAttribute($linhas)]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal272a6032dbeb3c07e89494d9783841db)): ?>
<?php $attributes = $__attributesOriginal272a6032dbeb3c07e89494d9783841db; ?>
<?php unset($__attributesOriginal272a6032dbeb3c07e89494d9783841db); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal272a6032dbeb3c07e89494d9783841db)): ?>
<?php $component = $__componentOriginal272a6032dbeb3c07e89494d9783841db; ?>
<?php unset($__componentOriginal272a6032dbeb3c07e89494d9783841db); ?>
<?php endif; ?>
                            <div id="horarios-linhas-content" class="d-none" aria-hidden="true"></div>
                        <?php else: ?>
                            <form class="ma-hero__search" id="ma-hero-search" action="<?php echo e(route('mobiangra.horarios')); ?>"
                                method="get" role="search">
                                <label class="visually-hidden" for="ma-search-input"><?php echo e(__('Buscar linha, bairro ou destino')); ?></label>
                                <div class="ma-hero__search-inner">
                                    <i class="fa-solid fa-magnifying-glass ma-hero__search-icon" aria-hidden="true"></i>
                                    <input type="search" name="linha" id="ma-search-input" class="ma-hero__search-input"
                                        placeholder="<?php echo e(__('Digite a linha, bairro ou destino')); ?>"
                                        autocomplete="off" enterkeyhint="search">
                                    <button type="submit" class="btn ma-hero__search-btn d-none d-lg-inline-flex">
                                        <?php echo e(__('Buscar')); ?>

                                    </button>
                                </div>
                            </form>
                        <?php endif; ?>
                    </div>

                    <div class="ma-hero__actions-wrap d-none d-lg-block" aria-label="<?php echo e(__('Ações rápidas')); ?>">
                        <div class="ma-hero__actions-grid ma-hero__actions-grid--desktop">
                            <a href="<?php echo e(route('mobiangra.mapa')); ?>" class="ma-hero__action-card">
                                <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                                    <i class="fa-solid fa-map-location-dot"></i>
                                </span>
                                <span class="ma-hero__action-label"><?php echo e(__('Mapa em tempo real')); ?></span>
                            </a>
                            <a href="<?php echo e(route('mobiangra.horarios')); ?>" class="ma-hero__action-card">
                                <span class="ma-hero__action-icon ma-hero__action-icon--green" aria-hidden="true">
                                    <i class="fa-solid fa-bus-simple"></i>
                                </span>
                                <span class="ma-hero__action-label"><?php echo e(__('Horários')); ?></span>
                            </a>
                            <a href="<?php echo e(route('mobiangra.passageiro_cidadao')); ?>" class="ma-hero__action-card">
                                <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                                    <i class="fa-solid fa-id-card"></i>
                                </span>
                                <span class="ma-hero__action-label"><?php echo e(__('Passageiro Cidadão')); ?></span>
                            </a>
                            <a href="<?php echo e(route('mobiangra.informacoes')); ?>" class="ma-hero__action-card">
                                <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                                    <i class="fa-solid fa-circle-info"></i>
                                </span>
                                <span class="ma-hero__action-label"><?php echo e(__('Informações ao Usuário')); ?></span>
                            </a>
                            <a href="<?php echo e(route('mobiangra.fale_conosco')); ?>" class="ma-hero__action-card">
                                <span class="ma-hero__action-icon ma-hero__action-icon--purple" aria-hidden="true">
                                    <i class="fa-solid fa-comments"></i>
                                </span>
                                <span class="ma-hero__action-label"><?php echo e(__('Fale Conosco')); ?></span>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="ma-hero__extras d-lg-none" aria-label="<?php echo e(__('Ações rápidas')); ?>">
            <div class="ma-hero__actions-grid ma-hero__actions-grid--mobile">
                <a href="<?php echo e(route('mobiangra.mapa')); ?>" class="ma-hero__action-card ma-hero__action-card--featured">
                    <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                        <i class="fa-solid fa-map-location-dot"></i>
                    </span>
                    <span class="ma-hero__action-label"><?php echo e(__('Mapa em tempo real')); ?></span>
                </a>
                <a href="<?php echo e(route('mobiangra.horarios')); ?>" class="ma-hero__action-card">
                    <span class="ma-hero__action-icon ma-hero__action-icon--green" aria-hidden="true">
                        <i class="fa-solid fa-bus-simple"></i>
                    </span>
                    <span class="ma-hero__action-label"><?php echo e(__('Horários')); ?></span>
                </a>
                <a href="<?php echo e(route('mobiangra.passageiro_cidadao')); ?>" class="ma-hero__action-card">
                    <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                        <i class="fa-solid fa-id-card"></i>
                    </span>
                    <span class="ma-hero__action-label"><?php echo e(__('Passageiro Cidadão')); ?></span>
                </a>
                <a href="<?php echo e(route('mobiangra.informacoes')); ?>" class="ma-hero__action-card">
                    <span class="ma-hero__action-icon ma-hero__action-icon--blue" aria-hidden="true">
                        <i class="fa-solid fa-circle-info"></i>
                    </span>
                    <span class="ma-hero__action-label"><?php echo e(__('Informações ao Usuário')); ?></span>
                </a>
                <a href="<?php echo e(route('mobiangra.fale_conosco')); ?>" class="ma-hero__action-card">
                    <span class="ma-hero__action-icon ma-hero__action-icon--purple" aria-hidden="true">
                        <i class="fa-solid fa-comments"></i>
                    </span>
                    <span class="ma-hero__action-label"><?php echo e(__('Fale Conosco')); ?></span>
                </a>
            </div>
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/hero.blade.php ENDPATH**/ ?>