<?php $__env->startSection('title', env('APP_NAME') . ' :: Manual de Redação Oficial'); ?>
<?php $__env->startSection('content'); ?>
    <section>
        <div class="container">
            <div class="row">
                <hr />
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(route('paginas.home')); ?>">Portal</a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="<?php echo e(url('/secretarias/secretaria-de-governo-e-relacoes-institucionais')); ?>"><?php echo e(__('Secretaria de Governo e Relações Institucionais')); ?></a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Manual de Redação Oficial da Prefeitura de
                                Angra</li>
                        </ol>
                    </nav>
                </div>
                <div class="col-md-9 nopadding single-article espaco_conteudo">
                    <header class="article-header">
                        <!-- Title -->
                        <h1 class="title">Manual de Reda&ccedil;&atilde;o Oficial da Prefeitura de Angra</h1>
                        <!-- Excerpt -->
                    </header>
                    <article class="article-main">

                        <img src="images/secretarias/sgri/manual-de-redacao.jpg" alt="Manual de Reda&ccedil;&atilde;o PMAR"
                            width="250" class="alignleft" style="border:solid 1px #000;">
                        <p>Com o objetivo de contribuir para a melhoria dos serviços públicos oferecidos à população, a
                            Prefeitura Municipal de Angra dos Reis apresenta este Manual de Redação Oficial aos servidores
                            públicos, propondo orientações seguras na elaboração de documentos. Trata-se de um instrumento
                            complementar, que visa padronizar e dar ordenamento às comunicações oficiais que são comuns à
                            maioria das Superintendências, Secretarias, Fundações e Autarquias.</p>
                        <p>Neste manual, os servidores terão uma fonte permanente de consulta de normas gerais e técnicas de
                            elaboração e redação, além de orientações sobre padrões de procedimento, formato e acordos
                            ortográficos na apresentação das comunicações administrativas escritas.</p>

                        <div class="clear"></div>
                        <div class="list_down top25">
                            <ul>
                                <a href="downloads/sgri/Manual_redacao_pmar-2-ED-FINAL.pdf" target="_blank">
                                    <li><img
                                        src="<?php echo e(asset('pmar/assets/img/icons/download.gif')); ?>"
                                        alt="Baixar arquivo" width="18" height="18" border="0"><strong>Download do Manual de Redação</strong><span class="preto"> (PDF,
                                            2.3MB)</span></li>
                                </a>
                                <a href="downloads/SAD/servidor/brasao_angra_peq2.gif" target="_blank">
                                    <li><img
                                        src="<?php echo e(asset('pmar/assets/img/icons/download.gif')); ?>"
                                        alt="Baixar arquivo" width="18" height="18" border="0"><strong>Bras&atilde;o da Munic&iacute;pio </strong> <span class="preto">(GIF, 8KB,
                                            74x90)</span></li>
                                </a>
                                <a href="downloads/SAD/servidor/brasao_angra_peq.gif" target="_blank">
                                    <li><img
                                        src="<?php echo e(asset('pmar/assets/img/icons/download.gif')); ?>"
                                        alt="Baixar arquivo" width="18" height="18" border="0"><strong>Bras&atilde;o da Munic&iacute;pio </strong> <span class="preto">(GIF, 30KB,
                                            217x625)</span></li>
                                </a>
                                <a href="downloads/SAD/servidor/brasao_angra_big.gif" target="_blank">
                                    <li><img
                                        src="<?php echo e(asset('pmar/assets/img/icons/download.gif')); ?>"
                                        alt="Baixar arquivo" width="18" height="18" border="0"><strong>Bras&atilde;o da Munic&iacute;pio </strong> <span class="preto">(GIF, 87KB,
                                            447x546)</span></li>
                                </a>
                                <a href="downloads/SAD/servidor/brasao_angra_cdr.rar">
                                    <li><img
                                        src="<?php echo e(asset('pmar/assets/img/icons/download.gif')); ?>"
                                        alt="Baixar arquivo" width="18" height="18" border="0"><strong>Bras&atilde;o da Munic&iacute;pio </strong> <span class="preto">(CDR,
                                            94KB)</span></li>
                                </a>
                            </ul>
                        </div>
                    </article>

                </div>
            </div>
        </div>
    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.pmar.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/paginas/manual-de-redacao.blade.php ENDPATH**/ ?>