<tr>
    <td align="center" style="background-color:#007bc3; padding:30px;">
        <img src="https://angra.rj.gov.br/pmar/assets/img/brasao-2026.png"
             alt="{{ __('Logo Prefeitura de Angra dos Reis') }}"
             width="260"
             style="max-width:80px; height:auto; display:block;">
    </td>
</tr>
