<section class="secretario-footer bg-waves">
    <div class="container">
        <div class="row secretario-footer-row">
            <!-- Foto e nome do Secretário -->
            <div class="secretario-footer-foto col-sm-12 col-md-12 col-lg-12 col-xl-3 col-xxl-3">
                <img src="<?php echo e(asset($secretaria->managerPhoto)); ?>" alt="<?php echo e($secretaria->manager); ?>" title="<?php echo e($secretaria->manager); ?>"                    >
                <p>
                    <?php if($secretaria->type == 'SECRETARIA'): ?>
                        <?php if($secretaria->pronunciation == 'SECRETARIO'): ?>
                            <?php echo e(__('Secretário')); ?>

                        <?php elseif($secretaria->pronunciation == 'PROCURADO_GERAL_DO_MUNICIPIO'): ?>
                            <?php echo e(__('Procurador-Geral')); ?>

                        <?php elseif($secretaria->pronunciation == 'CONTROLADOR_GERAL_DO_MUNICIPIO'): ?>
                            <?php echo e(__('Controlador-Geral')); ?>

                        <?php elseif($secretaria->pronunciation == 'DIRETOR'): ?>
                            <?php echo e(__('Diretor')); ?>

                        <?php elseif($secretaria->pronunciation == 'DIRETORA'): ?>
                            <?php echo e(__('Diretora')); ?>

                        <?php elseif($secretaria->pronunciation == 'SUPERINTENDENTE'): ?>
                            <?php echo e(__('Superintendente')); ?>

                        <?php else: ?>
                            <?php echo e(__('Secretária')); ?>

                        <?php endif; ?>
                    <?php elseif($secretaria->type == 'FUNDACAO' || $secretaria->type == 'AUTARQUIA'): ?>
                        <?php echo e(__('Presidente')); ?>

                    <?php elseif($secretaria->type == 'SECRETARIA_EXECUTIVA'): ?>
                        <?php if($secretaria->pronunciation == 'SECRETARIO_EXECUTIVO'): ?>
                            <?php echo e(__('Secretário Executivo')); ?>

                        <?php else: ?>
                            <?php echo e(__('Secretária Executiva')); ?>

                        <?php endif; ?>
                    <?php endif; ?>
                </p>
                <a href="<?php echo e(route("paginas.formacao-academica", $secretaria->slug)); ?>">
                    <h5><?php echo e($secretaria->manager); ?></h5>
                </a>
            </div>

            <!-- Localização -->
            <?php echo $__env->make('paginas.parts.google-maps', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </div>
</section><?php /**PATH /var/www/html/portal/resources/views/paginas/parts/secretario.blade.php ENDPATH**/ ?>