<?php $attributes ??= new \Illuminate\View\ComponentAttributeBag;

$__newAttributes = [];
$__propNames = \Illuminate\View\ComponentAttributeBag::extractPropNames(([
    'nearbyUrl' => route('mobiangra.nearby_lines'),
    'mapaUrl' => route('mobiangra.mapa', ['modo' => 'proximos']),
    'defaultRadius' => (int) config('mobiangra.nearby.default_radius_m', 800),
    'defaultLimit' => (int) config('mobiangra.nearby.default_limit', 5),
]));

foreach ($attributes->all() as $__key => $__value) {
    if (in_array($__key, $__propNames)) {
        $$__key = $$__key ?? $__value;
    } else {
        $__newAttributes[$__key] = $__value;
    }
}

$attributes = new \Illuminate\View\ComponentAttributeBag($__newAttributes);

unset($__propNames);
unset($__newAttributes);

foreach (array_filter(([
    'nearbyUrl' => route('mobiangra.nearby_lines'),
    'mapaUrl' => route('mobiangra.mapa', ['modo' => 'proximos']),
    'defaultRadius' => (int) config('mobiangra.nearby.default_radius_m', 800),
    'defaultLimit' => (int) config('mobiangra.nearby.default_limit', 5),
]), 'is_string', ARRAY_FILTER_USE_KEY) as $__key => $__value) {
    $$__key = $$__key ?? $__value;
}

$__defined_vars = get_defined_vars();

foreach ($attributes->all() as $__key => $__value) {
    if (array_key_exists($__key, $__defined_vars)) unset($$__key);
}

unset($__defined_vars, $__key, $__value); ?>

<div class="ma-nearby-lines"
    id="ma-nearby-lines"
    data-nearby-url="<?php echo e($nearbyUrl); ?>"
    data-mapa-url="<?php echo e($mapaUrl); ?>"
    data-radius="<?php echo e($defaultRadius); ?>"
    data-limit="<?php echo e($defaultLimit); ?>"
    data-label-loading="<?php echo e(__('Buscando linhas próximas...')); ?>"
    data-label-empty="<?php echo e(__('Nenhuma linha encontrada em um raio de :radius m.', ['radius' => $defaultRadius])); ?>"
    data-label-error-permission="<?php echo e(__('Permissão de localização negada. Ative o GPS nas configurações do navegador.')); ?>"
    data-label-error-unavailable="<?php echo e(__('Não foi possível obter sua localização. Tente novamente.')); ?>"
    data-label-error-outside="<?php echo e(__('Sua localização está fora da área de cobertura do transporte coletivo de Angra dos Reis.')); ?>"
    data-label-error-generic="<?php echo e(__('Não foi possível carregar as linhas próximas. Tente novamente.')); ?>"
    data-label-distance="<?php echo e(__('a :distance m')); ?>"
    data-label-stop="<?php echo e(__('Parada')); ?>"
    data-label-horarios="<?php echo e(__('Horários')); ?>"
    data-label-horarios-aria="<?php echo e(__('Horários da linha :linha')); ?>"
    data-label-mapa="<?php echo e(__('Ver no mapa')); ?>">
    <div class="ma-alerts__header">
        <h2 class="ma-alerts__title">
            <i class="fa-solid fa-location-crosshairs ma-nearby-lines__title-icon" aria-hidden="true"></i>
            <?php echo e(__('Linhas próximas a você')); ?>

        </h2>
        <a href="<?php echo e($mapaUrl); ?>" class="ma-alerts__see-all ma-nearby-lines__map-link">
            <?php echo e(__('Ver no mapa')); ?>

            <i class="fa-solid fa-arrow-right" aria-hidden="true"></i>
        </a>
    </div>

    <p class="ma-nearby-lines__intro text-muted">
        <?php echo e(__('Descubra quais linhas passam perto de onde você está.')); ?>

    </p>

    <div class="ma-nearby-lines__actions">
        <button type="button"
            class="btn btn-primary btn-sm ma-nearby-lines__locate-btn"
            id="ma-nearby-lines-locate"
            aria-controls="ma-nearby-lines-body"
            aria-describedby="ma-nearby-lines-hint">
            <i class="fa-solid fa-location-crosshairs" aria-hidden="true"></i>
            <?php echo e(__('Usar minha localização')); ?>

        </button>
    </div>

    <p class="ma-nearby-lines__hint text-muted mb-0" id="ma-nearby-lines-hint">
        <?php echo e(__('Sua localização não é armazenada. O acesso ao GPS exige sua permissão.')); ?>

    </p>

    <div class="ma-nearby-lines__body"
        id="ma-nearby-lines-body"
        role="region"
        aria-live="polite"
        aria-atomic="true"
        hidden></div>
</div>
<?php /**PATH /var/www/html/portal/resources/views/components/mobiangra/nearby-lines-card.blade.php ENDPATH**/ ?>