@extends('layouts.cmgd.theme')
@section("title", "Comitê CMGD - Governança Digital - Angra dos Reis" )
@section('content')

    @include('cmgd/header')
    @include('cmgd/estrategia')
    @include('cmgd/comite')

    <section class="bg-white" id="atas">
        <div class="container">
            <div class="row">
                <div class="col-12 text-center mb-5">
                    <h2>{{ __("Atas e Pareceres") }}</h2>
                </div>
            </div>
            @php $num = false; @endphp

            @if($num)
                <div class="row">
                    <div class="col-md-6 col-sm-6 p-3">
                        @include('cmgd/atas')
                    </div>
                    <div class="col-md-6 col-sm-6 p-3">
                        @include('cmgd/pareceres')
                    </div>
                </div>
            @else
                <div class="row">
                    <div class="col-12 p-3 text-center">
                        <small class="text-info">Aguardando publicação.</small>
                    </div>
                </div>
            @endif
        </div>
    </section>

    @include('cmgd/legislacao')    
    @include('cmgd/accordion')


@endsection