<div class="col-12 mb-3">
    <div class="row d-flex flex-column align-items-center">
        <div class="col">
            <div class="card-slug mb-5" data-telefones-toggle-wrap>
                <h2 class="slug-telefone"><?php echo e(__('Contatos')); ?></h2>

                <ul id="telefones-container" class="list-unstyled">
                    <?php $__empty_1 = true; $__currentLoopData = $telefones; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $telefone): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                    <li class="telefone-item <?php echo e($index >= 5 ? 'd-none' : ''); ?>">
                        <h5 class="slug-summary mt-3"><?php echo e($telefone['telefone']); ?></h5>
                        <ul class="list-unstyled">
                            <?php $__currentLoopData = $telefone['numeros']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $numero): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li>
                                <i class="bi bi-telephone icon-telefone" aria-hidden="true"></i>
                                <a class="text-dark text-decoration-none tel-number" href="tel:<?php echo e($numero['link']); ?>">
                                    <?php echo e($numero['numero']); ?>

                                </a>
                            </li>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </ul>
                    </li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
                        <li><?php echo e(__('* Nenhum telefone encontrado!')); ?></li>
                    <?php endif; ?>
                </ul>

                <?php if(count($telefones) > 5): ?>
                <button type="button"
                        class="text-center btn text-secondary rounded-5 bg-light mt-3"
                        data-telefones-toggle-btn
                        data-label-more="<?php echo e(__('Ver mais')); ?>"
                        data-label-less="<?php echo e(__('Mostrar menos')); ?>"><?php echo e(__('Ver mais')); ?></button>
                <?php endif; ?>

            </div>
        </div>
    </div>
</div>
<?php if (! $__env->hasRenderedOnce('b9243f37-a072-4bc1-8e7f-1b6dfb82a43e')): $__env->markAsRenderedOnce('b9243f37-a072-4bc1-8e7f-1b6dfb82a43e'); ?>
    <?php $__env->startPush('scripts'); ?>
        <script src="<?php echo e(asset('pmar/js/telefones-toggle.js')); ?>" defer></script>
    <?php $__env->stopPush(); ?>
<?php endif; ?>
<?php /**PATH /var/www/html/portal/resources/views/paginas/parts/telefones.blade.php ENDPATH**/ ?>