<nav class="navbar navbar-menu navbar-light" style="background-color: rgb(17, 16, 29);">
    <div class="container-fluid">
        <a class="navbar-brand text-white" href="{{ route("paginas.home") }}">
            {{ __("Prefeitura de Angra dos Reis") }}
        </a>
        <div class="d-flex align-items-center">
            <div class="d-inline ms-3">
                <img src="{{ asset(auth()->user()->photo) }}" class="img-fluid img-thumbnail src-file-image" alt="{{ auth()->user()->firstName }} {{ auth()->user()->lastName }}" title="{{ auth()->user()->firstName }} {{ auth()->user()->lastName }}" width="40px"/>
            </div>
            <div class="d-inline text-start text-white ms-1">Olá, <span class="fs-1 fw-bold">{{ auth()->user()->firstName }}</span></div>
            <div class="d-inline ms-3">
                <button class="btn btn-light" onclick="javascript:window.location.href='{{ route("admin.profile") }}'">{{ __("Perfil") }}</button>
            </div>
            <div class="d-inline ms-3">
                <button class="btn btn-danger" onclick="javascript:window.location.href='{{ route((Auth::user()->govbr_sub != null) ? 'admin.logout.govbr' : 'admin.logout') }}'">{{ __("Sair") }}</button>
            </div>
        </div>
    </div>
   
</nav>