@foreach($items as $item)
    <li class="nav-item-fibromialgia me-2" role="presentation">
        <a class="nav-link fw-bold {{ $item['class'] ?? '' }}"
           data-bs-toggle="tab"
           href="#{{ $item['hash'] }}"
           role="tab">
            {!! $item['label'] !!}
        </a>
    </li>
@endforeach