<section class="ma-alerts-promo" id="ma-nearby-promo">
    <div class="container">
        <div class="row g-4">
            <div class="col-12 col-lg-7 order-2 order-lg-1">
                <div class="ma-alerts">
                    <?php if (isset($component)) { $__componentOriginal76bb3df5db76d5572baa02ecfbf5381e = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal76bb3df5db76d5572baa02ecfbf5381e = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'components.mobiangra.nearby-lines-card','data' => []] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('mobiangra.nearby-lines-card'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal76bb3df5db76d5572baa02ecfbf5381e)): ?>
<?php $attributes = $__attributesOriginal76bb3df5db76d5572baa02ecfbf5381e; ?>
<?php unset($__attributesOriginal76bb3df5db76d5572baa02ecfbf5381e); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal76bb3df5db76d5572baa02ecfbf5381e)): ?>
<?php $component = $__componentOriginal76bb3df5db76d5572baa02ecfbf5381e; ?>
<?php unset($__componentOriginal76bb3df5db76d5572baa02ecfbf5381e); ?>
<?php endif; ?>
                </div>
            </div>

            <div class="col-12 col-lg-5 order-1 order-lg-2">
                <article class="ma-promo">
                    <div class="ma-promo__header">
                        <i class="fa-solid fa-leaf ma-promo__icon" aria-hidden="true"></i>
                        <h2 class="ma-promo__title"><?php echo e(__('Transporte público é mais qualidade de vida')); ?></h2>
                    </div>
                    <p class="ma-promo__text">
                        <?php echo e(__('Use, cuide e valorize o que é de todos. O transporte coletivo conecta pessoas, reduz o trânsito e melhora a qualidade de vida em Angra dos Reis.')); ?>

                    </p>
                    <a href="<?php echo e(route('mobiangra.informacoes')); ?>" class="btn btn-outline-success ma-promo__btn">
                        <?php echo e(__('Saiba mais')); ?>

                    </a>
                </article>
            </div>
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/mobiangra/sections/alerts-promo.blade.php ENDPATH**/ ?>