<div class="list-group mb-3">
    <a class="list-group-item list-group-item-action active" aria-current="true">
        <h5 class="mb-1"><?php echo e(__($title)); ?></h5>
        <small onclick="<?php echo e($onclick); ?>" class="text-warning" style="cursor: pointer"><?php echo e($small); ?></small>
    </a>
    <div class="list-group-item list-group-item-action">
        <div class="mb-1" id="<?php echo e($id); ?>">
            <table class="table table-striped">
                <?php $__currentLoopData = $collection; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $secretaria): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <tr>
                        <td>
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="belongsTo[]" value="<?php echo e($secretaria->id); ?>" id="<?php echo e($secretaria->id); ?>" <?php echo e(in_array($secretaria->id, $belongsTo ?? []) ? 'checked' : ''); ?> >
                                <label class="form-check-label" for="<?php echo e($secretaria->id); ?>">
                                    <?php echo e($secretaria->name); ?>

                                </label>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </table>
        </div>
    </div>
</div>

<?php /**PATH /var/www/html/portal/resources/views/components/inputs/inputCheckBoxListNoticias.blade.php ENDPATH**/ ?>