<?php $__env->startSection('title', 'Pesquisa Científica do Parque da Cidade da Prefeitura Municipal de Angra dos Reis'); ?>
<?php $__env->startSection('content'); ?>

    <div class="page-title dark-background" data-aos="fade"
        style="background-image: url(<?php echo e(asset('parquedacidade/imagens/img-fundo.jpg')); ?>);">
        <div class="container position-relative">
            <h1 class="text-white">Realização de Pesquisas Científicas no PNMA</h1>
        </div>
    </div>

    <div class="container">
        <div class="row internas mt-5">

            <div class="col-12 blog-post">

                <p class="lead">Um dos principais objetivos de todas as categorias de Unidade de Conservação (UC) é possibilitar a
                    realização de pesquisas científicas dentro de seus limites. Isso porque estes estudos geram conhecimento
                    sobre a biodiversidade, os diversos ecossistemas, a história, os saberes tradicionais e as relações
                    sociais das áreas protegidas. De acordo com a <a
                        href="http://www.planalto.gov.br/ccivil_03/LEIS/L9985.htm" target="_blank"><strong>Lei n° 9.985/2000
                            de 18 de julho de 2000</strong></a>, que institui o Sistema Nacional de Unidades de Conservação
                    da Natureza (SNUC), a execução de pesquisa científica em UCs depende de autorização prévia do órgão
                    responsável pela unidade e está sujeita às condições e restrições por ele estabelecidas.</p>

                <p class="lead">A Prefeitura Municipal de Angra dos Reis (PMAR), através do Instituto Municipal do Ambiente de Angra dos
                    Reis (IMAAR), fomenta, apoia e incentiva a pesquisa nas Unidades de Conservação sob sua administração,
                    para que este conhecimento seja revertido em benefícios à comunidade e subsídios à gestão da UC do
                    município. Para que possamos organizar a gama de pesquisas dentro de nossa Unidade de Conservação, é
                    necessário que os pesquisadores façam o pedido de licença de seus projetos e encaminhem suas publicações
                    ao IMAAR.</p>

                <p class="lead">Os interessados em desenvolver projetos de pesquisa no PNMMA/Parque da Cidade, precisam preencher o
                    <strong><a href="downloads/FormularioAutorizacaoPesquisaNoParqueNaturalMunicipalMataAtlantica.pdf"
                            target="_blank">Formulário para pedido de autorização de pesquisa <i
                                class="fas fa-download"></i></a></strong>, e encaminhá-lo ao IMAAR, nas seguintes formas:
                </p>

                <ul type="disc">
                    <li><strong>Entrega presencial</strong><br>
                        Instituto Municipal do Ambiente de Angra dos Reis - IMAAR<br>
                        Entregar no setor de protocolo em horário comercial<br>
                        Rua do Comércio, Nº 17, Centro. Angra dos Reis<br>
                        CEP: 23.900-560
                    </li>
                    <li><strong>Entrega por e-mail</strong><br>
                        imaar.supma@angra.rj.gov.br
                    </li>
                </ul>
                <p class="lead"><strong>Dúvidas:</strong> Entre em contato pelo telefone <strong>(24) 3368-4435</strong> - IMAAR</p>


            </div>
        </div>
    </div>

<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.parquedacidade.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/parque-da-cidade/pesquisa-cientifica.blade.php ENDPATH**/ ?>