<?php $__env->startSection("title", "Comitê CMGD - Governança Digital - Angra dos Reis" ); ?>
<?php $__env->startSection('content'); ?>

    <?php echo $__env->make('cmgd/header', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('cmgd/estrategia', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
    <?php echo $__env->make('cmgd/comite', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

    <section class="bg-white" id="atas">
        <div class="container">
            <div class="row">
                <div class="col-12 text-center mb-5">
                    <h2><?php echo e(__("Atas e Pareceres")); ?></h2>
                </div>
            </div>
            <?php $num = false; ?>

            <?php if($num): ?>
                <div class="row">
                    <div class="col-md-6 col-sm-6 p-3">
                        <?php echo $__env->make('cmgd/atas', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    </div>
                    <div class="col-md-6 col-sm-6 p-3">
                        <?php echo $__env->make('cmgd/pareceres', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
                    </div>
                </div>
            <?php else: ?>
                <div class="row">
                    <div class="col-12 p-3 text-center">
                        <small class="text-info">Aguardando publicação.</small>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </section>

    <?php echo $__env->make('cmgd/legislacao', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>    
    <?php echo $__env->make('cmgd/accordion', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>


<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.cmgd.theme', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH /var/www/html/portal/resources/views/cmgd/index.blade.php ENDPATH**/ ?>