<section class="bg-light" id="comite" style="padding-top: 0 !important; padding-bottom: 0 !important;">
    <div class="container">
        <div class="row">
            <div class="col-12 p-5 text-center">
                <h2><?php echo e(__("Comitê Gestor")); ?></h2>
            </div>
        </div>
        <div class="row">
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Rodolfo Orion Lebres Bontempo"),
                "cargo" => __("Presidente"),
                "sigla" => __("SPG"),
                "matricula" => __('33110'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Gilberto Bicalho Cardoso"),
                "cargo" => __("Titular"),
                "sigla" => __("SMGP"),
                "matricula" => __('26292'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Brunna Correa Pinheiro da Silva"),
                "cargo" => __("Titular"),
                "sigla" => __("PGM"),
                "matricula" => __('31587'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Rogério de Almeida Pontes"),
                "cargo" => __("Vice-Presidente"),
                "sigla" => __("SPG"),
                "matricula" => __('28934'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?> 
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Tiago Soares da Rosa"),
                "cargo" => __("Titular"),
                "sigla" => __("SMGP"),
                "matricula" => __('19823'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Eduarda Arruda"),
                "cargo" => __("Suplente"),
                "sigla" => __("PGM"),
                "matricula" => __('29509'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Tiago Soares da Rosa"),
                "cargo" => __("Titular"),
                "sigla" => __("CGM"),
                "matricula" => __('12569'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Leidiane Anacleto Pinheiro Soares"),
                "cargo" => __("Suplente"),
                "sigla" => __("SMGP"),
                "matricula" => __('32564'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Mariana de Abreu Ferreirao"),
                "cargo" => __("Titular"),
                "sigla" => __("SFI"),
                "matricula" => __('13774'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Jobson Rodrigues da Silva"),
                "cargo" => __("Suplente"),
                "sigla" => __("CGM"),
                "matricula" => __('19706'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Isaque Soares do Brasil Luiz"),
                "cargo" => __("Suplente"),
                "sigla" => __("SMGP"),
                "matricula" => __('32766'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
            <?php echo $__env->make('components.cards._cardComiteGestor', [
                "nome" => __("Claúdia Porto de Arroxellas Bragança"),
                "cargo" => __("Suplente"),
                "sigla" => __("SFI"),
                "matricula" => __('22299'),
            ], array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </div>
</section>
<?php /**PATH /var/www/html/portal/resources/views/cmgd/comite.blade.php ENDPATH**/ ?>