@php
    $ppNomeFieldId = $ppFormFieldId ?? 'nome';
@endphp
<div class="mb-3">
    <label for="{{ $ppNomeFieldId }}" class="form-label">{{ __('Nome') }}</label>
    <input type="text"
           name="nome"
           id="{{ $ppNomeFieldId }}"
           class="form-control"
           value="{{ old('nome', $objetivo->nome ?? '') }}"
           required>
</div>

<div class="d-flex justify-content-end mt-3">
    <button type="submit" class="btn btn-primary">
        <i class="fa-solid fa-save me-1"></i> {{ __('Salvar') }}
    </button>
</div>

