@php
    $decretoLei = $decretoLei ?? null;
@endphp

<div class="row g-4">

    {{-- INFORMAÇÕES PRINCIPAIS --}}
    <div class="col-12">
        <h5 class="border-bottom pb-2 mb-3 text-primary">
            <i class="fa-solid fa-file-lines me-2"></i> {{ __('Informações do Decreto/Lei') }}
        </h5>
    </div>

    <div class="col-md-8">
        @include('components.inputs._inputType', [
            'label' => __('Título'),
            'name' => 'titulo',
            'required' => true,
            'old' => $decretoLei?->titulo,
        ])
    </div>

    <div class="col-md-4">
        @include('components.inputs._inputType', [
            'label' => __('Número da lei'),
            'name' => 'numero_lei',
            'old' => $decretoLei?->numero_lei,
        ])
    </div>

    <div class="col-12">
        @include('components.inputs._textarea', [
            'label' => __('Descrição'),
            'name' => 'descricao',
            'value' => $decretoLei?->descricao ?? '',
            'rows' => 4,
        ])
    </div>

    <div class="col-md-4">
        @include('components.inputs._inputType', [
            'label' => __('Data de publicação'),
            'name' => 'data_publicacao',
            'type' => 'date',
            'old' => $decretoLei?->data_publicacao?->format('Y-m-d'),
        ])
    </div>

    <div class="col-md-4">
        <label class="form-label text-bold">{{ __('Status') }} <span class="text-danger">*</span></label>
        <select class="form-select @error('status') is-invalid @enderror" name="status">
            @foreach(\App\Enums\StatusEnum::cases() as $status)
                <option value="{{ $status->name }}"
                    {{ old('status', $decretoLei?->status ?? 'ATIVADO') === $status->name ? 'selected' : '' }}>
                    {{ $status->value }}
                </option>
            @endforeach
        </select>
        @error('status')
            <small class="text-danger">{{ $message }}</small>
        @enderror
    </div>

    <div class="col-md-4">
        @include('components.inputs._inputType', [
            'label' => __('Ordem de exibição'),
            'name' => 'ordem',
            'type' => 'number',
            'old' => (string) ($decretoLei?->ordem ?? 0),
        ])
    </div>

    {{-- ARQUIVO --}}
    <div class="col-12 mt-4">
        <h5 class="border-bottom pb-2 mb-3 text-primary">
            <i class="fa-solid fa-upload me-2"></i> {{ __('Arquivo') }}
        </h5>
    </div>

    <div class="col-12">
        <div class="border rounded p-4 bg-light position-relative">

            <label for="arquivo" class="form-label fw-bold">
                {{ __('Arquivo (PDF ou documento)') }}
            </label>

            <input 
                type="file" 
                class="form-control @error('arquivo') is-invalid @enderror" 
                name="arquivo" 
                id="arquivo"
                accept=".pdf,.doc,.docx,.xls,.xlsx,.odt,.ods"
            />

            <small class="text-muted d-block mt-2">
                {{ __('Formatos aceitos: PDF, Word, Excel, OpenDocument') }}
            </small>

            @if($decretoLei?->arquivo)
                <div class="mt-2">
                    <span class="badge bg-secondary">
                        <i class="fa-solid fa-file me-1"></i>
                        {{ basename($decretoLei->arquivo) }}
                    </span>
                </div>
            @endif

            @error('arquivo')
                <small class="text-danger d-block mt-2">{{ $message }}</small>
            @enderror

        </div>
    </div>

</div>