@if (isset($permission) && auth()->user()->getPermissaoDetalhes($permission)['editar'])
    <button type="button" class="btn btn-primary"
            onclick="enableEdit('{{ str_replace('-', '_', $id) }}')">
        @if(isset($fontawesome) && $fontawesome != null)
            <i class="{{ $fontawesome }}"></i> {{ $text }}
        @else
            <i class="fa-solid fa-pen-to-square"></i> {{ $text }}
        @endif
    </button>
@endif