<script src="{{ asset('pmar/js/jquery-3.7.1.min.js') }}"></script>
<script src="{{ asset('pmar/bootstrap/js/bootstrap.min.js') }}"/></script>
<script src="{{ asset('pmar/fontawesome/js/all.min.js') }}"/></script>
<script src="{{ asset('sei/js/app.js') }}"></script>
<script src="{{ asset('sei/js/functions.js') }}"></script>