@extends('layouts.admin.theme')
@section('title', env('APP_NAME') . ' :: ' . __('Carta de Serviços'))

@section('content')
    @include('errors.messageFlash')

    <div class="card shadow-sm">
        @php $headLine = "<i class='fa-solid fa-file-lines'></i> " . __('Carta de Serviços'); @endphp
        @include('components.buttons._headLineButtonsBackAdd', [
            'headLine' => __($headLine),
            'routeBack' => 'admin.dashboard',
            'routeBackParams' => [],
            'nameBack' => __('Voltar'),
            'routeAdd' => 'admin.cartaServicos.create',
            'nameAdd' => __('Novo serviço'),
            'permission' => 'GERENCIADOR_DA_CARTA_DE_SERVICOS',
        ])

        <div class="card-body">
            <div class="row g-4">
                <div class="col-12">
                    <div class="d-flex justify-content-between align-items-center mb-3">
                        <h5 class="mb-0">{{ __('Serviços cadastrados') }}</h5>
                        <a href="{{ route('admin.cartaServicos.tipos.create') }}" class="btn btn-success btn-sm">
                            <i class="fa-solid fa-plus"></i> {{ __('Nova categoria') }}
                        </a>
                    </div>
                    <form method="get" class="row g-2 mb-3">
                        <div class="col-md-6">
                            <input type="text" name="q" value="{{ request('q') }}" class="form-control" placeholder="{{ __('Buscar por título ou descrição') }}">
                        </div>
                        <div class="col-md-4">
                            <select class="form-select" name="tipo_id">
                                <option value="">{{ __('Todas as categorias') }}</option>
                                @foreach($tipos as $tipo)
                                    <option value="{{ $tipo->id_tipo }}" @selected((int) request('tipo_id') === (int) $tipo->id_tipo)>{{ $tipo->tip_descricao }}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="col-md-2 d-grid">
                            <button class="btn btn-outline-success" type="submit">{{ __('Filtrar') }}</button>
                        </div>
                    </form>

                    <x-tables._table :thead="['#', __('Título'), __('Status'), __('Ações')]" :pagination="$servicos->links()">
                        <x-slot name="body">
                            @php $index = $servicos->firstItem(); @endphp
                            @forelse($servicos as $servico)
                                <tr>
                                    <td>{{ $index }}</td>
                                    <td class="text-start">{{ $servico->cds_titulo }}</td>
                                    <td>
                                        {{ $servico->cds_status === '3' ? __('Publicado') : __('Rascunho') }}
                                    </td>
                                    <td>
                                        <div class="d-flex justify-content-center gap-2">
                                            <a href="{{ route('admin.cartaServicos.edit', [$servico->id_cds] + request()->only(['q', 'tipo_id', 'page'])) }}" class="btn btn-sm btn-warning">
                                                <i class="fa-solid fa-pen-to-square"></i>
                                            </a>
                                            <form method="post" action="{{ route('admin.cartaServicos.destroy', $servico->id_cds) }}" onsubmit="return confirmDelete(this)">
                                                @csrf
                                                @method('delete')
                                                @foreach(request()->only(['q', 'tipo_id', 'page']) as $key => $value)
                                                    <input type="hidden" name="{{ $key }}" value="{{ $value }}">
                                                @endforeach
                                                <input type="hidden" name="confirm" value="{{ __('* Este serviço será excluído e esta ação não poderá ser desfeita, deseja continuar?') }}">
                                                <button type="submit" class="btn btn-sm btn-danger">
                                                    <i class="fa-solid fa-trash"></i>
                                                </button>
                                            </form>
                                        </div>
                                    </td>
                                </tr>
                                @php $index++; @endphp
                            @empty
                                <tr>
                                    <td colspan="4" class="text-center">{{ __('Nenhum serviço cadastrado.') }}</td>
                                </tr>
                            @endforelse
                        </x-slot>
                    </x-tables._table>
                </div>
            </div>
        </div>
    </div>
@endsection
