@extends('layouts.admin.theme')
@section('title', env('APP_NAME').' :: '.__('Criar Xpto'))
@section('content')
<div class="card shadow-sm">
@php $headLine = __('Criar Xpto'); @endphp
@include('components.buttons._headLineButtonsBackAdd', ['headLine' => $headLine, 'routeBack' => 'admin.meuTest.index', 'nameBack' => __('Voltar'), 'permission' => 'ADMIN'])
<div class="card-body">
@include('errors.messageFlash')
<form action="{{ route('admin.meuTest.store') }}" method="POST">@csrf
@include('components.inputs._inputType', ['label'=>'Nome','name'=>'nome','required'=>true])
<button class="btn btn-success" type="submit">{{ __('Salvar') }}</button>
</form>
</div>
</div>
@endsection
