@props([
    'alertas' => collect(),
    'emptyMessage' => __('Nenhum alerta publicado no momento.'),
    'compact' => false,
])

@if ($alertas->isNotEmpty())
    <ul class="ma-alerts__list">
        @foreach ($alertas as $alerta)
            <li class="ma-alerts__item">
                <span @class(['ma-alerts__tag', $alerta->categoria->tagClass()])>
                    {{ $alerta->categoria->label() }}
                </span>
                <h3 class="ma-alerts__item-title" title="{{ $alerta->titulo }}">
                    {{ $compact ? $alerta->titulo_resumido : $alerta->titulo }}
                </h3>
                @if ($alerta->mensagem_exibicao)
                    <p class="ma-alerts__item-text">
                        {{ $compact ? $alerta->mensagem_resumida_exibicao : $alerta->mensagem_exibicao }}
                    </p>
                @endif
                <time class="ma-alerts__date" datetime="{{ $alerta->publicado_em?->toIso8601String() }}">
                    {{ $alerta->data_formatada }}
                </time>
            </li>
        @endforeach
    </ul>
@else
    <p class="ma-alerts__empty text-muted mb-0">{{ $emptyMessage }}</p>
@endif
