<div class="row">
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Telefone da empresa') . ' *',
            'name' => 'telefone',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('telefone', $empresa?->telefone),
            'oninput' => "javascript:aplicarMascaraTelefone(this)",
            'readonly' => false,
            'small' => null,
        ])
    </div>
    <div class="col-sm-12 col-md-4">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Celular da empresa') . ' *',
            'name' => 'celular',
            'id' => null,
            'required' => true,
            'type' => null,
            'old' => old('celular', $empresa?->celular),
            'oninput' => "javascript:aplicarMascaraTelefone(this)",
            'readonly' => false,
            'small' => null,
        ])

        @php
            $possuiWhatsapp = (string) old('possui_whatsapp', $empresa?->possui_whatsapp ? '1' : '0');
        @endphp
        <div class="mt-1 mb-0">
            <div class="d-flex flex-wrap align-items-center gap-2" role="radiogroup" aria-label="{{ __('Tem WhatsApp?') }}">
                <span class="small text-secondary mb-0">
                    {{ __('Tem WhatsApp?') }} <span class="span-admin-create">*</span>
                </span>
                <div class="form-check form-check-inline mb-0">
                    <input class="form-check-input @error('possui_whatsapp') is-invalid @enderror"
                           type="radio"
                           name="possui_whatsapp"
                           id="possui_whatsapp_sim"
                           value="1"
                           @checked($possuiWhatsapp === '1')
                           required>
                    <label class="form-check-label small" for="possui_whatsapp_sim">{{ __('Sim') }}</label>
                </div>
                <div class="form-check form-check-inline mb-0">
                    <input class="form-check-input @error('possui_whatsapp') is-invalid @enderror"
                           type="radio"
                           name="possui_whatsapp"
                           id="possui_whatsapp_nao"
                           value="0"
                           @checked($possuiWhatsapp === '0')>
                    <label class="form-check-label small" for="possui_whatsapp_nao">{{ __('Não') }}</label>
                </div>
            </div>
            @error('possui_whatsapp')
                <small class="text-danger text-bold d-block">{{ $message }}</small>
            @enderror
        </div>
    </div>
    <div class="col-sm-12 col-md-3">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Email da empresa') . ' *',
            'name' => 'email',
            'id' => null,
            'required' => true,
            'type' => 'email',
            'old' => old('email', $empresa?->email),
            'oninput' => "javascript:this.value = this.value.toLowerCase()",
            'readonly' => false,
            'small' => null,
            'placeholder' => 'nome@email.com',
        ])
    </div>
    <div class="col-sm-12 col-md-2">
        @include('components.inputs._inputType',[
            'for' => null,
            'label' => __('Site da empresa'),
            'name' => 'site',
            'id' => null,
            'required' => false,
            'type' => 'url',
            'old' => old('site', $empresa?->site),
            'oninput' => "javascript:this.value = this.value.toLowerCase()",
            'readonly' => false,
            'small' => null,
            'placeholder' => 'https://seusite.com',
        ])
    </div>
</div>

<div class="mb-3 text-wrap">
    @include('components.inputs._textarea', [
        'label' => __('Principal atividade'),
        'name' => 'principalAtividade',
        'id' => null,
        'rows' => 0,
        'required' => false,
        'height' => '100px',
        'class' => null,
        'style' => null,
        'value' => old('principalAtividade', $empresa?->principalAtividade),
    ])
</div>
