<thead class="table-light">
    <tr>
        @foreach($thead as $index => $th)
            <th @if(!empty($theadWidths[$index])) style="width: {{ $theadWidths[$index] }}" @endif>{{ $th }}</th>
        @endforeach
    </tr>
</thead>